body.mce-content-body {
    margin: revert;
    text-align: initial;
}

/** Web Accessibility - color contrast. */
body.mce-content-body a[data-mce-selected="inline-boundary"] {
    background-color: unset;
}
body.mce-content-body a {
    color: #0f6cbf;
}

/** blockquote */
.mce-content-body blockquote {
    margin: 0 0.5rem 1rem;
    padding-left: 1rem;
    color: #495057;
    border-left: 5px solid #8f959e;
}

.mce-content-body svg[contentEditable=false] {
    cursor: not-allowed;
}

.mce-content-body p > math,
.mce-content-body p > svg {
    display: inline-block;
    outline: 3px solid #b4d7ff;
}

.mce-content-body .h5p-placeholder + br {
    display: none;
}
.mce-content-body .h5p-placeholder {
    color: #6c757d;
    width: 100%;
    word-break: break-all;
    height: 260px;
    cursor: pointer;
    background: url(/theme/image.php/moove/tiny_h5p/1756787986/icon-white) center center / 100px auto no-repeat #6c757d;
}

