<?php

class __Mustache_7c693c343b6060fdc7a96ed778f32b42 extends Mustache_Template
{
    public function renderInternal(Mustache_Context $context, $indent = '')
    {
        $buffer = '';

        $buffer .= $indent . '<li class="list-group-item course-listitem border-start-0 border-end-0 border-top-0 px-2 rounded-0">
';
        $buffer .= $indent . '    <div class="row">
';
        $buffer .= $indent . '        <div class="col-md-2 d-flex align-items-center">
';
        $buffer .= $indent . '            <div class="bg-pulse-grey card-img w-100" style="height: 1rem; width: 1rem;"></div>
';
        $buffer .= $indent . '        </div>
';
        $buffer .= $indent . '        <div class="col-md-10 d-flex flex-column">
';
        $buffer .= $indent . '            <div class="bg-pulse-grey w-50" style="height: 1rem; margin: 0.5rem 0"></div>
';
        $buffer .= $indent . '        </div>
';
        $buffer .= $indent . '    </div>
';
        $buffer .= $indent . '</li>
';

        return $buffer;
    }
}
