<?php

class __Mustache_b5534ed92d6c3aa047d726331a120c8e extends Mustache_Template
{
    public function renderInternal(Mustache_Context $context, $indent = '')
    {
        $buffer = '';

        $buffer .= $indent . '<span class="visually-hidden-focusable" data-region="jumpto" tabindex="-1"></span>
';

        return $buffer;
    }
}
