<?php
// ********** This file is generated DO NOT EDIT **********
$CFG->siteidentifier = 'k2zjxSH9bKmTSjs5OONZ6KpQmd6nT2i3eudoviges.mayaeducacion.com';
$CFG->bootstraphash = 'cb209b51bf8634ca92b17e7887d8fb20';
// Only if the file is not stale and has not been defined.
if ($CFG->bootstraphash === hash_local_config_cache() && !defined('SYSCONTEXTID')) {
    define('SYSCONTEXTID', 1);
}
