<?php

class __Mustache_07afc4250a6bcf34c7fc6f4c0c3ec922 extends Mustache_Template
{
    public function renderInternal(Mustache_Context $context, $indent = '')
    {
        $buffer = '';

        $buffer .= $indent . '<div class="card border-0 px-1">
';
        $buffer .= $indent . '    <div class="card-img-top bg-pulse-grey w-100" style="height: 7rem">
';
        $buffer .= $indent . '    </div>
';
        $buffer .= $indent . '    <div class="card-body pe-1 course-info-container">
';
        $buffer .= $indent . '        <div class="bg-pulse-grey w-100" style="height: 1rem"></div>
';
        $buffer .= $indent . '    </div>
';
        $buffer .= $indent . '</div>
';

        return $buffer;
    }
}
