<?php

class __Mustache_f38c7a94448028ffed62d7eef3ab38ec extends Mustache_Template
{
    public function renderInternal(Mustache_Context $context, $indent = '')
    {
        $buffer = '';

        $buffer .= $indent . '<div class="p-2 d-flex list-group-item border-0" data-region="placeholder">
';
        $buffer .= $indent . '    <div
';
        $buffer .= $indent . '        class="rounded-circle bg-pulse-grey"
';
        $buffer .= $indent . '        style="height: 38px; width: 38px"
';
        $buffer .= $indent . '    >
';
        $buffer .= $indent . '    </div>
';
        $buffer .= $indent . '    <div
';
        $buffer .= $indent . '        class="ms-2 bg-pulse-grey w-50"
';
        $buffer .= $indent . '        style="height: 20px;"
';
        $buffer .= $indent . '    >
';
        $buffer .= $indent . '    </div>
';
        $buffer .= $indent . '</div>';

        return $buffer;
    }
}
