<?php

class __Mustache_6b52ec5321c0df1f4fe9453672eef1a2 extends Mustache_Template
{
    private $lambdaHelper;

    public function renderInternal(Mustache_Context $context, $indent = '')
    {
        $this->lambdaHelper = new Mustache_LambdaHelper($this->mustache, $context);
        $buffer = '';

        $buffer .= $indent . '<tr class="preference-row" data-region="preference-row" data-preference-key="';
        $value = $this->resolveValue($context->find('preferencekey'), $context);
        $buffer .= ($value === null ? '' : $value);
        $buffer .= '">
';
        $buffer .= $indent . '    <td class="preference-name">';
        $value = $this->resolveValue($context->find('displayname'), $context);
        $buffer .= ($value === null ? '' : $value);
        $buffer .= '</td>
';
        $value = $context->find('processors');
        $buffer .= $this->sectionD3a1637d5c16e1040d8509e3a4e6cd72($context, $indent, $value);
        $buffer .= $indent . '</tr>
';

        return $buffer;
    }

    private function section6a1518e04e90a0c8fb32c8ce8150cb39(Mustache_Context $context, $indent, $value)
    {
        $buffer = '';
    
        if (!is_string($value) && is_callable($value)) {
            $source = '
                    <div class="dimmed_text" title="{{lockedlabel}}">{{{lockedmessage}}}</div>
                ';
            $result = (string) call_user_func($value, $source, $this->lambdaHelper);
            $buffer .= $result;
        } elseif (!empty($value)) {
            $values = $this->isIterable($value) ? $value : array($value);
            foreach ($values as $value) {
                $context->push($value);
                
                $buffer .= $indent . '                    <div class="dimmed_text" title="';
                $value = $this->resolveValue($context->find('lockedlabel'), $context);
                $buffer .= ($value === null ? '' : call_user_func($this->mustache->getEscape(), $value));
                $buffer .= '">';
                $value = $this->resolveValue($context->find('lockedmessage'), $context);
                $buffer .= ($value === null ? '' : $value);
                $buffer .= '</div>
';
                $context->pop();
            }
        }
    
        return $buffer;
    }

    private function section05828eb925ccd1e324128320ddd16fea(Mustache_Context $context, $indent, $value)
    {
        $buffer = '';
    
        if (!is_string($value) && is_callable($value)) {
            $source = ' disabled';
            $result = (string) call_user_func($value, $source, $this->lambdaHelper);
            $buffer .= $result;
        } elseif (!empty($value)) {
            $values = $this->isIterable($value) ? $value : array($value);
            foreach ($values as $value) {
                $context->push($value);
                
                $buffer .= ' disabled';
                $context->pop();
            }
        }
    
        return $buffer;
    }

    private function section7f9a54cf7dec731721abbf0255e3e5bb(Mustache_Context $context, $indent, $value)
    {
        $buffer = '';
    
        if (!is_string($value) && is_callable($value)) {
            $source = ' disabled="true" ';
            $result = (string) call_user_func($value, $source, $this->lambdaHelper);
            $buffer .= $result;
        } elseif (!empty($value)) {
            $values = $this->isIterable($value) ? $value : array($value);
            foreach ($values as $value) {
                $context->push($value);
                
                $buffer .= ' disabled="true" ';
                $context->pop();
            }
        }
    
        return $buffer;
    }

    private function section51d7c9c652ced0161cb587bacd669266(Mustache_Context $context, $indent, $value)
    {
        $buffer = '';
    
        if (!is_string($value) && is_callable($value)) {
            $source = 'checked';
            $result = (string) call_user_func($value, $source, $this->lambdaHelper);
            $buffer .= $result;
        } elseif (!empty($value)) {
            $values = $this->isIterable($value) ? $value : array($value);
            foreach ($values as $value) {
                $context->push($value);
                
                $buffer .= 'checked';
                $context->pop();
            }
        }
    
        return $buffer;
    }

    private function sectionC7e0fc2a8a1eb47776c74396c4de6fb4(Mustache_Context $context, $indent, $value)
    {
        $buffer = '';
    
        if (!is_string($value) && is_callable($value)) {
            $source = '
                {{#locked}}
                    <div class="dimmed_text" title="{{lockedlabel}}">{{{lockedmessage}}}</div>
                {{/locked}}
                {{^locked}}
                    <form>
                        <div class="preference-state" data-preference="{{{preferencekey}}}_{{{name}}}">
                            <div class="form-check form-switch">
                                <input type="checkbox"
                                       id="{{{preferencekey}}}_{{{name}}}"
                                       name="{{{preferencekey}}}_{{{name}}}"
                                       class="form-check-input notification_enabled{{#disableall}} disabled{{/disableall}}"
                                    {{#disableall}} disabled="true" {{/disableall}}
                                    {{#enabled}}checked{{/enabled}}
                                >
                                <label for="{{{preferencekey}}}_{{{name}}}" class="form-check-label"
                                       title="{{enabledlabel}}" >
                                </label>
                            </div>
                        </div>
                    </form>
                {{/locked}}
            ';
            $result = (string) call_user_func($value, $source, $this->lambdaHelper);
            $buffer .= $result;
        } elseif (!empty($value)) {
            $values = $this->isIterable($value) ? $value : array($value);
            foreach ($values as $value) {
                $context->push($value);
                
                $value = $context->find('locked');
                $buffer .= $this->section6a1518e04e90a0c8fb32c8ce8150cb39($context, $indent, $value);
                $value = $context->find('locked');
                if (empty($value)) {
                    
                    $buffer .= $indent . '                    <form>
';
                    $buffer .= $indent . '                        <div class="preference-state" data-preference="';
                    $value = $this->resolveValue($context->find('preferencekey'), $context);
                    $buffer .= ($value === null ? '' : $value);
                    $buffer .= '_';
                    $value = $this->resolveValue($context->find('name'), $context);
                    $buffer .= ($value === null ? '' : $value);
                    $buffer .= '">
';
                    $buffer .= $indent . '                            <div class="form-check form-switch">
';
                    $buffer .= $indent . '                                <input type="checkbox"
';
                    $buffer .= $indent . '                                       id="';
                    $value = $this->resolveValue($context->find('preferencekey'), $context);
                    $buffer .= ($value === null ? '' : $value);
                    $buffer .= '_';
                    $value = $this->resolveValue($context->find('name'), $context);
                    $buffer .= ($value === null ? '' : $value);
                    $buffer .= '"
';
                    $buffer .= $indent . '                                       name="';
                    $value = $this->resolveValue($context->find('preferencekey'), $context);
                    $buffer .= ($value === null ? '' : $value);
                    $buffer .= '_';
                    $value = $this->resolveValue($context->find('name'), $context);
                    $buffer .= ($value === null ? '' : $value);
                    $buffer .= '"
';
                    $buffer .= $indent . '                                       class="form-check-input notification_enabled';
                    $value = $context->find('disableall');
                    $buffer .= $this->section05828eb925ccd1e324128320ddd16fea($context, $indent, $value);
                    $buffer .= '"
';
                    $buffer .= $indent . '                                    ';
                    $value = $context->find('disableall');
                    $buffer .= $this->section7f9a54cf7dec731721abbf0255e3e5bb($context, $indent, $value);
                    $buffer .= '
';
                    $buffer .= $indent . '                                    ';
                    $value = $context->find('enabled');
                    $buffer .= $this->section51d7c9c652ced0161cb587bacd669266($context, $indent, $value);
                    $buffer .= '
';
                    $buffer .= $indent . '                                >
';
                    $buffer .= $indent . '                                <label for="';
                    $value = $this->resolveValue($context->find('preferencekey'), $context);
                    $buffer .= ($value === null ? '' : $value);
                    $buffer .= '_';
                    $value = $this->resolveValue($context->find('name'), $context);
                    $buffer .= ($value === null ? '' : $value);
                    $buffer .= '" class="form-check-label"
';
                    $buffer .= $indent . '                                       title="';
                    $value = $this->resolveValue($context->find('enabledlabel'), $context);
                    $buffer .= ($value === null ? '' : call_user_func($this->mustache->getEscape(), $value));
                    $buffer .= '" >
';
                    $buffer .= $indent . '                                </label>
';
                    $buffer .= $indent . '                            </div>
';
                    $buffer .= $indent . '                        </div>
';
                    $buffer .= $indent . '                    </form>
';
                }
                $context->pop();
            }
        }
    
        return $buffer;
    }

    private function sectionDff69a45e631983037ea43a58749e8dd(Mustache_Context $context, $indent, $value)
    {
        $buffer = '';
    
        if (!is_string($value) && is_callable($value)) {
            $source = ' notsupported, core_message ';
            $result = (string) call_user_func($value, $source, $this->lambdaHelper);
            $buffer .= $result;
        } elseif (!empty($value)) {
            $values = $this->isIterable($value) ? $value : array($value);
            foreach ($values as $value) {
                $context->push($value);
                
                $buffer .= ' notsupported, core_message ';
                $context->pop();
            }
        }
    
        return $buffer;
    }

    private function sectionD3a1637d5c16e1040d8509e3a4e6cd72(Mustache_Context $context, $indent, $value)
    {
        $buffer = '';
    
        if (!is_string($value) && is_callable($value)) {
            $source = '
        <td {{^userconfigured}}class="disabled"{{/userconfigured}} data-processor-name="{{name}}">
            {{#supportsprocessor}}
                {{#locked}}
                    <div class="dimmed_text" title="{{lockedlabel}}">{{{lockedmessage}}}</div>
                {{/locked}}
                {{^locked}}
                    <form>
                        <div class="preference-state" data-preference="{{{preferencekey}}}_{{{name}}}">
                            <div class="form-check form-switch">
                                <input type="checkbox"
                                       id="{{{preferencekey}}}_{{{name}}}"
                                       name="{{{preferencekey}}}_{{{name}}}"
                                       class="form-check-input notification_enabled{{#disableall}} disabled{{/disableall}}"
                                    {{#disableall}} disabled="true" {{/disableall}}
                                    {{#enabled}}checked{{/enabled}}
                                >
                                <label for="{{{preferencekey}}}_{{{name}}}" class="form-check-label"
                                       title="{{enabledlabel}}" >
                                </label>
                            </div>
                        </div>
                    </form>
                {{/locked}}
            {{/supportsprocessor}}
            {{^supportsprocessor}}
                <div class="text-center">
                    {{#str}} notsupported, core_message {{/str}}
                </div>
            {{/supportsprocessor}}
        </td>
    ';
            $result = (string) call_user_func($value, $source, $this->lambdaHelper);
            $buffer .= $result;
        } elseif (!empty($value)) {
            $values = $this->isIterable($value) ? $value : array($value);
            foreach ($values as $value) {
                $context->push($value);
                
                $buffer .= $indent . '        <td ';
                $value = $context->find('userconfigured');
                if (empty($value)) {
                    
                    $buffer .= 'class="disabled"';
                }
                $buffer .= ' data-processor-name="';
                $value = $this->resolveValue($context->find('name'), $context);
                $buffer .= ($value === null ? '' : call_user_func($this->mustache->getEscape(), $value));
                $buffer .= '">
';
                $value = $context->find('supportsprocessor');
                $buffer .= $this->sectionC7e0fc2a8a1eb47776c74396c4de6fb4($context, $indent, $value);
                $value = $context->find('supportsprocessor');
                if (empty($value)) {
                    
                    $buffer .= $indent . '                <div class="text-center">
';
                    $buffer .= $indent . '                    ';
                    $value = $context->find('str');
                    $buffer .= $this->sectionDff69a45e631983037ea43a58749e8dd($context, $indent, $value);
                    $buffer .= '
';
                    $buffer .= $indent . '                </div>
';
                }
                $buffer .= $indent . '        </td>
';
                $context->pop();
            }
        }
    
        return $buffer;
    }

}
