<?php
$cache = array (
  'subsystems' => 
  array (
    'ai' => '/var/www/html/plantilla/ai',
    'access' => NULL,
    'admin' => '/var/www/html/plantilla/admin',
    'adminpresets' => '/var/www/html/plantilla/admin/presets',
    'analytics' => '/var/www/html/plantilla/analytics',
    'antivirus' => '/var/www/html/plantilla/lib/antivirus',
    'auth' => '/var/www/html/plantilla/auth',
    'availability' => '/var/www/html/plantilla/availability',
    'backup' => '/var/www/html/plantilla/backup/util/ui',
    'badges' => '/var/www/html/plantilla/badges',
    'block' => '/var/www/html/plantilla/blocks',
    'blog' => '/var/www/html/plantilla/blog',
    'bulkusers' => NULL,
    'cache' => '/var/www/html/plantilla/cache',
    'calendar' => '/var/www/html/plantilla/calendar',
    'cohort' => '/var/www/html/plantilla/cohort',
    'comment' => '/var/www/html/plantilla/comment',
    'communication' => '/var/www/html/plantilla/communication',
    'competency' => '/var/www/html/plantilla/competency',
    'completion' => '/var/www/html/plantilla/completion',
    'contentbank' => '/var/www/html/plantilla/contentbank',
    'countries' => NULL,
    'course' => '/var/www/html/plantilla/course',
    'courseformat' => '/var/www/html/plantilla/course/format',
    'currencies' => NULL,
    'customfield' => '/var/www/html/plantilla/customfield',
    'dbtransfer' => NULL,
    'debug' => NULL,
    'editor' => '/var/www/html/plantilla/lib/editor',
    'edufields' => NULL,
    'enrol' => '/var/www/html/plantilla/enrol',
    'error' => NULL,
    'external' => '/var/www/html/plantilla/lib/external',
    'favourites' => '/var/www/html/plantilla/favourites',
    'filepicker' => NULL,
    'fileconverter' => '/var/www/html/plantilla/files/converter',
    'files' => '/var/www/html/plantilla/files',
    'filters' => '/var/www/html/plantilla/filter',
    'form' => '/var/www/html/plantilla/lib/form',
    'grades' => '/var/www/html/plantilla/grade',
    'grading' => '/var/www/html/plantilla/grade/grading',
    'group' => '/var/www/html/plantilla/group',
    'help' => NULL,
    'hub' => NULL,
    'h5p' => '/var/www/html/plantilla/h5p',
    'imscc' => NULL,
    'install' => NULL,
    'iso6392' => NULL,
    'langconfig' => NULL,
    'license' => NULL,
    'mathslib' => NULL,
    'media' => '/var/www/html/plantilla/media',
    'message' => '/var/www/html/plantilla/message',
    'mimetypes' => NULL,
    'mnet' => '/var/www/html/plantilla/mnet',
    'my' => '/var/www/html/plantilla/my',
    'notes' => '/var/www/html/plantilla/notes',
    'pagetype' => NULL,
    'payment' => '/var/www/html/plantilla/payment',
    'pix' => NULL,
    'plagiarism' => '/var/www/html/plantilla/plagiarism',
    'plugin' => NULL,
    'portfolio' => '/var/www/html/plantilla/portfolio',
    'privacy' => '/var/www/html/plantilla/privacy',
    'question' => '/var/www/html/plantilla/question',
    'rating' => '/var/www/html/plantilla/rating',
    'report' => '/var/www/html/plantilla/report',
    'reportbuilder' => '/var/www/html/plantilla/reportbuilder',
    'repository' => '/var/www/html/plantilla/repository',
    'rss' => '/var/www/html/plantilla/rss',
    'role' => '/var/www/html/plantilla/admin/roles',
    'search' => '/var/www/html/plantilla/search',
    'sms' => '/var/www/html/plantilla/sms',
    'table' => '/var/www/html/plantilla/lib/table',
    'tag' => '/var/www/html/plantilla/tag',
    'timezones' => NULL,
    'user' => '/var/www/html/plantilla/user',
    'userkey' => '/var/www/html/plantilla/lib/userkey',
    'webservice' => '/var/www/html/plantilla/webservice',
    'xapi' => '/var/www/html/plantilla/lib/xapi',
  ),
  'plugintypes' => 
  array (
    'aiplacement' => '/var/www/html/plantilla/ai/placement',
    'aiprovider' => '/var/www/html/plantilla/ai/provider',
    'antivirus' => '/var/www/html/plantilla/lib/antivirus',
    'availability' => '/var/www/html/plantilla/availability/condition',
    'qtype' => '/var/www/html/plantilla/question/type',
    'mod' => '/var/www/html/plantilla/mod',
    'auth' => '/var/www/html/plantilla/auth',
    'calendartype' => '/var/www/html/plantilla/calendar/type',
    'communication' => '/var/www/html/plantilla/communication/provider',
    'customfield' => '/var/www/html/plantilla/customfield/field',
    'enrol' => '/var/www/html/plantilla/enrol',
    'message' => '/var/www/html/plantilla/message/output',
    'block' => '/var/www/html/plantilla/blocks',
    'media' => '/var/www/html/plantilla/media/player',
    'filter' => '/var/www/html/plantilla/filter',
    'editor' => '/var/www/html/plantilla/lib/editor',
    'format' => '/var/www/html/plantilla/course/format',
    'dataformat' => '/var/www/html/plantilla/dataformat',
    'profilefield' => '/var/www/html/plantilla/user/profile/field',
    'report' => '/var/www/html/plantilla/report',
    'coursereport' => '/var/www/html/plantilla/course/report',
    'gradeexport' => '/var/www/html/plantilla/grade/export',
    'gradeimport' => '/var/www/html/plantilla/grade/import',
    'gradepenalty' => '/var/www/html/plantilla/grade/penalty',
    'gradereport' => '/var/www/html/plantilla/grade/report',
    'gradingform' => '/var/www/html/plantilla/grade/grading/form',
    'mlbackend' => '/var/www/html/plantilla/lib/mlbackend',
    'webservice' => '/var/www/html/plantilla/webservice',
    'repository' => '/var/www/html/plantilla/repository',
    'portfolio' => '/var/www/html/plantilla/portfolio',
    'search' => '/var/www/html/plantilla/search/engine',
    'qbank' => '/var/www/html/plantilla/question/bank',
    'qbehaviour' => '/var/www/html/plantilla/question/behaviour',
    'qformat' => '/var/www/html/plantilla/question/format',
    'plagiarism' => '/var/www/html/plantilla/plagiarism',
    'tool' => '/var/www/html/plantilla/admin/tool',
    'cachestore' => '/var/www/html/plantilla/cache/stores',
    'cachelock' => '/var/www/html/plantilla/cache/locks',
    'fileconverter' => '/var/www/html/plantilla/files/converter',
    'contenttype' => '/var/www/html/plantilla/contentbank/contenttype',
    'theme' => '/var/www/html/plantilla/theme',
    'local' => '/var/www/html/plantilla/local',
    'h5plib' => '/var/www/html/plantilla/h5p/h5plib',
    'paygw' => '/var/www/html/plantilla/payment/gateway',
    'smsgateway' => '/var/www/html/plantilla/sms/gateway',
    'assignsubmission' => '/var/www/html/plantilla/mod/assign/submission',
    'assignfeedback' => '/var/www/html/plantilla/mod/assign/feedback',
    'bbbext' => '/var/www/html/plantilla/mod/bigbluebuttonbn/extension',
    'booktool' => '/var/www/html/plantilla/mod/book/tool',
    'datafield' => '/var/www/html/plantilla/mod/data/field',
    'datapreset' => '/var/www/html/plantilla/mod/data/preset',
    'forumreport' => '/var/www/html/plantilla/mod/forum/report',
    'ltisource' => '/var/www/html/plantilla/mod/lti/source',
    'ltiservice' => '/var/www/html/plantilla/mod/lti/service',
    'quiz' => '/var/www/html/plantilla/mod/quiz/report',
    'quizaccess' => '/var/www/html/plantilla/mod/quiz/accessrule',
    'scormreport' => '/var/www/html/plantilla/mod/scorm/report',
    'workshopform' => '/var/www/html/plantilla/mod/workshop/form',
    'workshopallocation' => '/var/www/html/plantilla/mod/workshop/allocation',
    'workshopeval' => '/var/www/html/plantilla/mod/workshop/eval',
    'tiny' => '/var/www/html/plantilla/lib/editor/tiny/plugins',
    'logstore' => '/var/www/html/plantilla/admin/tool/log/store',
    'factor' => '/var/www/html/plantilla/admin/tool/mfa/factor',
  ),
  'deprecatedplugintypes' => 
  array (
    'mnetservice' => '/var/www/html/plantilla/mnet/service',
  ),
  'deletedplugintypes' => 
  array (
  ),
  'plugins' => 
  array (
    'aiplacement' => 
    array (
      'courseassist' => '/var/www/html/plantilla/ai/placement/courseassist',
      'editor' => '/var/www/html/plantilla/ai/placement/editor',
    ),
    'aiprovider' => 
    array (
      'azureai' => '/var/www/html/plantilla/ai/provider/azureai',
      'ollama' => '/var/www/html/plantilla/ai/provider/ollama',
      'openai' => '/var/www/html/plantilla/ai/provider/openai',
    ),
    'antivirus' => 
    array (
      'clamav' => '/var/www/html/plantilla/lib/antivirus/clamav',
    ),
    'availability' => 
    array (
      'completion' => '/var/www/html/plantilla/availability/condition/completion',
      'date' => '/var/www/html/plantilla/availability/condition/date',
      'grade' => '/var/www/html/plantilla/availability/condition/grade',
      'group' => '/var/www/html/plantilla/availability/condition/group',
      'grouping' => '/var/www/html/plantilla/availability/condition/grouping',
      'profile' => '/var/www/html/plantilla/availability/condition/profile',
    ),
    'qtype' => 
    array (
      'calculated' => '/var/www/html/plantilla/question/type/calculated',
      'calculatedmulti' => '/var/www/html/plantilla/question/type/calculatedmulti',
      'calculatedsimple' => '/var/www/html/plantilla/question/type/calculatedsimple',
      'ddimageortext' => '/var/www/html/plantilla/question/type/ddimageortext',
      'ddmarker' => '/var/www/html/plantilla/question/type/ddmarker',
      'ddwtos' => '/var/www/html/plantilla/question/type/ddwtos',
      'description' => '/var/www/html/plantilla/question/type/description',
      'essay' => '/var/www/html/plantilla/question/type/essay',
      'gapselect' => '/var/www/html/plantilla/question/type/gapselect',
      'match' => '/var/www/html/plantilla/question/type/match',
      'missingtype' => '/var/www/html/plantilla/question/type/missingtype',
      'multianswer' => '/var/www/html/plantilla/question/type/multianswer',
      'multichoice' => '/var/www/html/plantilla/question/type/multichoice',
      'numerical' => '/var/www/html/plantilla/question/type/numerical',
      'ordering' => '/var/www/html/plantilla/question/type/ordering',
      'random' => '/var/www/html/plantilla/question/type/random',
      'randomsamatch' => '/var/www/html/plantilla/question/type/randomsamatch',
      'shortanswer' => '/var/www/html/plantilla/question/type/shortanswer',
      'truefalse' => '/var/www/html/plantilla/question/type/truefalse',
    ),
    'mod' => 
    array (
      'assign' => '/var/www/html/plantilla/mod/assign',
      'bigbluebuttonbn' => '/var/www/html/plantilla/mod/bigbluebuttonbn',
      'book' => '/var/www/html/plantilla/mod/book',
      'choice' => '/var/www/html/plantilla/mod/choice',
      'data' => '/var/www/html/plantilla/mod/data',
      'feedback' => '/var/www/html/plantilla/mod/feedback',
      'folder' => '/var/www/html/plantilla/mod/folder',
      'forum' => '/var/www/html/plantilla/mod/forum',
      'game' => '/var/www/html/plantilla/mod/game',
      'glossary' => '/var/www/html/plantilla/mod/glossary',
      'h5pactivity' => '/var/www/html/plantilla/mod/h5pactivity',
      'hvp' => '/var/www/html/plantilla/mod/hvp',
      'imscp' => '/var/www/html/plantilla/mod/imscp',
      'label' => '/var/www/html/plantilla/mod/label',
      'lesson' => '/var/www/html/plantilla/mod/lesson',
      'lti' => '/var/www/html/plantilla/mod/lti',
      'page' => '/var/www/html/plantilla/mod/page',
      'qbank' => '/var/www/html/plantilla/mod/qbank',
      'quiz' => '/var/www/html/plantilla/mod/quiz',
      'resource' => '/var/www/html/plantilla/mod/resource',
      'scorm' => '/var/www/html/plantilla/mod/scorm',
      'subsection' => '/var/www/html/plantilla/mod/subsection',
      'url' => '/var/www/html/plantilla/mod/url',
      'wiki' => '/var/www/html/plantilla/mod/wiki',
      'workshop' => '/var/www/html/plantilla/mod/workshop',
    ),
    'auth' => 
    array (
      'db' => '/var/www/html/plantilla/auth/db',
      'email' => '/var/www/html/plantilla/auth/email',
      'ldap' => '/var/www/html/plantilla/auth/ldap',
      'lti' => '/var/www/html/plantilla/auth/lti',
      'manual' => '/var/www/html/plantilla/auth/manual',
      'nologin' => '/var/www/html/plantilla/auth/nologin',
      'none' => '/var/www/html/plantilla/auth/none',
      'oauth2' => '/var/www/html/plantilla/auth/oauth2',
      'shibboleth' => '/var/www/html/plantilla/auth/shibboleth',
      'webservice' => '/var/www/html/plantilla/auth/webservice',
    ),
    'calendartype' => 
    array (
      'gregorian' => '/var/www/html/plantilla/calendar/type/gregorian',
    ),
    'communication' => 
    array (
      'customlink' => '/var/www/html/plantilla/communication/provider/customlink',
      'matrix' => '/var/www/html/plantilla/communication/provider/matrix',
    ),
    'customfield' => 
    array (
      'checkbox' => '/var/www/html/plantilla/customfield/field/checkbox',
      'date' => '/var/www/html/plantilla/customfield/field/date',
      'number' => '/var/www/html/plantilla/customfield/field/number',
      'select' => '/var/www/html/plantilla/customfield/field/select',
      'text' => '/var/www/html/plantilla/customfield/field/text',
      'textarea' => '/var/www/html/plantilla/customfield/field/textarea',
    ),
    'enrol' => 
    array (
      'category' => '/var/www/html/plantilla/enrol/category',
      'cohort' => '/var/www/html/plantilla/enrol/cohort',
      'database' => '/var/www/html/plantilla/enrol/database',
      'fee' => '/var/www/html/plantilla/enrol/fee',
      'flatfile' => '/var/www/html/plantilla/enrol/flatfile',
      'guest' => '/var/www/html/plantilla/enrol/guest',
      'imsenterprise' => '/var/www/html/plantilla/enrol/imsenterprise',
      'ldap' => '/var/www/html/plantilla/enrol/ldap',
      'lti' => '/var/www/html/plantilla/enrol/lti',
      'manual' => '/var/www/html/plantilla/enrol/manual',
      'meta' => '/var/www/html/plantilla/enrol/meta',
      'paypal' => '/var/www/html/plantilla/enrol/paypal',
      'self' => '/var/www/html/plantilla/enrol/self',
    ),
    'message' => 
    array (
      'airnotifier' => '/var/www/html/plantilla/message/output/airnotifier',
      'email' => '/var/www/html/plantilla/message/output/email',
      'popup' => '/var/www/html/plantilla/message/output/popup',
      'sms' => '/var/www/html/plantilla/message/output/sms',
    ),
    'block' => 
    array (
      'accessreview' => '/var/www/html/plantilla/blocks/accessreview',
      'activity_modules' => '/var/www/html/plantilla/blocks/activity_modules',
      'activity_results' => '/var/www/html/plantilla/blocks/activity_results',
      'admin_bookmarks' => '/var/www/html/plantilla/blocks/admin_bookmarks',
      'badges' => '/var/www/html/plantilla/blocks/badges',
      'blog_menu' => '/var/www/html/plantilla/blocks/blog_menu',
      'blog_recent' => '/var/www/html/plantilla/blocks/blog_recent',
      'blog_tags' => '/var/www/html/plantilla/blocks/blog_tags',
      'calendar_month' => '/var/www/html/plantilla/blocks/calendar_month',
      'calendar_upcoming' => '/var/www/html/plantilla/blocks/calendar_upcoming',
      'comments' => '/var/www/html/plantilla/blocks/comments',
      'completionstatus' => '/var/www/html/plantilla/blocks/completionstatus',
      'configurable_reports' => '/var/www/html/plantilla/blocks/configurable_reports',
      'course_list' => '/var/www/html/plantilla/blocks/course_list',
      'course_summary' => '/var/www/html/plantilla/blocks/course_summary',
      'feedback' => '/var/www/html/plantilla/blocks/feedback',
      'globalsearch' => '/var/www/html/plantilla/blocks/globalsearch',
      'glossary_random' => '/var/www/html/plantilla/blocks/glossary_random',
      'html' => '/var/www/html/plantilla/blocks/html',
      'login' => '/var/www/html/plantilla/blocks/login',
      'lp' => '/var/www/html/plantilla/blocks/lp',
      'mentees' => '/var/www/html/plantilla/blocks/mentees',
      'myoverview' => '/var/www/html/plantilla/blocks/myoverview',
      'myprofile' => '/var/www/html/plantilla/blocks/myprofile',
      'navigation' => '/var/www/html/plantilla/blocks/navigation',
      'news_items' => '/var/www/html/plantilla/blocks/news_items',
      'online_users' => '/var/www/html/plantilla/blocks/online_users',
      'private_files' => '/var/www/html/plantilla/blocks/private_files',
      'recent_activity' => '/var/www/html/plantilla/blocks/recent_activity',
      'recentlyaccessedcourses' => '/var/www/html/plantilla/blocks/recentlyaccessedcourses',
      'recentlyaccesseditems' => '/var/www/html/plantilla/blocks/recentlyaccesseditems',
      'rss_client' => '/var/www/html/plantilla/blocks/rss_client',
      'search_forums' => '/var/www/html/plantilla/blocks/search_forums',
      'section_links' => '/var/www/html/plantilla/blocks/section_links',
      'selfcompletion' => '/var/www/html/plantilla/blocks/selfcompletion',
      'settings' => '/var/www/html/plantilla/blocks/settings',
      'site_main_menu' => '/var/www/html/plantilla/blocks/site_main_menu',
      'social_activities' => '/var/www/html/plantilla/blocks/social_activities',
      'starredcourses' => '/var/www/html/plantilla/blocks/starredcourses',
      'tag_flickr' => '/var/www/html/plantilla/blocks/tag_flickr',
      'tag_youtube' => '/var/www/html/plantilla/blocks/tag_youtube',
      'tags' => '/var/www/html/plantilla/blocks/tags',
      'timeline' => '/var/www/html/plantilla/blocks/timeline',
    ),
    'media' => 
    array (
      'html5audio' => '/var/www/html/plantilla/media/player/html5audio',
      'html5video' => '/var/www/html/plantilla/media/player/html5video',
      'videojs' => '/var/www/html/plantilla/media/player/videojs',
      'vimeo' => '/var/www/html/plantilla/media/player/vimeo',
      'youtube' => '/var/www/html/plantilla/media/player/youtube',
    ),
    'filter' => 
    array (
      'activitynames' => '/var/www/html/plantilla/filter/activitynames',
      'algebra' => '/var/www/html/plantilla/filter/algebra',
      'codehighlighter' => '/var/www/html/plantilla/filter/codehighlighter',
      'data' => '/var/www/html/plantilla/filter/data',
      'displayh5p' => '/var/www/html/plantilla/filter/displayh5p',
      'emailprotect' => '/var/www/html/plantilla/filter/emailprotect',
      'emoticon' => '/var/www/html/plantilla/filter/emoticon',
      'glossary' => '/var/www/html/plantilla/filter/glossary',
      'mathjaxloader' => '/var/www/html/plantilla/filter/mathjaxloader',
      'mediaplugin' => '/var/www/html/plantilla/filter/mediaplugin',
      'multilang' => '/var/www/html/plantilla/filter/multilang',
      'tex' => '/var/www/html/plantilla/filter/tex',
      'urltolink' => '/var/www/html/plantilla/filter/urltolink',
    ),
    'editor' => 
    array (
      'textarea' => '/var/www/html/plantilla/lib/editor/textarea',
      'tiny' => '/var/www/html/plantilla/lib/editor/tiny',
    ),
    'format' => 
    array (
      'singleactivity' => '/var/www/html/plantilla/course/format/singleactivity',
      'social' => '/var/www/html/plantilla/course/format/social',
      'tiles' => '/var/www/html/plantilla/course/format/tiles',
      'topics' => '/var/www/html/plantilla/course/format/topics',
      'weeks' => '/var/www/html/plantilla/course/format/weeks',
    ),
    'dataformat' => 
    array (
      'csv' => '/var/www/html/plantilla/dataformat/csv',
      'excel' => '/var/www/html/plantilla/dataformat/excel',
      'html' => '/var/www/html/plantilla/dataformat/html',
      'json' => '/var/www/html/plantilla/dataformat/json',
      'ods' => '/var/www/html/plantilla/dataformat/ods',
      'pdf' => '/var/www/html/plantilla/dataformat/pdf',
    ),
    'profilefield' => 
    array (
      'checkbox' => '/var/www/html/plantilla/user/profile/field/checkbox',
      'datetime' => '/var/www/html/plantilla/user/profile/field/datetime',
      'menu' => '/var/www/html/plantilla/user/profile/field/menu',
      'social' => '/var/www/html/plantilla/user/profile/field/social',
      'text' => '/var/www/html/plantilla/user/profile/field/text',
      'textarea' => '/var/www/html/plantilla/user/profile/field/textarea',
    ),
    'report' => 
    array (
      'backups' => '/var/www/html/plantilla/report/backups',
      'competency' => '/var/www/html/plantilla/report/competency',
      'completion' => '/var/www/html/plantilla/report/completion',
      'configlog' => '/var/www/html/plantilla/report/configlog',
      'courseoverview' => '/var/www/html/plantilla/report/courseoverview',
      'customsql' => '/var/www/html/plantilla/report/customsql',
      'eventlist' => '/var/www/html/plantilla/report/eventlist',
      'infectedfiles' => '/var/www/html/plantilla/report/infectedfiles',
      'insights' => '/var/www/html/plantilla/report/insights',
      'log' => '/var/www/html/plantilla/report/log',
      'loglive' => '/var/www/html/plantilla/report/loglive',
      'outline' => '/var/www/html/plantilla/report/outline',
      'participation' => '/var/www/html/plantilla/report/participation',
      'performance' => '/var/www/html/plantilla/report/performance',
      'progress' => '/var/www/html/plantilla/report/progress',
      'questioninstances' => '/var/www/html/plantilla/report/questioninstances',
      'security' => '/var/www/html/plantilla/report/security',
      'stats' => '/var/www/html/plantilla/report/stats',
      'status' => '/var/www/html/plantilla/report/status',
      'themeusage' => '/var/www/html/plantilla/report/themeusage',
      'usersessions' => '/var/www/html/plantilla/report/usersessions',
    ),
    'coursereport' => 
    array (
    ),
    'gradeexport' => 
    array (
      'ods' => '/var/www/html/plantilla/grade/export/ods',
      'txt' => '/var/www/html/plantilla/grade/export/txt',
      'xls' => '/var/www/html/plantilla/grade/export/xls',
      'xml' => '/var/www/html/plantilla/grade/export/xml',
    ),
    'gradeimport' => 
    array (
      'csv' => '/var/www/html/plantilla/grade/import/csv',
      'direct' => '/var/www/html/plantilla/grade/import/direct',
      'xml' => '/var/www/html/plantilla/grade/import/xml',
    ),
    'gradepenalty' => 
    array (
      'duedate' => '/var/www/html/plantilla/grade/penalty/duedate',
    ),
    'gradereport' => 
    array (
      'grader' => '/var/www/html/plantilla/grade/report/grader',
      'history' => '/var/www/html/plantilla/grade/report/history',
      'outcomes' => '/var/www/html/plantilla/grade/report/outcomes',
      'overview' => '/var/www/html/plantilla/grade/report/overview',
      'singleview' => '/var/www/html/plantilla/grade/report/singleview',
      'summary' => '/var/www/html/plantilla/grade/report/summary',
      'user' => '/var/www/html/plantilla/grade/report/user',
    ),
    'gradingform' => 
    array (
      'guide' => '/var/www/html/plantilla/grade/grading/form/guide',
      'rubric' => '/var/www/html/plantilla/grade/grading/form/rubric',
    ),
    'mlbackend' => 
    array (
      'python' => '/var/www/html/plantilla/lib/mlbackend/python',
    ),
    'webservice' => 
    array (
      'rest' => '/var/www/html/plantilla/webservice/rest',
      'soap' => '/var/www/html/plantilla/webservice/soap',
    ),
    'repository' => 
    array (
      'areafiles' => '/var/www/html/plantilla/repository/areafiles',
      'contentbank' => '/var/www/html/plantilla/repository/contentbank',
      'coursefiles' => '/var/www/html/plantilla/repository/coursefiles',
      'dropbox' => '/var/www/html/plantilla/repository/dropbox',
      'equella' => '/var/www/html/plantilla/repository/equella',
      'filesystem' => '/var/www/html/plantilla/repository/filesystem',
      'flickr' => '/var/www/html/plantilla/repository/flickr',
      'flickr_public' => '/var/www/html/plantilla/repository/flickr_public',
      'googledocs' => '/var/www/html/plantilla/repository/googledocs',
      'local' => '/var/www/html/plantilla/repository/local',
      'merlot' => '/var/www/html/plantilla/repository/merlot',
      'nextcloud' => '/var/www/html/plantilla/repository/nextcloud',
      'onedrive' => '/var/www/html/plantilla/repository/onedrive',
      'recent' => '/var/www/html/plantilla/repository/recent',
      's3' => '/var/www/html/plantilla/repository/s3',
      'upload' => '/var/www/html/plantilla/repository/upload',
      'url' => '/var/www/html/plantilla/repository/url',
      'user' => '/var/www/html/plantilla/repository/user',
      'webdav' => '/var/www/html/plantilla/repository/webdav',
      'wikimedia' => '/var/www/html/plantilla/repository/wikimedia',
      'youtube' => '/var/www/html/plantilla/repository/youtube',
    ),
    'portfolio' => 
    array (
      'download' => '/var/www/html/plantilla/portfolio/download',
      'flickr' => '/var/www/html/plantilla/portfolio/flickr',
      'googledocs' => '/var/www/html/plantilla/portfolio/googledocs',
    ),
    'search' => 
    array (
      'simpledb' => '/var/www/html/plantilla/search/engine/simpledb',
      'solr' => '/var/www/html/plantilla/search/engine/solr',
    ),
    'qbank' => 
    array (
      'bulkmove' => '/var/www/html/plantilla/question/bank/bulkmove',
      'columnsortorder' => '/var/www/html/plantilla/question/bank/columnsortorder',
      'comment' => '/var/www/html/plantilla/question/bank/comment',
      'customfields' => '/var/www/html/plantilla/question/bank/customfields',
      'deletequestion' => '/var/www/html/plantilla/question/bank/deletequestion',
      'editquestion' => '/var/www/html/plantilla/question/bank/editquestion',
      'exportquestions' => '/var/www/html/plantilla/question/bank/exportquestions',
      'exporttoxml' => '/var/www/html/plantilla/question/bank/exporttoxml',
      'history' => '/var/www/html/plantilla/question/bank/history',
      'importquestions' => '/var/www/html/plantilla/question/bank/importquestions',
      'managecategories' => '/var/www/html/plantilla/question/bank/managecategories',
      'previewquestion' => '/var/www/html/plantilla/question/bank/previewquestion',
      'statistics' => '/var/www/html/plantilla/question/bank/statistics',
      'tagquestion' => '/var/www/html/plantilla/question/bank/tagquestion',
      'usage' => '/var/www/html/plantilla/question/bank/usage',
      'viewcreator' => '/var/www/html/plantilla/question/bank/viewcreator',
      'viewquestionname' => '/var/www/html/plantilla/question/bank/viewquestionname',
      'viewquestiontext' => '/var/www/html/plantilla/question/bank/viewquestiontext',
      'viewquestiontype' => '/var/www/html/plantilla/question/bank/viewquestiontype',
    ),
    'qbehaviour' => 
    array (
      'adaptive' => '/var/www/html/plantilla/question/behaviour/adaptive',
      'adaptivenopenalty' => '/var/www/html/plantilla/question/behaviour/adaptivenopenalty',
      'deferredcbm' => '/var/www/html/plantilla/question/behaviour/deferredcbm',
      'deferredfeedback' => '/var/www/html/plantilla/question/behaviour/deferredfeedback',
      'immediatecbm' => '/var/www/html/plantilla/question/behaviour/immediatecbm',
      'immediatefeedback' => '/var/www/html/plantilla/question/behaviour/immediatefeedback',
      'informationitem' => '/var/www/html/plantilla/question/behaviour/informationitem',
      'interactive' => '/var/www/html/plantilla/question/behaviour/interactive',
      'interactivecountback' => '/var/www/html/plantilla/question/behaviour/interactivecountback',
      'manualgraded' => '/var/www/html/plantilla/question/behaviour/manualgraded',
      'missing' => '/var/www/html/plantilla/question/behaviour/missing',
    ),
    'qformat' => 
    array (
      'aiken' => '/var/www/html/plantilla/question/format/aiken',
      'blackboard_six' => '/var/www/html/plantilla/question/format/blackboard_six',
      'gift' => '/var/www/html/plantilla/question/format/gift',
      'missingword' => '/var/www/html/plantilla/question/format/missingword',
      'multianswer' => '/var/www/html/plantilla/question/format/multianswer',
      'xhtml' => '/var/www/html/plantilla/question/format/xhtml',
      'xml' => '/var/www/html/plantilla/question/format/xml',
    ),
    'plagiarism' => 
    array (
    ),
    'tool' => 
    array (
      'admin_presets' => '/var/www/html/plantilla/admin/tool/admin_presets',
      'analytics' => '/var/www/html/plantilla/admin/tool/analytics',
      'availabilityconditions' => '/var/www/html/plantilla/admin/tool/availabilityconditions',
      'behat' => '/var/www/html/plantilla/admin/tool/behat',
      'brickfield' => '/var/www/html/plantilla/admin/tool/brickfield',
      'capability' => '/var/www/html/plantilla/admin/tool/capability',
      'cohortroles' => '/var/www/html/plantilla/admin/tool/cohortroles',
      'componentlibrary' => '/var/www/html/plantilla/admin/tool/componentlibrary',
      'customlang' => '/var/www/html/plantilla/admin/tool/customlang',
      'dataprivacy' => '/var/www/html/plantilla/admin/tool/dataprivacy',
      'dbtransfer' => '/var/www/html/plantilla/admin/tool/dbtransfer',
      'filetypes' => '/var/www/html/plantilla/admin/tool/filetypes',
      'generator' => '/var/www/html/plantilla/admin/tool/generator',
      'httpsreplace' => '/var/www/html/plantilla/admin/tool/httpsreplace',
      'installaddon' => '/var/www/html/plantilla/admin/tool/installaddon',
      'langimport' => '/var/www/html/plantilla/admin/tool/langimport',
      'licensemanager' => '/var/www/html/plantilla/admin/tool/licensemanager',
      'log' => '/var/www/html/plantilla/admin/tool/log',
      'lp' => '/var/www/html/plantilla/admin/tool/lp',
      'lpimportcsv' => '/var/www/html/plantilla/admin/tool/lpimportcsv',
      'lpmigrate' => '/var/www/html/plantilla/admin/tool/lpmigrate',
      'messageinbound' => '/var/www/html/plantilla/admin/tool/messageinbound',
      'mfa' => '/var/www/html/plantilla/admin/tool/mfa',
      'mobile' => '/var/www/html/plantilla/admin/tool/mobile',
      'monitor' => '/var/www/html/plantilla/admin/tool/monitor',
      'moodlenet' => '/var/www/html/plantilla/admin/tool/moodlenet',
      'multilangupgrade' => '/var/www/html/plantilla/admin/tool/multilangupgrade',
      'oauth2' => '/var/www/html/plantilla/admin/tool/oauth2',
      'phpunit' => '/var/www/html/plantilla/admin/tool/phpunit',
      'policy' => '/var/www/html/plantilla/admin/tool/policy',
      'profiling' => '/var/www/html/plantilla/admin/tool/profiling',
      'recyclebin' => '/var/www/html/plantilla/admin/tool/recyclebin',
      'replace' => '/var/www/html/plantilla/admin/tool/replace',
      'spamcleaner' => '/var/www/html/plantilla/admin/tool/spamcleaner',
      'task' => '/var/www/html/plantilla/admin/tool/task',
      'templatelibrary' => '/var/www/html/plantilla/admin/tool/templatelibrary',
      'unsuproles' => '/var/www/html/plantilla/admin/tool/unsuproles',
      'uploadcourse' => '/var/www/html/plantilla/admin/tool/uploadcourse',
      'uploaduser' => '/var/www/html/plantilla/admin/tool/uploaduser',
      'usertours' => '/var/www/html/plantilla/admin/tool/usertours',
      'xmldb' => '/var/www/html/plantilla/admin/tool/xmldb',
    ),
    'cachestore' => 
    array (
      'apcu' => '/var/www/html/plantilla/cache/stores/apcu',
      'file' => '/var/www/html/plantilla/cache/stores/file',
      'redis' => '/var/www/html/plantilla/cache/stores/redis',
      'session' => '/var/www/html/plantilla/cache/stores/session',
      'static' => '/var/www/html/plantilla/cache/stores/static',
    ),
    'cachelock' => 
    array (
      'file' => '/var/www/html/plantilla/cache/locks/file',
    ),
    'fileconverter' => 
    array (
      'googledrive' => '/var/www/html/plantilla/files/converter/googledrive',
      'unoconv' => '/var/www/html/plantilla/files/converter/unoconv',
    ),
    'contenttype' => 
    array (
      'h5p' => '/var/www/html/plantilla/contentbank/contenttype/h5p',
    ),
    'theme' => 
    array (
      'boost' => '/var/www/html/plantilla/theme/boost',
      'classic' => '/var/www/html/plantilla/theme/classic',
      'moove' => '/var/www/html/plantilla/theme/moove',
    ),
    'local' => 
    array (
    ),
    'h5plib' => 
    array (
      'v127' => '/var/www/html/plantilla/h5p/h5plib/v127',
    ),
    'paygw' => 
    array (
      'paypal' => '/var/www/html/plantilla/payment/gateway/paypal',
    ),
    'smsgateway' => 
    array (
      'aws' => '/var/www/html/plantilla/sms/gateway/aws',
      'modica' => '/var/www/html/plantilla/sms/gateway/modica',
    ),
    'assignsubmission' => 
    array (
      'comments' => '/var/www/html/plantilla/mod/assign/submission/comments',
      'file' => '/var/www/html/plantilla/mod/assign/submission/file',
      'onlinetext' => '/var/www/html/plantilla/mod/assign/submission/onlinetext',
    ),
    'assignfeedback' => 
    array (
      'comments' => '/var/www/html/plantilla/mod/assign/feedback/comments',
      'editpdf' => '/var/www/html/plantilla/mod/assign/feedback/editpdf',
      'file' => '/var/www/html/plantilla/mod/assign/feedback/file',
      'offline' => '/var/www/html/plantilla/mod/assign/feedback/offline',
    ),
    'bbbext' => 
    array (
    ),
    'booktool' => 
    array (
      'exportimscp' => '/var/www/html/plantilla/mod/book/tool/exportimscp',
      'importhtml' => '/var/www/html/plantilla/mod/book/tool/importhtml',
      'print' => '/var/www/html/plantilla/mod/book/tool/print',
    ),
    'datafield' => 
    array (
      'checkbox' => '/var/www/html/plantilla/mod/data/field/checkbox',
      'date' => '/var/www/html/plantilla/mod/data/field/date',
      'file' => '/var/www/html/plantilla/mod/data/field/file',
      'latlong' => '/var/www/html/plantilla/mod/data/field/latlong',
      'menu' => '/var/www/html/plantilla/mod/data/field/menu',
      'multimenu' => '/var/www/html/plantilla/mod/data/field/multimenu',
      'number' => '/var/www/html/plantilla/mod/data/field/number',
      'picture' => '/var/www/html/plantilla/mod/data/field/picture',
      'radiobutton' => '/var/www/html/plantilla/mod/data/field/radiobutton',
      'text' => '/var/www/html/plantilla/mod/data/field/text',
      'textarea' => '/var/www/html/plantilla/mod/data/field/textarea',
      'url' => '/var/www/html/plantilla/mod/data/field/url',
    ),
    'datapreset' => 
    array (
      'imagegallery' => '/var/www/html/plantilla/mod/data/preset/imagegallery',
      'journal' => '/var/www/html/plantilla/mod/data/preset/journal',
      'proposals' => '/var/www/html/plantilla/mod/data/preset/proposals',
      'resources' => '/var/www/html/plantilla/mod/data/preset/resources',
    ),
    'forumreport' => 
    array (
      'summary' => '/var/www/html/plantilla/mod/forum/report/summary',
    ),
    'ltisource' => 
    array (
    ),
    'ltiservice' => 
    array (
      'basicoutcomes' => '/var/www/html/plantilla/mod/lti/service/basicoutcomes',
      'gradebookservices' => '/var/www/html/plantilla/mod/lti/service/gradebookservices',
      'memberships' => '/var/www/html/plantilla/mod/lti/service/memberships',
      'profile' => '/var/www/html/plantilla/mod/lti/service/profile',
      'toolproxy' => '/var/www/html/plantilla/mod/lti/service/toolproxy',
      'toolsettings' => '/var/www/html/plantilla/mod/lti/service/toolsettings',
    ),
    'quiz' => 
    array (
      'grading' => '/var/www/html/plantilla/mod/quiz/report/grading',
      'overview' => '/var/www/html/plantilla/mod/quiz/report/overview',
      'responses' => '/var/www/html/plantilla/mod/quiz/report/responses',
      'statistics' => '/var/www/html/plantilla/mod/quiz/report/statistics',
    ),
    'quizaccess' => 
    array (
      'delaybetweenattempts' => '/var/www/html/plantilla/mod/quiz/accessrule/delaybetweenattempts',
      'ipaddress' => '/var/www/html/plantilla/mod/quiz/accessrule/ipaddress',
      'numattempts' => '/var/www/html/plantilla/mod/quiz/accessrule/numattempts',
      'offlineattempts' => '/var/www/html/plantilla/mod/quiz/accessrule/offlineattempts',
      'openclosedate' => '/var/www/html/plantilla/mod/quiz/accessrule/openclosedate',
      'password' => '/var/www/html/plantilla/mod/quiz/accessrule/password',
      'seb' => '/var/www/html/plantilla/mod/quiz/accessrule/seb',
      'securewindow' => '/var/www/html/plantilla/mod/quiz/accessrule/securewindow',
      'timelimit' => '/var/www/html/plantilla/mod/quiz/accessrule/timelimit',
    ),
    'scormreport' => 
    array (
      'basic' => '/var/www/html/plantilla/mod/scorm/report/basic',
      'graphs' => '/var/www/html/plantilla/mod/scorm/report/graphs',
      'interactions' => '/var/www/html/plantilla/mod/scorm/report/interactions',
      'objectives' => '/var/www/html/plantilla/mod/scorm/report/objectives',
    ),
    'workshopform' => 
    array (
      'accumulative' => '/var/www/html/plantilla/mod/workshop/form/accumulative',
      'comments' => '/var/www/html/plantilla/mod/workshop/form/comments',
      'numerrors' => '/var/www/html/plantilla/mod/workshop/form/numerrors',
      'rubric' => '/var/www/html/plantilla/mod/workshop/form/rubric',
    ),
    'workshopallocation' => 
    array (
      'manual' => '/var/www/html/plantilla/mod/workshop/allocation/manual',
      'random' => '/var/www/html/plantilla/mod/workshop/allocation/random',
      'scheduled' => '/var/www/html/plantilla/mod/workshop/allocation/scheduled',
    ),
    'workshopeval' => 
    array (
      'best' => '/var/www/html/plantilla/mod/workshop/eval/best',
    ),
    'tiny' => 
    array (
      'accessibilitychecker' => '/var/www/html/plantilla/lib/editor/tiny/plugins/accessibilitychecker',
      'aiplacement' => '/var/www/html/plantilla/lib/editor/tiny/plugins/aiplacement',
      'autosave' => '/var/www/html/plantilla/lib/editor/tiny/plugins/autosave',
      'equation' => '/var/www/html/plantilla/lib/editor/tiny/plugins/equation',
      'h5p' => '/var/www/html/plantilla/lib/editor/tiny/plugins/h5p',
      'html' => '/var/www/html/plantilla/lib/editor/tiny/plugins/html',
      'link' => '/var/www/html/plantilla/lib/editor/tiny/plugins/link',
      'media' => '/var/www/html/plantilla/lib/editor/tiny/plugins/media',
      'noautolink' => '/var/www/html/plantilla/lib/editor/tiny/plugins/noautolink',
      'premium' => '/var/www/html/plantilla/lib/editor/tiny/plugins/premium',
      'recordrtc' => '/var/www/html/plantilla/lib/editor/tiny/plugins/recordrtc',
    ),
    'logstore' => 
    array (
      'database' => '/var/www/html/plantilla/admin/tool/log/store/database',
      'standard' => '/var/www/html/plantilla/admin/tool/log/store/standard',
    ),
    'factor' => 
    array (
      'admin' => '/var/www/html/plantilla/admin/tool/mfa/factor/admin',
      'auth' => '/var/www/html/plantilla/admin/tool/mfa/factor/auth',
      'capability' => '/var/www/html/plantilla/admin/tool/mfa/factor/capability',
      'cohort' => '/var/www/html/plantilla/admin/tool/mfa/factor/cohort',
      'email' => '/var/www/html/plantilla/admin/tool/mfa/factor/email',
      'grace' => '/var/www/html/plantilla/admin/tool/mfa/factor/grace',
      'iprange' => '/var/www/html/plantilla/admin/tool/mfa/factor/iprange',
      'nosetup' => '/var/www/html/plantilla/admin/tool/mfa/factor/nosetup',
      'role' => '/var/www/html/plantilla/admin/tool/mfa/factor/role',
      'sms' => '/var/www/html/plantilla/admin/tool/mfa/factor/sms',
      'token' => '/var/www/html/plantilla/admin/tool/mfa/factor/token',
      'totp' => '/var/www/html/plantilla/admin/tool/mfa/factor/totp',
      'webauthn' => '/var/www/html/plantilla/admin/tool/mfa/factor/webauthn',
    ),
  ),
  'deprecatedplugins' => 
  array (
    'mnetservice' => 
    array (
    ),
  ),
  'deletedplugins' => 
  array (
  ),
  'subplugins' => 
  array (
    'mod_assign' => 
    array (
      'assignsubmission' => 
      array (
        0 => 'comments',
        1 => 'file',
        2 => 'onlinetext',
      ),
      'assignfeedback' => 
      array (
        0 => 'comments',
        1 => 'editpdf',
        2 => 'file',
        3 => 'offline',
      ),
    ),
    'mod_bigbluebuttonbn' => 
    array (
      'bbbext' => 
      array (
      ),
    ),
    'mod_book' => 
    array (
      'booktool' => 
      array (
        0 => 'exportimscp',
        1 => 'importhtml',
        2 => 'print',
      ),
    ),
    'mod_data' => 
    array (
      'datafield' => 
      array (
        0 => 'checkbox',
        1 => 'date',
        2 => 'file',
        3 => 'latlong',
        4 => 'menu',
        5 => 'multimenu',
        6 => 'number',
        7 => 'picture',
        8 => 'radiobutton',
        9 => 'text',
        10 => 'textarea',
        11 => 'url',
      ),
      'datapreset' => 
      array (
        0 => 'imagegallery',
        1 => 'journal',
        2 => 'proposals',
        3 => 'resources',
      ),
    ),
    'mod_forum' => 
    array (
      'forumreport' => 
      array (
        0 => 'summary',
      ),
    ),
    'mod_lti' => 
    array (
      'ltisource' => 
      array (
      ),
      'ltiservice' => 
      array (
        0 => 'basicoutcomes',
        1 => 'gradebookservices',
        2 => 'memberships',
        3 => 'profile',
        4 => 'toolproxy',
        5 => 'toolsettings',
      ),
    ),
    'mod_quiz' => 
    array (
      'quiz' => 
      array (
        0 => 'grading',
        1 => 'overview',
        2 => 'responses',
        3 => 'statistics',
      ),
      'quizaccess' => 
      array (
        0 => 'delaybetweenattempts',
        1 => 'ipaddress',
        2 => 'numattempts',
        3 => 'offlineattempts',
        4 => 'openclosedate',
        5 => 'password',
        6 => 'seb',
        7 => 'securewindow',
        8 => 'timelimit',
      ),
    ),
    'mod_scorm' => 
    array (
      'scormreport' => 
      array (
        0 => 'basic',
        1 => 'graphs',
        2 => 'interactions',
        3 => 'objectives',
      ),
    ),
    'mod_workshop' => 
    array (
      'workshopform' => 
      array (
        0 => 'accumulative',
        1 => 'comments',
        2 => 'numerrors',
        3 => 'rubric',
      ),
      'workshopallocation' => 
      array (
        0 => 'manual',
        1 => 'random',
        2 => 'scheduled',
      ),
      'workshopeval' => 
      array (
        0 => 'best',
      ),
    ),
    'editor_tiny' => 
    array (
      'tiny' => 
      array (
        0 => 'accessibilitychecker',
        1 => 'aiplacement',
        2 => 'autosave',
        3 => 'equation',
        4 => 'h5p',
        5 => 'html',
        6 => 'link',
        7 => 'media',
        8 => 'noautolink',
        9 => 'premium',
        10 => 'recordrtc',
      ),
    ),
    'tool_log' => 
    array (
      'logstore' => 
      array (
        0 => 'database',
        1 => 'standard',
      ),
    ),
    'tool_mfa' => 
    array (
      'factor' => 
      array (
        0 => 'admin',
        1 => 'auth',
        2 => 'capability',
        3 => 'cohort',
        4 => 'email',
        5 => 'grace',
        6 => 'iprange',
        7 => 'nosetup',
        8 => 'role',
        9 => 'sms',
        10 => 'token',
        11 => 'totp',
        12 => 'webauthn',
      ),
    ),
  ),
  'deprecatedsubplugins' => 
  array (
    'mod_assign' => 
    array (
    ),
    'mod_bigbluebuttonbn' => 
    array (
    ),
    'mod_book' => 
    array (
    ),
    'mod_data' => 
    array (
    ),
    'mod_forum' => 
    array (
    ),
    'mod_lti' => 
    array (
    ),
    'mod_quiz' => 
    array (
    ),
    'mod_scorm' => 
    array (
    ),
    'mod_workshop' => 
    array (
    ),
    'editor_tiny' => 
    array (
    ),
    'tool_log' => 
    array (
    ),
    'tool_mfa' => 
    array (
    ),
  ),
  'deletedsubplugins' => 
  array (
    'mod_assign' => 
    array (
    ),
    'mod_bigbluebuttonbn' => 
    array (
    ),
    'mod_book' => 
    array (
    ),
    'mod_data' => 
    array (
    ),
    'mod_forum' => 
    array (
    ),
    'mod_lti' => 
    array (
    ),
    'mod_quiz' => 
    array (
    ),
    'mod_scorm' => 
    array (
    ),
    'mod_workshop' => 
    array (
    ),
    'editor_tiny' => 
    array (
    ),
    'tool_log' => 
    array (
    ),
    'tool_mfa' => 
    array (
    ),
  ),
  'parents' => 
  array (
    'assignsubmission' => 'mod_assign',
    'assignfeedback' => 'mod_assign',
    'bbbext' => 'mod_bigbluebuttonbn',
    'booktool' => 'mod_book',
    'datafield' => 'mod_data',
    'datapreset' => 'mod_data',
    'forumreport' => 'mod_forum',
    'ltisource' => 'mod_lti',
    'ltiservice' => 'mod_lti',
    'quiz' => 'mod_quiz',
    'quizaccess' => 'mod_quiz',
    'scormreport' => 'mod_scorm',
    'workshopform' => 'mod_workshop',
    'workshopallocation' => 'mod_workshop',
    'workshopeval' => 'mod_workshop',
    'tiny' => 'editor_tiny',
    'logstore' => 'tool_log',
    'factor' => 'tool_mfa',
  ),
  'apis' => 
  array (
    'access' => 
    (object) array(
       'component' => 'core_access',
       'allowedlevel2' => true,
       'allowedspread' => false,
    ),
    'admin' => 
    (object) array(
       'component' => 'core_admin',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'adminpresets' => 
    (object) array(
       'component' => 'core_adminpresets',
       'allowedlevel2' => true,
       'allowedspread' => false,
    ),
    'aiactions' => 
    (object) array(
       'component' => 'core_ai',
       'allowedlevel2' => true,
       'allowedspread' => false,
    ),
    'aimodel' => 
    (object) array(
       'component' => 'core_ai',
       'allowedlevel2' => true,
       'allowedspread' => false,
    ),
    'analytics' => 
    (object) array(
       'component' => 'core_analytics',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'attribute' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'availability' => 
    (object) array(
       'component' => 'core_availability',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'backup' => 
    (object) array(
       'component' => 'core_backup',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'badges' => 
    (object) array(
       'component' => 'core_badges',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'cache' => 
    (object) array(
       'component' => 'core_cache',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'calendar' => 
    (object) array(
       'component' => 'core_calendar',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'check' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'comment' => 
    (object) array(
       'component' => 'core_comment',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'competency' => 
    (object) array(
       'component' => 'core_competency',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'completion' => 
    (object) array(
       'component' => 'core_completion',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'context' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => true,
       'allowedspread' => false,
    ),
    'core' => 
    (object) array(
       'component' => NULL,
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'courseformat' => 
    (object) array(
       'component' => 'core_courseformat',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'customfield' => 
    (object) array(
       'component' => 'core_customfield',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'ddl' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => true,
       'allowedspread' => false,
    ),
    'dml' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => true,
       'allowedspread' => false,
    ),
    'enrol' => 
    (object) array(
       'component' => 'core_enrol',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'event' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'exception' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'external' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'files' => 
    (object) array(
       'component' => 'core_files',
       'allowedlevel2' => true,
       'allowedspread' => false,
    ),
    'form' => 
    (object) array(
       'component' => 'core_form',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'grade' => 
    (object) array(
       'component' => 'core_grades',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'grading' => 
    (object) array(
       'component' => 'core_grading',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'group' => 
    (object) array(
       'component' => 'core_group',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'h5p' => 
    (object) array(
       'component' => 'core_h5p',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'hook' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'lock' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => true,
       'allowedspread' => false,
    ),
    'log' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'media' => 
    (object) array(
       'component' => 'core_media',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'message' => 
    (object) array(
       'component' => 'core_message',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'moodlenet' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'navigation' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'oauth2' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'output' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'page' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'payment' => 
    (object) array(
       'component' => 'core_payment',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'plagiarism' => 
    (object) array(
       'component' => 'core_plagiarism',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'portfolio' => 
    (object) array(
       'component' => 'core_portfolio',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'preference' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'privacy' => 
    (object) array(
       'component' => 'core_privacy',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'question' => 
    (object) array(
       'component' => 'core_question',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'rating' => 
    (object) array(
       'component' => 'core_rating',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'redactor' => 
    (object) array(
       'component' => 'core_files',
       'allowedlevel2' => true,
       'allowedspread' => false,
    ),
    'reportbuilder' => 
    (object) array(
       'component' => 'core_reportbuilder',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'route' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'router' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'rss' => 
    (object) array(
       'component' => 'core_rss',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'search' => 
    (object) array(
       'component' => 'core_search',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'string' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'tag' => 
    (object) array(
       'component' => 'core_tag',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'task' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
    'test' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'time' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'upgrade' => 
    (object) array(
       'component' => 'core',
       'allowedlevel2' => true,
       'allowedspread' => false,
    ),
    'webservice' => 
    (object) array(
       'component' => 'core_webservice',
       'allowedlevel2' => false,
       'allowedspread' => false,
    ),
    'xapi' => 
    (object) array(
       'component' => 'core_xapi',
       'allowedlevel2' => true,
       'allowedspread' => true,
    ),
  ),
  'classmap' => 
  array (
    'YUI_config' => '/var/www/html/plantilla/lib/classes/output/requirements/yui.php',
    'action_link' => '/var/www/html/plantilla/lib/classes/output/action_link.php',
    'action_menu' => '/var/www/html/plantilla/lib/classes/output/action_menu.php',
    'action_menu_filler' => '/var/www/html/plantilla/lib/classes/output/action_menu/filler.php',
    'action_menu_link' => '/var/www/html/plantilla/lib/classes/output/action_menu/link.php',
    'action_menu_link_primary' => '/var/www/html/plantilla/lib/classes/output/action_menu/link_primary.php',
    'action_menu_link_secondary' => '/var/www/html/plantilla/lib/classes/output/action_menu/link_secondary.php',
    'aiplacement_courseassist\\external\\explain_text' => '/var/www/html/plantilla/ai/placement/courseassist/classes/external/explain_text.php',
    'aiplacement_courseassist\\external\\summarise_text' => '/var/www/html/plantilla/ai/placement/courseassist/classes/external/summarise_text.php',
    'aiplacement_courseassist\\hook_callbacks' => '/var/www/html/plantilla/ai/placement/courseassist/classes/hook_callbacks.php',
    'aiplacement_courseassist\\output\\assist_ui' => '/var/www/html/plantilla/ai/placement/courseassist/classes/output/assist_ui.php',
    'aiplacement_courseassist\\placement' => '/var/www/html/plantilla/ai/placement/courseassist/classes/placement.php',
    'aiplacement_courseassist\\privacy\\provider' => '/var/www/html/plantilla/ai/placement/courseassist/classes/privacy/provider.php',
    'aiplacement_courseassist\\utils' => '/var/www/html/plantilla/ai/placement/courseassist/classes/utils.php',
    'aiplacement_courseassist_hook_callbacks' => '/var/www/html/plantilla/ai/placement/courseassist/classes/hook_callbacks.php',
    'aiplacement_courseassist_placement' => '/var/www/html/plantilla/ai/placement/courseassist/classes/placement.php',
    'aiplacement_courseassist_utils' => '/var/www/html/plantilla/ai/placement/courseassist/classes/utils.php',
    'aiplacement_editor\\external\\generate_image' => '/var/www/html/plantilla/ai/placement/editor/classes/external/generate_image.php',
    'aiplacement_editor\\external\\generate_text' => '/var/www/html/plantilla/ai/placement/editor/classes/external/generate_text.php',
    'aiplacement_editor\\placement' => '/var/www/html/plantilla/ai/placement/editor/classes/placement.php',
    'aiplacement_editor\\privacy\\provider' => '/var/www/html/plantilla/ai/placement/editor/classes/privacy/provider.php',
    'aiplacement_editor\\utils' => '/var/www/html/plantilla/ai/placement/editor/classes/utils.php',
    'aiplacement_editor_placement' => '/var/www/html/plantilla/ai/placement/editor/classes/placement.php',
    'aiplacement_editor_utils' => '/var/www/html/plantilla/ai/placement/editor/classes/utils.php',
    'aiprovider_azureai\\abstract_processor' => '/var/www/html/plantilla/ai/provider/azureai/classes/abstract_processor.php',
    'aiprovider_azureai\\form\\action_generate_image_form' => '/var/www/html/plantilla/ai/provider/azureai/classes/form/action_generate_image_form.php',
    'aiprovider_azureai\\form\\action_generate_text_form' => '/var/www/html/plantilla/ai/provider/azureai/classes/form/action_generate_text_form.php',
    'aiprovider_azureai\\hook_listener' => '/var/www/html/plantilla/ai/provider/azureai/classes/hook_listener.php',
    'aiprovider_azureai\\privacy\\provider' => '/var/www/html/plantilla/ai/provider/azureai/classes/privacy/provider.php',
    'aiprovider_azureai\\process_explain_text' => '/var/www/html/plantilla/ai/provider/azureai/classes/process_explain_text.php',
    'aiprovider_azureai\\process_generate_image' => '/var/www/html/plantilla/ai/provider/azureai/classes/process_generate_image.php',
    'aiprovider_azureai\\process_generate_text' => '/var/www/html/plantilla/ai/provider/azureai/classes/process_generate_text.php',
    'aiprovider_azureai\\process_summarise_text' => '/var/www/html/plantilla/ai/provider/azureai/classes/process_summarise_text.php',
    'aiprovider_azureai\\provider' => '/var/www/html/plantilla/ai/provider/azureai/classes/provider.php',
    'aiprovider_azureai_abstract_processor' => '/var/www/html/plantilla/ai/provider/azureai/classes/abstract_processor.php',
    'aiprovider_azureai_hook_listener' => '/var/www/html/plantilla/ai/provider/azureai/classes/hook_listener.php',
    'aiprovider_azureai_process_explain_text' => '/var/www/html/plantilla/ai/provider/azureai/classes/process_explain_text.php',
    'aiprovider_azureai_process_generate_image' => '/var/www/html/plantilla/ai/provider/azureai/classes/process_generate_image.php',
    'aiprovider_azureai_process_generate_text' => '/var/www/html/plantilla/ai/provider/azureai/classes/process_generate_text.php',
    'aiprovider_azureai_process_summarise_text' => '/var/www/html/plantilla/ai/provider/azureai/classes/process_summarise_text.php',
    'aiprovider_azureai_provider' => '/var/www/html/plantilla/ai/provider/azureai/classes/provider.php',
    'aiprovider_ollama\\abstract_processor' => '/var/www/html/plantilla/ai/provider/ollama/classes/abstract_processor.php',
    'aiprovider_ollama\\aimodel\\llama33' => '/var/www/html/plantilla/ai/provider/ollama/classes/aimodel/llama33.php',
    'aiprovider_ollama\\aimodel\\ollama_base' => '/var/www/html/plantilla/ai/provider/ollama/classes/aimodel/ollama_base.php',
    'aiprovider_ollama\\form\\action_form' => '/var/www/html/plantilla/ai/provider/ollama/classes/form/action_form.php',
    'aiprovider_ollama\\form\\action_generate_text_form' => '/var/www/html/plantilla/ai/provider/ollama/classes/form/action_generate_text_form.php',
    'aiprovider_ollama\\helper' => '/var/www/html/plantilla/ai/provider/ollama/classes/helper.php',
    'aiprovider_ollama\\hook_listener' => '/var/www/html/plantilla/ai/provider/ollama/classes/hook_listener.php',
    'aiprovider_ollama\\privacy\\provider' => '/var/www/html/plantilla/ai/provider/ollama/classes/privacy/provider.php',
    'aiprovider_ollama\\process_explain_text' => '/var/www/html/plantilla/ai/provider/ollama/classes/process_explain_text.php',
    'aiprovider_ollama\\process_generate_text' => '/var/www/html/plantilla/ai/provider/ollama/classes/process_generate_text.php',
    'aiprovider_ollama\\process_summarise_text' => '/var/www/html/plantilla/ai/provider/ollama/classes/process_summarise_text.php',
    'aiprovider_ollama\\provider' => '/var/www/html/plantilla/ai/provider/ollama/classes/provider.php',
    'aiprovider_ollama_abstract_processor' => '/var/www/html/plantilla/ai/provider/ollama/classes/abstract_processor.php',
    'aiprovider_ollama_helper' => '/var/www/html/plantilla/ai/provider/ollama/classes/helper.php',
    'aiprovider_ollama_hook_listener' => '/var/www/html/plantilla/ai/provider/ollama/classes/hook_listener.php',
    'aiprovider_ollama_process_explain_text' => '/var/www/html/plantilla/ai/provider/ollama/classes/process_explain_text.php',
    'aiprovider_ollama_process_generate_text' => '/var/www/html/plantilla/ai/provider/ollama/classes/process_generate_text.php',
    'aiprovider_ollama_process_summarise_text' => '/var/www/html/plantilla/ai/provider/ollama/classes/process_summarise_text.php',
    'aiprovider_ollama_provider' => '/var/www/html/plantilla/ai/provider/ollama/classes/provider.php',
    'aiprovider_openai\\abstract_processor' => '/var/www/html/plantilla/ai/provider/openai/classes/abstract_processor.php',
    'aiprovider_openai\\aimodel\\dalle3' => '/var/www/html/plantilla/ai/provider/openai/classes/aimodel/dalle3.php',
    'aiprovider_openai\\aimodel\\gpt4o' => '/var/www/html/plantilla/ai/provider/openai/classes/aimodel/gpt4o.php',
    'aiprovider_openai\\aimodel\\o1' => '/var/www/html/plantilla/ai/provider/openai/classes/aimodel/o1.php',
    'aiprovider_openai\\aimodel\\openai_base' => '/var/www/html/plantilla/ai/provider/openai/classes/aimodel/openai_base.php',
    'aiprovider_openai\\form\\action_form' => '/var/www/html/plantilla/ai/provider/openai/classes/form/action_form.php',
    'aiprovider_openai\\form\\action_generate_image_form' => '/var/www/html/plantilla/ai/provider/openai/classes/form/action_generate_image_form.php',
    'aiprovider_openai\\form\\action_generate_text_form' => '/var/www/html/plantilla/ai/provider/openai/classes/form/action_generate_text_form.php',
    'aiprovider_openai\\helper' => '/var/www/html/plantilla/ai/provider/openai/classes/helper.php',
    'aiprovider_openai\\hook_listener' => '/var/www/html/plantilla/ai/provider/openai/classes/hook_listener.php',
    'aiprovider_openai\\privacy\\provider' => '/var/www/html/plantilla/ai/provider/openai/classes/privacy/provider.php',
    'aiprovider_openai\\process_explain_text' => '/var/www/html/plantilla/ai/provider/openai/classes/process_explain_text.php',
    'aiprovider_openai\\process_generate_image' => '/var/www/html/plantilla/ai/provider/openai/classes/process_generate_image.php',
    'aiprovider_openai\\process_generate_text' => '/var/www/html/plantilla/ai/provider/openai/classes/process_generate_text.php',
    'aiprovider_openai\\process_summarise_text' => '/var/www/html/plantilla/ai/provider/openai/classes/process_summarise_text.php',
    'aiprovider_openai\\provider' => '/var/www/html/plantilla/ai/provider/openai/classes/provider.php',
    'aiprovider_openai\\test\\testcase_helper_trait' => '/var/www/html/plantilla/ai/provider/openai/classes/test/testcase_helper_trait.php',
    'aiprovider_openai_abstract_processor' => '/var/www/html/plantilla/ai/provider/openai/classes/abstract_processor.php',
    'aiprovider_openai_helper' => '/var/www/html/plantilla/ai/provider/openai/classes/helper.php',
    'aiprovider_openai_hook_listener' => '/var/www/html/plantilla/ai/provider/openai/classes/hook_listener.php',
    'aiprovider_openai_process_explain_text' => '/var/www/html/plantilla/ai/provider/openai/classes/process_explain_text.php',
    'aiprovider_openai_process_generate_image' => '/var/www/html/plantilla/ai/provider/openai/classes/process_generate_image.php',
    'aiprovider_openai_process_generate_text' => '/var/www/html/plantilla/ai/provider/openai/classes/process_generate_text.php',
    'aiprovider_openai_process_summarise_text' => '/var/www/html/plantilla/ai/provider/openai/classes/process_summarise_text.php',
    'aiprovider_openai_provider' => '/var/www/html/plantilla/ai/provider/openai/classes/provider.php',
    'antivirus_clamav\\privacy\\provider' => '/var/www/html/plantilla/lib/antivirus/clamav/classes/privacy/provider.php',
    'antivirus_clamav\\scanner' => '/var/www/html/plantilla/lib/antivirus/clamav/classes/scanner.php',
    'antivirus_clamav_scanner' => '/var/www/html/plantilla/lib/antivirus/clamav/classes/scanner.php',
    'assignfeedback_comments\\privacy\\provider' => '/var/www/html/plantilla/mod/assign/feedback/comments/classes/privacy/provider.php',
    'assignfeedback_editpdf\\annotation' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/annotation.php',
    'assignfeedback_editpdf\\combined_document' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/combined_document.php',
    'assignfeedback_editpdf\\comment' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/comment.php',
    'assignfeedback_editpdf\\comments_quick_list' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/comments_quick_list.php',
    'assignfeedback_editpdf\\document_services' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/document_services.php',
    'assignfeedback_editpdf\\event\\observer' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/event/observer.php',
    'assignfeedback_editpdf\\page_editor' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/page_editor.php',
    'assignfeedback_editpdf\\pdf' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/pdf.php',
    'assignfeedback_editpdf\\privacy\\provider' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/privacy/provider.php',
    'assignfeedback_editpdf\\renderer' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/renderer.php',
    'assignfeedback_editpdf\\task\\bump_submission_for_stale_conversions' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/task/bump_submission_for_stale_conversions.php',
    'assignfeedback_editpdf\\task\\convert_submission' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/task/convert_submission.php',
    'assignfeedback_editpdf\\task\\remove_orphaned_editpdf_files' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/task/remove_orphaned_editpdf_files.php',
    'assignfeedback_editpdf\\widget' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/widget.php',
    'assignfeedback_editpdf_annotation' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/annotation.php',
    'assignfeedback_editpdf_combined_document' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/combined_document.php',
    'assignfeedback_editpdf_comment' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/comment.php',
    'assignfeedback_editpdf_comments_quick_list' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/comments_quick_list.php',
    'assignfeedback_editpdf_document_services' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/document_services.php',
    'assignfeedback_editpdf_page_editor' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/page_editor.php',
    'assignfeedback_editpdf_pdf' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/pdf.php',
    'assignfeedback_editpdf_renderer' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/renderer.php',
    'assignfeedback_editpdf_widget' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/classes/widget.php',
    'assignfeedback_file\\privacy\\provider' => '/var/www/html/plantilla/mod/assign/feedback/file/classes/privacy/provider.php',
    'assignfeedback_offline\\privacy\\provider' => '/var/www/html/plantilla/mod/assign/feedback/offline/classes/privacy/provider.php',
    'assignsubmission_comments\\event\\comment_created' => '/var/www/html/plantilla/mod/assign/submission/comments/classes/event/comment_created.php',
    'assignsubmission_comments\\event\\comment_deleted' => '/var/www/html/plantilla/mod/assign/submission/comments/classes/event/comment_deleted.php',
    'assignsubmission_comments\\privacy\\provider' => '/var/www/html/plantilla/mod/assign/submission/comments/classes/privacy/provider.php',
    'assignsubmission_file\\event\\assessable_uploaded' => '/var/www/html/plantilla/mod/assign/submission/file/classes/event/assessable_uploaded.php',
    'assignsubmission_file\\event\\submission_created' => '/var/www/html/plantilla/mod/assign/submission/file/classes/event/submission_created.php',
    'assignsubmission_file\\event\\submission_updated' => '/var/www/html/plantilla/mod/assign/submission/file/classes/event/submission_updated.php',
    'assignsubmission_file\\privacy\\provider' => '/var/www/html/plantilla/mod/assign/submission/file/classes/privacy/provider.php',
    'assignsubmission_onlinetext\\event\\assessable_uploaded' => '/var/www/html/plantilla/mod/assign/submission/onlinetext/classes/event/assessable_uploaded.php',
    'assignsubmission_onlinetext\\event\\submission_created' => '/var/www/html/plantilla/mod/assign/submission/onlinetext/classes/event/submission_created.php',
    'assignsubmission_onlinetext\\event\\submission_updated' => '/var/www/html/plantilla/mod/assign/submission/onlinetext/classes/event/submission_updated.php',
    'assignsubmission_onlinetext\\privacy\\provider' => '/var/www/html/plantilla/mod/assign/submission/onlinetext/classes/privacy/provider.php',
    'auth_db\\admin_setting_special_auth_configtext' => '/var/www/html/plantilla/auth/db/classes/admin_setting_special_auth_configtext.php',
    'auth_db\\privacy\\provider' => '/var/www/html/plantilla/auth/db/classes/privacy/provider.php',
    'auth_db\\task\\sync_users' => '/var/www/html/plantilla/auth/db/classes/task/sync_users.php',
    'auth_db_admin_setting_special_auth_configtext' => '/var/www/html/plantilla/auth/db/classes/admin_setting_special_auth_configtext.php',
    'auth_email\\external' => '/var/www/html/plantilla/auth/email/classes/external.php',
    'auth_email\\privacy\\provider' => '/var/www/html/plantilla/auth/email/classes/privacy/provider.php',
    'auth_email_external' => '/var/www/html/plantilla/auth/email/classes/external.php',
    'auth_ldap\\admin_setting_special_contexts_configtext' => '/var/www/html/plantilla/auth/ldap/classes/admin_setting_special_contexts_configtext.php',
    'auth_ldap\\admin_setting_special_lowercase_configtext' => '/var/www/html/plantilla/auth/ldap/classes/admin_setting_special_lowercase_configtext.php',
    'auth_ldap\\admin_setting_special_ntlm_configtext' => '/var/www/html/plantilla/auth/ldap/classes/admin_setting_special_ntlm_configtext.php',
    'auth_ldap\\adminpresets\\adminpresets_auth_ldap_admin_setting_special_contexts_configtext' => '/var/www/html/plantilla/auth/ldap/classes/adminpresets/adminpresets_auth_ldap_admin_setting_special_contexts_configtext.php',
    'auth_ldap\\privacy\\provider' => '/var/www/html/plantilla/auth/ldap/classes/privacy/provider.php',
    'auth_ldap\\task\\asynchronous_sync_task' => '/var/www/html/plantilla/auth/ldap/classes/task/asynchronous_sync_task.php',
    'auth_ldap\\task\\sync_roles' => '/var/www/html/plantilla/auth/ldap/classes/task/sync_roles.php',
    'auth_ldap\\task\\sync_task' => '/var/www/html/plantilla/auth/ldap/classes/task/sync_task.php',
    'auth_ldap_admin_setting_special_contexts_configtext' => '/var/www/html/plantilla/auth/ldap/classes/admin_setting_special_contexts_configtext.php',
    'auth_ldap_admin_setting_special_lowercase_configtext' => '/var/www/html/plantilla/auth/ldap/classes/admin_setting_special_lowercase_configtext.php',
    'auth_ldap_admin_setting_special_ntlm_configtext' => '/var/www/html/plantilla/auth/ldap/classes/admin_setting_special_ntlm_configtext.php',
    'auth_lti\\local\\ltiadvantage\\entity\\user_migration_claim' => '/var/www/html/plantilla/auth/lti/classes/local/ltiadvantage/entity/user_migration_claim.php',
    'auth_lti\\local\\ltiadvantage\\event\\event_handler' => '/var/www/html/plantilla/auth/lti/classes/local/ltiadvantage/event/event_handler.php',
    'auth_lti\\local\\ltiadvantage\\utility\\cookie_helper' => '/var/www/html/plantilla/auth/lti/classes/local/ltiadvantage/utility/cookie_helper.php',
    'auth_lti\\output\\renderer' => '/var/www/html/plantilla/auth/lti/classes/output/renderer.php',
    'auth_lti\\privacy\\provider' => '/var/www/html/plantilla/auth/lti/classes/privacy/provider.php',
    'auth_manual\\privacy\\provider' => '/var/www/html/plantilla/auth/manual/classes/privacy/provider.php',
    'auth_nologin\\privacy\\provider' => '/var/www/html/plantilla/auth/nologin/classes/privacy/provider.php',
    'auth_none\\check\\noauth' => '/var/www/html/plantilla/auth/none/classes/check/noauth.php',
    'auth_none\\privacy\\provider' => '/var/www/html/plantilla/auth/none/classes/privacy/provider.php',
    'auth_oauth2\\api' => '/var/www/html/plantilla/auth/oauth2/classes/api.php',
    'auth_oauth2\\auth' => '/var/www/html/plantilla/auth/oauth2/classes/auth.php',
    'auth_oauth2\\linked_login' => '/var/www/html/plantilla/auth/oauth2/classes/linked_login.php',
    'auth_oauth2\\output\\renderer' => '/var/www/html/plantilla/auth/oauth2/classes/output/renderer.php',
    'auth_oauth2\\privacy\\provider' => '/var/www/html/plantilla/auth/oauth2/classes/privacy/provider.php',
    'auth_oauth2_api' => '/var/www/html/plantilla/auth/oauth2/classes/api.php',
    'auth_oauth2_auth' => '/var/www/html/plantilla/auth/oauth2/classes/auth.php',
    'auth_oauth2_linked_login' => '/var/www/html/plantilla/auth/oauth2/classes/linked_login.php',
    'auth_shibboleth\\admin_setting_special_convert_data_configfile' => '/var/www/html/plantilla/auth/shibboleth/classes/admin_setting_special_convert_data_configfile.php',
    'auth_shibboleth\\admin_setting_special_idp_configtextarea' => '/var/www/html/plantilla/auth/shibboleth/classes/admin_setting_special_idp_configtextarea.php',
    'auth_shibboleth\\admin_setting_special_wayf_select' => '/var/www/html/plantilla/auth/shibboleth/classes/admin_setting_special_wayf_select.php',
    'auth_shibboleth\\helper' => '/var/www/html/plantilla/auth/shibboleth/classes/helper.php',
    'auth_shibboleth\\privacy\\provider' => '/var/www/html/plantilla/auth/shibboleth/classes/privacy/provider.php',
    'auth_shibboleth_admin_setting_special_convert_data_configfile' => '/var/www/html/plantilla/auth/shibboleth/classes/admin_setting_special_convert_data_configfile.php',
    'auth_shibboleth_admin_setting_special_idp_configtextarea' => '/var/www/html/plantilla/auth/shibboleth/classes/admin_setting_special_idp_configtextarea.php',
    'auth_shibboleth_admin_setting_special_wayf_select' => '/var/www/html/plantilla/auth/shibboleth/classes/admin_setting_special_wayf_select.php',
    'auth_shibboleth_helper' => '/var/www/html/plantilla/auth/shibboleth/classes/helper.php',
    'auth_webservice\\privacy\\provider' => '/var/www/html/plantilla/auth/webservice/classes/privacy/provider.php',
    'availability_completion\\condition' => '/var/www/html/plantilla/availability/condition/completion/classes/condition.php',
    'availability_completion\\frontend' => '/var/www/html/plantilla/availability/condition/completion/classes/frontend.php',
    'availability_completion\\privacy\\provider' => '/var/www/html/plantilla/availability/condition/completion/classes/privacy/provider.php',
    'availability_completion_condition' => '/var/www/html/plantilla/availability/condition/completion/classes/condition.php',
    'availability_completion_frontend' => '/var/www/html/plantilla/availability/condition/completion/classes/frontend.php',
    'availability_date\\condition' => '/var/www/html/plantilla/availability/condition/date/classes/condition.php',
    'availability_date\\frontend' => '/var/www/html/plantilla/availability/condition/date/classes/frontend.php',
    'availability_date\\privacy\\provider' => '/var/www/html/plantilla/availability/condition/date/classes/privacy/provider.php',
    'availability_date_condition' => '/var/www/html/plantilla/availability/condition/date/classes/condition.php',
    'availability_date_frontend' => '/var/www/html/plantilla/availability/condition/date/classes/frontend.php',
    'availability_grade\\callbacks' => '/var/www/html/plantilla/availability/condition/grade/classes/callbacks.php',
    'availability_grade\\condition' => '/var/www/html/plantilla/availability/condition/grade/classes/condition.php',
    'availability_grade\\frontend' => '/var/www/html/plantilla/availability/condition/grade/classes/frontend.php',
    'availability_grade\\privacy\\provider' => '/var/www/html/plantilla/availability/condition/grade/classes/privacy/provider.php',
    'availability_grade_callbacks' => '/var/www/html/plantilla/availability/condition/grade/classes/callbacks.php',
    'availability_grade_condition' => '/var/www/html/plantilla/availability/condition/grade/classes/condition.php',
    'availability_grade_frontend' => '/var/www/html/plantilla/availability/condition/grade/classes/frontend.php',
    'availability_group\\condition' => '/var/www/html/plantilla/availability/condition/group/classes/condition.php',
    'availability_group\\frontend' => '/var/www/html/plantilla/availability/condition/group/classes/frontend.php',
    'availability_group\\privacy\\provider' => '/var/www/html/plantilla/availability/condition/group/classes/privacy/provider.php',
    'availability_group_condition' => '/var/www/html/plantilla/availability/condition/group/classes/condition.php',
    'availability_group_frontend' => '/var/www/html/plantilla/availability/condition/group/classes/frontend.php',
    'availability_grouping\\condition' => '/var/www/html/plantilla/availability/condition/grouping/classes/condition.php',
    'availability_grouping\\frontend' => '/var/www/html/plantilla/availability/condition/grouping/classes/frontend.php',
    'availability_grouping\\privacy\\provider' => '/var/www/html/plantilla/availability/condition/grouping/classes/privacy/provider.php',
    'availability_grouping_condition' => '/var/www/html/plantilla/availability/condition/grouping/classes/condition.php',
    'availability_grouping_frontend' => '/var/www/html/plantilla/availability/condition/grouping/classes/frontend.php',
    'availability_profile\\condition' => '/var/www/html/plantilla/availability/condition/profile/classes/condition.php',
    'availability_profile\\frontend' => '/var/www/html/plantilla/availability/condition/profile/classes/frontend.php',
    'availability_profile\\privacy\\provider' => '/var/www/html/plantilla/availability/condition/profile/classes/privacy/provider.php',
    'availability_profile_condition' => '/var/www/html/plantilla/availability/condition/profile/classes/condition.php',
    'availability_profile_frontend' => '/var/www/html/plantilla/availability/condition/profile/classes/frontend.php',
    'block_accessreview\\external\\get_module_data' => '/var/www/html/plantilla/blocks/accessreview/classes/external/get_module_data.php',
    'block_accessreview\\external\\get_section_data' => '/var/www/html/plantilla/blocks/accessreview/classes/external/get_section_data.php',
    'block_accessreview\\privacy\\provider' => '/var/www/html/plantilla/blocks/accessreview/classes/privacy/provider.php',
    'block_activity_modules\\privacy\\provider' => '/var/www/html/plantilla/blocks/activity_modules/classes/privacy/provider.php',
    'block_activity_results\\privacy\\provider' => '/var/www/html/plantilla/blocks/activity_results/classes/privacy/provider.php',
    'block_admin_bookmarks\\privacy\\provider' => '/var/www/html/plantilla/blocks/admin_bookmarks/classes/privacy/provider.php',
    'block_badges\\privacy\\provider' => '/var/www/html/plantilla/blocks/badges/classes/privacy/provider.php',
    'block_blog_menu\\privacy\\provider' => '/var/www/html/plantilla/blocks/blog_menu/classes/privacy/provider.php',
    'block_blog_recent\\privacy\\provider' => '/var/www/html/plantilla/blocks/blog_recent/classes/privacy/provider.php',
    'block_blog_tags\\privacy\\provider' => '/var/www/html/plantilla/blocks/blog_tags/classes/privacy/provider.php',
    'block_calendar_month\\privacy\\provider' => '/var/www/html/plantilla/blocks/calendar_month/classes/privacy/provider.php',
    'block_calendar_upcoming\\privacy\\provider' => '/var/www/html/plantilla/blocks/calendar_upcoming/classes/privacy/provider.php',
    'block_comments\\event\\comment_created' => '/var/www/html/plantilla/blocks/comments/classes/event/comment_created.php',
    'block_comments\\event\\comment_deleted' => '/var/www/html/plantilla/blocks/comments/classes/event/comment_deleted.php',
    'block_comments\\privacy\\provider' => '/var/www/html/plantilla/blocks/comments/classes/privacy/provider.php',
    'block_completionstatus\\privacy\\provider' => '/var/www/html/plantilla/blocks/completionstatus/classes/privacy/provider.php',
    'block_configurable_reports\\check\\sql_execution' => '/var/www/html/plantilla/blocks/configurable_reports/classes/check/sql_execution.php',
    'block_configurable_reports\\external' => '/var/www/html/plantilla/blocks/configurable_reports/classes/external.php',
    'block_configurable_reports\\github' => '/var/www/html/plantilla/blocks/configurable_reports/classes/github.php',
    'block_configurable_reports\\privacy\\provider' => '/var/www/html/plantilla/blocks/configurable_reports/classes/privacy/provider.php',
    'block_configurable_reports_external' => '/var/www/html/plantilla/blocks/configurable_reports/classes/external.php',
    'block_configurable_reports_github' => '/var/www/html/plantilla/blocks/configurable_reports/classes/github.php',
    'block_contents' => '/var/www/html/plantilla/blocks/classes/output/block_contents.php',
    'block_course_list\\privacy\\provider' => '/var/www/html/plantilla/blocks/course_list/classes/privacy/provider.php',
    'block_course_summary\\privacy\\provider' => '/var/www/html/plantilla/blocks/course_summary/classes/privacy/provider.php',
    'block_feedback\\privacy\\provider' => '/var/www/html/plantilla/blocks/feedback/classes/privacy/provider.php',
    'block_globalsearch\\privacy\\provider' => '/var/www/html/plantilla/blocks/globalsearch/classes/privacy/provider.php',
    'block_glossary_random\\privacy\\provider' => '/var/www/html/plantilla/blocks/glossary_random/classes/privacy/provider.php',
    'block_html\\privacy\\provider' => '/var/www/html/plantilla/blocks/html/classes/privacy/provider.php',
    'block_html\\search\\content' => '/var/www/html/plantilla/blocks/html/classes/search/content.php',
    'block_login\\privacy\\provider' => '/var/www/html/plantilla/blocks/login/classes/privacy/provider.php',
    'block_lp\\output\\competencies_to_review_page' => '/var/www/html/plantilla/blocks/lp/classes/output/competencies_to_review_page.php',
    'block_lp\\output\\plans_to_review_page' => '/var/www/html/plantilla/blocks/lp/classes/output/plans_to_review_page.php',
    'block_lp\\output\\renderer' => '/var/www/html/plantilla/blocks/lp/classes/output/renderer.php',
    'block_lp\\output\\summary' => '/var/www/html/plantilla/blocks/lp/classes/output/summary.php',
    'block_lp\\privacy\\provider' => '/var/www/html/plantilla/blocks/lp/classes/privacy/provider.php',
    'block_mentees\\privacy\\provider' => '/var/www/html/plantilla/blocks/mentees/classes/privacy/provider.php',
    'block_move_target' => '/var/www/html/plantilla/blocks/classes/output/block_move_target.php',
    'block_myoverview\\output\\main' => '/var/www/html/plantilla/blocks/myoverview/classes/output/main.php',
    'block_myoverview\\output\\renderer' => '/var/www/html/plantilla/blocks/myoverview/classes/output/renderer.php',
    'block_myoverview\\privacy\\provider' => '/var/www/html/plantilla/blocks/myoverview/classes/privacy/provider.php',
    'block_myprofile\\output\\myprofile' => '/var/www/html/plantilla/blocks/myprofile/classes/output/myprofile.php',
    'block_myprofile\\output\\renderer' => '/var/www/html/plantilla/blocks/myprofile/classes/output/renderer.php',
    'block_myprofile\\privacy\\provider' => '/var/www/html/plantilla/blocks/myprofile/classes/privacy/provider.php',
    'block_navigation\\privacy\\provider' => '/var/www/html/plantilla/blocks/navigation/classes/privacy/provider.php',
    'block_news_items\\privacy\\provider' => '/var/www/html/plantilla/blocks/news_items/classes/privacy/provider.php',
    'block_online_users\\fetcher' => '/var/www/html/plantilla/blocks/online_users/classes/fetcher.php',
    'block_online_users\\privacy\\provider' => '/var/www/html/plantilla/blocks/online_users/classes/privacy/provider.php',
    'block_online_users_fetcher' => '/var/www/html/plantilla/blocks/online_users/classes/fetcher.php',
    'block_private_files\\privacy\\provider' => '/var/www/html/plantilla/blocks/private_files/classes/privacy/provider.php',
    'block_recent_activity\\observer' => '/var/www/html/plantilla/blocks/recent_activity/classes/observer.php',
    'block_recent_activity\\privacy\\provider' => '/var/www/html/plantilla/blocks/recent_activity/classes/privacy/provider.php',
    'block_recent_activity\\task\\cleanup' => '/var/www/html/plantilla/blocks/recent_activity/classes/task/cleanup.php',
    'block_recent_activity_observer' => '/var/www/html/plantilla/blocks/recent_activity/classes/observer.php',
    'block_recentlyaccessedcourses\\output\\main' => '/var/www/html/plantilla/blocks/recentlyaccessedcourses/classes/output/main.php',
    'block_recentlyaccessedcourses\\output\\renderer' => '/var/www/html/plantilla/blocks/recentlyaccessedcourses/classes/output/renderer.php',
    'block_recentlyaccessedcourses\\privacy\\provider' => '/var/www/html/plantilla/blocks/recentlyaccessedcourses/classes/privacy/provider.php',
    'block_recentlyaccesseditems\\external' => '/var/www/html/plantilla/blocks/recentlyaccesseditems/classes/external.php',
    'block_recentlyaccesseditems\\external\\recentlyaccesseditems_item_exporter' => '/var/www/html/plantilla/blocks/recentlyaccesseditems/classes/external/recentlyaccesseditems_item_exporter.php',
    'block_recentlyaccesseditems\\helper' => '/var/www/html/plantilla/blocks/recentlyaccesseditems/classes/helper.php',
    'block_recentlyaccesseditems\\observer' => '/var/www/html/plantilla/blocks/recentlyaccesseditems/classes/observer.php',
    'block_recentlyaccesseditems\\output\\main' => '/var/www/html/plantilla/blocks/recentlyaccesseditems/classes/output/main.php',
    'block_recentlyaccesseditems\\output\\renderer' => '/var/www/html/plantilla/blocks/recentlyaccesseditems/classes/output/renderer.php',
    'block_recentlyaccesseditems\\privacy\\provider' => '/var/www/html/plantilla/blocks/recentlyaccesseditems/classes/privacy/provider.php',
    'block_recentlyaccesseditems_external' => '/var/www/html/plantilla/blocks/recentlyaccesseditems/classes/external.php',
    'block_recentlyaccesseditems_helper' => '/var/www/html/plantilla/blocks/recentlyaccesseditems/classes/helper.php',
    'block_recentlyaccesseditems_observer' => '/var/www/html/plantilla/blocks/recentlyaccesseditems/classes/observer.php',
    'block_rss_client\\output\\block' => '/var/www/html/plantilla/blocks/rss_client/classes/output/block.php',
    'block_rss_client\\output\\channel_image' => '/var/www/html/plantilla/blocks/rss_client/classes/output/channel_image.php',
    'block_rss_client\\output\\feed' => '/var/www/html/plantilla/blocks/rss_client/classes/output/feed.php',
    'block_rss_client\\output\\footer' => '/var/www/html/plantilla/blocks/rss_client/classes/output/footer.php',
    'block_rss_client\\output\\item' => '/var/www/html/plantilla/blocks/rss_client/classes/output/item.php',
    'block_rss_client\\output\\renderer' => '/var/www/html/plantilla/blocks/rss_client/classes/output/renderer.php',
    'block_rss_client\\privacy\\provider' => '/var/www/html/plantilla/blocks/rss_client/classes/privacy/provider.php',
    'block_rss_client\\task\\refreshfeeds' => '/var/www/html/plantilla/blocks/rss_client/classes/task/refreshfeeds.php',
    'block_search_forums\\output\\renderer' => '/var/www/html/plantilla/blocks/search_forums/classes/output/renderer.php',
    'block_search_forums\\output\\search_form' => '/var/www/html/plantilla/blocks/search_forums/classes/output/search_form.php',
    'block_search_forums\\privacy\\provider' => '/var/www/html/plantilla/blocks/search_forums/classes/privacy/provider.php',
    'block_section_links\\privacy\\provider' => '/var/www/html/plantilla/blocks/section_links/classes/privacy/provider.php',
    'block_selfcompletion\\privacy\\provider' => '/var/www/html/plantilla/blocks/selfcompletion/classes/privacy/provider.php',
    'block_settings\\privacy\\provider' => '/var/www/html/plantilla/blocks/settings/classes/privacy/provider.php',
    'block_site_main_menu\\output\\mainsection' => '/var/www/html/plantilla/blocks/site_main_menu/classes/output/mainsection.php',
    'block_site_main_menu\\privacy\\provider' => '/var/www/html/plantilla/blocks/site_main_menu/classes/privacy/provider.php',
    'block_social_activities\\output\\blocksection' => '/var/www/html/plantilla/blocks/social_activities/classes/output/blocksection.php',
    'block_social_activities\\privacy\\provider' => '/var/www/html/plantilla/blocks/social_activities/classes/privacy/provider.php',
    'block_starredcourses\\external' => '/var/www/html/plantilla/blocks/starredcourses/classes/external.php',
    'block_starredcourses\\output\\main' => '/var/www/html/plantilla/blocks/starredcourses/classes/output/main.php',
    'block_starredcourses\\output\\renderer' => '/var/www/html/plantilla/blocks/starredcourses/classes/output/renderer.php',
    'block_starredcourses\\privacy\\provider' => '/var/www/html/plantilla/blocks/starredcourses/classes/privacy/provider.php',
    'block_starredcourses_external' => '/var/www/html/plantilla/blocks/starredcourses/classes/external.php',
    'block_tag_flickr\\privacy\\provider' => '/var/www/html/plantilla/blocks/tag_flickr/classes/privacy/provider.php',
    'block_tag_youtube\\privacy\\provider' => '/var/www/html/plantilla/blocks/tag_youtube/classes/privacy/provider.php',
    'block_tags\\privacy\\provider' => '/var/www/html/plantilla/blocks/tags/classes/privacy/provider.php',
    'block_timeline\\output\\main' => '/var/www/html/plantilla/blocks/timeline/classes/output/main.php',
    'block_timeline\\output\\renderer' => '/var/www/html/plantilla/blocks/timeline/classes/output/renderer.php',
    'block_timeline\\privacy\\provider' => '/var/www/html/plantilla/blocks/timeline/classes/privacy/provider.php',
    'booktool_exportimscp\\event\\book_exported' => '/var/www/html/plantilla/mod/book/tool/exportimscp/classes/event/book_exported.php',
    'booktool_exportimscp\\privacy\\provider' => '/var/www/html/plantilla/mod/book/tool/exportimscp/classes/privacy/provider.php',
    'booktool_importhtml\\privacy\\provider' => '/var/www/html/plantilla/mod/book/tool/importhtml/classes/privacy/provider.php',
    'booktool_print\\event\\book_printed' => '/var/www/html/plantilla/mod/book/tool/print/classes/event/book_printed.php',
    'booktool_print\\event\\chapter_printed' => '/var/www/html/plantilla/mod/book/tool/print/classes/event/chapter_printed.php',
    'booktool_print\\output\\print_book_chapter_page' => '/var/www/html/plantilla/mod/book/tool/print/classes/output/print_book_chapter_page.php',
    'booktool_print\\output\\print_book_page' => '/var/www/html/plantilla/mod/book/tool/print/classes/output/print_book_page.php',
    'booktool_print\\output\\renderer' => '/var/www/html/plantilla/mod/book/tool/print/classes/output/renderer.php',
    'booktool_print\\privacy\\provider' => '/var/www/html/plantilla/mod/book/tool/print/classes/privacy/provider.php',
    'bootstrap_renderer' => '/var/www/html/plantilla/lib/classes/output/bootstrap_renderer.php',
    'cache' => '/var/www/html/plantilla/cache/classes/cache.php',
    'cache_application' => '/var/www/html/plantilla/cache/classes/application_cache.php',
    'cache_cached_object' => '/var/www/html/plantilla/cache/classes/cached_object.php',
    'cache_config' => '/var/www/html/plantilla/cache/classes/config.php',
    'cache_config_disabled' => '/var/www/html/plantilla/cache/classes/disabled_config.php',
    'cache_config_writer' => '/var/www/html/plantilla/cache/classes/config_writer.php',
    'cache_data_source' => '/var/www/html/plantilla/cache/classes/data_source_interface.php',
    'cache_data_source_versionable' => '/var/www/html/plantilla/cache/classes/versionable_data_source_interface.php',
    'cache_definition' => '/var/www/html/plantilla/cache/classes/definition.php',
    'cache_definition_mappings_form' => '/var/www/html/plantilla/cache/classes/form/cache_definition_mappings_form.php',
    'cache_definition_sharing_form' => '/var/www/html/plantilla/cache/classes/form/cache_definition_sharing_form.php',
    'cache_disabled' => '/var/www/html/plantilla/cache/classes/disabled_cache.php',
    'cache_exception' => '/var/www/html/plantilla/cache/classes/exception/cache_exception.php',
    'cache_factory' => '/var/www/html/plantilla/cache/classes/factory.php',
    'cache_factory_disabled' => '/var/www/html/plantilla/cache/classes/disabled_factory.php',
    'cache_helper' => '/var/www/html/plantilla/cache/classes/helper.php',
    'cache_is_configurable' => '/var/www/html/plantilla/cache/classes/configurable_cache_interface.php',
    'cache_is_key_aware' => '/var/www/html/plantilla/cache/classes/key_aware_cache_interface.php',
    'cache_is_lockable' => '/var/www/html/plantilla/cache/classes/lockable_cache_interface.php',
    'cache_is_searchable' => '/var/www/html/plantilla/cache/classes/searchable_cache_interface.php',
    'cache_loader' => '/var/www/html/plantilla/cache/classes/loader_interface.php',
    'cache_loader_with_locking' => '/var/www/html/plantilla/cache/classes/loader_with_locking_interface.php',
    'cache_lock_form' => '/var/www/html/plantilla/cache/classes/form/cache_lock_form.php',
    'cache_lock_interface' => '/var/www/html/plantilla/cache/classes/cache_lock_interface.php',
    'cache_mode_mappings_form' => '/var/www/html/plantilla/cache/classes/form/cache_mode_mappings_form.php',
    'cache_request' => '/var/www/html/plantilla/cache/classes/request_cache.php',
    'cache_session' => '/var/www/html/plantilla/cache/classes/session_cache.php',
    'cache_store' => '/var/www/html/plantilla/cache/classes/store.php',
    'cache_store_interface' => '/var/www/html/plantilla/cache/classes/store_interface.php',
    'cache_ttl_wrapper' => '/var/www/html/plantilla/cache/classes/ttl_wrapper.php',
    'cacheable_object' => '/var/www/html/plantilla/cache/classes/cacheable_object_interface.php',
    'cacheable_object_array' => '/var/www/html/plantilla/cache/classes/cacheable_object_array.php',
    'cachelock_file\\privacy\\provider' => '/var/www/html/plantilla/cache/locks/file/classes/privacy/provider.php',
    'cachestore_addinstance_form' => '/var/www/html/plantilla/cache/classes/form/cachestore_addinstance_form.php',
    'cachestore_apcu\\privacy\\provider' => '/var/www/html/plantilla/cache/stores/apcu/classes/privacy/provider.php',
    'cachestore_file\\privacy\\provider' => '/var/www/html/plantilla/cache/stores/file/classes/privacy/provider.php',
    'cachestore_file\\task\\asyncpurge' => '/var/www/html/plantilla/cache/stores/file/classes/task/asyncpurge.php',
    'cachestore_redis\\privacy\\provider' => '/var/www/html/plantilla/cache/stores/redis/classes/privacy/provider.php',
    'cachestore_redis\\task\\ttl' => '/var/www/html/plantilla/cache/stores/redis/classes/task/ttl.php',
    'cachestore_session\\privacy\\provider' => '/var/www/html/plantilla/cache/stores/session/classes/privacy/provider.php',
    'cachestore_static\\privacy\\provider' => '/var/www/html/plantilla/cache/stores/static/classes/privacy/provider.php',
    'calendartype_gregorian\\privacy\\provider' => '/var/www/html/plantilla/calendar/type/gregorian/classes/privacy/provider.php',
    'calendartype_gregorian\\structure' => '/var/www/html/plantilla/calendar/type/gregorian/classes/structure.php',
    'calendartype_gregorian_structure' => '/var/www/html/plantilla/calendar/type/gregorian/classes/structure.php',
    'coding_exception' => '/var/www/html/plantilla/lib/classes/exception/coding_exception.php',
    'combined_progress_trace' => '/var/www/html/plantilla/lib/classes/output/progress_trace/combined_progress_trace.php',
    'communication_customlink\\communication_feature' => '/var/www/html/plantilla/communication/provider/customlink/classes/communication_feature.php',
    'communication_customlink\\privacy\\provider' => '/var/www/html/plantilla/communication/provider/customlink/classes/privacy/provider.php',
    'communication_customlink_communication_feature' => '/var/www/html/plantilla/communication/provider/customlink/classes/communication_feature.php',
    'communication_matrix\\communication_feature' => '/var/www/html/plantilla/communication/provider/matrix/classes/communication_feature.php',
    'communication_matrix\\local\\command' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/command.php',
    'communication_matrix\\local\\spec\\features\\matrix\\create_room_v3' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/features/matrix/create_room_v3.php',
    'communication_matrix\\local\\spec\\features\\matrix\\get_room_members_v3' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/features/matrix/get_room_members_v3.php',
    'communication_matrix\\local\\spec\\features\\matrix\\get_room_power_levels_v3' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/features/matrix/get_room_power_levels_v3.php',
    'communication_matrix\\local\\spec\\features\\matrix\\get_room_powerlevels_from_sync_v3' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/features/matrix/get_room_powerlevels_from_sync_v3.php',
    'communication_matrix\\local\\spec\\features\\matrix\\media_create_v1' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/features/matrix/media_create_v1.php',
    'communication_matrix\\local\\spec\\features\\matrix\\remove_member_from_room_v3' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/features/matrix/remove_member_from_room_v3.php',
    'communication_matrix\\local\\spec\\features\\matrix\\update_room_avatar_v3' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/features/matrix/update_room_avatar_v3.php',
    'communication_matrix\\local\\spec\\features\\matrix\\update_room_name_v3' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/features/matrix/update_room_name_v3.php',
    'communication_matrix\\local\\spec\\features\\matrix\\update_room_power_levels_v3' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/features/matrix/update_room_power_levels_v3.php',
    'communication_matrix\\local\\spec\\features\\matrix\\update_room_topic_v3' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/features/matrix/update_room_topic_v3.php',
    'communication_matrix\\local\\spec\\features\\matrix\\upload_content_v3' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/features/matrix/upload_content_v3.php',
    'communication_matrix\\local\\spec\\features\\synapse\\create_user_v2' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/features/synapse/create_user_v2.php',
    'communication_matrix\\local\\spec\\features\\synapse\\get_room_info_v1' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/features/synapse/get_room_info_v1.php',
    'communication_matrix\\local\\spec\\features\\synapse\\get_user_info_v2' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/features/synapse/get_user_info_v2.php',
    'communication_matrix\\local\\spec\\features\\synapse\\invite_member_to_room_v1' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/features/synapse/invite_member_to_room_v1.php',
    'communication_matrix\\local\\spec\\v1p1' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/v1p1.php',
    'communication_matrix\\local\\spec\\v1p2' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/v1p2.php',
    'communication_matrix\\local\\spec\\v1p3' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/v1p3.php',
    'communication_matrix\\local\\spec\\v1p4' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/v1p4.php',
    'communication_matrix\\local\\spec\\v1p5' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/v1p5.php',
    'communication_matrix\\local\\spec\\v1p6' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/v1p6.php',
    'communication_matrix\\local\\spec\\v1p7' => '/var/www/html/plantilla/communication/provider/matrix/classes/local/spec/v1p7.php',
    'communication_matrix\\matrix_client' => '/var/www/html/plantilla/communication/provider/matrix/classes/matrix_client.php',
    'communication_matrix\\matrix_constants' => '/var/www/html/plantilla/communication/provider/matrix/classes/matrix_constants.php',
    'communication_matrix\\matrix_room' => '/var/www/html/plantilla/communication/provider/matrix/classes/matrix_room.php',
    'communication_matrix\\matrix_user_manager' => '/var/www/html/plantilla/communication/provider/matrix/classes/matrix_user_manager.php',
    'communication_matrix\\privacy\\provider' => '/var/www/html/plantilla/communication/provider/matrix/classes/privacy/provider.php',
    'communication_matrix_communication_feature' => '/var/www/html/plantilla/communication/provider/matrix/classes/communication_feature.php',
    'communication_matrix_matrix_client' => '/var/www/html/plantilla/communication/provider/matrix/classes/matrix_client.php',
    'communication_matrix_matrix_constants' => '/var/www/html/plantilla/communication/provider/matrix/classes/matrix_constants.php',
    'communication_matrix_matrix_room' => '/var/www/html/plantilla/communication/provider/matrix/classes/matrix_room.php',
    'communication_matrix_matrix_user_manager' => '/var/www/html/plantilla/communication/provider/matrix/classes/matrix_user_manager.php',
    'component_action' => '/var/www/html/plantilla/lib/classes/output/actions/component_action.php',
    'config_writer' => '/var/www/html/plantilla/cache/classes/config_writer.php',
    'confirm_action' => '/var/www/html/plantilla/lib/classes/output/actions/confirm_action.php',
    'contenttype_h5p\\content' => '/var/www/html/plantilla/contentbank/contenttype/h5p/classes/content.php',
    'contenttype_h5p\\contenttype' => '/var/www/html/plantilla/contentbank/contenttype/h5p/classes/contenttype.php',
    'contenttype_h5p\\form\\editor' => '/var/www/html/plantilla/contentbank/contenttype/h5p/classes/form/editor.php',
    'contenttype_h5p\\privacy\\provider' => '/var/www/html/plantilla/contentbank/contenttype/h5p/classes/privacy/provider.php',
    'contenttype_h5p_content' => '/var/www/html/plantilla/contentbank/contenttype/h5p/classes/content.php',
    'contenttype_h5p_contenttype' => '/var/www/html/plantilla/contentbank/contenttype/h5p/classes/contenttype.php',
    'context_header' => '/var/www/html/plantilla/lib/classes/output/context_header.php',
    'core\\access\\get_user_capability_course_helper' => '/var/www/html/plantilla/lib/classes/access/get_user_capability_course_helper.php',
    'core\\activity_dates' => '/var/www/html/plantilla/lib/classes/activity_dates.php',
    'core\\analytics\\analyser\\courses' => '/var/www/html/plantilla/lib/classes/analytics/analyser/courses.php',
    'core\\analytics\\analyser\\site_courses' => '/var/www/html/plantilla/lib/classes/analytics/analyser/site_courses.php',
    'core\\analytics\\analyser\\student_enrolments' => '/var/www/html/plantilla/lib/classes/analytics/analyser/student_enrolments.php',
    'core\\analytics\\analyser\\users' => '/var/www/html/plantilla/lib/classes/analytics/analyser/users.php',
    'core\\analytics\\indicator\\any_access_after_end' => '/var/www/html/plantilla/lib/classes/analytics/indicator/any_access_after_end.php',
    'core\\analytics\\indicator\\any_access_before_start' => '/var/www/html/plantilla/lib/classes/analytics/indicator/any_access_before_start.php',
    'core\\analytics\\indicator\\any_course_access' => '/var/www/html/plantilla/lib/classes/analytics/indicator/any_course_access.php',
    'core\\analytics\\indicator\\any_write_action' => '/var/www/html/plantilla/lib/classes/analytics/indicator/any_write_action.php',
    'core\\analytics\\indicator\\any_write_action_in_course' => '/var/www/html/plantilla/lib/classes/analytics/indicator/any_write_action_in_course.php',
    'core\\analytics\\indicator\\read_actions' => '/var/www/html/plantilla/lib/classes/analytics/indicator/read_actions.php',
    'core\\analytics\\time_splitting\\deciles' => '/var/www/html/plantilla/lib/classes/analytics/time_splitting/deciles.php',
    'core\\analytics\\time_splitting\\deciles_accum' => '/var/www/html/plantilla/lib/classes/analytics/time_splitting/deciles_accum.php',
    'core\\analytics\\time_splitting\\no_splitting' => '/var/www/html/plantilla/lib/classes/analytics/time_splitting/no_splitting.php',
    'core\\analytics\\time_splitting\\one_month_after_start' => '/var/www/html/plantilla/lib/classes/analytics/time_splitting/one_month_after_start.php',
    'core\\analytics\\time_splitting\\one_week_after_start' => '/var/www/html/plantilla/lib/classes/analytics/time_splitting/one_week_after_start.php',
    'core\\analytics\\time_splitting\\past_3_days' => '/var/www/html/plantilla/lib/classes/analytics/time_splitting/past_3_days.php',
    'core\\analytics\\time_splitting\\past_month' => '/var/www/html/plantilla/lib/classes/analytics/time_splitting/past_month.php',
    'core\\analytics\\time_splitting\\past_week' => '/var/www/html/plantilla/lib/classes/analytics/time_splitting/past_week.php',
    'core\\analytics\\time_splitting\\quarters' => '/var/www/html/plantilla/lib/classes/analytics/time_splitting/quarters.php',
    'core\\analytics\\time_splitting\\quarters_accum' => '/var/www/html/plantilla/lib/classes/analytics/time_splitting/quarters_accum.php',
    'core\\analytics\\time_splitting\\single_range' => '/var/www/html/plantilla/lib/classes/analytics/time_splitting/single_range.php',
    'core\\analytics\\time_splitting\\ten_percent_after_start' => '/var/www/html/plantilla/lib/classes/analytics/time_splitting/ten_percent_after_start.php',
    'core\\analytics\\time_splitting\\upcoming_3_days' => '/var/www/html/plantilla/lib/classes/analytics/time_splitting/upcoming_3_days.php',
    'core\\analytics\\time_splitting\\upcoming_fortnight' => '/var/www/html/plantilla/lib/classes/analytics/time_splitting/upcoming_fortnight.php',
    'core\\analytics\\time_splitting\\upcoming_week' => '/var/www/html/plantilla/lib/classes/analytics/time_splitting/upcoming_week.php',
    'core\\antivirus\\manager' => '/var/www/html/plantilla/lib/classes/antivirus/manager.php',
    'core\\antivirus\\quarantine' => '/var/www/html/plantilla/lib/classes/antivirus/quarantine.php',
    'core\\antivirus\\scanner' => '/var/www/html/plantilla/lib/classes/antivirus/scanner.php',
    'core\\antivirus\\scanner_exception' => '/var/www/html/plantilla/lib/classes/antivirus/scanner_exception.php',
    'core\\attribute\\deprecated' => '/var/www/html/plantilla/lib/classes/attribute/deprecated.php',
    'core\\attribute\\deprecated_with_reference' => '/var/www/html/plantilla/lib/classes/attribute/deprecated_with_reference.php',
    'core\\attribute\\example' => '/var/www/html/plantilla/lib/classes/attribute/example.php',
    'core\\attribute\\hook\\replaces_callbacks' => '/var/www/html/plantilla/lib/classes/attribute/hook/replaces_callbacks.php',
    'core\\attribute\\label' => '/var/www/html/plantilla/lib/classes/attribute/label.php',
    'core\\attribute\\tags' => '/var/www/html/plantilla/lib/classes/attribute/tags.php',
    'core\\attribute_helper' => '/var/www/html/plantilla/lib/classes/attribute_helper.php',
    'core\\aws\\admin_settings_aws_region' => '/var/www/html/plantilla/lib/classes/aws/admin_settings_aws_region.php',
    'core\\aws\\aws_helper' => '/var/www/html/plantilla/lib/classes/aws/aws_helper.php',
    'core\\aws\\client_factory' => '/var/www/html/plantilla/lib/classes/aws/client_factory.php',
    'core\\chart_axis' => '/var/www/html/plantilla/lib/classes/chart_axis.php',
    'core\\chart_bar' => '/var/www/html/plantilla/lib/classes/chart_bar.php',
    'core\\chart_base' => '/var/www/html/plantilla/lib/classes/chart_base.php',
    'core\\chart_line' => '/var/www/html/plantilla/lib/classes/chart_line.php',
    'core\\chart_pie' => '/var/www/html/plantilla/lib/classes/chart_pie.php',
    'core\\chart_series' => '/var/www/html/plantilla/lib/classes/chart_series.php',
    'core\\check\\access\\defaultuserrole' => '/var/www/html/plantilla/lib/classes/check/access/defaultuserrole.php',
    'core\\check\\access\\frontpagerole' => '/var/www/html/plantilla/lib/classes/check/access/frontpagerole.php',
    'core\\check\\access\\guestrole' => '/var/www/html/plantilla/lib/classes/check/access/guestrole.php',
    'core\\check\\access\\riskadmin' => '/var/www/html/plantilla/lib/classes/check/access/riskadmin.php',
    'core\\check\\access\\riskbackup' => '/var/www/html/plantilla/lib/classes/check/access/riskbackup.php',
    'core\\check\\access\\riskbackup_result' => '/var/www/html/plantilla/lib/classes/check/access/riskbackup_result.php',
    'core\\check\\access\\riskxss' => '/var/www/html/plantilla/lib/classes/check/access/riskxss.php',
    'core\\check\\access\\riskxss_result' => '/var/www/html/plantilla/lib/classes/check/access/riskxss_result.php',
    'core\\check\\check' => '/var/www/html/plantilla/lib/classes/check/check.php',
    'core\\check\\environment\\antivirus' => '/var/www/html/plantilla/lib/classes/check/environment/antivirus.php',
    'core\\check\\environment\\configrw' => '/var/www/html/plantilla/lib/classes/check/environment/configrw.php',
    'core\\check\\environment\\displayerrors' => '/var/www/html/plantilla/lib/classes/check/environment/displayerrors.php',
    'core\\check\\environment\\environment' => '/var/www/html/plantilla/lib/classes/check/environment/environment.php',
    'core\\check\\environment\\preventexecpath' => '/var/www/html/plantilla/lib/classes/check/environment/preventexecpath.php',
    'core\\check\\environment\\publicpaths' => '/var/www/html/plantilla/lib/classes/check/environment/publicpaths.php',
    'core\\check\\environment\\unsecuredataroot' => '/var/www/html/plantilla/lib/classes/check/environment/unsecuredataroot.php',
    'core\\check\\environment\\upgradecheck' => '/var/www/html/plantilla/lib/classes/check/environment/upgradecheck.php',
    'core\\check\\external\\get_result_admintree' => '/var/www/html/plantilla/lib/classes/check/external/get_result_admintree.php',
    'core\\check\\http\\cookiesecure' => '/var/www/html/plantilla/lib/classes/check/http/cookiesecure.php',
    'core\\check\\manager' => '/var/www/html/plantilla/lib/classes/check/manager.php',
    'core\\check\\performance\\backups' => '/var/www/html/plantilla/lib/classes/check/performance/backups.php',
    'core\\check\\performance\\cachejs' => '/var/www/html/plantilla/lib/classes/check/performance/cachejs.php',
    'core\\check\\performance\\dbschema' => '/var/www/html/plantilla/lib/classes/check/performance/dbschema.php',
    'core\\check\\performance\\debugging' => '/var/www/html/plantilla/lib/classes/check/performance/debugging.php',
    'core\\check\\performance\\designermode' => '/var/www/html/plantilla/lib/classes/check/performance/designermode.php',
    'core\\check\\performance\\stats' => '/var/www/html/plantilla/lib/classes/check/performance/stats.php',
    'core\\check\\result' => '/var/www/html/plantilla/lib/classes/check/result.php',
    'core\\check\\security\\crawlers' => '/var/www/html/plantilla/lib/classes/check/security/crawlers.php',
    'core\\check\\security\\emailchangeconfirmation' => '/var/www/html/plantilla/lib/classes/check/security/emailchangeconfirmation.php',
    'core\\check\\security\\embed' => '/var/www/html/plantilla/lib/classes/check/security/embed.php',
    'core\\check\\security\\openprofiles' => '/var/www/html/plantilla/lib/classes/check/security/openprofiles.php',
    'core\\check\\security\\passwordpolicy' => '/var/www/html/plantilla/lib/classes/check/security/passwordpolicy.php',
    'core\\check\\security\\webcron' => '/var/www/html/plantilla/lib/classes/check/security/webcron.php',
    'core\\check\\table' => '/var/www/html/plantilla/lib/classes/check/table.php',
    'core\\clock' => '/var/www/html/plantilla/lib/classes/clock.php',
    'core\\collator' => '/var/www/html/plantilla/lib/classes/collator.php',
    'core\\component' => '/var/www/html/plantilla/lib/classes/component.php',
    'core\\content' => '/var/www/html/plantilla/lib/classes/content.php',
    'core\\content\\export\\exportable_item' => '/var/www/html/plantilla/lib/classes/content/export/exportable_item.php',
    'core\\content\\export\\exportable_items\\exportable_filearea' => '/var/www/html/plantilla/lib/classes/content/export/exportable_items/exportable_filearea.php',
    'core\\content\\export\\exportable_items\\exportable_stored_file' => '/var/www/html/plantilla/lib/classes/content/export/exportable_items/exportable_stored_file.php',
    'core\\content\\export\\exportable_items\\exportable_textarea' => '/var/www/html/plantilla/lib/classes/content/export/exportable_items/exportable_textarea.php',
    'core\\content\\export\\exported_item' => '/var/www/html/plantilla/lib/classes/content/export/exported_item.php',
    'core\\content\\export\\exporters\\abstract_mod_exporter' => '/var/www/html/plantilla/lib/classes/content/export/exporters/abstract_mod_exporter.php',
    'core\\content\\export\\exporters\\component_exporter' => '/var/www/html/plantilla/lib/classes/content/export/exporters/component_exporter.php',
    'core\\content\\export\\exporters\\course_exporter' => '/var/www/html/plantilla/lib/classes/content/export/exporters/course_exporter.php',
    'core\\content\\export\\zipwriter' => '/var/www/html/plantilla/lib/classes/content/export/zipwriter.php',
    'core\\context' => '/var/www/html/plantilla/lib/classes/context.php',
    'core\\context\\block' => '/var/www/html/plantilla/lib/classes/context/block.php',
    'core\\context\\course' => '/var/www/html/plantilla/lib/classes/context/course.php',
    'core\\context\\coursecat' => '/var/www/html/plantilla/lib/classes/context/coursecat.php',
    'core\\context\\module' => '/var/www/html/plantilla/lib/classes/context/module.php',
    'core\\context\\system' => '/var/www/html/plantilla/lib/classes/context/system.php',
    'core\\context\\user' => '/var/www/html/plantilla/lib/classes/context/user.php',
    'core\\context_helper' => '/var/www/html/plantilla/lib/classes/context_helper.php',
    'core\\cron' => '/var/www/html/plantilla/lib/classes/cron.php',
    'core\\cssparser' => '/var/www/html/plantilla/lib/classes/cssparser.php',
    'core\\dataformat' => '/var/www/html/plantilla/lib/classes/dataformat.php',
    'core\\dataformat\\base' => '/var/www/html/plantilla/lib/classes/dataformat/base.php',
    'core\\dataformat\\spout_base' => '/var/www/html/plantilla/lib/classes/dataformat/spout_base.php',
    'core\\date' => '/var/www/html/plantilla/lib/classes/date.php',
    'core\\deprecation' => '/var/www/html/plantilla/lib/classes/deprecation.php',
    'core\\di' => '/var/www/html/plantilla/lib/classes/di.php',
    'core\\dml\\recordset_walk' => '/var/www/html/plantilla/lib/classes/dml/recordset_walk.php',
    'core\\dml\\sql_join' => '/var/www/html/plantilla/lib/classes/dml/sql_join.php',
    'core\\dml\\table' => '/var/www/html/plantilla/lib/classes/dml/table.php',
    'core\\emoticon_manager' => '/var/www/html/plantilla/lib/classes/emoticon_manager.php',
    'core\\encryption' => '/var/www/html/plantilla/lib/classes/encryption.php',
    'core\\event\\antivirus_scan_data_error' => '/var/www/html/plantilla/lib/classes/event/antivirus_scan_data_error.php',
    'core\\event\\antivirus_scan_file_error' => '/var/www/html/plantilla/lib/classes/event/antivirus_scan_file_error.php',
    'core\\event\\assessable_submitted' => '/var/www/html/plantilla/lib/classes/event/assessable_submitted.php',
    'core\\event\\assessable_uploaded' => '/var/www/html/plantilla/lib/classes/event/assessable_uploaded.php',
    'core\\event\\badge_archived' => '/var/www/html/plantilla/lib/classes/event/badge_archived.php',
    'core\\event\\badge_awarded' => '/var/www/html/plantilla/lib/classes/event/badge_awarded.php',
    'core\\event\\badge_created' => '/var/www/html/plantilla/lib/classes/event/badge_created.php',
    'core\\event\\badge_criteria_created' => '/var/www/html/plantilla/lib/classes/event/badge_criteria_created.php',
    'core\\event\\badge_criteria_deleted' => '/var/www/html/plantilla/lib/classes/event/badge_criteria_deleted.php',
    'core\\event\\badge_criteria_updated' => '/var/www/html/plantilla/lib/classes/event/badge_criteria_updated.php',
    'core\\event\\badge_deleted' => '/var/www/html/plantilla/lib/classes/event/badge_deleted.php',
    'core\\event\\badge_disabled' => '/var/www/html/plantilla/lib/classes/event/badge_disabled.php',
    'core\\event\\badge_duplicated' => '/var/www/html/plantilla/lib/classes/event/badge_duplicated.php',
    'core\\event\\badge_enabled' => '/var/www/html/plantilla/lib/classes/event/badge_enabled.php',
    'core\\event\\badge_listing_viewed' => '/var/www/html/plantilla/lib/classes/event/badge_listing_viewed.php',
    'core\\event\\badge_revoked' => '/var/www/html/plantilla/lib/classes/event/badge_revoked.php',
    'core\\event\\badge_updated' => '/var/www/html/plantilla/lib/classes/event/badge_updated.php',
    'core\\event\\badge_viewed' => '/var/www/html/plantilla/lib/classes/event/badge_viewed.php',
    'core\\event\\base' => '/var/www/html/plantilla/lib/classes/event/base.php',
    'core\\event\\blog_association_created' => '/var/www/html/plantilla/lib/classes/event/blog_association_created.php',
    'core\\event\\blog_association_deleted' => '/var/www/html/plantilla/lib/classes/event/blog_association_deleted.php',
    'core\\event\\blog_comment_created' => '/var/www/html/plantilla/lib/classes/event/blog_comment_created.php',
    'core\\event\\blog_comment_deleted' => '/var/www/html/plantilla/lib/classes/event/blog_comment_deleted.php',
    'core\\event\\blog_entries_viewed' => '/var/www/html/plantilla/lib/classes/event/blog_entries_viewed.php',
    'core\\event\\blog_entry_created' => '/var/www/html/plantilla/lib/classes/event/blog_entry_created.php',
    'core\\event\\blog_entry_deleted' => '/var/www/html/plantilla/lib/classes/event/blog_entry_deleted.php',
    'core\\event\\blog_entry_updated' => '/var/www/html/plantilla/lib/classes/event/blog_entry_updated.php',
    'core\\event\\blog_external_added' => '/var/www/html/plantilla/lib/classes/event/blog_external_added.php',
    'core\\event\\blog_external_removed' => '/var/www/html/plantilla/lib/classes/event/blog_external_removed.php',
    'core\\event\\blog_external_updated' => '/var/www/html/plantilla/lib/classes/event/blog_external_updated.php',
    'core\\event\\blog_external_viewed' => '/var/www/html/plantilla/lib/classes/event/blog_external_viewed.php',
    'core\\event\\calendar_event_created' => '/var/www/html/plantilla/lib/classes/event/calendar_event_created.php',
    'core\\event\\calendar_event_deleted' => '/var/www/html/plantilla/lib/classes/event/calendar_event_deleted.php',
    'core\\event\\calendar_event_updated' => '/var/www/html/plantilla/lib/classes/event/calendar_event_updated.php',
    'core\\event\\calendar_subscription_created' => '/var/www/html/plantilla/lib/classes/event/calendar_subscription_created.php',
    'core\\event\\calendar_subscription_deleted' => '/var/www/html/plantilla/lib/classes/event/calendar_subscription_deleted.php',
    'core\\event\\calendar_subscription_updated' => '/var/www/html/plantilla/lib/classes/event/calendar_subscription_updated.php',
    'core\\event\\capability_assigned' => '/var/www/html/plantilla/lib/classes/event/capability_assigned.php',
    'core\\event\\capability_unassigned' => '/var/www/html/plantilla/lib/classes/event/capability_unassigned.php',
    'core\\event\\cohort_created' => '/var/www/html/plantilla/lib/classes/event/cohort_created.php',
    'core\\event\\cohort_deleted' => '/var/www/html/plantilla/lib/classes/event/cohort_deleted.php',
    'core\\event\\cohort_member_added' => '/var/www/html/plantilla/lib/classes/event/cohort_member_added.php',
    'core\\event\\cohort_member_removed' => '/var/www/html/plantilla/lib/classes/event/cohort_member_removed.php',
    'core\\event\\cohort_updated' => '/var/www/html/plantilla/lib/classes/event/cohort_updated.php',
    'core\\event\\comment_created' => '/var/www/html/plantilla/lib/classes/event/comment_created.php',
    'core\\event\\comment_deleted' => '/var/www/html/plantilla/lib/classes/event/comment_deleted.php',
    'core\\event\\comments_viewed' => '/var/www/html/plantilla/lib/classes/event/comments_viewed.php',
    'core\\event\\competency_comment_created' => '/var/www/html/plantilla/lib/classes/event/competency_comment_created.php',
    'core\\event\\competency_comment_deleted' => '/var/www/html/plantilla/lib/classes/event/competency_comment_deleted.php',
    'core\\event\\competency_created' => '/var/www/html/plantilla/lib/classes/event/competency_created.php',
    'core\\event\\competency_deleted' => '/var/www/html/plantilla/lib/classes/event/competency_deleted.php',
    'core\\event\\competency_evidence_created' => '/var/www/html/plantilla/lib/classes/event/competency_evidence_created.php',
    'core\\event\\competency_framework_created' => '/var/www/html/plantilla/lib/classes/event/competency_framework_created.php',
    'core\\event\\competency_framework_deleted' => '/var/www/html/plantilla/lib/classes/event/competency_framework_deleted.php',
    'core\\event\\competency_framework_updated' => '/var/www/html/plantilla/lib/classes/event/competency_framework_updated.php',
    'core\\event\\competency_framework_viewed' => '/var/www/html/plantilla/lib/classes/event/competency_framework_viewed.php',
    'core\\event\\competency_plan_approved' => '/var/www/html/plantilla/lib/classes/event/competency_plan_approved.php',
    'core\\event\\competency_plan_completed' => '/var/www/html/plantilla/lib/classes/event/competency_plan_completed.php',
    'core\\event\\competency_plan_created' => '/var/www/html/plantilla/lib/classes/event/competency_plan_created.php',
    'core\\event\\competency_plan_deleted' => '/var/www/html/plantilla/lib/classes/event/competency_plan_deleted.php',
    'core\\event\\competency_plan_reopened' => '/var/www/html/plantilla/lib/classes/event/competency_plan_reopened.php',
    'core\\event\\competency_plan_review_request_cancelled' => '/var/www/html/plantilla/lib/classes/event/competency_plan_review_request_cancelled.php',
    'core\\event\\competency_plan_review_requested' => '/var/www/html/plantilla/lib/classes/event/competency_plan_review_requested.php',
    'core\\event\\competency_plan_review_started' => '/var/www/html/plantilla/lib/classes/event/competency_plan_review_started.php',
    'core\\event\\competency_plan_review_stopped' => '/var/www/html/plantilla/lib/classes/event/competency_plan_review_stopped.php',
    'core\\event\\competency_plan_unapproved' => '/var/www/html/plantilla/lib/classes/event/competency_plan_unapproved.php',
    'core\\event\\competency_plan_unlinked' => '/var/www/html/plantilla/lib/classes/event/competency_plan_unlinked.php',
    'core\\event\\competency_plan_updated' => '/var/www/html/plantilla/lib/classes/event/competency_plan_updated.php',
    'core\\event\\competency_plan_viewed' => '/var/www/html/plantilla/lib/classes/event/competency_plan_viewed.php',
    'core\\event\\competency_template_created' => '/var/www/html/plantilla/lib/classes/event/competency_template_created.php',
    'core\\event\\competency_template_deleted' => '/var/www/html/plantilla/lib/classes/event/competency_template_deleted.php',
    'core\\event\\competency_template_updated' => '/var/www/html/plantilla/lib/classes/event/competency_template_updated.php',
    'core\\event\\competency_template_viewed' => '/var/www/html/plantilla/lib/classes/event/competency_template_viewed.php',
    'core\\event\\competency_updated' => '/var/www/html/plantilla/lib/classes/event/competency_updated.php',
    'core\\event\\competency_user_competency_plan_viewed' => '/var/www/html/plantilla/lib/classes/event/competency_user_competency_plan_viewed.php',
    'core\\event\\competency_user_competency_rated' => '/var/www/html/plantilla/lib/classes/event/competency_user_competency_rated.php',
    'core\\event\\competency_user_competency_rated_in_course' => '/var/www/html/plantilla/lib/classes/event/competency_user_competency_rated_in_course.php',
    'core\\event\\competency_user_competency_rated_in_plan' => '/var/www/html/plantilla/lib/classes/event/competency_user_competency_rated_in_plan.php',
    'core\\event\\competency_user_competency_review_request_cancelled' => '/var/www/html/plantilla/lib/classes/event/competency_user_competency_review_request_cancelled.php',
    'core\\event\\competency_user_competency_review_requested' => '/var/www/html/plantilla/lib/classes/event/competency_user_competency_review_requested.php',
    'core\\event\\competency_user_competency_review_started' => '/var/www/html/plantilla/lib/classes/event/competency_user_competency_review_started.php',
    'core\\event\\competency_user_competency_review_stopped' => '/var/www/html/plantilla/lib/classes/event/competency_user_competency_review_stopped.php',
    'core\\event\\competency_user_competency_viewed' => '/var/www/html/plantilla/lib/classes/event/competency_user_competency_viewed.php',
    'core\\event\\competency_user_competency_viewed_in_course' => '/var/www/html/plantilla/lib/classes/event/competency_user_competency_viewed_in_course.php',
    'core\\event\\competency_user_competency_viewed_in_plan' => '/var/www/html/plantilla/lib/classes/event/competency_user_competency_viewed_in_plan.php',
    'core\\event\\competency_user_evidence_created' => '/var/www/html/plantilla/lib/classes/event/competency_user_evidence_created.php',
    'core\\event\\competency_user_evidence_deleted' => '/var/www/html/plantilla/lib/classes/event/competency_user_evidence_deleted.php',
    'core\\event\\competency_user_evidence_updated' => '/var/www/html/plantilla/lib/classes/event/competency_user_evidence_updated.php',
    'core\\event\\competency_viewed' => '/var/www/html/plantilla/lib/classes/event/competency_viewed.php',
    'core\\event\\completion_defaults_updated' => '/var/www/html/plantilla/lib/classes/event/completion_defaults_updated.php',
    'core\\event\\config_log_created' => '/var/www/html/plantilla/lib/classes/event/config_log_created.php',
    'core\\event\\content_viewed' => '/var/www/html/plantilla/lib/classes/event/content_viewed.php',
    'core\\event\\contentbank_content_created' => '/var/www/html/plantilla/lib/classes/event/contentbank_content_created.php',
    'core\\event\\contentbank_content_deleted' => '/var/www/html/plantilla/lib/classes/event/contentbank_content_deleted.php',
    'core\\event\\contentbank_content_updated' => '/var/www/html/plantilla/lib/classes/event/contentbank_content_updated.php',
    'core\\event\\contentbank_content_uploaded' => '/var/www/html/plantilla/lib/classes/event/contentbank_content_uploaded.php',
    'core\\event\\contentbank_content_viewed' => '/var/www/html/plantilla/lib/classes/event/contentbank_content_viewed.php',
    'core\\event\\context_locked' => '/var/www/html/plantilla/lib/classes/event/context_locked.php',
    'core\\event\\context_unlocked' => '/var/www/html/plantilla/lib/classes/event/context_unlocked.php',
    'core\\event\\course_backup_created' => '/var/www/html/plantilla/lib/classes/event/course_backup_created.php',
    'core\\event\\course_category_created' => '/var/www/html/plantilla/lib/classes/event/course_category_created.php',
    'core\\event\\course_category_deleted' => '/var/www/html/plantilla/lib/classes/event/course_category_deleted.php',
    'core\\event\\course_category_updated' => '/var/www/html/plantilla/lib/classes/event/course_category_updated.php',
    'core\\event\\course_category_viewed' => '/var/www/html/plantilla/lib/classes/event/course_category_viewed.php',
    'core\\event\\course_completed' => '/var/www/html/plantilla/lib/classes/event/course_completed.php',
    'core\\event\\course_completion_updated' => '/var/www/html/plantilla/lib/classes/event/course_completion_updated.php',
    'core\\event\\course_content_deleted' => '/var/www/html/plantilla/lib/classes/event/course_content_deleted.php',
    'core\\event\\course_created' => '/var/www/html/plantilla/lib/classes/event/course_created.php',
    'core\\event\\course_deleted' => '/var/www/html/plantilla/lib/classes/event/course_deleted.php',
    'core\\event\\course_ended' => '/var/www/html/plantilla/lib/classes/event/course_ended.php',
    'core\\event\\course_information_viewed' => '/var/www/html/plantilla/lib/classes/event/course_information_viewed.php',
    'core\\event\\course_module_completion_updated' => '/var/www/html/plantilla/lib/classes/event/course_module_completion_updated.php',
    'core\\event\\course_module_created' => '/var/www/html/plantilla/lib/classes/event/course_module_created.php',
    'core\\event\\course_module_deleted' => '/var/www/html/plantilla/lib/classes/event/course_module_deleted.php',
    'core\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/lib/classes/event/course_module_instance_list_viewed.php',
    'core\\event\\course_module_updated' => '/var/www/html/plantilla/lib/classes/event/course_module_updated.php',
    'core\\event\\course_module_viewed' => '/var/www/html/plantilla/lib/classes/event/course_module_viewed.php',
    'core\\event\\course_overview_viewed' => '/var/www/html/plantilla/lib/classes/event/course_overview_viewed.php',
    'core\\event\\course_reset_ended' => '/var/www/html/plantilla/lib/classes/event/course_reset_ended.php',
    'core\\event\\course_reset_started' => '/var/www/html/plantilla/lib/classes/event/course_reset_started.php',
    'core\\event\\course_resources_list_viewed' => '/var/www/html/plantilla/lib/classes/event/course_resources_list_viewed.php',
    'core\\event\\course_restored' => '/var/www/html/plantilla/lib/classes/event/course_restored.php',
    'core\\event\\course_section_created' => '/var/www/html/plantilla/lib/classes/event/course_section_created.php',
    'core\\event\\course_section_deleted' => '/var/www/html/plantilla/lib/classes/event/course_section_deleted.php',
    'core\\event\\course_section_updated' => '/var/www/html/plantilla/lib/classes/event/course_section_updated.php',
    'core\\event\\course_started' => '/var/www/html/plantilla/lib/classes/event/course_started.php',
    'core\\event\\course_updated' => '/var/www/html/plantilla/lib/classes/event/course_updated.php',
    'core\\event\\course_user_report_viewed' => '/var/www/html/plantilla/lib/classes/event/course_user_report_viewed.php',
    'core\\event\\course_viewed' => '/var/www/html/plantilla/lib/classes/event/course_viewed.php',
    'core\\event\\courses_searched' => '/var/www/html/plantilla/lib/classes/event/courses_searched.php',
    'core\\event\\dashboard_reset' => '/var/www/html/plantilla/lib/classes/event/dashboard_reset.php',
    'core\\event\\dashboard_viewed' => '/var/www/html/plantilla/lib/classes/event/dashboard_viewed.php',
    'core\\event\\dashboards_reset' => '/var/www/html/plantilla/lib/classes/event/dashboards_reset.php',
    'core\\event\\database_text_field_content_replaced' => '/var/www/html/plantilla/lib/classes/event/database_text_field_content_replaced.php',
    'core\\event\\draft_file_added' => '/var/www/html/plantilla/lib/classes/event/draft_file_added.php',
    'core\\event\\draft_file_deleted' => '/var/www/html/plantilla/lib/classes/event/draft_file_deleted.php',
    'core\\event\\email_failed' => '/var/www/html/plantilla/lib/classes/event/email_failed.php',
    'core\\event\\enrol_instance_created' => '/var/www/html/plantilla/lib/classes/event/enrol_instance_created.php',
    'core\\event\\enrol_instance_deleted' => '/var/www/html/plantilla/lib/classes/event/enrol_instance_deleted.php',
    'core\\event\\enrol_instance_updated' => '/var/www/html/plantilla/lib/classes/event/enrol_instance_updated.php',
    'core\\event\\grade_deleted' => '/var/www/html/plantilla/lib/classes/event/grade_deleted.php',
    'core\\event\\grade_exported' => '/var/www/html/plantilla/lib/classes/event/grade_exported.php',
    'core\\event\\grade_item_created' => '/var/www/html/plantilla/lib/classes/event/grade_item_created.php',
    'core\\event\\grade_item_deleted' => '/var/www/html/plantilla/lib/classes/event/grade_item_deleted.php',
    'core\\event\\grade_item_updated' => '/var/www/html/plantilla/lib/classes/event/grade_item_updated.php',
    'core\\event\\grade_letter_created' => '/var/www/html/plantilla/lib/classes/event/grade_letter_created.php',
    'core\\event\\grade_letter_deleted' => '/var/www/html/plantilla/lib/classes/event/grade_letter_deleted.php',
    'core\\event\\grade_letter_updated' => '/var/www/html/plantilla/lib/classes/event/grade_letter_updated.php',
    'core\\event\\grade_report_viewed' => '/var/www/html/plantilla/lib/classes/event/grade_report_viewed.php',
    'core\\event\\group_created' => '/var/www/html/plantilla/lib/classes/event/group_created.php',
    'core\\event\\group_deleted' => '/var/www/html/plantilla/lib/classes/event/group_deleted.php',
    'core\\event\\group_member_added' => '/var/www/html/plantilla/lib/classes/event/group_member_added.php',
    'core\\event\\group_member_removed' => '/var/www/html/plantilla/lib/classes/event/group_member_removed.php',
    'core\\event\\group_message_sent' => '/var/www/html/plantilla/lib/classes/event/group_message_sent.php',
    'core\\event\\group_updated' => '/var/www/html/plantilla/lib/classes/event/group_updated.php',
    'core\\event\\grouping_created' => '/var/www/html/plantilla/lib/classes/event/grouping_created.php',
    'core\\event\\grouping_deleted' => '/var/www/html/plantilla/lib/classes/event/grouping_deleted.php',
    'core\\event\\grouping_group_assigned' => '/var/www/html/plantilla/lib/classes/event/grouping_group_assigned.php',
    'core\\event\\grouping_group_unassigned' => '/var/www/html/plantilla/lib/classes/event/grouping_group_unassigned.php',
    'core\\event\\grouping_updated' => '/var/www/html/plantilla/lib/classes/event/grouping_updated.php',
    'core\\event\\insights_viewed' => '/var/www/html/plantilla/lib/classes/event/insights_viewed.php',
    'core\\event\\manager' => '/var/www/html/plantilla/lib/classes/event/manager.php',
    'core\\event\\message_contact_added' => '/var/www/html/plantilla/lib/classes/event/message_contact_added.php',
    'core\\event\\message_contact_removed' => '/var/www/html/plantilla/lib/classes/event/message_contact_removed.php',
    'core\\event\\message_deleted' => '/var/www/html/plantilla/lib/classes/event/message_deleted.php',
    'core\\event\\message_sent' => '/var/www/html/plantilla/lib/classes/event/message_sent.php',
    'core\\event\\message_user_blocked' => '/var/www/html/plantilla/lib/classes/event/message_user_blocked.php',
    'core\\event\\message_user_unblocked' => '/var/www/html/plantilla/lib/classes/event/message_user_unblocked.php',
    'core\\event\\message_viewed' => '/var/www/html/plantilla/lib/classes/event/message_viewed.php',
    'core\\event\\mnet_access_control_created' => '/var/www/html/plantilla/lib/classes/event/mnet_access_control_created.php',
    'core\\event\\mnet_access_control_updated' => '/var/www/html/plantilla/lib/classes/event/mnet_access_control_updated.php',
    'core\\event\\moodlenet_resource_exported' => '/var/www/html/plantilla/lib/classes/event/moodlenet_resource_exported.php',
    'core\\event\\mycourses_viewed' => '/var/www/html/plantilla/lib/classes/event/mycourses_viewed.php',
    'core\\event\\note_created' => '/var/www/html/plantilla/lib/classes/event/note_created.php',
    'core\\event\\note_deleted' => '/var/www/html/plantilla/lib/classes/event/note_deleted.php',
    'core\\event\\note_updated' => '/var/www/html/plantilla/lib/classes/event/note_updated.php',
    'core\\event\\notes_viewed' => '/var/www/html/plantilla/lib/classes/event/notes_viewed.php',
    'core\\event\\notification_sent' => '/var/www/html/plantilla/lib/classes/event/notification_sent.php',
    'core\\event\\notification_viewed' => '/var/www/html/plantilla/lib/classes/event/notification_viewed.php',
    'core\\event\\prediction_action_started' => '/var/www/html/plantilla/lib/classes/event/prediction_action_started.php',
    'core\\event\\qbank_plugin_base' => '/var/www/html/plantilla/lib/classes/event/qbank_plugin_base.php',
    'core\\event\\qbank_plugin_disabled' => '/var/www/html/plantilla/lib/classes/event/qbank_plugin_disabled.php',
    'core\\event\\qbank_plugin_enabled' => '/var/www/html/plantilla/lib/classes/event/qbank_plugin_enabled.php',
    'core\\event\\question_base' => '/var/www/html/plantilla/lib/classes/event/question_base.php',
    'core\\event\\question_category_base' => '/var/www/html/plantilla/lib/classes/event/question_category_base.php',
    'core\\event\\question_category_created' => '/var/www/html/plantilla/lib/classes/event/question_category_created.php',
    'core\\event\\question_category_deleted' => '/var/www/html/plantilla/lib/classes/event/question_category_deleted.php',
    'core\\event\\question_category_moved' => '/var/www/html/plantilla/lib/classes/event/question_category_moved.php',
    'core\\event\\question_category_updated' => '/var/www/html/plantilla/lib/classes/event/question_category_updated.php',
    'core\\event\\question_category_viewed' => '/var/www/html/plantilla/lib/classes/event/question_category_viewed.php',
    'core\\event\\question_created' => '/var/www/html/plantilla/lib/classes/event/question_created.php',
    'core\\event\\question_deleted' => '/var/www/html/plantilla/lib/classes/event/question_deleted.php',
    'core\\event\\question_moved' => '/var/www/html/plantilla/lib/classes/event/question_moved.php',
    'core\\event\\question_updated' => '/var/www/html/plantilla/lib/classes/event/question_updated.php',
    'core\\event\\question_viewed' => '/var/www/html/plantilla/lib/classes/event/question_viewed.php',
    'core\\event\\questions_exported' => '/var/www/html/plantilla/lib/classes/event/questions_exported.php',
    'core\\event\\questions_imported' => '/var/www/html/plantilla/lib/classes/event/questions_imported.php',
    'core\\event\\recent_activity_viewed' => '/var/www/html/plantilla/lib/classes/event/recent_activity_viewed.php',
    'core\\event\\role_allow_assign_updated' => '/var/www/html/plantilla/lib/classes/event/role_allow_assign_updated.php',
    'core\\event\\role_allow_override_updated' => '/var/www/html/plantilla/lib/classes/event/role_allow_override_updated.php',
    'core\\event\\role_allow_switch_updated' => '/var/www/html/plantilla/lib/classes/event/role_allow_switch_updated.php',
    'core\\event\\role_allow_view_updated' => '/var/www/html/plantilla/lib/classes/event/role_allow_view_updated.php',
    'core\\event\\role_assigned' => '/var/www/html/plantilla/lib/classes/event/role_assigned.php',
    'core\\event\\role_capabilities_updated' => '/var/www/html/plantilla/lib/classes/event/role_capabilities_updated.php',
    'core\\event\\role_created' => '/var/www/html/plantilla/lib/classes/event/role_created.php',
    'core\\event\\role_deleted' => '/var/www/html/plantilla/lib/classes/event/role_deleted.php',
    'core\\event\\role_unassigned' => '/var/www/html/plantilla/lib/classes/event/role_unassigned.php',
    'core\\event\\role_updated' => '/var/www/html/plantilla/lib/classes/event/role_updated.php',
    'core\\event\\scale_created' => '/var/www/html/plantilla/lib/classes/event/scale_created.php',
    'core\\event\\scale_deleted' => '/var/www/html/plantilla/lib/classes/event/scale_deleted.php',
    'core\\event\\scale_updated' => '/var/www/html/plantilla/lib/classes/event/scale_updated.php',
    'core\\event\\search_indexed' => '/var/www/html/plantilla/lib/classes/event/search_indexed.php',
    'core\\event\\search_results_viewed' => '/var/www/html/plantilla/lib/classes/event/search_results_viewed.php',
    'core\\event\\section_viewed' => '/var/www/html/plantilla/lib/classes/event/section_viewed.php',
    'core\\event\\tag_added' => '/var/www/html/plantilla/lib/classes/event/tag_added.php',
    'core\\event\\tag_collection_created' => '/var/www/html/plantilla/lib/classes/event/tag_collection_created.php',
    'core\\event\\tag_collection_deleted' => '/var/www/html/plantilla/lib/classes/event/tag_collection_deleted.php',
    'core\\event\\tag_collection_updated' => '/var/www/html/plantilla/lib/classes/event/tag_collection_updated.php',
    'core\\event\\tag_created' => '/var/www/html/plantilla/lib/classes/event/tag_created.php',
    'core\\event\\tag_deleted' => '/var/www/html/plantilla/lib/classes/event/tag_deleted.php',
    'core\\event\\tag_flagged' => '/var/www/html/plantilla/lib/classes/event/tag_flagged.php',
    'core\\event\\tag_removed' => '/var/www/html/plantilla/lib/classes/event/tag_removed.php',
    'core\\event\\tag_unflagged' => '/var/www/html/plantilla/lib/classes/event/tag_unflagged.php',
    'core\\event\\tag_updated' => '/var/www/html/plantilla/lib/classes/event/tag_updated.php',
    'core\\event\\unknown_logged' => '/var/www/html/plantilla/lib/classes/event/unknown_logged.php',
    'core\\event\\url_blocked' => '/var/www/html/plantilla/lib/classes/event/url_blocked.php',
    'core\\event\\user_created' => '/var/www/html/plantilla/lib/classes/event/user_created.php',
    'core\\event\\user_deleted' => '/var/www/html/plantilla/lib/classes/event/user_deleted.php',
    'core\\event\\user_enrolment_created' => '/var/www/html/plantilla/lib/classes/event/user_enrolment_created.php',
    'core\\event\\user_enrolment_deleted' => '/var/www/html/plantilla/lib/classes/event/user_enrolment_deleted.php',
    'core\\event\\user_enrolment_updated' => '/var/www/html/plantilla/lib/classes/event/user_enrolment_updated.php',
    'core\\event\\user_graded' => '/var/www/html/plantilla/lib/classes/event/user_graded.php',
    'core\\event\\user_info_category_created' => '/var/www/html/plantilla/lib/classes/event/user_info_category_created.php',
    'core\\event\\user_info_category_deleted' => '/var/www/html/plantilla/lib/classes/event/user_info_category_deleted.php',
    'core\\event\\user_info_category_updated' => '/var/www/html/plantilla/lib/classes/event/user_info_category_updated.php',
    'core\\event\\user_info_field_created' => '/var/www/html/plantilla/lib/classes/event/user_info_field_created.php',
    'core\\event\\user_info_field_deleted' => '/var/www/html/plantilla/lib/classes/event/user_info_field_deleted.php',
    'core\\event\\user_info_field_updated' => '/var/www/html/plantilla/lib/classes/event/user_info_field_updated.php',
    'core\\event\\user_list_viewed' => '/var/www/html/plantilla/lib/classes/event/user_list_viewed.php',
    'core\\event\\user_loggedin' => '/var/www/html/plantilla/lib/classes/event/user_loggedin.php',
    'core\\event\\user_loggedinas' => '/var/www/html/plantilla/lib/classes/event/user_loggedinas.php',
    'core\\event\\user_loggedout' => '/var/www/html/plantilla/lib/classes/event/user_loggedout.php',
    'core\\event\\user_login_failed' => '/var/www/html/plantilla/lib/classes/event/user_login_failed.php',
    'core\\event\\user_password_policy_failed' => '/var/www/html/plantilla/lib/classes/event/user_password_policy_failed.php',
    'core\\event\\user_password_updated' => '/var/www/html/plantilla/lib/classes/event/user_password_updated.php',
    'core\\event\\user_profile_viewed' => '/var/www/html/plantilla/lib/classes/event/user_profile_viewed.php',
    'core\\event\\user_updated' => '/var/www/html/plantilla/lib/classes/event/user_updated.php',
    'core\\event\\userfeedback_give' => '/var/www/html/plantilla/lib/classes/event/userfeedback_give.php',
    'core\\event\\userfeedback_remind' => '/var/www/html/plantilla/lib/classes/event/userfeedback_remind.php',
    'core\\event\\virus_infected_data_detected' => '/var/www/html/plantilla/lib/classes/event/virus_infected_data_detected.php',
    'core\\event\\virus_infected_file_detected' => '/var/www/html/plantilla/lib/classes/event/virus_infected_file_detected.php',
    'core\\event\\webservice_function_called' => '/var/www/html/plantilla/lib/classes/event/webservice_function_called.php',
    'core\\event\\webservice_login_failed' => '/var/www/html/plantilla/lib/classes/event/webservice_login_failed.php',
    'core\\event\\webservice_service_created' => '/var/www/html/plantilla/lib/classes/event/webservice_service_created.php',
    'core\\event\\webservice_service_deleted' => '/var/www/html/plantilla/lib/classes/event/webservice_service_deleted.php',
    'core\\event\\webservice_service_updated' => '/var/www/html/plantilla/lib/classes/event/webservice_service_updated.php',
    'core\\event\\webservice_service_user_added' => '/var/www/html/plantilla/lib/classes/event/webservice_service_user_added.php',
    'core\\event\\webservice_service_user_removed' => '/var/www/html/plantilla/lib/classes/event/webservice_service_user_removed.php',
    'core\\event\\webservice_token_created' => '/var/www/html/plantilla/lib/classes/event/webservice_token_created.php',
    'core\\event\\webservice_token_sent' => '/var/www/html/plantilla/lib/classes/event/webservice_token_sent.php',
    'core\\exception\\access_denied_exception' => '/var/www/html/plantilla/lib/classes/exception/access_denied_exception.php',
    'core\\exception\\coding_exception' => '/var/www/html/plantilla/lib/classes/exception/coding_exception.php',
    'core\\exception\\file_serving_exception' => '/var/www/html/plantilla/lib/classes/exception/file_serving_exception.php',
    'core\\exception\\invalid_dataroot_permissions' => '/var/www/html/plantilla/lib/classes/exception/invalid_dataroot_permissions.php',
    'core\\exception\\invalid_parameter_exception' => '/var/www/html/plantilla/lib/classes/exception/invalid_parameter_exception.php',
    'core\\exception\\invalid_response_exception' => '/var/www/html/plantilla/lib/classes/exception/invalid_response_exception.php',
    'core\\exception\\invalid_state_exception' => '/var/www/html/plantilla/lib/classes/exception/invalid_state_exception.php',
    'core\\exception\\moodle_exception' => '/var/www/html/plantilla/lib/classes/exception/moodle_exception.php',
    'core\\exception\\not_found_exception' => '/var/www/html/plantilla/lib/classes/exception/not_found_exception.php',
    'core\\exception\\require_login_exception' => '/var/www/html/plantilla/lib/classes/exception/require_login_exception.php',
    'core\\exception\\require_login_session_timeout_exception' => '/var/www/html/plantilla/lib/classes/exception/require_login_session_timeout_exception.php',
    'core\\exception\\required_capability_exception' => '/var/www/html/plantilla/lib/classes/exception/required_capability_exception.php',
    'core\\exception\\response_aware_exception' => '/var/www/html/plantilla/lib/classes/exception/response_aware_exception.php',
    'core\\exception\\webservice_parameter_exception' => '/var/www/html/plantilla/lib/classes/exception/webservice_parameter_exception.php',
    'core\\external\\coursecat_summary_exporter' => '/var/www/html/plantilla/lib/classes/external/coursecat_summary_exporter.php',
    'core\\external\\dynamic_tabs_get_content' => '/var/www/html/plantilla/lib/classes/external/dynamic_tabs_get_content.php',
    'core\\external\\editmode' => '/var/www/html/plantilla/lib/classes/external/editmode.php',
    'core\\external\\exporter' => '/var/www/html/plantilla/lib/classes/external/exporter.php',
    'core\\external\\moodlenet_auth_check' => '/var/www/html/plantilla/lib/classes/external/moodlenet_auth_check.php',
    'core\\external\\moodlenet_get_share_info_activity' => '/var/www/html/plantilla/lib/classes/external/moodlenet_get_share_info_activity.php',
    'core\\external\\moodlenet_get_shared_course_info' => '/var/www/html/plantilla/lib/classes/external/moodlenet_get_shared_course_info.php',
    'core\\external\\moodlenet_send_activity' => '/var/www/html/plantilla/lib/classes/external/moodlenet_send_activity.php',
    'core\\external\\moodlenet_send_course' => '/var/www/html/plantilla/lib/classes/external/moodlenet_send_course.php',
    'core\\external\\output\\icon_system\\load_fontawesome_map' => '/var/www/html/plantilla/lib/classes/external/output/icon_system/load_fontawesome_map.php',
    'core\\external\\output\\poll_stored_progress' => '/var/www/html/plantilla/lib/classes/external/output/poll_stored_progress.php',
    'core\\external\\paged_content_exporter' => '/var/www/html/plantilla/lib/classes/external/paged_content_exporter.php',
    'core\\external\\persistent_exporter' => '/var/www/html/plantilla/lib/classes/external/persistent_exporter.php',
    'core\\external\\record_userfeedback_action' => '/var/www/html/plantilla/lib/classes/external/record_userfeedback_action.php',
    'core\\files\\curl_security_helper' => '/var/www/html/plantilla/lib/classes/files/curl_security_helper.php',
    'core\\files\\curl_security_helper_base' => '/var/www/html/plantilla/lib/classes/files/curl_security_helper_base.php',
    'core\\filetypes' => '/var/www/html/plantilla/lib/classes/filetypes.php',
    'core\\form\\error_feedback' => '/var/www/html/plantilla/lib/classes/form/error_feedback.php',
    'core\\form\\persistent' => '/var/www/html/plantilla/lib/classes/form/persistent.php',
    'core\\formatting' => '/var/www/html/plantilla/lib/classes/formatting.php',
    'core\\geopattern' => '/var/www/html/plantilla/lib/classes/geopattern.php',
    'core\\grades_external' => '/var/www/html/plantilla/lib/classes/grades_external.php',
    'core\\grading_external' => '/var/www/html/plantilla/lib/classes/grading_external.php',
    'core\\hook\\access\\after_role_assigned' => '/var/www/html/plantilla/lib/classes/hook/access/after_role_assigned.php',
    'core\\hook\\access\\after_role_switched' => '/var/www/html/plantilla/lib/classes/hook/access/after_role_switched.php',
    'core\\hook\\access\\after_role_unassigned' => '/var/www/html/plantilla/lib/classes/hook/access/after_role_unassigned.php',
    'core\\hook\\after_config' => '/var/www/html/plantilla/lib/classes/hook/after_config.php',
    'core\\hook\\deprecated_callback_replacement' => '/var/www/html/plantilla/lib/classes/hook/deprecated_callback_replacement.php',
    'core\\hook\\described_hook' => '/var/www/html/plantilla/lib/classes/hook/described_hook.php',
    'core\\hook\\di_configuration' => '/var/www/html/plantilla/lib/classes/hook/di_configuration.php',
    'core\\hook\\discovery_agent' => '/var/www/html/plantilla/lib/classes/hook/discovery_agent.php',
    'core\\hook\\manager' => '/var/www/html/plantilla/lib/classes/hook/manager.php',
    'core\\hook\\navigation\\primary_extend' => '/var/www/html/plantilla/lib/classes/hook/navigation/primary_extend.php',
    'core\\hook\\navigation\\secondary_extend' => '/var/www/html/plantilla/lib/classes/hook/navigation/secondary_extend.php',
    'core\\hook\\output\\after_http_headers' => '/var/www/html/plantilla/lib/classes/hook/output/after_http_headers.php',
    'core\\hook\\output\\after_standard_main_region_html_generation' => '/var/www/html/plantilla/lib/classes/hook/output/after_standard_main_region_html_generation.php',
    'core\\hook\\output\\before_footer_html_generation' => '/var/www/html/plantilla/lib/classes/hook/output/before_footer_html_generation.php',
    'core\\hook\\output\\before_html_attributes' => '/var/www/html/plantilla/lib/classes/hook/output/before_html_attributes.php',
    'core\\hook\\output\\before_http_headers' => '/var/www/html/plantilla/lib/classes/hook/output/before_http_headers.php',
    'core\\hook\\output\\before_standard_footer_html_generation' => '/var/www/html/plantilla/lib/classes/hook/output/before_standard_footer_html_generation.php',
    'core\\hook\\output\\before_standard_head_html_generation' => '/var/www/html/plantilla/lib/classes/hook/output/before_standard_head_html_generation.php',
    'core\\hook\\output\\before_standard_top_of_body_html_generation' => '/var/www/html/plantilla/lib/classes/hook/output/before_standard_top_of_body_html_generation.php',
    'core\\hook\\stoppable_trait' => '/var/www/html/plantilla/lib/classes/hook/stoppable_trait.php',
    'core\\hook\\task\\after_failed_task_max_delay' => '/var/www/html/plantilla/lib/classes/hook/task/after_failed_task_max_delay.php',
    'core\\hooks' => '/var/www/html/plantilla/lib/classes/hooks.php',
    'core\\http_client' => '/var/www/html/plantilla/lib/classes/http_client.php',
    'core\\hub\\api' => '/var/www/html/plantilla/lib/classes/hub/api.php',
    'core\\hub\\registration' => '/var/www/html/plantilla/lib/classes/hub/registration.php',
    'core\\hub\\site_registration_form' => '/var/www/html/plantilla/lib/classes/hub/site_registration_form.php',
    'core\\invalid_persistent_exception' => '/var/www/html/plantilla/lib/classes/invalid_persistent_exception.php',
    'core\\ip_utils' => '/var/www/html/plantilla/lib/classes/ip_utils.php',
    'core\\lang_string' => '/var/www/html/plantilla/lib/classes/lang_string.php',
    'core\\local\\cli\\shutdown' => '/var/www/html/plantilla/lib/classes/local/cli/shutdown.php',
    'core\\local\\guzzle\\cache_handler' => '/var/www/html/plantilla/lib/classes/local/guzzle/cache_handler.php',
    'core\\local\\guzzle\\cache_item' => '/var/www/html/plantilla/lib/classes/local/guzzle/cache_item.php',
    'core\\local\\guzzle\\cache_storage' => '/var/www/html/plantilla/lib/classes/local/guzzle/cache_storage.php',
    'core\\local\\guzzle\\check_request' => '/var/www/html/plantilla/lib/classes/local/guzzle/check_request.php',
    'core\\local\\guzzle\\redirect_middleware' => '/var/www/html/plantilla/lib/classes/local/guzzle/redirect_middleware.php',
    'core\\locale' => '/var/www/html/plantilla/lib/classes/locale.php',
    'core\\lock\\db_record_lock_factory' => '/var/www/html/plantilla/lib/classes/lock/db_record_lock_factory.php',
    'core\\lock\\file_lock_factory' => '/var/www/html/plantilla/lib/classes/lock/file_lock_factory.php',
    'core\\lock\\installation_lock_factory' => '/var/www/html/plantilla/lib/classes/lock/installation_lock_factory.php',
    'core\\lock\\lock' => '/var/www/html/plantilla/lib/classes/lock/lock.php',
    'core\\lock\\lock_config' => '/var/www/html/plantilla/lib/classes/lock/lock_config.php',
    'core\\lock\\lock_factory' => '/var/www/html/plantilla/lib/classes/lock/lock_factory.php',
    'core\\lock\\lock_utils' => '/var/www/html/plantilla/lib/classes/lock/lock_utils.php',
    'core\\lock\\mysql_lock_factory' => '/var/www/html/plantilla/lib/classes/lock/mysql_lock_factory.php',
    'core\\lock\\postgres_lock_factory' => '/var/www/html/plantilla/lib/classes/lock/postgres_lock_factory.php',
    'core\\lock\\timing_wrapper_lock_factory' => '/var/www/html/plantilla/lib/classes/lock/timing_wrapper_lock_factory.php',
    'core\\log\\dummy_manager' => '/var/www/html/plantilla/lib/classes/log/dummy_manager.php',
    'core\\log\\manager' => '/var/www/html/plantilla/lib/classes/log/manager.php',
    'core\\log\\reader' => '/var/www/html/plantilla/lib/classes/log/reader.php',
    'core\\log\\sql_internal_table_reader' => '/var/www/html/plantilla/lib/classes/log/sql_internal_table_reader.php',
    'core\\log\\sql_reader' => '/var/www/html/plantilla/lib/classes/log/sql_reader.php',
    'core\\message\\inbound\\address_manager' => '/var/www/html/plantilla/lib/classes/message/inbound/address_manager.php',
    'core\\message\\inbound\\handler' => '/var/www/html/plantilla/lib/classes/message/inbound/handler.php',
    'core\\message\\inbound\\manager' => '/var/www/html/plantilla/lib/classes/message/inbound/manager.php',
    'core\\message\\inbound\\private_files_handler' => '/var/www/html/plantilla/lib/classes/message/inbound/private_files_handler.php',
    'core\\message\\inbound\\processing_failed_exception' => '/var/www/html/plantilla/lib/classes/message/inbound/processing_failed_exception.php',
    'core\\message\\manager' => '/var/www/html/plantilla/lib/classes/message/manager.php',
    'core\\message\\message' => '/var/www/html/plantilla/lib/classes/message/message.php',
    'core\\minify' => '/var/www/html/plantilla/lib/classes/minify.php',
    'core\\moodlenet\\activity_packager' => '/var/www/html/plantilla/lib/classes/moodlenet/activity_packager.php',
    'core\\moodlenet\\activity_sender' => '/var/www/html/plantilla/lib/classes/moodlenet/activity_sender.php',
    'core\\moodlenet\\course_packager' => '/var/www/html/plantilla/lib/classes/moodlenet/course_packager.php',
    'core\\moodlenet\\course_partial_packager' => '/var/www/html/plantilla/lib/classes/moodlenet/course_partial_packager.php',
    'core\\moodlenet\\course_partial_sender' => '/var/www/html/plantilla/lib/classes/moodlenet/course_partial_sender.php',
    'core\\moodlenet\\course_sender' => '/var/www/html/plantilla/lib/classes/moodlenet/course_sender.php',
    'core\\moodlenet\\moodlenet_client' => '/var/www/html/plantilla/lib/classes/moodlenet/moodlenet_client.php',
    'core\\moodlenet\\resource_packager' => '/var/www/html/plantilla/lib/classes/moodlenet/resource_packager.php',
    'core\\moodlenet\\resource_sender' => '/var/www/html/plantilla/lib/classes/moodlenet/resource_sender.php',
    'core\\moodlenet\\share_progress_table' => '/var/www/html/plantilla/lib/classes/moodlenet/share_progress_table.php',
    'core\\moodlenet\\share_recorder' => '/var/www/html/plantilla/lib/classes/moodlenet/share_recorder.php',
    'core\\moodlenet\\utilities' => '/var/www/html/plantilla/lib/classes/moodlenet/utilities.php',
    'core\\navigation\\output\\more_menu' => '/var/www/html/plantilla/lib/classes/navigation/output/more_menu.php',
    'core\\navigation\\output\\primary' => '/var/www/html/plantilla/lib/classes/navigation/output/primary.php',
    'core\\navigation\\views\\primary' => '/var/www/html/plantilla/lib/classes/navigation/views/primary.php',
    'core\\navigation\\views\\secondary' => '/var/www/html/plantilla/lib/classes/navigation/views/secondary.php',
    'core\\navigation\\views\\view' => '/var/www/html/plantilla/lib/classes/navigation/views/view.php',
    'core\\notification' => '/var/www/html/plantilla/lib/classes/notification.php',
    'core\\oauth2\\access_token' => '/var/www/html/plantilla/lib/classes/oauth2/access_token.php',
    'core\\oauth2\\api' => '/var/www/html/plantilla/lib/classes/oauth2/api.php',
    'core\\oauth2\\client' => '/var/www/html/plantilla/lib/classes/oauth2/client.php',
    'core\\oauth2\\client\\linkedin' => '/var/www/html/plantilla/lib/classes/oauth2/client/linkedin.php',
    'core\\oauth2\\client\\microsoft' => '/var/www/html/plantilla/lib/classes/oauth2/client/microsoft.php',
    'core\\oauth2\\discovery\\auth_server_config_reader' => '/var/www/html/plantilla/lib/classes/oauth2/discovery/auth_server_config_reader.php',
    'core\\oauth2\\discovery\\base_definition' => '/var/www/html/plantilla/lib/classes/oauth2/discovery/base_definition.php',
    'core\\oauth2\\discovery\\imsbadgeconnect' => '/var/www/html/plantilla/lib/classes/oauth2/discovery/imsbadgeconnect.php',
    'core\\oauth2\\discovery\\openidconnect' => '/var/www/html/plantilla/lib/classes/oauth2/discovery/openidconnect.php',
    'core\\oauth2\\endpoint' => '/var/www/html/plantilla/lib/classes/oauth2/endpoint.php',
    'core\\oauth2\\issuer' => '/var/www/html/plantilla/lib/classes/oauth2/issuer.php',
    'core\\oauth2\\refresh_system_tokens_task' => '/var/www/html/plantilla/lib/classes/oauth2/refresh_system_tokens_task.php',
    'core\\oauth2\\rest' => '/var/www/html/plantilla/lib/classes/oauth2/rest.php',
    'core\\oauth2\\rest_exception' => '/var/www/html/plantilla/lib/classes/oauth2/rest_exception.php',
    'core\\oauth2\\service\\clever' => '/var/www/html/plantilla/lib/classes/oauth2/service/clever.php',
    'core\\oauth2\\service\\custom' => '/var/www/html/plantilla/lib/classes/oauth2/service/custom.php',
    'core\\oauth2\\service\\facebook' => '/var/www/html/plantilla/lib/classes/oauth2/service/facebook.php',
    'core\\oauth2\\service\\google' => '/var/www/html/plantilla/lib/classes/oauth2/service/google.php',
    'core\\oauth2\\service\\imsobv2p1' => '/var/www/html/plantilla/lib/classes/oauth2/service/imsobv2p1.php',
    'core\\oauth2\\service\\issuer_interface' => '/var/www/html/plantilla/lib/classes/oauth2/service/issuer_interface.php',
    'core\\oauth2\\service\\linkedin' => '/var/www/html/plantilla/lib/classes/oauth2/service/linkedin.php',
    'core\\oauth2\\service\\microsoft' => '/var/www/html/plantilla/lib/classes/oauth2/service/microsoft.php',
    'core\\oauth2\\service\\moodlenet' => '/var/www/html/plantilla/lib/classes/oauth2/service/moodlenet.php',
    'core\\oauth2\\service\\nextcloud' => '/var/www/html/plantilla/lib/classes/oauth2/service/nextcloud.php',
    'core\\oauth2\\system_account' => '/var/www/html/plantilla/lib/classes/oauth2/system_account.php',
    'core\\oauth2\\user_field_mapping' => '/var/www/html/plantilla/lib/classes/oauth2/user_field_mapping.php',
    'core\\output\\action_link' => '/var/www/html/plantilla/lib/classes/output/action_link.php',
    'core\\output\\action_menu' => '/var/www/html/plantilla/lib/classes/output/action_menu.php',
    'core\\output\\action_menu\\filler' => '/var/www/html/plantilla/lib/classes/output/action_menu/filler.php',
    'core\\output\\action_menu\\link' => '/var/www/html/plantilla/lib/classes/output/action_menu/link.php',
    'core\\output\\action_menu\\link_primary' => '/var/www/html/plantilla/lib/classes/output/action_menu/link_primary.php',
    'core\\output\\action_menu\\link_secondary' => '/var/www/html/plantilla/lib/classes/output/action_menu/link_secondary.php',
    'core\\output\\action_menu\\subpanel' => '/var/www/html/plantilla/lib/classes/output/action_menu/subpanel.php',
    'core\\output\\actions\\component_action' => '/var/www/html/plantilla/lib/classes/output/actions/component_action.php',
    'core\\output\\actions\\confirm_action' => '/var/www/html/plantilla/lib/classes/output/actions/confirm_action.php',
    'core\\output\\actions\\popup_action' => '/var/www/html/plantilla/lib/classes/output/actions/popup_action.php',
    'core\\output\\activity_header' => '/var/www/html/plantilla/lib/classes/output/activity_header.php',
    'core\\output\\bootstrap_renderer' => '/var/www/html/plantilla/lib/classes/output/bootstrap_renderer.php',
    'core\\output\\checkbox_toggleall' => '/var/www/html/plantilla/lib/classes/output/checkbox_toggleall.php',
    'core\\output\\choicelist' => '/var/www/html/plantilla/lib/classes/output/choicelist.php',
    'core\\output\\chooser' => '/var/www/html/plantilla/lib/classes/output/chooser.php',
    'core\\output\\chooser_item' => '/var/www/html/plantilla/lib/classes/output/chooser_item.php',
    'core\\output\\chooser_section' => '/var/www/html/plantilla/lib/classes/output/chooser_section.php',
    'core\\output\\comboboxsearch' => '/var/www/html/plantilla/lib/classes/output/comboboxsearch.php',
    'core\\output\\context_header' => '/var/www/html/plantilla/lib/classes/output/context_header.php',
    'core\\output\\core_renderer' => '/var/www/html/plantilla/lib/classes/output/core_renderer.php',
    'core\\output\\core_renderer_ajax' => '/var/www/html/plantilla/lib/classes/output/core_renderer_ajax.php',
    'core\\output\\core_renderer_cli' => '/var/www/html/plantilla/lib/classes/output/core_renderer_cli.php',
    'core\\output\\core_renderer_maintenance' => '/var/www/html/plantilla/lib/classes/output/core_renderer_maintenance.php',
    'core\\output\\custom_menu' => '/var/www/html/plantilla/lib/classes/output/custom_menu.php',
    'core\\output\\custom_menu_item' => '/var/www/html/plantilla/lib/classes/output/custom_menu_item.php',
    'core\\output\\datafilter' => '/var/www/html/plantilla/lib/classes/output/datafilter.php',
    'core\\output\\dynamic_tabs' => '/var/www/html/plantilla/lib/classes/output/dynamic_tabs.php',
    'core\\output\\dynamic_tabs\\base' => '/var/www/html/plantilla/lib/classes/output/dynamic_tabs/base.php',
    'core\\output\\external' => '/var/www/html/plantilla/lib/classes/output/external.php',
    'core\\output\\file_picker' => '/var/www/html/plantilla/lib/classes/output/file_picker.php',
    'core\\output\\help_icon' => '/var/www/html/plantilla/lib/classes/output/help_icon.php',
    'core\\output\\html_writer' => '/var/www/html/plantilla/lib/classes/output/html_writer.php',
    'core\\output\\icon_system' => '/var/www/html/plantilla/lib/classes/output/icon_system.php',
    'core\\output\\icon_system_font' => '/var/www/html/plantilla/lib/classes/output/icon_system_font.php',
    'core\\output\\icon_system_fontawesome' => '/var/www/html/plantilla/lib/classes/output/icon_system_fontawesome.php',
    'core\\output\\icon_system_standard' => '/var/www/html/plantilla/lib/classes/output/icon_system_standard.php',
    'core\\output\\image_icon' => '/var/www/html/plantilla/lib/classes/output/image_icon.php',
    'core\\output\\initials_bar' => '/var/www/html/plantilla/lib/classes/output/initials_bar.php',
    'core\\output\\inplace_editable' => '/var/www/html/plantilla/lib/classes/output/inplace_editable.php',
    'core\\output\\js_writer' => '/var/www/html/plantilla/lib/classes/output/js_writer.php',
    'core\\output\\language_menu' => '/var/www/html/plantilla/lib/classes/output/language_menu.php',
    'core\\output\\local\\action_menu\\subpanel' => '/var/www/html/plantilla/lib/classes/output/action_menu/subpanel.php',
    'core\\output\\local\\collapsable_section' => '/var/www/html/plantilla/lib/classes/output/local/collapsable_section.php',
    'core\\output\\local\\dropdown\\dialog' => '/var/www/html/plantilla/lib/classes/output/local/dropdown/dialog.php',
    'core\\output\\local\\dropdown\\status' => '/var/www/html/plantilla/lib/classes/output/local/dropdown/status.php',
    'core\\output\\local\\properties\\badge' => '/var/www/html/plantilla/lib/classes/output/local/properties/badge.php',
    'core\\output\\local\\properties\\button' => '/var/www/html/plantilla/lib/classes/output/local/properties/button.php',
    'core\\output\\local\\properties\\iconsize' => '/var/www/html/plantilla/lib/classes/output/local/properties/iconsize.php',
    'core\\output\\local\\properties\\text_align' => '/var/www/html/plantilla/lib/classes/output/local/properties/text_align.php',
    'core\\output\\mustache_clean_string_helper' => '/var/www/html/plantilla/lib/classes/output/mustache_clean_string_helper.php',
    'core\\output\\mustache_engine' => '/var/www/html/plantilla/lib/classes/output/mustache_engine.php',
    'core\\output\\mustache_filesystem_loader' => '/var/www/html/plantilla/lib/classes/output/mustache_filesystem_loader.php',
    'core\\output\\mustache_helper_collection' => '/var/www/html/plantilla/lib/classes/output/mustache_helper_collection.php',
    'core\\output\\mustache_javascript_helper' => '/var/www/html/plantilla/lib/classes/output/mustache_javascript_helper.php',
    'core\\output\\mustache_pix_helper' => '/var/www/html/plantilla/lib/classes/output/mustache_pix_helper.php',
    'core\\output\\mustache_quote_helper' => '/var/www/html/plantilla/lib/classes/output/mustache_quote_helper.php',
    'core\\output\\mustache_shorten_text_helper' => '/var/www/html/plantilla/lib/classes/output/mustache_shorten_text_helper.php',
    'core\\output\\mustache_string_helper' => '/var/www/html/plantilla/lib/classes/output/mustache_string_helper.php',
    'core\\output\\mustache_template_finder' => '/var/www/html/plantilla/lib/classes/output/mustache_template_finder.php',
    'core\\output\\mustache_template_source_loader' => '/var/www/html/plantilla/lib/classes/output/mustache_template_source_loader.php',
    'core\\output\\mustache_uniqid_helper' => '/var/www/html/plantilla/lib/classes/output/mustache_uniqid_helper.php',
    'core\\output\\mustache_user_date_helper' => '/var/www/html/plantilla/lib/classes/output/mustache_user_date_helper.php',
    'core\\output\\named_templatable' => '/var/www/html/plantilla/lib/classes/output/named_templatable.php',
    'core\\output\\notification' => '/var/www/html/plantilla/lib/classes/output/notification.php',
    'core\\output\\paging_bar' => '/var/www/html/plantilla/lib/classes/output/paging_bar.php',
    'core\\output\\participants_action_bar' => '/var/www/html/plantilla/lib/classes/output/participants_action_bar.php',
    'core\\output\\pix_emoticon' => '/var/www/html/plantilla/lib/classes/output/pix_emoticon.php',
    'core\\output\\pix_icon' => '/var/www/html/plantilla/lib/classes/output/pix_icon.php',
    'core\\output\\pix_icon_font' => '/var/www/html/plantilla/lib/classes/output/pix_icon_font.php',
    'core\\output\\pix_icon_fontawesome' => '/var/www/html/plantilla/lib/classes/output/pix_icon_fontawesome.php',
    'core\\output\\plugin_renderer_base' => '/var/www/html/plantilla/lib/classes/output/plugin_renderer_base.php',
    'core\\output\\preferences_group' => '/var/www/html/plantilla/lib/classes/output/preferences_group.php',
    'core\\output\\preferences_groups' => '/var/www/html/plantilla/lib/classes/output/preferences_groups.php',
    'core\\output\\progress_bar' => '/var/www/html/plantilla/lib/classes/output/progress_bar.php',
    'core\\output\\progress_trace' => '/var/www/html/plantilla/lib/classes/output/progress_trace.php',
    'core\\output\\progress_trace\\combined_progress_trace' => '/var/www/html/plantilla/lib/classes/output/progress_trace/combined_progress_trace.php',
    'core\\output\\progress_trace\\error_log_progress_trace' => '/var/www/html/plantilla/lib/classes/output/progress_trace/error_log_progress_trace.php',
    'core\\output\\progress_trace\\html_list_progress_trace' => '/var/www/html/plantilla/lib/classes/output/progress_trace/html_list_progress_trace.php',
    'core\\output\\progress_trace\\html_progress_trace' => '/var/www/html/plantilla/lib/classes/output/progress_trace/html_progress_trace.php',
    'core\\output\\progress_trace\\null_progress_trace' => '/var/www/html/plantilla/lib/classes/output/progress_trace/null_progress_trace.php',
    'core\\output\\progress_trace\\progress_trace_buffer' => '/var/www/html/plantilla/lib/classes/output/progress_trace/progress_trace_buffer.php',
    'core\\output\\progress_trace\\text_progress_trace' => '/var/www/html/plantilla/lib/classes/output/progress_trace/text_progress_trace.php',
    'core\\output\\renderable' => '/var/www/html/plantilla/lib/classes/output/renderable.php',
    'core\\output\\renderer_base' => '/var/www/html/plantilla/lib/classes/output/renderer_base.php',
    'core\\output\\renderer_factory\\renderer_factory_base' => '/var/www/html/plantilla/lib/classes/output/renderer_factory/renderer_factory_base.php',
    'core\\output\\renderer_factory\\renderer_factory_interface' => '/var/www/html/plantilla/lib/classes/output/renderer_factory/renderer_factory_interface.php',
    'core\\output\\renderer_factory\\standard_renderer_factory' => '/var/www/html/plantilla/lib/classes/output/renderer_factory/standard_renderer_factory.php',
    'core\\output\\renderer_factory\\theme_overridden_renderer_factory' => '/var/www/html/plantilla/lib/classes/output/renderer_factory/theme_overridden_renderer_factory.php',
    'core\\output\\renderer_helper' => '/var/www/html/plantilla/lib/classes/output/renderer_helper.php',
    'core\\output\\requirements\\fragment_requirements_manager' => '/var/www/html/plantilla/lib/classes/output/requirements/fragment_requirements_manager.php',
    'core\\output\\requirements\\page_requirements_manager' => '/var/www/html/plantilla/lib/classes/output/requirements/page_requirements_manager.php',
    'core\\output\\requirements\\yui' => '/var/www/html/plantilla/lib/classes/output/requirements/yui.php',
    'core\\output\\select_menu' => '/var/www/html/plantilla/lib/classes/output/select_menu.php',
    'core\\output\\single_button' => '/var/www/html/plantilla/lib/classes/output/single_button.php',
    'core\\output\\single_select' => '/var/www/html/plantilla/lib/classes/output/single_select.php',
    'core\\output\\sticky_footer' => '/var/www/html/plantilla/lib/classes/output/sticky_footer.php',
    'core\\output\\stored_progress_bar' => '/var/www/html/plantilla/lib/classes/output/stored_progress_bar.php',
    'core\\output\\tabobject' => '/var/www/html/plantilla/lib/classes/output/tabobject.php',
    'core\\output\\tabtree' => '/var/www/html/plantilla/lib/classes/output/tabtree.php',
    'core\\output\\task_indicator' => '/var/www/html/plantilla/lib/classes/output/task_indicator.php',
    'core\\output\\templatable' => '/var/www/html/plantilla/lib/classes/output/templatable.php',
    'core\\output\\theme_config' => '/var/www/html/plantilla/lib/classes/output/theme_config.php',
    'core\\output\\theme_usage' => '/var/www/html/plantilla/lib/classes/output/theme_usage.php',
    'core\\output\\url_rewriter' => '/var/www/html/plantilla/lib/classes/output/url_rewriter.php',
    'core\\output\\url_select' => '/var/www/html/plantilla/lib/classes/output/url_select.php',
    'core\\output\\user_picture' => '/var/www/html/plantilla/lib/classes/output/user_picture.php',
    'core\\output\\xhtml_container_stack' => '/var/www/html/plantilla/lib/classes/output/xhtml_container_stack.php',
    'core\\param' => '/var/www/html/plantilla/lib/classes/param.php',
    'core\\param_clientside_regex' => '/var/www/html/plantilla/lib/classes/param_clientside_regex.php',
    'core\\persistent' => '/var/www/html/plantilla/lib/classes/persistent.php',
    'core\\php_time_limit' => '/var/www/html/plantilla/lib/classes/php_time_limit.php',
    'core\\plugin_manager' => '/var/www/html/plantilla/lib/classes/plugin_manager.php',
    'core\\plugininfo\\aiplacement' => '/var/www/html/plantilla/lib/classes/plugininfo/aiplacement.php',
    'core\\plugininfo\\aiprovider' => '/var/www/html/plantilla/lib/classes/plugininfo/aiprovider.php',
    'core\\plugininfo\\antivirus' => '/var/www/html/plantilla/lib/classes/plugininfo/antivirus.php',
    'core\\plugininfo\\auth' => '/var/www/html/plantilla/lib/classes/plugininfo/auth.php',
    'core\\plugininfo\\availability' => '/var/www/html/plantilla/lib/classes/plugininfo/availability.php',
    'core\\plugininfo\\base' => '/var/www/html/plantilla/lib/classes/plugininfo/base.php',
    'core\\plugininfo\\block' => '/var/www/html/plantilla/lib/classes/plugininfo/block.php',
    'core\\plugininfo\\cachelock' => '/var/www/html/plantilla/lib/classes/plugininfo/cachelock.php',
    'core\\plugininfo\\cachestore' => '/var/www/html/plantilla/lib/classes/plugininfo/cachestore.php',
    'core\\plugininfo\\calendartype' => '/var/www/html/plantilla/lib/classes/plugininfo/calendartype.php',
    'core\\plugininfo\\communication' => '/var/www/html/plantilla/lib/classes/plugininfo/communication.php',
    'core\\plugininfo\\contenttype' => '/var/www/html/plantilla/lib/classes/plugininfo/contenttype.php',
    'core\\plugininfo\\coursereport' => '/var/www/html/plantilla/lib/classes/plugininfo/coursereport.php',
    'core\\plugininfo\\customfield' => '/var/www/html/plantilla/lib/classes/plugininfo/customfield.php',
    'core\\plugininfo\\dataformat' => '/var/www/html/plantilla/lib/classes/plugininfo/dataformat.php',
    'core\\plugininfo\\editor' => '/var/www/html/plantilla/lib/classes/plugininfo/editor.php',
    'core\\plugininfo\\enrol' => '/var/www/html/plantilla/lib/classes/plugininfo/enrol.php',
    'core\\plugininfo\\fileconverter' => '/var/www/html/plantilla/lib/classes/plugininfo/fileconverter.php',
    'core\\plugininfo\\filter' => '/var/www/html/plantilla/lib/classes/plugininfo/filter.php',
    'core\\plugininfo\\format' => '/var/www/html/plantilla/lib/classes/plugininfo/format.php',
    'core\\plugininfo\\general' => '/var/www/html/plantilla/lib/classes/plugininfo/general.php',
    'core\\plugininfo\\gradeexport' => '/var/www/html/plantilla/lib/classes/plugininfo/gradeexport.php',
    'core\\plugininfo\\gradeimport' => '/var/www/html/plantilla/lib/classes/plugininfo/gradeimport.php',
    'core\\plugininfo\\gradepenalty' => '/var/www/html/plantilla/lib/classes/plugininfo/gradepenalty.php',
    'core\\plugininfo\\gradereport' => '/var/www/html/plantilla/lib/classes/plugininfo/gradereport.php',
    'core\\plugininfo\\gradingform' => '/var/www/html/plantilla/lib/classes/plugininfo/gradingform.php',
    'core\\plugininfo\\h5plib' => '/var/www/html/plantilla/lib/classes/plugininfo/h5plib.php',
    'core\\plugininfo\\local' => '/var/www/html/plantilla/lib/classes/plugininfo/local.php',
    'core\\plugininfo\\media' => '/var/www/html/plantilla/lib/classes/plugininfo/media.php',
    'core\\plugininfo\\message' => '/var/www/html/plantilla/lib/classes/plugininfo/message.php',
    'core\\plugininfo\\mlbackend' => '/var/www/html/plantilla/lib/classes/plugininfo/mlbackend.php',
    'core\\plugininfo\\mnetservice' => '/var/www/html/plantilla/lib/classes/plugininfo/mnetservice.php',
    'core\\plugininfo\\mod' => '/var/www/html/plantilla/lib/classes/plugininfo/mod.php',
    'core\\plugininfo\\orphaned' => '/var/www/html/plantilla/lib/classes/plugininfo/orphaned.php',
    'core\\plugininfo\\paygw' => '/var/www/html/plantilla/lib/classes/plugininfo/paygw.php',
    'core\\plugininfo\\plagiarism' => '/var/www/html/plantilla/lib/classes/plugininfo/plagiarism.php',
    'core\\plugininfo\\portfolio' => '/var/www/html/plantilla/lib/classes/plugininfo/portfolio.php',
    'core\\plugininfo\\profilefield' => '/var/www/html/plantilla/lib/classes/plugininfo/profilefield.php',
    'core\\plugininfo\\qbank' => '/var/www/html/plantilla/lib/classes/plugininfo/qbank.php',
    'core\\plugininfo\\qbehaviour' => '/var/www/html/plantilla/lib/classes/plugininfo/qbehaviour.php',
    'core\\plugininfo\\qformat' => '/var/www/html/plantilla/lib/classes/plugininfo/qformat.php',
    'core\\plugininfo\\qtype' => '/var/www/html/plantilla/lib/classes/plugininfo/qtype.php',
    'core\\plugininfo\\report' => '/var/www/html/plantilla/lib/classes/plugininfo/report.php',
    'core\\plugininfo\\repository' => '/var/www/html/plantilla/lib/classes/plugininfo/repository.php',
    'core\\plugininfo\\search' => '/var/www/html/plantilla/lib/classes/plugininfo/search.php',
    'core\\plugininfo\\smsgateway' => '/var/www/html/plantilla/lib/classes/plugininfo/smsgateway.php',
    'core\\plugininfo\\theme' => '/var/www/html/plantilla/lib/classes/plugininfo/theme.php',
    'core\\plugininfo\\tool' => '/var/www/html/plantilla/lib/classes/plugininfo/tool.php',
    'core\\plugininfo\\webservice' => '/var/www/html/plantilla/lib/classes/plugininfo/webservice.php',
    'core\\privacy\\provider' => '/var/www/html/plantilla/lib/classes/privacy/provider.php',
    'core\\progress\\base' => '/var/www/html/plantilla/lib/classes/progress/base.php',
    'core\\progress\\db_updater' => '/var/www/html/plantilla/lib/classes/progress/db_updater.php',
    'core\\progress\\display' => '/var/www/html/plantilla/lib/classes/progress/display.php',
    'core\\progress\\display_if_slow' => '/var/www/html/plantilla/lib/classes/progress/display_if_slow.php',
    'core\\progress\\none' => '/var/www/html/plantilla/lib/classes/progress/none.php',
    'core\\progress\\stored' => '/var/www/html/plantilla/lib/classes/progress/stored.php',
    'core\\qrcode' => '/var/www/html/plantilla/lib/classes/qrcode.php',
    'core\\report_helper' => '/var/www/html/plantilla/lib/classes/report_helper.php',
    'core\\reportbuilder\\local\\entities\\context' => '/var/www/html/plantilla/lib/classes/reportbuilder/local/entities/context.php',
    'core\\requirejs' => '/var/www/html/plantilla/lib/classes/requirejs.php',
    'core\\route\\api\\templates' => '/var/www/html/plantilla/lib/classes/route/api/templates.php',
    'core\\route\\controller\\page_not_found_controller' => '/var/www/html/plantilla/lib/classes/route/controller/page_not_found_controller.php',
    'core\\route\\shim\\error_controller' => '/var/www/html/plantilla/lib/classes/route/shim/error_controller.php',
    'core\\router' => '/var/www/html/plantilla/lib/classes/router.php',
    'core\\router\\abstract_route_loader' => '/var/www/html/plantilla/lib/classes/router/abstract_route_loader.php',
    'core\\router\\apidocs' => '/var/www/html/plantilla/lib/classes/router/apidocs.php',
    'core\\router\\bridge' => '/var/www/html/plantilla/lib/classes/router/bridge.php',
    'core\\router\\callable_resolver' => '/var/www/html/plantilla/lib/classes/router/callable_resolver.php',
    'core\\router\\controller_invoker' => '/var/www/html/plantilla/lib/classes/router/controller_invoker.php',
    'core\\router\\error_handler' => '/var/www/html/plantilla/lib/classes/router/error_handler.php',
    'core\\router\\error_renderer' => '/var/www/html/plantilla/lib/classes/router/error_renderer.php',
    'core\\router\\hook_callbacks' => '/var/www/html/plantilla/lib/classes/router/hook_callbacks.php',
    'core\\router\\middleware\\cors_middleware' => '/var/www/html/plantilla/lib/classes/router/middleware/cors_middleware.php',
    'core\\router\\middleware\\error_handling_middleware' => '/var/www/html/plantilla/lib/classes/router/middleware/error_handling_middleware.php',
    'core\\router\\middleware\\moodle_api_authentication_middleware' => '/var/www/html/plantilla/lib/classes/router/middleware/moodle_api_authentication_middleware.php',
    'core\\router\\middleware\\moodle_authentication_middleware' => '/var/www/html/plantilla/lib/classes/router/middleware/moodle_authentication_middleware.php',
    'core\\router\\middleware\\moodle_bootstrap_middleware' => '/var/www/html/plantilla/lib/classes/router/middleware/moodle_bootstrap_middleware.php',
    'core\\router\\middleware\\moodle_route_attribute_middleware' => '/var/www/html/plantilla/lib/classes/router/middleware/moodle_route_attribute_middleware.php',
    'core\\router\\middleware\\uri_normalisation_middleware' => '/var/www/html/plantilla/lib/classes/router/middleware/uri_normalisation_middleware.php',
    'core\\router\\middleware\\validation_middleware' => '/var/www/html/plantilla/lib/classes/router/middleware/validation_middleware.php',
    'core\\router\\parameters\\header_language' => '/var/www/html/plantilla/lib/classes/router/parameters/header_language.php',
    'core\\router\\parameters\\path_component' => '/var/www/html/plantilla/lib/classes/router/parameters/path_component.php',
    'core\\router\\parameters\\path_course' => '/var/www/html/plantilla/lib/classes/router/parameters/path_course.php',
    'core\\router\\parameters\\path_themename' => '/var/www/html/plantilla/lib/classes/router/parameters/path_themename.php',
    'core\\router\\parameters\\path_user' => '/var/www/html/plantilla/lib/classes/router/parameters/path_user.php',
    'core\\router\\parameters\\query_returnurl' => '/var/www/html/plantilla/lib/classes/router/parameters/query_returnurl.php',
    'core\\router\\request_validator' => '/var/www/html/plantilla/lib/classes/router/request_validator.php',
    'core\\router\\request_validator_interface' => '/var/www/html/plantilla/lib/classes/router/request_validator_interface.php',
    'core\\router\\require_login' => '/var/www/html/plantilla/lib/classes/router/require_login.php',
    'core\\router\\response\\access_denied_response' => '/var/www/html/plantilla/lib/classes/router/response/access_denied_response.php',
    'core\\router\\response\\empty_response' => '/var/www/html/plantilla/lib/classes/router/response/empty_response.php',
    'core\\router\\response\\exception_response' => '/var/www/html/plantilla/lib/classes/router/response/exception_response.php',
    'core\\router\\response\\invalid_parameter_response' => '/var/www/html/plantilla/lib/classes/router/response/invalid_parameter_response.php',
    'core\\router\\response\\not_found_response' => '/var/www/html/plantilla/lib/classes/router/response/not_found_response.php',
    'core\\router\\response_handler' => '/var/www/html/plantilla/lib/classes/router/response_handler.php',
    'core\\router\\response_validator' => '/var/www/html/plantilla/lib/classes/router/response_validator.php',
    'core\\router\\response_validator_interface' => '/var/www/html/plantilla/lib/classes/router/response_validator_interface.php',
    'core\\router\\route' => '/var/www/html/plantilla/lib/classes/router/route.php',
    'core\\router\\route_controller' => '/var/www/html/plantilla/lib/classes/router/route_controller.php',
    'core\\router\\route_loader' => '/var/www/html/plantilla/lib/classes/router/route_loader.php',
    'core\\router\\route_loader_interface' => '/var/www/html/plantilla/lib/classes/router/route_loader_interface.php',
    'core\\router\\schema\\example' => '/var/www/html/plantilla/lib/classes/router/schema/example.php',
    'core\\router\\schema\\header_object' => '/var/www/html/plantilla/lib/classes/router/schema/header_object.php',
    'core\\router\\schema\\objects\\array_of_strings' => '/var/www/html/plantilla/lib/classes/router/schema/objects/array_of_strings.php',
    'core\\router\\schema\\objects\\array_of_things' => '/var/www/html/plantilla/lib/classes/router/schema/objects/array_of_things.php',
    'core\\router\\schema\\objects\\scalar_type' => '/var/www/html/plantilla/lib/classes/router/schema/objects/scalar_type.php',
    'core\\router\\schema\\objects\\schema_object' => '/var/www/html/plantilla/lib/classes/router/schema/objects/schema_object.php',
    'core\\router\\schema\\objects\\stacktrace' => '/var/www/html/plantilla/lib/classes/router/schema/objects/stacktrace.php',
    'core\\router\\schema\\objects\\type_base' => '/var/www/html/plantilla/lib/classes/router/schema/objects/type_base.php',
    'core\\router\\schema\\openapi_base' => '/var/www/html/plantilla/lib/classes/router/schema/openapi_base.php',
    'core\\router\\schema\\parameter' => '/var/www/html/plantilla/lib/classes/router/schema/parameter.php',
    'core\\router\\schema\\parameters\\header_object' => '/var/www/html/plantilla/lib/classes/router/schema/parameters/header_object.php',
    'core\\router\\schema\\parameters\\mapped_property_parameter' => '/var/www/html/plantilla/lib/classes/router/schema/parameters/mapped_property_parameter.php',
    'core\\router\\schema\\parameters\\path_parameter' => '/var/www/html/plantilla/lib/classes/router/schema/parameters/path_parameter.php',
    'core\\router\\schema\\parameters\\query_parameter' => '/var/www/html/plantilla/lib/classes/router/schema/parameters/query_parameter.php',
    'core\\router\\schema\\referenced_object' => '/var/www/html/plantilla/lib/classes/router/schema/referenced_object.php',
    'core\\router\\schema\\request_body' => '/var/www/html/plantilla/lib/classes/router/schema/request_body.php',
    'core\\router\\schema\\response\\abstract_response' => '/var/www/html/plantilla/lib/classes/router/schema/response/abstract_response.php',
    'core\\router\\schema\\response\\content\\json_media_type' => '/var/www/html/plantilla/lib/classes/router/schema/response/content/json_media_type.php',
    'core\\router\\schema\\response\\content\\media_type' => '/var/www/html/plantilla/lib/classes/router/schema/response/content/media_type.php',
    'core\\router\\schema\\response\\content\\payload_response_type' => '/var/www/html/plantilla/lib/classes/router/schema/response/content/payload_response_type.php',
    'core\\router\\schema\\response\\payload_response' => '/var/www/html/plantilla/lib/classes/router/schema/response/payload_response.php',
    'core\\router\\schema\\response\\response' => '/var/www/html/plantilla/lib/classes/router/schema/response/response.php',
    'core\\router\\schema\\response\\response_type' => '/var/www/html/plantilla/lib/classes/router/schema/response/response_type.php',
    'core\\router\\schema\\response\\view_response' => '/var/www/html/plantilla/lib/classes/router/schema/response/view_response.php',
    'core\\router\\schema\\specification' => '/var/www/html/plantilla/lib/classes/router/schema/specification.php',
    'core\\router\\util' => '/var/www/html/plantilla/lib/classes/router/util.php',
    'core\\rtlcss' => '/var/www/html/plantilla/lib/classes/rtlcss.php',
    'core\\scss' => '/var/www/html/plantilla/lib/classes/scss.php',
    'core\\session\\database' => '/var/www/html/plantilla/lib/classes/session/database.php',
    'core\\session\\exception' => '/var/www/html/plantilla/lib/classes/session/exception.php',
    'core\\session\\external' => '/var/www/html/plantilla/lib/classes/session/external.php',
    'core\\session\\file' => '/var/www/html/plantilla/lib/classes/session/file.php',
    'core\\session\\handler' => '/var/www/html/plantilla/lib/classes/session/handler.php',
    'core\\session\\loginas_helper' => '/var/www/html/plantilla/lib/classes/session/loginas_helper.php',
    'core\\session\\manager' => '/var/www/html/plantilla/lib/classes/session/manager.php',
    'core\\session\\memcached' => '/var/www/html/plantilla/lib/classes/session/memcached.php',
    'core\\session\\redis' => '/var/www/html/plantilla/lib/classes/session/redis.php',
    'core\\session\\utility\\cookie_helper' => '/var/www/html/plantilla/lib/classes/session/utility/cookie_helper.php',
    'core\\shutdown_manager' => '/var/www/html/plantilla/lib/classes/shutdown_manager.php',
    'core\\string_manager' => '/var/www/html/plantilla/lib/classes/string_manager.php',
    'core\\string_manager_install' => '/var/www/html/plantilla/lib/classes/string_manager_install.php',
    'core\\string_manager_standard' => '/var/www/html/plantilla/lib/classes/string_manager_standard.php',
    'core\\system_clock' => '/var/www/html/plantilla/lib/classes/system_clock.php',
    'core\\task\\adhoc_task' => '/var/www/html/plantilla/lib/classes/task/adhoc_task.php',
    'core\\task\\analytics_cleanup_task' => '/var/www/html/plantilla/lib/classes/task/analytics_cleanup_task.php',
    'core\\task\\antivirus_cleanup_task' => '/var/www/html/plantilla/lib/classes/task/antivirus_cleanup_task.php',
    'core\\task\\asynchronous_backup_task' => '/var/www/html/plantilla/lib/classes/task/asynchronous_backup_task.php',
    'core\\task\\asynchronous_copy_task' => '/var/www/html/plantilla/lib/classes/task/asynchronous_copy_task.php',
    'core\\task\\asynchronous_restore_task' => '/var/www/html/plantilla/lib/classes/task/asynchronous_restore_task.php',
    'core\\task\\automated_backup_report_task' => '/var/www/html/plantilla/lib/classes/task/automated_backup_report_task.php',
    'core\\task\\automated_backup_task' => '/var/www/html/plantilla/lib/classes/task/automated_backup_task.php',
    'core\\task\\backup_cleanup_task' => '/var/www/html/plantilla/lib/classes/task/backup_cleanup_task.php',
    'core\\task\\badges_adhoc_task' => '/var/www/html/plantilla/lib/classes/task/badges_adhoc_task.php',
    'core\\task\\badges_cron_task' => '/var/www/html/plantilla/lib/classes/task/badges_cron_task.php',
    'core\\task\\badges_message_task' => '/var/www/html/plantilla/lib/classes/task/badges_message_task.php',
    'core\\task\\blog_cron_task' => '/var/www/html/plantilla/lib/classes/task/blog_cron_task.php',
    'core\\task\\build_installed_themes_task' => '/var/www/html/plantilla/lib/classes/task/build_installed_themes_task.php',
    'core\\task\\cache_cleanup_task' => '/var/www/html/plantilla/lib/classes/task/cache_cleanup_task.php',
    'core\\task\\cache_cron_task' => '/var/www/html/plantilla/lib/classes/task/cache_cron_task.php',
    'core\\task\\calendar_cron_task' => '/var/www/html/plantilla/lib/classes/task/calendar_cron_task.php',
    'core\\task\\calendar_fix_orphaned_events' => '/var/www/html/plantilla/lib/classes/task/calendar_fix_orphaned_events.php',
    'core\\task\\check_for_updates_task' => '/var/www/html/plantilla/lib/classes/task/check_for_updates_task.php',
    'core\\task\\clean_up_deleted_search_area_task' => '/var/www/html/plantilla/lib/classes/task/clean_up_deleted_search_area_task.php',
    'core\\task\\complete_plans_task' => '/var/www/html/plantilla/lib/classes/task/complete_plans_task.php',
    'core\\task\\completion_daily_task' => '/var/www/html/plantilla/lib/classes/task/completion_daily_task.php',
    'core\\task\\completion_regular_task' => '/var/www/html/plantilla/lib/classes/task/completion_regular_task.php',
    'core\\task\\context_cleanup_task' => '/var/www/html/plantilla/lib/classes/task/context_cleanup_task.php',
    'core\\task\\course_backup_task' => '/var/www/html/plantilla/lib/classes/task/course_backup_task.php',
    'core\\task\\create_contexts_task' => '/var/www/html/plantilla/lib/classes/task/create_contexts_task.php',
    'core\\task\\database_logger' => '/var/www/html/plantilla/lib/classes/task/database_logger.php',
    'core\\task\\delete_incomplete_users_task' => '/var/www/html/plantilla/lib/classes/task/delete_incomplete_users_task.php',
    'core\\task\\delete_unconfirmed_users_task' => '/var/www/html/plantilla/lib/classes/task/delete_unconfirmed_users_task.php',
    'core\\task\\failed_task_callbacks' => '/var/www/html/plantilla/lib/classes/task/failed_task_callbacks.php',
    'core\\task\\file_temp_cleanup_task' => '/var/www/html/plantilla/lib/classes/task/file_temp_cleanup_task.php',
    'core\\task\\file_trash_cleanup_task' => '/var/www/html/plantilla/lib/classes/task/file_trash_cleanup_task.php',
    'core\\task\\fix_file_timestamps_task' => '/var/www/html/plantilla/lib/classes/task/fix_file_timestamps_task.php',
    'core\\task\\grade_cron_task' => '/var/www/html/plantilla/lib/classes/task/grade_cron_task.php',
    'core\\task\\grade_history_cleanup_task' => '/var/www/html/plantilla/lib/classes/task/grade_history_cleanup_task.php',
    'core\\task\\h5p_clean_orphaned_records_task' => '/var/www/html/plantilla/lib/classes/task/h5p_clean_orphaned_records_task.php',
    'core\\task\\h5p_get_content_types_task' => '/var/www/html/plantilla/lib/classes/task/h5p_get_content_types_task.php',
    'core\\task\\hide_ended_courses_task' => '/var/www/html/plantilla/lib/classes/task/hide_ended_courses_task.php',
    'core\\task\\logging_trait' => '/var/www/html/plantilla/lib/classes/task/logging_trait.php',
    'core\\task\\logmanager' => '/var/www/html/plantilla/lib/classes/task/logmanager.php',
    'core\\task\\manager' => '/var/www/html/plantilla/lib/classes/task/manager.php',
    'core\\task\\messaging_cleanup_task' => '/var/www/html/plantilla/lib/classes/task/messaging_cleanup_task.php',
    'core\\task\\password_reset_cleanup_task' => '/var/www/html/plantilla/lib/classes/task/password_reset_cleanup_task.php',
    'core\\task\\plagiarism_cron_task' => '/var/www/html/plantilla/lib/classes/task/plagiarism_cron_task.php',
    'core\\task\\portfolio_cron_task' => '/var/www/html/plantilla/lib/classes/task/portfolio_cron_task.php',
    'core\\task\\question_preview_cleanup_task' => '/var/www/html/plantilla/lib/classes/task/question_preview_cleanup_task.php',
    'core\\task\\refresh_mod_calendar_events_task' => '/var/www/html/plantilla/lib/classes/task/refresh_mod_calendar_events_task.php',
    'core\\task\\registration_cron_task' => '/var/www/html/plantilla/lib/classes/task/registration_cron_task.php',
    'core\\task\\scheduled_task' => '/var/www/html/plantilla/lib/classes/task/scheduled_task.php',
    'core\\task\\search_index_task' => '/var/www/html/plantilla/lib/classes/task/search_index_task.php',
    'core\\task\\search_optimize_task' => '/var/www/html/plantilla/lib/classes/task/search_optimize_task.php',
    'core\\task\\send_failed_login_notifications_task' => '/var/www/html/plantilla/lib/classes/task/send_failed_login_notifications_task.php',
    'core\\task\\send_login_notifications' => '/var/www/html/plantilla/lib/classes/task/send_login_notifications.php',
    'core\\task\\send_new_user_passwords_task' => '/var/www/html/plantilla/lib/classes/task/send_new_user_passwords_task.php',
    'core\\task\\session_cleanup_task' => '/var/www/html/plantilla/lib/classes/task/session_cleanup_task.php',
    'core\\task\\show_started_courses_task' => '/var/www/html/plantilla/lib/classes/task/show_started_courses_task.php',
    'core\\task\\stats_cron_task' => '/var/www/html/plantilla/lib/classes/task/stats_cron_task.php',
    'core\\task\\stored_progress_bar_cleanup_task' => '/var/www/html/plantilla/lib/classes/task/stored_progress_bar_cleanup_task.php',
    'core\\task\\stored_progress_task_trait' => '/var/www/html/plantilla/lib/classes/task/stored_progress_task_trait.php',
    'core\\task\\sync_plans_from_template_cohorts_task' => '/var/www/html/plantilla/lib/classes/task/sync_plans_from_template_cohorts_task.php',
    'core\\task\\tag_cron_task' => '/var/www/html/plantilla/lib/classes/task/tag_cron_task.php',
    'core\\task\\task_base' => '/var/www/html/plantilla/lib/classes/task/task_base.php',
    'core\\task\\task_lock_cleanup_task' => '/var/www/html/plantilla/lib/classes/task/task_lock_cleanup_task.php',
    'core\\task\\task_log_cleanup_task' => '/var/www/html/plantilla/lib/classes/task/task_log_cleanup_task.php',
    'core\\task\\task_logger' => '/var/www/html/plantilla/lib/classes/task/task_logger.php',
    'core\\task\\task_trait' => '/var/www/html/plantilla/lib/classes/task/task_trait.php',
    'core\\task\\update_geoip2file_task' => '/var/www/html/plantilla/lib/classes/task/update_geoip2file_task.php',
    'core\\test\\email_catcher' => '/var/www/html/plantilla/lib/classes/test/email_catcher.php',
    'core\\test\\mailpit_email_catcher' => '/var/www/html/plantilla/lib/classes/test/mailpit_email_catcher.php',
    'core\\test\\mailpit_message' => '/var/www/html/plantilla/lib/classes/test/mailpit_message.php',
    'core\\test\\mailpit_message_user' => '/var/www/html/plantilla/lib/classes/test/mailpit_message_user.php',
    'core\\test\\message' => '/var/www/html/plantilla/lib/classes/test/message.php',
    'core\\test\\message_user' => '/var/www/html/plantilla/lib/classes/test/message_user.php',
    'core\\tests\\route_testcase' => '/var/www/html/plantilla/lib/classes/tests/route_testcase.php',
    'core\\text' => '/var/www/html/plantilla/lib/classes/text.php',
    'core\\update\\api' => '/var/www/html/plantilla/lib/classes/update/api.php',
    'core\\update\\checker' => '/var/www/html/plantilla/lib/classes/update/checker.php',
    'core\\update\\checker_exception' => '/var/www/html/plantilla/lib/classes/update/checker_exception.php',
    'core\\update\\code_manager' => '/var/www/html/plantilla/lib/classes/update/code_manager.php',
    'core\\update\\info' => '/var/www/html/plantilla/lib/classes/update/info.php',
    'core\\update\\remote_info' => '/var/www/html/plantilla/lib/classes/update/remote_info.php',
    'core\\update\\validator' => '/var/www/html/plantilla/lib/classes/update/validator.php',
    'core\\upgrade\\util' => '/var/www/html/plantilla/lib/classes/upgrade/util.php',
    'core\\url' => '/var/www/html/plantilla/lib/classes/url.php',
    'core\\user' => '/var/www/html/plantilla/lib/classes/user.php',
    'core\\useragent' => '/var/www/html/plantilla/lib/classes/useragent.php',
    'core\\userfeedback' => '/var/www/html/plantilla/lib/classes/userfeedback.php',
    'core\\uuid' => '/var/www/html/plantilla/lib/classes/uuid.php',
    'core_activity_dates' => '/var/www/html/plantilla/lib/classes/activity_dates.php',
    'core_admin\\admin\\admin_setting_plugin_manager' => '/var/www/html/plantilla/admin/classes/admin/admin_setting_plugin_manager.php',
    'core_admin\\admin\\admin_setting_template_render' => '/var/www/html/plantilla/admin/classes/admin/admin_setting_template_render.php',
    'core_admin\\external\\set_block_protection' => '/var/www/html/plantilla/admin/classes/external/set_block_protection.php',
    'core_admin\\external\\set_plugin_order' => '/var/www/html/plantilla/admin/classes/external/set_plugin_order.php',
    'core_admin\\external\\set_plugin_state' => '/var/www/html/plantilla/admin/classes/external/set_plugin_state.php',
    'core_admin\\form\\purge_caches' => '/var/www/html/plantilla/admin/classes/form/purge_caches.php',
    'core_admin\\form\\testoutgoingmailconf_form' => '/var/www/html/plantilla/admin/classes/form/testoutgoingmailconf_form.php',
    'core_admin\\local\\externalpage\\accesscallback' => '/var/www/html/plantilla/admin/classes/local/externalpage/accesscallback.php',
    'core_admin\\local\\settings\\autocomplete' => '/var/www/html/plantilla/admin/classes/local/settings/autocomplete.php',
    'core_admin\\local\\settings\\filesize' => '/var/www/html/plantilla/admin/classes/local/settings/filesize.php',
    'core_admin\\local\\settings\\linkable_settings_page' => '/var/www/html/plantilla/admin/classes/local/settings/linkable_settings_page.php',
    'core_admin\\local\\settings\\manage_payment_gateway_plugins' => '/var/www/html/plantilla/admin/classes/local/settings/manage_payment_gateway_plugins.php',
    'core_admin\\local\\settings\\setting_scheduled_task_status' => '/var/www/html/plantilla/admin/classes/local/settings/setting_scheduled_task_status.php',
    'core_admin\\output\\theme_selector' => '/var/www/html/plantilla/admin/classes/output/theme_selector.php',
    'core_admin\\privacy\\provider' => '/var/www/html/plantilla/admin/classes/privacy/provider.php',
    'core_admin\\reportbuilder\\datasource\\task_logs' => '/var/www/html/plantilla/admin/classes/reportbuilder/datasource/task_logs.php',
    'core_admin\\reportbuilder\\local\\entities\\task_log' => '/var/www/html/plantilla/admin/classes/reportbuilder/local/entities/task_log.php',
    'core_admin\\reportbuilder\\local\\filters\\courserole' => '/var/www/html/plantilla/admin/classes/reportbuilder/local/filters/courserole.php',
    'core_admin\\reportbuilder\\local\\systemreports\\task_logs' => '/var/www/html/plantilla/admin/classes/reportbuilder/local/systemreports/task_logs.php',
    'core_admin\\reportbuilder\\local\\systemreports\\users' => '/var/www/html/plantilla/admin/classes/reportbuilder/local/systemreports/users.php',
    'core_admin\\table\\activity_management_table' => '/var/www/html/plantilla/admin/classes/table/activity_management_table.php',
    'core_admin\\table\\availability_management_table' => '/var/www/html/plantilla/admin/classes/table/availability_management_table.php',
    'core_admin\\table\\block_management_table' => '/var/www/html/plantilla/admin/classes/table/block_management_table.php',
    'core_admin\\table\\editor_management_table' => '/var/www/html/plantilla/admin/classes/table/editor_management_table.php',
    'core_admin\\table\\hook_list_table' => '/var/www/html/plantilla/admin/classes/table/hook_list_table.php',
    'core_admin\\table\\media_management_table' => '/var/www/html/plantilla/admin/classes/table/media_management_table.php',
    'core_admin\\table\\plugin_management_table' => '/var/www/html/plantilla/admin/classes/table/plugin_management_table.php',
    'core_admin\\table\\plugin_management_table_filterset' => '/var/www/html/plantilla/admin/classes/table/plugin_management_table_filterset.php',
    'core_admin\\table\\tool_plugin_management_table' => '/var/www/html/plantilla/admin/classes/table/tool_plugin_management_table.php',
    'core_adminpresets\\helper' => '/var/www/html/plantilla/admin/presets/classes/helper.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_bloglevel' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_bloglevel.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_configcheckbox' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_configcheckbox.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_configcheckbox_with_advanced' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_configcheckbox_with_advanced.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_configcheckbox_with_lock' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_configcheckbox_with_lock.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_configiplist' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_configiplist.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_configmulticheckbox' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_configmulticheckbox.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_configmultiselect' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_configmultiselect.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_configmultiselect_with_loader' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_configmultiselect_with_loader.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_configselect' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_configselect.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_configselect_with_advanced' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_configselect_with_advanced.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_configtext' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_configtext.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_configtext_with_advanced' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_configtext_with_advanced.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_configtime' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_configtime.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_devicedetectregex' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_devicedetectregex.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_gradecat_combo' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_gradecat_combo.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_sitesettext' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_sitesettext.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_special_backupdays' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_special_backupdays.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_special_calendar_weekend' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_special_calendar_weekend.php',
    'core_adminpresets\\local\\setting\\adminpresets_admin_setting_users_with_capability' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_admin_setting_users_with_capability.php',
    'core_adminpresets\\local\\setting\\adminpresets_setting' => '/var/www/html/plantilla/admin/presets/classes/local/setting/adminpresets_setting.php',
    'core_adminpresets\\local\\setting\\delegation' => '/var/www/html/plantilla/admin/presets/classes/local/setting/delegation.php',
    'core_adminpresets\\manager' => '/var/www/html/plantilla/admin/presets/classes/manager.php',
    'core_adminpresets\\privacy\\provider' => '/var/www/html/plantilla/admin/presets/classes/privacy/provider.php',
    'core_adminpresets_helper' => '/var/www/html/plantilla/admin/presets/classes/helper.php',
    'core_adminpresets_manager' => '/var/www/html/plantilla/admin/presets/classes/manager.php',
    'core_ai\\admin\\admin_setting_action_manager' => '/var/www/html/plantilla/ai/classes/admin/admin_setting_action_manager.php',
    'core_ai\\admin\\admin_setting_provider_manager' => '/var/www/html/plantilla/ai/classes/admin/admin_setting_provider_manager.php',
    'core_ai\\admin\\admin_settingspage_provider' => '/var/www/html/plantilla/ai/classes/admin/admin_settingspage_provider.php',
    'core_ai\\ai_image' => '/var/www/html/plantilla/ai/classes/ai_image.php',
    'core_ai\\aiactions\\base' => '/var/www/html/plantilla/ai/classes/aiactions/base.php',
    'core_ai\\aiactions\\explain_text' => '/var/www/html/plantilla/ai/classes/aiactions/explain_text.php',
    'core_ai\\aiactions\\generate_image' => '/var/www/html/plantilla/ai/classes/aiactions/generate_image.php',
    'core_ai\\aiactions\\generate_text' => '/var/www/html/plantilla/ai/classes/aiactions/generate_text.php',
    'core_ai\\aiactions\\responses\\response_base' => '/var/www/html/plantilla/ai/classes/aiactions/responses/response_base.php',
    'core_ai\\aiactions\\responses\\response_explain_text' => '/var/www/html/plantilla/ai/classes/aiactions/responses/response_explain_text.php',
    'core_ai\\aiactions\\responses\\response_generate_image' => '/var/www/html/plantilla/ai/classes/aiactions/responses/response_generate_image.php',
    'core_ai\\aiactions\\responses\\response_generate_text' => '/var/www/html/plantilla/ai/classes/aiactions/responses/response_generate_text.php',
    'core_ai\\aiactions\\responses\\response_summarise_text' => '/var/www/html/plantilla/ai/classes/aiactions/responses/response_summarise_text.php',
    'core_ai\\aiactions\\summarise_text' => '/var/www/html/plantilla/ai/classes/aiactions/summarise_text.php',
    'core_ai\\aimodel\\base' => '/var/www/html/plantilla/ai/classes/aimodel/base.php',
    'core_ai\\cache\\policy' => '/var/www/html/plantilla/ai/classes/cache/policy.php',
    'core_ai\\external\\delete_provider_instance' => '/var/www/html/plantilla/ai/classes/external/delete_provider_instance.php',
    'core_ai\\external\\get_policy_status' => '/var/www/html/plantilla/ai/classes/external/get_policy_status.php',
    'core_ai\\external\\set_action' => '/var/www/html/plantilla/ai/classes/external/set_action.php',
    'core_ai\\external\\set_policy_status' => '/var/www/html/plantilla/ai/classes/external/set_policy_status.php',
    'core_ai\\external\\set_provider_order' => '/var/www/html/plantilla/ai/classes/external/set_provider_order.php',
    'core_ai\\external\\set_provider_status' => '/var/www/html/plantilla/ai/classes/external/set_provider_status.php',
    'core_ai\\form\\action_settings_form' => '/var/www/html/plantilla/ai/classes/form/action_settings_form.php',
    'core_ai\\form\\ai_provider_form' => '/var/www/html/plantilla/ai/classes/form/ai_provider_form.php',
    'core_ai\\hook\\after_ai_action_settings_form_hook' => '/var/www/html/plantilla/ai/classes/hook/after_ai_action_settings_form_hook.php',
    'core_ai\\hook\\after_ai_provider_form_hook' => '/var/www/html/plantilla/ai/classes/hook/after_ai_provider_form_hook.php',
    'core_ai\\hook\\before_provider_deleted' => '/var/www/html/plantilla/ai/classes/hook/before_provider_deleted.php',
    'core_ai\\hook\\before_provider_disabled' => '/var/www/html/plantilla/ai/classes/hook/before_provider_disabled.php',
    'core_ai\\manager' => '/var/www/html/plantilla/ai/classes/manager.php',
    'core_ai\\placement' => '/var/www/html/plantilla/ai/classes/placement.php',
    'core_ai\\privacy\\provider' => '/var/www/html/plantilla/ai/classes/privacy/provider.php',
    'core_ai\\process_base' => '/var/www/html/plantilla/ai/classes/process_base.php',
    'core_ai\\provider' => '/var/www/html/plantilla/ai/classes/provider.php',
    'core_ai\\rate_limiter' => '/var/www/html/plantilla/ai/classes/rate_limiter.php',
    'core_ai\\reportbuilder\\local\\entities\\ai_action_register' => '/var/www/html/plantilla/ai/classes/reportbuilder/local/entities/ai_action_register.php',
    'core_ai\\reportbuilder\\local\\entities\\ai_policy_register' => '/var/www/html/plantilla/ai/classes/reportbuilder/local/entities/ai_policy_register.php',
    'core_ai\\reportbuilder\\local\\systemreports\\policy_acceptance' => '/var/www/html/plantilla/ai/classes/reportbuilder/local/systemreports/policy_acceptance.php',
    'core_ai\\reportbuilder\\local\\systemreports\\usage' => '/var/www/html/plantilla/ai/classes/reportbuilder/local/systemreports/usage.php',
    'core_ai\\table\\aiplacement_action_management_table' => '/var/www/html/plantilla/ai/classes/table/aiplacement_action_management_table.php',
    'core_ai\\table\\aiplacement_action_management_table_filterset' => '/var/www/html/plantilla/ai/classes/table/aiplacement_action_management_table_filterset.php',
    'core_ai\\table\\aiplacement_management_table' => '/var/www/html/plantilla/ai/classes/table/aiplacement_management_table.php',
    'core_ai\\table\\aiprovider_action_management_table' => '/var/www/html/plantilla/ai/classes/table/aiprovider_action_management_table.php',
    'core_ai\\table\\aiprovider_action_management_table_filterset' => '/var/www/html/plantilla/ai/classes/table/aiprovider_action_management_table_filterset.php',
    'core_ai\\table\\aiprovider_management_table' => '/var/www/html/plantilla/ai/classes/table/aiprovider_management_table.php',
    'core_ai\\table\\aiprovider_management_table_filterset' => '/var/www/html/plantilla/ai/classes/table/aiprovider_management_table_filterset.php',
    'core_ai_ai_image' => '/var/www/html/plantilla/ai/classes/ai_image.php',
    'core_ai_manager' => '/var/www/html/plantilla/ai/classes/manager.php',
    'core_ai_placement' => '/var/www/html/plantilla/ai/classes/placement.php',
    'core_ai_process_base' => '/var/www/html/plantilla/ai/classes/process_base.php',
    'core_ai_provider' => '/var/www/html/plantilla/ai/classes/provider.php',
    'core_ai_rate_limiter' => '/var/www/html/plantilla/ai/classes/rate_limiter.php',
    'core_analytics\\action' => '/var/www/html/plantilla/analytics/classes/action.php',
    'core_analytics\\admin_setting_predictor' => '/var/www/html/plantilla/analytics/classes/admin_setting_predictor.php',
    'core_analytics\\analysable' => '/var/www/html/plantilla/analytics/classes/analysable.php',
    'core_analytics\\analysis' => '/var/www/html/plantilla/analytics/classes/analysis.php',
    'core_analytics\\bulk_action' => '/var/www/html/plantilla/analytics/classes/bulk_action.php',
    'core_analytics\\calculable' => '/var/www/html/plantilla/analytics/classes/calculable.php',
    'core_analytics\\calculation_info' => '/var/www/html/plantilla/analytics/classes/calculation_info.php',
    'core_analytics\\classifier' => '/var/www/html/plantilla/analytics/classes/classifier.php',
    'core_analytics\\course' => '/var/www/html/plantilla/analytics/classes/course.php',
    'core_analytics\\dataset_manager' => '/var/www/html/plantilla/analytics/classes/dataset_manager.php',
    'core_analytics\\default_bulk_actions' => '/var/www/html/plantilla/analytics/classes/default_bulk_actions.php',
    'core_analytics\\insights_generator' => '/var/www/html/plantilla/analytics/classes/insights_generator.php',
    'core_analytics\\local\\analyser\\base' => '/var/www/html/plantilla/analytics/classes/local/analyser/base.php',
    'core_analytics\\local\\analyser\\by_course' => '/var/www/html/plantilla/analytics/classes/local/analyser/by_course.php',
    'core_analytics\\local\\analyser\\sitewide' => '/var/www/html/plantilla/analytics/classes/local/analyser/sitewide.php',
    'core_analytics\\local\\analysis\\result' => '/var/www/html/plantilla/analytics/classes/local/analysis/result.php',
    'core_analytics\\local\\analysis\\result_array' => '/var/www/html/plantilla/analytics/classes/local/analysis/result_array.php',
    'core_analytics\\local\\analysis\\result_file' => '/var/www/html/plantilla/analytics/classes/local/analysis/result_file.php',
    'core_analytics\\local\\indicator\\base' => '/var/www/html/plantilla/analytics/classes/local/indicator/base.php',
    'core_analytics\\local\\indicator\\binary' => '/var/www/html/plantilla/analytics/classes/local/indicator/binary.php',
    'core_analytics\\local\\indicator\\community_of_inquiry_activity' => '/var/www/html/plantilla/analytics/classes/local/indicator/community_of_inquiry_activity.php',
    'core_analytics\\local\\indicator\\discrete' => '/var/www/html/plantilla/analytics/classes/local/indicator/discrete.php',
    'core_analytics\\local\\indicator\\linear' => '/var/www/html/plantilla/analytics/classes/local/indicator/linear.php',
    'core_analytics\\local\\target\\base' => '/var/www/html/plantilla/analytics/classes/local/target/base.php',
    'core_analytics\\local\\target\\binary' => '/var/www/html/plantilla/analytics/classes/local/target/binary.php',
    'core_analytics\\local\\target\\discrete' => '/var/www/html/plantilla/analytics/classes/local/target/discrete.php',
    'core_analytics\\local\\target\\linear' => '/var/www/html/plantilla/analytics/classes/local/target/linear.php',
    'core_analytics\\local\\time_splitting\\accumulative_parts' => '/var/www/html/plantilla/analytics/classes/local/time_splitting/accumulative_parts.php',
    'core_analytics\\local\\time_splitting\\after_now' => '/var/www/html/plantilla/analytics/classes/local/time_splitting/after_now.php',
    'core_analytics\\local\\time_splitting\\after_start' => '/var/www/html/plantilla/analytics/classes/local/time_splitting/after_start.php',
    'core_analytics\\local\\time_splitting\\base' => '/var/www/html/plantilla/analytics/classes/local/time_splitting/base.php',
    'core_analytics\\local\\time_splitting\\before_now' => '/var/www/html/plantilla/analytics/classes/local/time_splitting/before_now.php',
    'core_analytics\\local\\time_splitting\\equal_parts' => '/var/www/html/plantilla/analytics/classes/local/time_splitting/equal_parts.php',
    'core_analytics\\local\\time_splitting\\past_periodic' => '/var/www/html/plantilla/analytics/classes/local/time_splitting/past_periodic.php',
    'core_analytics\\local\\time_splitting\\periodic' => '/var/www/html/plantilla/analytics/classes/local/time_splitting/periodic.php',
    'core_analytics\\local\\time_splitting\\upcoming_periodic' => '/var/www/html/plantilla/analytics/classes/local/time_splitting/upcoming_periodic.php',
    'core_analytics\\manager' => '/var/www/html/plantilla/analytics/classes/manager.php',
    'core_analytics\\model' => '/var/www/html/plantilla/analytics/classes/model.php',
    'core_analytics\\model_config' => '/var/www/html/plantilla/analytics/classes/model_config.php',
    'core_analytics\\packable' => '/var/www/html/plantilla/analytics/classes/packable.php',
    'core_analytics\\prediction' => '/var/www/html/plantilla/analytics/classes/prediction.php',
    'core_analytics\\prediction_action' => '/var/www/html/plantilla/analytics/classes/prediction_action.php',
    'core_analytics\\predictor' => '/var/www/html/plantilla/analytics/classes/predictor.php',
    'core_analytics\\privacy\\provider' => '/var/www/html/plantilla/analytics/classes/privacy/provider.php',
    'core_analytics\\regressor' => '/var/www/html/plantilla/analytics/classes/regressor.php',
    'core_analytics\\requirements_exception' => '/var/www/html/plantilla/analytics/classes/requirements_exception.php',
    'core_analytics\\site' => '/var/www/html/plantilla/analytics/classes/site.php',
    'core_analytics\\stats' => '/var/www/html/plantilla/analytics/classes/stats.php',
    'core_analytics\\user' => '/var/www/html/plantilla/analytics/classes/user.php',
    'core_analytics_action' => '/var/www/html/plantilla/analytics/classes/action.php',
    'core_analytics_admin_setting_predictor' => '/var/www/html/plantilla/analytics/classes/admin_setting_predictor.php',
    'core_analytics_analysable' => '/var/www/html/plantilla/analytics/classes/analysable.php',
    'core_analytics_analysis' => '/var/www/html/plantilla/analytics/classes/analysis.php',
    'core_analytics_bulk_action' => '/var/www/html/plantilla/analytics/classes/bulk_action.php',
    'core_analytics_calculable' => '/var/www/html/plantilla/analytics/classes/calculable.php',
    'core_analytics_calculation_info' => '/var/www/html/plantilla/analytics/classes/calculation_info.php',
    'core_analytics_classifier' => '/var/www/html/plantilla/analytics/classes/classifier.php',
    'core_analytics_course' => '/var/www/html/plantilla/analytics/classes/course.php',
    'core_analytics_dataset_manager' => '/var/www/html/plantilla/analytics/classes/dataset_manager.php',
    'core_analytics_default_bulk_actions' => '/var/www/html/plantilla/analytics/classes/default_bulk_actions.php',
    'core_analytics_insights_generator' => '/var/www/html/plantilla/analytics/classes/insights_generator.php',
    'core_analytics_manager' => '/var/www/html/plantilla/analytics/classes/manager.php',
    'core_analytics_model' => '/var/www/html/plantilla/analytics/classes/model.php',
    'core_analytics_model_config' => '/var/www/html/plantilla/analytics/classes/model_config.php',
    'core_analytics_packable' => '/var/www/html/plantilla/analytics/classes/packable.php',
    'core_analytics_prediction' => '/var/www/html/plantilla/analytics/classes/prediction.php',
    'core_analytics_prediction_action' => '/var/www/html/plantilla/analytics/classes/prediction_action.php',
    'core_analytics_predictor' => '/var/www/html/plantilla/analytics/classes/predictor.php',
    'core_analytics_regressor' => '/var/www/html/plantilla/analytics/classes/regressor.php',
    'core_analytics_requirements_exception' => '/var/www/html/plantilla/analytics/classes/requirements_exception.php',
    'core_analytics_site' => '/var/www/html/plantilla/analytics/classes/site.php',
    'core_analytics_stats' => '/var/www/html/plantilla/analytics/classes/stats.php',
    'core_analytics_user' => '/var/www/html/plantilla/analytics/classes/user.php',
    'core_antivirus\\privacy\\provider' => '/var/www/html/plantilla/lib/antivirus/classes/privacy/provider.php',
    'core_attribute_helper' => '/var/www/html/plantilla/lib/classes/attribute_helper.php',
    'core_auth\\digital_consent' => '/var/www/html/plantilla/auth/classes/digital_consent.php',
    'core_auth\\external' => '/var/www/html/plantilla/auth/classes/external.php',
    'core_auth\\form\\verify_age_location_form' => '/var/www/html/plantilla/auth/classes/form/verify_age_location_form.php',
    'core_auth\\output\\digital_minor_page' => '/var/www/html/plantilla/auth/classes/output/digital_minor_page.php',
    'core_auth\\output\\login' => '/var/www/html/plantilla/auth/classes/output/login.php',
    'core_auth\\output\\verify_age_location_page' => '/var/www/html/plantilla/auth/classes/output/verify_age_location_page.php',
    'core_auth\\privacy\\provider' => '/var/www/html/plantilla/auth/classes/privacy/provider.php',
    'core_auth_digital_consent' => '/var/www/html/plantilla/auth/classes/digital_consent.php',
    'core_auth_external' => '/var/www/html/plantilla/auth/classes/external.php',
    'core_availability\\capability_checker' => '/var/www/html/plantilla/availability/classes/capability_checker.php',
    'core_availability\\condition' => '/var/www/html/plantilla/availability/classes/condition.php',
    'core_availability\\frontend' => '/var/www/html/plantilla/availability/classes/frontend.php',
    'core_availability\\info' => '/var/www/html/plantilla/availability/classes/info.php',
    'core_availability\\info_module' => '/var/www/html/plantilla/availability/classes/info_module.php',
    'core_availability\\info_section' => '/var/www/html/plantilla/availability/classes/info_section.php',
    'core_availability\\multiple_messages' => '/var/www/html/plantilla/availability/classes/multiple_messages.php',
    'core_availability\\output\\availability_info' => '/var/www/html/plantilla/availability/classes/output/availability_info.php',
    'core_availability\\privacy\\provider' => '/var/www/html/plantilla/availability/classes/privacy/provider.php',
    'core_availability\\result' => '/var/www/html/plantilla/availability/classes/result.php',
    'core_availability\\tree' => '/var/www/html/plantilla/availability/classes/tree.php',
    'core_availability\\tree_node' => '/var/www/html/plantilla/availability/classes/tree_node.php',
    'core_availability_capability_checker' => '/var/www/html/plantilla/availability/classes/capability_checker.php',
    'core_availability_condition' => '/var/www/html/plantilla/availability/classes/condition.php',
    'core_availability_frontend' => '/var/www/html/plantilla/availability/classes/frontend.php',
    'core_availability_info' => '/var/www/html/plantilla/availability/classes/info.php',
    'core_availability_info_module' => '/var/www/html/plantilla/availability/classes/info_module.php',
    'core_availability_info_section' => '/var/www/html/plantilla/availability/classes/info_section.php',
    'core_availability_multiple_messages' => '/var/www/html/plantilla/availability/classes/multiple_messages.php',
    'core_availability_result' => '/var/www/html/plantilla/availability/classes/result.php',
    'core_availability_tree' => '/var/www/html/plantilla/availability/classes/tree.php',
    'core_availability_tree_node' => '/var/www/html/plantilla/availability/classes/tree_node.php',
    'core_backup\\hook\\after_copy_form_definition' => '/var/www/html/plantilla/backup/util/ui/classes/hook/after_copy_form_definition.php',
    'core_backup\\hook\\after_restore_root_define_settings' => '/var/www/html/plantilla/backup/util/ui/classes/hook/after_restore_root_define_settings.php',
    'core_backup\\hook\\before_copy_course_execute' => '/var/www/html/plantilla/backup/util/ui/classes/hook/before_copy_course_execute.php',
    'core_backup\\hook\\before_course_modified_check' => '/var/www/html/plantilla/backup/util/ui/classes/hook/before_course_modified_check.php',
    'core_backup\\hook\\copy_helper_process_formdata' => '/var/www/html/plantilla/backup/util/ui/classes/hook/copy_helper_process_formdata.php',
    'core_backup\\output\\copy_form' => '/var/www/html/plantilla/backup/util/ui/classes/output/copy_form.php',
    'core_backup\\privacy\\provider' => '/var/www/html/plantilla/backup/util/ui/classes/privacy/provider.php',
    'core_badges\\assertion' => '/var/www/html/plantilla/badges/classes/assertion.php',
    'core_badges\\backpack_api' => '/var/www/html/plantilla/badges/classes/backpack_api.php',
    'core_badges\\backpack_api2p1' => '/var/www/html/plantilla/badges/classes/backpack_api2p1.php',
    'core_badges\\backpack_api2p1_mapping' => '/var/www/html/plantilla/badges/classes/backpack_api2p1_mapping.php',
    'core_badges\\backpack_api_mapping' => '/var/www/html/plantilla/badges/classes/backpack_api_mapping.php',
    'core_badges\\badge' => '/var/www/html/plantilla/badges/classes/badge.php',
    'core_badges\\external' => '/var/www/html/plantilla/badges/classes/external.php',
    'core_badges\\external\\alignment_exporter' => '/var/www/html/plantilla/badges/classes/external/alignment_exporter.php',
    'core_badges\\external\\assertion_exporter' => '/var/www/html/plantilla/badges/classes/external/assertion_exporter.php',
    'core_badges\\external\\backpack_exporter' => '/var/www/html/plantilla/badges/classes/external/backpack_exporter.php',
    'core_badges\\external\\badgeclass_exporter' => '/var/www/html/plantilla/badges/classes/external/badgeclass_exporter.php',
    'core_badges\\external\\collection_exporter' => '/var/www/html/plantilla/badges/classes/external/collection_exporter.php',
    'core_badges\\external\\disable_badges' => '/var/www/html/plantilla/badges/classes/external/disable_badges.php',
    'core_badges\\external\\enable_badges' => '/var/www/html/plantilla/badges/classes/external/enable_badges.php',
    'core_badges\\external\\endorsement_exporter' => '/var/www/html/plantilla/badges/classes/external/endorsement_exporter.php',
    'core_badges\\external\\get_badge' => '/var/www/html/plantilla/badges/classes/external/get_badge.php',
    'core_badges\\external\\get_user_badge_by_hash' => '/var/www/html/plantilla/badges/classes/external/get_user_badge_by_hash.php',
    'core_badges\\external\\issuer_exporter' => '/var/www/html/plantilla/badges/classes/external/issuer_exporter.php',
    'core_badges\\external\\recipient_exporter' => '/var/www/html/plantilla/badges/classes/external/recipient_exporter.php',
    'core_badges\\external\\related_info_exporter' => '/var/www/html/plantilla/badges/classes/external/related_info_exporter.php',
    'core_badges\\external\\user_badge_exporter' => '/var/www/html/plantilla/badges/classes/external/user_badge_exporter.php',
    'core_badges\\external\\verification_exporter' => '/var/www/html/plantilla/badges/classes/external/verification_exporter.php',
    'core_badges\\form\\alignment' => '/var/www/html/plantilla/badges/classes/form/alignment.php',
    'core_badges\\form\\backpack' => '/var/www/html/plantilla/badges/classes/form/backpack.php',
    'core_badges\\form\\badge' => '/var/www/html/plantilla/badges/classes/form/badge.php',
    'core_badges\\form\\collections' => '/var/www/html/plantilla/badges/classes/form/collections.php',
    'core_badges\\form\\endorsement' => '/var/www/html/plantilla/badges/classes/form/endorsement.php',
    'core_badges\\form\\external_backpack' => '/var/www/html/plantilla/badges/classes/form/external_backpack.php',
    'core_badges\\form\\message' => '/var/www/html/plantilla/badges/classes/form/message.php',
    'core_badges\\form\\preferences' => '/var/www/html/plantilla/badges/classes/form/preferences.php',
    'core_badges\\form\\related' => '/var/www/html/plantilla/badges/classes/form/related.php',
    'core_badges\\helper' => '/var/www/html/plantilla/badges/classes/helper.php',
    'core_badges\\oauth2\\auth' => '/var/www/html/plantilla/badges/classes/oauth2/auth.php',
    'core_badges\\oauth2\\badge_backpack_oauth2' => '/var/www/html/plantilla/badges/classes/oauth2/badge_backpack_oauth2.php',
    'core_badges\\oauth2\\client' => '/var/www/html/plantilla/badges/classes/oauth2/client.php',
    'core_badges\\observer' => '/var/www/html/plantilla/badges/classes/observer.php',
    'core_badges\\output\\badge_alignments' => '/var/www/html/plantilla/badges/classes/output/badge_alignments.php',
    'core_badges\\output\\badge_collection' => '/var/www/html/plantilla/badges/classes/output/badge_collection.php',
    'core_badges\\output\\badge_recipients' => '/var/www/html/plantilla/badges/classes/output/badge_recipients.php',
    'core_badges\\output\\badge_related' => '/var/www/html/plantilla/badges/classes/output/badge_related.php',
    'core_badges\\output\\badge_user_collection' => '/var/www/html/plantilla/badges/classes/output/badge_user_collection.php',
    'core_badges\\output\\badgeclass' => '/var/www/html/plantilla/badges/classes/output/badgeclass.php',
    'core_badges\\output\\base_action_bar' => '/var/www/html/plantilla/badges/classes/output/base_action_bar.php',
    'core_badges\\output\\external_backpacks_page' => '/var/www/html/plantilla/badges/classes/output/external_backpacks_page.php',
    'core_badges\\output\\external_backpacks_table' => '/var/www/html/plantilla/badges/classes/output/external_backpacks_table.php',
    'core_badges\\output\\external_badge' => '/var/www/html/plantilla/badges/classes/output/external_badge.php',
    'core_badges\\output\\issued_badge' => '/var/www/html/plantilla/badges/classes/output/issued_badge.php',
    'core_badges\\output\\manage_badge_action_bar' => '/var/www/html/plantilla/badges/classes/output/manage_badge_action_bar.php',
    'core_badges\\output\\recipients_action_bar' => '/var/www/html/plantilla/badges/classes/output/recipients_action_bar.php',
    'core_badges\\output\\standard_action_bar' => '/var/www/html/plantilla/badges/classes/output/standard_action_bar.php',
    'core_badges\\png_metadata_handler' => '/var/www/html/plantilla/badges/classes/png_metadata_handler.php',
    'core_badges\\privacy\\provider' => '/var/www/html/plantilla/badges/classes/privacy/provider.php',
    'core_badges\\reportbuilder\\datasource\\badges' => '/var/www/html/plantilla/badges/classes/reportbuilder/datasource/badges.php',
    'core_badges\\reportbuilder\\datasource\\users' => '/var/www/html/plantilla/badges/classes/reportbuilder/datasource/users.php',
    'core_badges\\reportbuilder\\local\\entities\\badge' => '/var/www/html/plantilla/badges/classes/reportbuilder/local/entities/badge.php',
    'core_badges\\reportbuilder\\local\\entities\\badge_issued' => '/var/www/html/plantilla/badges/classes/reportbuilder/local/entities/badge_issued.php',
    'core_badges\\reportbuilder\\local\\systemreports\\badges' => '/var/www/html/plantilla/badges/classes/reportbuilder/local/systemreports/badges.php',
    'core_badges\\reportbuilder\\local\\systemreports\\course_badges' => '/var/www/html/plantilla/badges/classes/reportbuilder/local/systemreports/course_badges.php',
    'core_badges\\reportbuilder\\local\\systemreports\\recipients' => '/var/www/html/plantilla/badges/classes/reportbuilder/local/systemreports/recipients.php',
    'core_badges_assertion' => '/var/www/html/plantilla/badges/classes/assertion.php',
    'core_badges_backpack_api' => '/var/www/html/plantilla/badges/classes/backpack_api.php',
    'core_badges_backpack_api2p1' => '/var/www/html/plantilla/badges/classes/backpack_api2p1.php',
    'core_badges_backpack_api2p1_mapping' => '/var/www/html/plantilla/badges/classes/backpack_api2p1_mapping.php',
    'core_badges_backpack_api_mapping' => '/var/www/html/plantilla/badges/classes/backpack_api_mapping.php',
    'core_badges_badge' => '/var/www/html/plantilla/badges/classes/badge.php',
    'core_badges_external' => '/var/www/html/plantilla/badges/classes/external.php',
    'core_badges_helper' => '/var/www/html/plantilla/badges/classes/helper.php',
    'core_badges_observer' => '/var/www/html/plantilla/badges/classes/observer.php',
    'core_badges_png_metadata_handler' => '/var/www/html/plantilla/badges/classes/png_metadata_handler.php',
    'core_block\\external' => '/var/www/html/plantilla/blocks/classes/external.php',
    'core_block\\external\\fetch_addable_blocks' => '/var/www/html/plantilla/blocks/classes/external/fetch_addable_blocks.php',
    'core_block\\navigation\\views\\secondary' => '/var/www/html/plantilla/blocks/classes/navigation/views/secondary.php',
    'core_block\\output\\block_contents' => '/var/www/html/plantilla/blocks/classes/output/block_contents.php',
    'core_block\\output\\block_move_target' => '/var/www/html/plantilla/blocks/classes/output/block_move_target.php',
    'core_block\\privacy\\provider' => '/var/www/html/plantilla/blocks/classes/privacy/provider.php',
    'core_block_external' => '/var/www/html/plantilla/blocks/classes/external.php',
    'core_blog\\external' => '/var/www/html/plantilla/blog/classes/external.php',
    'core_blog\\external\\add_entry' => '/var/www/html/plantilla/blog/classes/external/add_entry.php',
    'core_blog\\external\\delete_entry' => '/var/www/html/plantilla/blog/classes/external/delete_entry.php',
    'core_blog\\external\\get_access_information' => '/var/www/html/plantilla/blog/classes/external/get_access_information.php',
    'core_blog\\external\\post_exporter' => '/var/www/html/plantilla/blog/classes/external/post_exporter.php',
    'core_blog\\external\\prepare_entry_for_edition' => '/var/www/html/plantilla/blog/classes/external/prepare_entry_for_edition.php',
    'core_blog\\external\\update_entry' => '/var/www/html/plantilla/blog/classes/external/update_entry.php',
    'core_blog\\privacy\\provider' => '/var/www/html/plantilla/blog/classes/privacy/provider.php',
    'core_blog\\reportbuilder\\datasource\\blogs' => '/var/www/html/plantilla/blog/classes/reportbuilder/datasource/blogs.php',
    'core_blog\\reportbuilder\\local\\entities\\blog' => '/var/www/html/plantilla/blog/classes/reportbuilder/local/entities/blog.php',
    'core_blog_external' => '/var/www/html/plantilla/blog/classes/external.php',
    'core_cache\\administration_helper' => '/var/www/html/plantilla/cache/classes/administration_helper.php',
    'core_cache\\allow_temporary_caches' => '/var/www/html/plantilla/cache/classes/allow_temporary_caches.php',
    'core_cache\\application_cache' => '/var/www/html/plantilla/cache/classes/application_cache.php',
    'core_cache\\cache' => '/var/www/html/plantilla/cache/classes/cache.php',
    'core_cache\\cache_lock_interface' => '/var/www/html/plantilla/cache/classes/cache_lock_interface.php',
    'core_cache\\cacheable_object_array' => '/var/www/html/plantilla/cache/classes/cacheable_object_array.php',
    'core_cache\\cacheable_object_interface' => '/var/www/html/plantilla/cache/classes/cacheable_object_interface.php',
    'core_cache\\cached_object' => '/var/www/html/plantilla/cache/classes/cached_object.php',
    'core_cache\\config' => '/var/www/html/plantilla/cache/classes/config.php',
    'core_cache\\config_writer' => '/var/www/html/plantilla/cache/classes/config_writer.php',
    'core_cache\\configurable_cache_interface' => '/var/www/html/plantilla/cache/classes/configurable_cache_interface.php',
    'core_cache\\data_source_interface' => '/var/www/html/plantilla/cache/classes/data_source_interface.php',
    'core_cache\\definition' => '/var/www/html/plantilla/cache/classes/definition.php',
    'core_cache\\disabled_cache' => '/var/www/html/plantilla/cache/classes/disabled_cache.php',
    'core_cache\\disabled_config' => '/var/www/html/plantilla/cache/classes/disabled_config.php',
    'core_cache\\disabled_factory' => '/var/www/html/plantilla/cache/classes/disabled_factory.php',
    'core_cache\\dummy_cachestore' => '/var/www/html/plantilla/cache/classes/dummy_cachestore.php',
    'core_cache\\exception\\cache_exception' => '/var/www/html/plantilla/cache/classes/exception/cache_exception.php',
    'core_cache\\factory' => '/var/www/html/plantilla/cache/classes/factory.php',
    'core_cache\\form\\cache_definition_mappings_form' => '/var/www/html/plantilla/cache/classes/form/cache_definition_mappings_form.php',
    'core_cache\\form\\cache_definition_sharing_form' => '/var/www/html/plantilla/cache/classes/form/cache_definition_sharing_form.php',
    'core_cache\\form\\cache_lock_form' => '/var/www/html/plantilla/cache/classes/form/cache_lock_form.php',
    'core_cache\\form\\cache_mode_mappings_form' => '/var/www/html/plantilla/cache/classes/form/cache_mode_mappings_form.php',
    'core_cache\\form\\cachestore_addinstance_form' => '/var/www/html/plantilla/cache/classes/form/cachestore_addinstance_form.php',
    'core_cache\\helper' => '/var/www/html/plantilla/cache/classes/helper.php',
    'core_cache\\key_aware_cache_interface' => '/var/www/html/plantilla/cache/classes/key_aware_cache_interface.php',
    'core_cache\\loader_interface' => '/var/www/html/plantilla/cache/classes/loader_interface.php',
    'core_cache\\loader_with_locking_interface' => '/var/www/html/plantilla/cache/classes/loader_with_locking_interface.php',
    'core_cache\\local\\administration_display_helper' => '/var/www/html/plantilla/cache/classes/local/administration_display_helper.php',
    'core_cache\\lockable_cache_interface' => '/var/www/html/plantilla/cache/classes/lockable_cache_interface.php',
    'core_cache\\output\\renderer' => '/var/www/html/plantilla/cache/classes/output/renderer.php',
    'core_cache\\output\\usage_samples_form' => '/var/www/html/plantilla/cache/classes/output/usage_samples_form.php',
    'core_cache\\privacy\\provider' => '/var/www/html/plantilla/cache/classes/privacy/provider.php',
    'core_cache\\request_cache' => '/var/www/html/plantilla/cache/classes/request_cache.php',
    'core_cache\\searchable_cache_interface' => '/var/www/html/plantilla/cache/classes/searchable_cache_interface.php',
    'core_cache\\session_cache' => '/var/www/html/plantilla/cache/classes/session_cache.php',
    'core_cache\\store' => '/var/www/html/plantilla/cache/classes/store.php',
    'core_cache\\store_interface' => '/var/www/html/plantilla/cache/classes/store_interface.php',
    'core_cache\\ttl_wrapper' => '/var/www/html/plantilla/cache/classes/ttl_wrapper.php',
    'core_cache\\version_wrapper' => '/var/www/html/plantilla/cache/classes/version_wrapper.php',
    'core_cache\\versionable_data_source_interface' => '/var/www/html/plantilla/cache/classes/versionable_data_source_interface.php',
    'core_cache_administration_helper' => '/var/www/html/plantilla/cache/classes/administration_helper.php',
    'core_cache_allow_temporary_caches' => '/var/www/html/plantilla/cache/classes/allow_temporary_caches.php',
    'core_cache_application_cache' => '/var/www/html/plantilla/cache/classes/application_cache.php',
    'core_cache_cache' => '/var/www/html/plantilla/cache/classes/cache.php',
    'core_cache_cache_lock_interface' => '/var/www/html/plantilla/cache/classes/cache_lock_interface.php',
    'core_cache_cacheable_object_array' => '/var/www/html/plantilla/cache/classes/cacheable_object_array.php',
    'core_cache_cacheable_object_interface' => '/var/www/html/plantilla/cache/classes/cacheable_object_interface.php',
    'core_cache_cached_object' => '/var/www/html/plantilla/cache/classes/cached_object.php',
    'core_cache_config' => '/var/www/html/plantilla/cache/classes/config.php',
    'core_cache_config_writer' => '/var/www/html/plantilla/cache/classes/config_writer.php',
    'core_cache_configurable_cache_interface' => '/var/www/html/plantilla/cache/classes/configurable_cache_interface.php',
    'core_cache_data_source_interface' => '/var/www/html/plantilla/cache/classes/data_source_interface.php',
    'core_cache_definition' => '/var/www/html/plantilla/cache/classes/definition.php',
    'core_cache_disabled_cache' => '/var/www/html/plantilla/cache/classes/disabled_cache.php',
    'core_cache_disabled_config' => '/var/www/html/plantilla/cache/classes/disabled_config.php',
    'core_cache_disabled_factory' => '/var/www/html/plantilla/cache/classes/disabled_factory.php',
    'core_cache_dummy_cachestore' => '/var/www/html/plantilla/cache/classes/dummy_cachestore.php',
    'core_cache_factory' => '/var/www/html/plantilla/cache/classes/factory.php',
    'core_cache_helper' => '/var/www/html/plantilla/cache/classes/helper.php',
    'core_cache_key_aware_cache_interface' => '/var/www/html/plantilla/cache/classes/key_aware_cache_interface.php',
    'core_cache_loader_interface' => '/var/www/html/plantilla/cache/classes/loader_interface.php',
    'core_cache_loader_with_locking_interface' => '/var/www/html/plantilla/cache/classes/loader_with_locking_interface.php',
    'core_cache_lockable_cache_interface' => '/var/www/html/plantilla/cache/classes/lockable_cache_interface.php',
    'core_cache_request_cache' => '/var/www/html/plantilla/cache/classes/request_cache.php',
    'core_cache_searchable_cache_interface' => '/var/www/html/plantilla/cache/classes/searchable_cache_interface.php',
    'core_cache_session_cache' => '/var/www/html/plantilla/cache/classes/session_cache.php',
    'core_cache_store' => '/var/www/html/plantilla/cache/classes/store.php',
    'core_cache_store_interface' => '/var/www/html/plantilla/cache/classes/store_interface.php',
    'core_cache_ttl_wrapper' => '/var/www/html/plantilla/cache/classes/ttl_wrapper.php',
    'core_cache_version_wrapper' => '/var/www/html/plantilla/cache/classes/version_wrapper.php',
    'core_cache_versionable_data_source_interface' => '/var/www/html/plantilla/cache/classes/versionable_data_source_interface.php',
    'core_calendar\\action_factory' => '/var/www/html/plantilla/calendar/classes/action_factory.php',
    'core_calendar\\export_form' => '/var/www/html/plantilla/calendar/classes/export_form.php',
    'core_calendar\\external\\calendar_day_exporter' => '/var/www/html/plantilla/calendar/classes/external/calendar_day_exporter.php',
    'core_calendar\\external\\calendar_event_exporter' => '/var/www/html/plantilla/calendar/classes/external/calendar_event_exporter.php',
    'core_calendar\\external\\calendar_upcoming_exporter' => '/var/www/html/plantilla/calendar/classes/external/calendar_upcoming_exporter.php',
    'core_calendar\\external\\date_exporter' => '/var/www/html/plantilla/calendar/classes/external/date_exporter.php',
    'core_calendar\\external\\day_exporter' => '/var/www/html/plantilla/calendar/classes/external/day_exporter.php',
    'core_calendar\\external\\day_name_exporter' => '/var/www/html/plantilla/calendar/classes/external/day_name_exporter.php',
    'core_calendar\\external\\event_action_exporter' => '/var/www/html/plantilla/calendar/classes/external/event_action_exporter.php',
    'core_calendar\\external\\event_exporter' => '/var/www/html/plantilla/calendar/classes/external/event_exporter.php',
    'core_calendar\\external\\event_exporter_base' => '/var/www/html/plantilla/calendar/classes/external/event_exporter_base.php',
    'core_calendar\\external\\event_icon_exporter' => '/var/www/html/plantilla/calendar/classes/external/event_icon_exporter.php',
    'core_calendar\\external\\event_subscription_exporter' => '/var/www/html/plantilla/calendar/classes/external/event_subscription_exporter.php',
    'core_calendar\\external\\events_exporter' => '/var/www/html/plantilla/calendar/classes/external/events_exporter.php',
    'core_calendar\\external\\events_grouped_by_course_exporter' => '/var/www/html/plantilla/calendar/classes/external/events_grouped_by_course_exporter.php',
    'core_calendar\\external\\events_related_objects_cache' => '/var/www/html/plantilla/calendar/classes/external/events_related_objects_cache.php',
    'core_calendar\\external\\events_same_course_exporter' => '/var/www/html/plantilla/calendar/classes/external/events_same_course_exporter.php',
    'core_calendar\\external\\export\\token' => '/var/www/html/plantilla/calendar/classes/external/export/token.php',
    'core_calendar\\external\\footer_options_exporter' => '/var/www/html/plantilla/calendar/classes/external/footer_options_exporter.php',
    'core_calendar\\external\\month_exporter' => '/var/www/html/plantilla/calendar/classes/external/month_exporter.php',
    'core_calendar\\external\\subscription\\delete' => '/var/www/html/plantilla/calendar/classes/external/subscription/delete.php',
    'core_calendar\\external\\week_day_exporter' => '/var/www/html/plantilla/calendar/classes/external/week_day_exporter.php',
    'core_calendar\\external\\week_exporter' => '/var/www/html/plantilla/calendar/classes/external/week_exporter.php',
    'core_calendar\\local\\api' => '/var/www/html/plantilla/calendar/classes/local/api.php',
    'core_calendar\\local\\event\\container' => '/var/www/html/plantilla/calendar/classes/local/event/container.php',
    'core_calendar\\local\\event\\data_access\\event_vault' => '/var/www/html/plantilla/calendar/classes/local/event/data_access/event_vault.php',
    'core_calendar\\local\\event\\data_access\\event_vault_interface' => '/var/www/html/plantilla/calendar/classes/local/event/data_access/event_vault_interface.php',
    'core_calendar\\local\\event\\entities\\action_event' => '/var/www/html/plantilla/calendar/classes/local/event/entities/action_event.php',
    'core_calendar\\local\\event\\entities\\action_event_interface' => '/var/www/html/plantilla/calendar/classes/local/event/entities/action_event_interface.php',
    'core_calendar\\local\\event\\entities\\action_interface' => '/var/www/html/plantilla/calendar/classes/local/event/entities/action_interface.php',
    'core_calendar\\local\\event\\entities\\event' => '/var/www/html/plantilla/calendar/classes/local/event/entities/event.php',
    'core_calendar\\local\\event\\entities\\event_collection_interface' => '/var/www/html/plantilla/calendar/classes/local/event/entities/event_collection_interface.php',
    'core_calendar\\local\\event\\entities\\event_interface' => '/var/www/html/plantilla/calendar/classes/local/event/entities/event_interface.php',
    'core_calendar\\local\\event\\entities\\repeat_event_collection' => '/var/www/html/plantilla/calendar/classes/local/event/entities/repeat_event_collection.php',
    'core_calendar\\local\\event\\exceptions\\invalid_callback_exception' => '/var/www/html/plantilla/calendar/classes/local/event/exceptions/invalid_callback_exception.php',
    'core_calendar\\local\\event\\exceptions\\invalid_parameter_exception' => '/var/www/html/plantilla/calendar/classes/local/event/exceptions/invalid_parameter_exception.php',
    'core_calendar\\local\\event\\exceptions\\limit_invalid_parameter_exception' => '/var/www/html/plantilla/calendar/classes/local/event/exceptions/limit_invalid_parameter_exception.php',
    'core_calendar\\local\\event\\exceptions\\member_does_not_exist_exception' => '/var/www/html/plantilla/calendar/classes/local/event/exceptions/member_does_not_exist_exception.php',
    'core_calendar\\local\\event\\exceptions\\timesort_invalid_parameter_exception' => '/var/www/html/plantilla/calendar/classes/local/event/exceptions/timesort_invalid_parameter_exception.php',
    'core_calendar\\local\\event\\factories\\action_factory_interface' => '/var/www/html/plantilla/calendar/classes/local/event/factories/action_factory_interface.php',
    'core_calendar\\local\\event\\factories\\event_abstract_factory' => '/var/www/html/plantilla/calendar/classes/local/event/factories/event_abstract_factory.php',
    'core_calendar\\local\\event\\factories\\event_factory' => '/var/www/html/plantilla/calendar/classes/local/event/factories/event_factory.php',
    'core_calendar\\local\\event\\factories\\event_factory_interface' => '/var/www/html/plantilla/calendar/classes/local/event/factories/event_factory_interface.php',
    'core_calendar\\local\\event\\forms\\create' => '/var/www/html/plantilla/calendar/classes/local/event/forms/create.php',
    'core_calendar\\local\\event\\forms\\eventtype' => '/var/www/html/plantilla/calendar/classes/local/event/forms/eventtype.php',
    'core_calendar\\local\\event\\forms\\managesubscriptions' => '/var/www/html/plantilla/calendar/classes/local/event/forms/managesubscriptions.php',
    'core_calendar\\local\\event\\forms\\update' => '/var/www/html/plantilla/calendar/classes/local/event/forms/update.php',
    'core_calendar\\local\\event\\mappers\\create_update_form_mapper' => '/var/www/html/plantilla/calendar/classes/local/event/mappers/create_update_form_mapper.php',
    'core_calendar\\local\\event\\mappers\\create_update_form_mapper_interface' => '/var/www/html/plantilla/calendar/classes/local/event/mappers/create_update_form_mapper_interface.php',
    'core_calendar\\local\\event\\mappers\\event_mapper' => '/var/www/html/plantilla/calendar/classes/local/event/mappers/event_mapper.php',
    'core_calendar\\local\\event\\mappers\\event_mapper_interface' => '/var/www/html/plantilla/calendar/classes/local/event/mappers/event_mapper_interface.php',
    'core_calendar\\local\\event\\proxies\\cm_info_proxy' => '/var/www/html/plantilla/calendar/classes/local/event/proxies/cm_info_proxy.php',
    'core_calendar\\local\\event\\proxies\\coursecat_proxy' => '/var/www/html/plantilla/calendar/classes/local/event/proxies/coursecat_proxy.php',
    'core_calendar\\local\\event\\proxies\\proxy_interface' => '/var/www/html/plantilla/calendar/classes/local/event/proxies/proxy_interface.php',
    'core_calendar\\local\\event\\proxies\\std_proxy' => '/var/www/html/plantilla/calendar/classes/local/event/proxies/std_proxy.php',
    'core_calendar\\local\\event\\strategies\\raw_event_retrieval_strategy' => '/var/www/html/plantilla/calendar/classes/local/event/strategies/raw_event_retrieval_strategy.php',
    'core_calendar\\local\\event\\strategies\\raw_event_retrieval_strategy_interface' => '/var/www/html/plantilla/calendar/classes/local/event/strategies/raw_event_retrieval_strategy_interface.php',
    'core_calendar\\local\\event\\value_objects\\action' => '/var/www/html/plantilla/calendar/classes/local/event/value_objects/action.php',
    'core_calendar\\local\\event\\value_objects\\description_interface' => '/var/www/html/plantilla/calendar/classes/local/event/value_objects/description_interface.php',
    'core_calendar\\local\\event\\value_objects\\event_description' => '/var/www/html/plantilla/calendar/classes/local/event/value_objects/event_description.php',
    'core_calendar\\local\\event\\value_objects\\event_times' => '/var/www/html/plantilla/calendar/classes/local/event/value_objects/event_times.php',
    'core_calendar\\local\\event\\value_objects\\times_interface' => '/var/www/html/plantilla/calendar/classes/local/event/value_objects/times_interface.php',
    'core_calendar\\output\\humandate' => '/var/www/html/plantilla/calendar/classes/output/humandate.php',
    'core_calendar\\output\\humantimeperiod' => '/var/www/html/plantilla/calendar/classes/output/humantimeperiod.php',
    'core_calendar\\output\\refreshintervalcollection' => '/var/www/html/plantilla/calendar/classes/output/refreshintervalcollection.php',
    'core_calendar\\privacy\\provider' => '/var/www/html/plantilla/calendar/classes/privacy/provider.php',
    'core_calendar\\rrule_manager' => '/var/www/html/plantilla/calendar/classes/rrule_manager.php',
    'core_calendar\\type_base' => '/var/www/html/plantilla/calendar/classes/type_base.php',
    'core_calendar\\type_factory' => '/var/www/html/plantilla/calendar/classes/type_factory.php',
    'core_calendar_action_factory' => '/var/www/html/plantilla/calendar/classes/action_factory.php',
    'core_calendar_export_form' => '/var/www/html/plantilla/calendar/classes/export_form.php',
    'core_calendar_rrule_manager' => '/var/www/html/plantilla/calendar/classes/rrule_manager.php',
    'core_calendar_type_base' => '/var/www/html/plantilla/calendar/classes/type_base.php',
    'core_calendar_type_factory' => '/var/www/html/plantilla/calendar/classes/type_factory.php',
    'core_chart_axis' => '/var/www/html/plantilla/lib/classes/chart_axis.php',
    'core_chart_bar' => '/var/www/html/plantilla/lib/classes/chart_bar.php',
    'core_chart_base' => '/var/www/html/plantilla/lib/classes/chart_base.php',
    'core_chart_line' => '/var/www/html/plantilla/lib/classes/chart_line.php',
    'core_chart_pie' => '/var/www/html/plantilla/lib/classes/chart_pie.php',
    'core_chart_series' => '/var/www/html/plantilla/lib/classes/chart_series.php',
    'core_clock' => '/var/www/html/plantilla/lib/classes/clock.php',
    'core_cohort\\customfield\\cohort_handler' => '/var/www/html/plantilla/cohort/classes/customfield/cohort_handler.php',
    'core_cohort\\external\\cohort_summary_exporter' => '/var/www/html/plantilla/cohort/classes/external/cohort_summary_exporter.php',
    'core_cohort\\output\\cohortidnumber' => '/var/www/html/plantilla/cohort/classes/output/cohortidnumber.php',
    'core_cohort\\output\\cohortname' => '/var/www/html/plantilla/cohort/classes/output/cohortname.php',
    'core_cohort\\privacy\\provider' => '/var/www/html/plantilla/cohort/classes/privacy/provider.php',
    'core_cohort\\reportbuilder\\audience\\cohortmember' => '/var/www/html/plantilla/cohort/classes/reportbuilder/audience/cohortmember.php',
    'core_cohort\\reportbuilder\\datasource\\cohorts' => '/var/www/html/plantilla/cohort/classes/reportbuilder/datasource/cohorts.php',
    'core_cohort\\reportbuilder\\local\\entities\\cohort' => '/var/www/html/plantilla/cohort/classes/reportbuilder/local/entities/cohort.php',
    'core_cohort\\reportbuilder\\local\\entities\\cohort_member' => '/var/www/html/plantilla/cohort/classes/reportbuilder/local/entities/cohort_member.php',
    'core_cohort\\reportbuilder\\local\\systemreports\\cohorts' => '/var/www/html/plantilla/cohort/classes/reportbuilder/local/systemreports/cohorts.php',
    'core_collator' => '/var/www/html/plantilla/lib/classes/collator.php',
    'core_comment\\external' => '/var/www/html/plantilla/comment/classes/external.php',
    'core_comment\\external\\comment_area_exporter' => '/var/www/html/plantilla/comment/classes/external/comment_area_exporter.php',
    'core_comment\\privacy\\provider' => '/var/www/html/plantilla/comment/classes/privacy/provider.php',
    'core_comment\\reportbuilder\\datasource\\comments' => '/var/www/html/plantilla/comment/classes/reportbuilder/datasource/comments.php',
    'core_comment\\reportbuilder\\local\\entities\\comment' => '/var/www/html/plantilla/comment/classes/reportbuilder/local/entities/comment.php',
    'core_comment\\reportbuilder\\local\\systemreports\\comments' => '/var/www/html/plantilla/comment/classes/reportbuilder/local/systemreports/comments.php',
    'core_comment_external' => '/var/www/html/plantilla/comment/classes/external.php',
    'core_communication\\admin\\manage_communication_providers_page' => '/var/www/html/plantilla/communication/classes/admin/manage_communication_providers_page.php',
    'core_communication\\api' => '/var/www/html/plantilla/communication/classes/api.php',
    'core_communication\\communication_provider' => '/var/www/html/plantilla/communication/classes/communication_provider.php',
    'core_communication\\constants' => '/var/www/html/plantilla/communication/classes/constants.php',
    'core_communication\\form\\configure_form' => '/var/www/html/plantilla/communication/classes/form/configure_form.php',
    'core_communication\\form_provider' => '/var/www/html/plantilla/communication/classes/form_provider.php',
    'core_communication\\helper' => '/var/www/html/plantilla/communication/classes/helper.php',
    'core_communication\\hook_listener' => '/var/www/html/plantilla/communication/classes/hook_listener.php',
    'core_communication\\privacy\\provider' => '/var/www/html/plantilla/communication/classes/privacy/provider.php',
    'core_communication\\processor' => '/var/www/html/plantilla/communication/classes/processor.php',
    'core_communication\\room_chat_provider' => '/var/www/html/plantilla/communication/classes/room_chat_provider.php',
    'core_communication\\room_user_provider' => '/var/www/html/plantilla/communication/classes/room_user_provider.php',
    'core_communication\\synchronise_provider' => '/var/www/html/plantilla/communication/classes/synchronise_provider.php',
    'core_communication\\task\\add_members_to_room_task' => '/var/www/html/plantilla/communication/classes/task/add_members_to_room_task.php',
    'core_communication\\task\\create_and_configure_room_task' => '/var/www/html/plantilla/communication/classes/task/create_and_configure_room_task.php',
    'core_communication\\task\\delete_room_task' => '/var/www/html/plantilla/communication/classes/task/delete_room_task.php',
    'core_communication\\task\\remove_members_from_room' => '/var/www/html/plantilla/communication/classes/task/remove_members_from_room.php',
    'core_communication\\task\\synchronise_provider_task' => '/var/www/html/plantilla/communication/classes/task/synchronise_provider_task.php',
    'core_communication\\task\\synchronise_providers_task' => '/var/www/html/plantilla/communication/classes/task/synchronise_providers_task.php',
    'core_communication\\task\\update_room_membership_task' => '/var/www/html/plantilla/communication/classes/task/update_room_membership_task.php',
    'core_communication\\task\\update_room_task' => '/var/www/html/plantilla/communication/classes/task/update_room_task.php',
    'core_communication\\user_provider' => '/var/www/html/plantilla/communication/classes/user_provider.php',
    'core_communication_api' => '/var/www/html/plantilla/communication/classes/api.php',
    'core_communication_communication_provider' => '/var/www/html/plantilla/communication/classes/communication_provider.php',
    'core_communication_constants' => '/var/www/html/plantilla/communication/classes/constants.php',
    'core_communication_form_provider' => '/var/www/html/plantilla/communication/classes/form_provider.php',
    'core_communication_helper' => '/var/www/html/plantilla/communication/classes/helper.php',
    'core_communication_hook_listener' => '/var/www/html/plantilla/communication/classes/hook_listener.php',
    'core_communication_processor' => '/var/www/html/plantilla/communication/classes/processor.php',
    'core_communication_room_chat_provider' => '/var/www/html/plantilla/communication/classes/room_chat_provider.php',
    'core_communication_room_user_provider' => '/var/www/html/plantilla/communication/classes/room_user_provider.php',
    'core_communication_synchronise_provider' => '/var/www/html/plantilla/communication/classes/synchronise_provider.php',
    'core_communication_user_provider' => '/var/www/html/plantilla/communication/classes/user_provider.php',
    'core_competency\\api' => '/var/www/html/plantilla/competency/classes/api.php',
    'core_competency\\competency' => '/var/www/html/plantilla/competency/classes/competency.php',
    'core_competency\\competency_framework' => '/var/www/html/plantilla/competency/classes/competency_framework.php',
    'core_competency\\competency_rule' => '/var/www/html/plantilla/competency/classes/competency_rule.php',
    'core_competency\\competency_rule_all' => '/var/www/html/plantilla/competency/classes/competency_rule_all.php',
    'core_competency\\competency_rule_points' => '/var/www/html/plantilla/competency/classes/competency_rule_points.php',
    'core_competency\\course_competency' => '/var/www/html/plantilla/competency/classes/course_competency.php',
    'core_competency\\course_competency_settings' => '/var/www/html/plantilla/competency/classes/course_competency_settings.php',
    'core_competency\\course_module_competency' => '/var/www/html/plantilla/competency/classes/course_module_competency.php',
    'core_competency\\evidence' => '/var/www/html/plantilla/competency/classes/evidence.php',
    'core_competency\\external' => '/var/www/html/plantilla/competency/classes/external.php',
    'core_competency\\external\\competency_exporter' => '/var/www/html/plantilla/competency/classes/external/competency_exporter.php',
    'core_competency\\external\\competency_framework_exporter' => '/var/www/html/plantilla/competency/classes/external/competency_framework_exporter.php',
    'core_competency\\external\\course_competency_exporter' => '/var/www/html/plantilla/competency/classes/external/course_competency_exporter.php',
    'core_competency\\external\\course_competency_settings_exporter' => '/var/www/html/plantilla/competency/classes/external/course_competency_settings_exporter.php',
    'core_competency\\external\\course_module_competency_exporter' => '/var/www/html/plantilla/competency/classes/external/course_module_competency_exporter.php',
    'core_competency\\external\\evidence_exporter' => '/var/www/html/plantilla/competency/classes/external/evidence_exporter.php',
    'core_competency\\external\\performance_helper' => '/var/www/html/plantilla/competency/classes/external/performance_helper.php',
    'core_competency\\external\\plan_competency_exporter' => '/var/www/html/plantilla/competency/classes/external/plan_competency_exporter.php',
    'core_competency\\external\\plan_exporter' => '/var/www/html/plantilla/competency/classes/external/plan_exporter.php',
    'core_competency\\external\\related_competency_exporter' => '/var/www/html/plantilla/competency/classes/external/related_competency_exporter.php',
    'core_competency\\external\\template_competency_exporter' => '/var/www/html/plantilla/competency/classes/external/template_competency_exporter.php',
    'core_competency\\external\\template_exporter' => '/var/www/html/plantilla/competency/classes/external/template_exporter.php',
    'core_competency\\external\\user_competency_course_exporter' => '/var/www/html/plantilla/competency/classes/external/user_competency_course_exporter.php',
    'core_competency\\external\\user_competency_exporter' => '/var/www/html/plantilla/competency/classes/external/user_competency_exporter.php',
    'core_competency\\external\\user_competency_plan_exporter' => '/var/www/html/plantilla/competency/classes/external/user_competency_plan_exporter.php',
    'core_competency\\external\\user_evidence_competency_exporter' => '/var/www/html/plantilla/competency/classes/external/user_evidence_competency_exporter.php',
    'core_competency\\external\\user_evidence_exporter' => '/var/www/html/plantilla/competency/classes/external/user_evidence_exporter.php',
    'core_competency\\persistent' => '/var/www/html/plantilla/competency/classes/persistent.php',
    'core_competency\\plan' => '/var/www/html/plantilla/competency/classes/plan.php',
    'core_competency\\plan_competency' => '/var/www/html/plantilla/competency/classes/plan_competency.php',
    'core_competency\\privacy\\provider' => '/var/www/html/plantilla/competency/classes/privacy/provider.php',
    'core_competency\\related_competency' => '/var/www/html/plantilla/competency/classes/related_competency.php',
    'core_competency\\reportbuilder\\datasource\\competencies' => '/var/www/html/plantilla/competency/classes/reportbuilder/datasource/competencies.php',
    'core_competency\\reportbuilder\\local\\entities\\competency' => '/var/www/html/plantilla/competency/classes/reportbuilder/local/entities/competency.php',
    'core_competency\\reportbuilder\\local\\entities\\framework' => '/var/www/html/plantilla/competency/classes/reportbuilder/local/entities/framework.php',
    'core_competency\\reportbuilder\\local\\entities\\usercompetency' => '/var/www/html/plantilla/competency/classes/reportbuilder/local/entities/usercompetency.php',
    'core_competency\\template' => '/var/www/html/plantilla/competency/classes/template.php',
    'core_competency\\template_cohort' => '/var/www/html/plantilla/competency/classes/template_cohort.php',
    'core_competency\\template_competency' => '/var/www/html/plantilla/competency/classes/template_competency.php',
    'core_competency\\url' => '/var/www/html/plantilla/competency/classes/url.php',
    'core_competency\\user_competency' => '/var/www/html/plantilla/competency/classes/user_competency.php',
    'core_competency\\user_competency_course' => '/var/www/html/plantilla/competency/classes/user_competency_course.php',
    'core_competency\\user_competency_plan' => '/var/www/html/plantilla/competency/classes/user_competency_plan.php',
    'core_competency\\user_evidence' => '/var/www/html/plantilla/competency/classes/user_evidence.php',
    'core_competency\\user_evidence_competency' => '/var/www/html/plantilla/competency/classes/user_evidence_competency.php',
    'core_competency_api' => '/var/www/html/plantilla/competency/classes/api.php',
    'core_competency_competency' => '/var/www/html/plantilla/competency/classes/competency.php',
    'core_competency_competency_framework' => '/var/www/html/plantilla/competency/classes/competency_framework.php',
    'core_competency_competency_rule' => '/var/www/html/plantilla/competency/classes/competency_rule.php',
    'core_competency_competency_rule_all' => '/var/www/html/plantilla/competency/classes/competency_rule_all.php',
    'core_competency_competency_rule_points' => '/var/www/html/plantilla/competency/classes/competency_rule_points.php',
    'core_competency_course_competency' => '/var/www/html/plantilla/competency/classes/course_competency.php',
    'core_competency_course_competency_settings' => '/var/www/html/plantilla/competency/classes/course_competency_settings.php',
    'core_competency_course_module_competency' => '/var/www/html/plantilla/competency/classes/course_module_competency.php',
    'core_competency_evidence' => '/var/www/html/plantilla/competency/classes/evidence.php',
    'core_competency_external' => '/var/www/html/plantilla/competency/classes/external.php',
    'core_competency_persistent' => '/var/www/html/plantilla/competency/classes/persistent.php',
    'core_competency_plan' => '/var/www/html/plantilla/competency/classes/plan.php',
    'core_competency_plan_competency' => '/var/www/html/plantilla/competency/classes/plan_competency.php',
    'core_competency_related_competency' => '/var/www/html/plantilla/competency/classes/related_competency.php',
    'core_competency_template' => '/var/www/html/plantilla/competency/classes/template.php',
    'core_competency_template_cohort' => '/var/www/html/plantilla/competency/classes/template_cohort.php',
    'core_competency_template_competency' => '/var/www/html/plantilla/competency/classes/template_competency.php',
    'core_competency_url' => '/var/www/html/plantilla/competency/classes/url.php',
    'core_competency_user_competency' => '/var/www/html/plantilla/competency/classes/user_competency.php',
    'core_competency_user_competency_course' => '/var/www/html/plantilla/competency/classes/user_competency_course.php',
    'core_competency_user_competency_plan' => '/var/www/html/plantilla/competency/classes/user_competency_plan.php',
    'core_competency_user_evidence' => '/var/www/html/plantilla/competency/classes/user_evidence.php',
    'core_competency_user_evidence_competency' => '/var/www/html/plantilla/competency/classes/user_evidence_competency.php',
    'core_completion\\activity_custom_completion' => '/var/www/html/plantilla/completion/classes/activity_custom_completion.php',
    'core_completion\\api' => '/var/www/html/plantilla/completion/classes/api.php',
    'core_completion\\bulkedit_form' => '/var/www/html/plantilla/completion/classes/bulkedit_form.php',
    'core_completion\\cm_completion_details' => '/var/www/html/plantilla/completion/classes/cm_completion_details.php',
    'core_completion\\defaultedit_form' => '/var/www/html/plantilla/completion/classes/defaultedit_form.php',
    'core_completion\\edit_base_form' => '/var/www/html/plantilla/completion/classes/edit_base_form.php',
    'core_completion\\external' => '/var/www/html/plantilla/completion/classes/external.php',
    'core_completion\\external\\completion_info_exporter' => '/var/www/html/plantilla/completion/classes/external/completion_info_exporter.php',
    'core_completion\\form\\form_trait' => '/var/www/html/plantilla/completion/classes/form/form_trait.php',
    'core_completion\\hook\\after_cm_completion_updated' => '/var/www/html/plantilla/completion/classes/hook/after_cm_completion_updated.php',
    'core_completion\\manager' => '/var/www/html/plantilla/completion/classes/manager.php',
    'core_completion\\privacy\\provider' => '/var/www/html/plantilla/completion/classes/privacy/provider.php',
    'core_completion\\progress' => '/var/www/html/plantilla/completion/classes/progress.php',
    'core_completion_activity_custom_completion' => '/var/www/html/plantilla/completion/classes/activity_custom_completion.php',
    'core_completion_api' => '/var/www/html/plantilla/completion/classes/api.php',
    'core_completion_bulkedit_form' => '/var/www/html/plantilla/completion/classes/bulkedit_form.php',
    'core_completion_cm_completion_details' => '/var/www/html/plantilla/completion/classes/cm_completion_details.php',
    'core_completion_defaultedit_form' => '/var/www/html/plantilla/completion/classes/defaultedit_form.php',
    'core_completion_edit_base_form' => '/var/www/html/plantilla/completion/classes/edit_base_form.php',
    'core_completion_external' => '/var/www/html/plantilla/completion/classes/external.php',
    'core_completion_manager' => '/var/www/html/plantilla/completion/classes/manager.php',
    'core_completion_progress' => '/var/www/html/plantilla/completion/classes/progress.php',
    'core_component' => '/var/www/html/plantilla/lib/classes/component.php',
    'core_content' => '/var/www/html/plantilla/lib/classes/content.php',
    'core_contentbank\\content' => '/var/www/html/plantilla/contentbank/classes/content.php',
    'core_contentbank\\contentbank' => '/var/www/html/plantilla/contentbank/classes/contentbank.php',
    'core_contentbank\\contenttype' => '/var/www/html/plantilla/contentbank/classes/contenttype.php',
    'core_contentbank\\customfield\\content_handler' => '/var/www/html/plantilla/contentbank/classes/customfield/content_handler.php',
    'core_contentbank\\external\\copy_content' => '/var/www/html/plantilla/contentbank/classes/external/copy_content.php',
    'core_contentbank\\external\\delete_content' => '/var/www/html/plantilla/contentbank/classes/external/delete_content.php',
    'core_contentbank\\external\\rename_content' => '/var/www/html/plantilla/contentbank/classes/external/rename_content.php',
    'core_contentbank\\external\\set_content_visibility' => '/var/www/html/plantilla/contentbank/classes/external/set_content_visibility.php',
    'core_contentbank\\form\\edit_content' => '/var/www/html/plantilla/contentbank/classes/form/edit_content.php',
    'core_contentbank\\form\\upload_files' => '/var/www/html/plantilla/contentbank/classes/form/upload_files.php',
    'core_contentbank\\helper' => '/var/www/html/plantilla/contentbank/classes/helper.php',
    'core_contentbank\\output\\bankcontent' => '/var/www/html/plantilla/contentbank/classes/output/bankcontent.php',
    'core_contentbank\\output\\customfields' => '/var/www/html/plantilla/contentbank/classes/output/customfields.php',
    'core_contentbank\\output\\viewcontent' => '/var/www/html/plantilla/contentbank/classes/output/viewcontent.php',
    'core_contentbank\\privacy\\provider' => '/var/www/html/plantilla/contentbank/classes/privacy/provider.php',
    'core_contentbank_content' => '/var/www/html/plantilla/contentbank/classes/content.php',
    'core_contentbank_contentbank' => '/var/www/html/plantilla/contentbank/classes/contentbank.php',
    'core_contentbank_contenttype' => '/var/www/html/plantilla/contentbank/classes/contenttype.php',
    'core_contentbank_helper' => '/var/www/html/plantilla/contentbank/classes/helper.php',
    'core_context' => '/var/www/html/plantilla/lib/classes/context.php',
    'core_context_helper' => '/var/www/html/plantilla/lib/classes/context_helper.php',
    'core_course\\analytics\\indicator\\activities_due' => '/var/www/html/plantilla/course/classes/analytics/indicator/activities_due.php',
    'core_course\\analytics\\indicator\\completion_enabled' => '/var/www/html/plantilla/course/classes/analytics/indicator/completion_enabled.php',
    'core_course\\analytics\\indicator\\no_student' => '/var/www/html/plantilla/course/classes/analytics/indicator/no_student.php',
    'core_course\\analytics\\indicator\\no_teacher' => '/var/www/html/plantilla/course/classes/analytics/indicator/no_teacher.php',
    'core_course\\analytics\\indicator\\potential_cognitive_depth' => '/var/www/html/plantilla/course/classes/analytics/indicator/potential_cognitive_depth.php',
    'core_course\\analytics\\indicator\\potential_social_breadth' => '/var/www/html/plantilla/course/classes/analytics/indicator/potential_social_breadth.php',
    'core_course\\analytics\\target\\course_competencies' => '/var/www/html/plantilla/course/classes/analytics/target/course_competencies.php',
    'core_course\\analytics\\target\\course_completion' => '/var/www/html/plantilla/course/classes/analytics/target/course_completion.php',
    'core_course\\analytics\\target\\course_dropout' => '/var/www/html/plantilla/course/classes/analytics/target/course_dropout.php',
    'core_course\\analytics\\target\\course_enrolments' => '/var/www/html/plantilla/course/classes/analytics/target/course_enrolments.php',
    'core_course\\analytics\\target\\course_gradetopass' => '/var/www/html/plantilla/course/classes/analytics/target/course_gradetopass.php',
    'core_course\\analytics\\target\\no_access_since_course_start' => '/var/www/html/plantilla/course/classes/analytics/target/no_access_since_course_start.php',
    'core_course\\analytics\\target\\no_recent_accesses' => '/var/www/html/plantilla/course/classes/analytics/target/no_recent_accesses.php',
    'core_course\\analytics\\target\\no_teaching' => '/var/www/html/plantilla/course/classes/analytics/target/no_teaching.php',
    'core_course\\cache\\course_image' => '/var/www/html/plantilla/course/classes/cache/course_image.php',
    'core_course\\category' => '/var/www/html/plantilla/course/classes/category.php',
    'core_course\\constants' => '/var/www/html/plantilla/course/classes/constants.php',
    'core_course\\customfield\\course_handler' => '/var/www/html/plantilla/course/classes/customfield/course_handler.php',
    'core_course\\deletecategory_form' => '/var/www/html/plantilla/course/classes/deletecategory_form.php',
    'core_course\\editcategory_form' => '/var/www/html/plantilla/course/classes/editcategory_form.php',
    'core_course\\external\\course_module_summary_exporter' => '/var/www/html/plantilla/course/classes/external/course_module_summary_exporter.php',
    'core_course\\external\\course_summary_exporter' => '/var/www/html/plantilla/course/classes/external/course_summary_exporter.php',
    'core_course\\external\\get_enrolled_courses_with_action_events_by_timeline_classification' => '/var/www/html/plantilla/course/classes/external/get_enrolled_courses_with_action_events_by_timeline_classification.php',
    'core_course\\external\\helper_for_get_mods_by_courses' => '/var/www/html/plantilla/course/classes/external/helper_for_get_mods_by_courses.php',
    'core_course\\form\\tags_form' => '/var/www/html/plantilla/course/classes/form/tags_form.php',
    'core_course\\hook\\after_course_created' => '/var/www/html/plantilla/course/classes/hook/after_course_created.php',
    'core_course\\hook\\after_course_updated' => '/var/www/html/plantilla/course/classes/hook/after_course_updated.php',
    'core_course\\hook\\after_form_definition' => '/var/www/html/plantilla/course/classes/hook/after_form_definition.php',
    'core_course\\hook\\after_form_definition_after_data' => '/var/www/html/plantilla/course/classes/hook/after_form_definition_after_data.php',
    'core_course\\hook\\after_form_submission' => '/var/www/html/plantilla/course/classes/hook/after_form_submission.php',
    'core_course\\hook\\after_form_validation' => '/var/www/html/plantilla/course/classes/hook/after_form_validation.php',
    'core_course\\hook\\before_activitychooserbutton_exported' => '/var/www/html/plantilla/course/classes/hook/before_activitychooserbutton_exported.php',
    'core_course\\hook\\before_course_deleted' => '/var/www/html/plantilla/course/classes/hook/before_course_deleted.php',
    'core_course\\hook\\before_course_viewed' => '/var/www/html/plantilla/course/classes/hook/before_course_viewed.php',
    'core_course\\list_element' => '/var/www/html/plantilla/course/classes/list_element.php',
    'core_course\\local\\entity\\activity_chooser_footer' => '/var/www/html/plantilla/course/classes/local/entity/activity_chooser_footer.php',
    'core_course\\local\\entity\\content_item' => '/var/www/html/plantilla/course/classes/local/entity/content_item.php',
    'core_course\\local\\entity\\lang_string_title' => '/var/www/html/plantilla/course/classes/local/entity/lang_string_title.php',
    'core_course\\local\\entity\\string_title' => '/var/www/html/plantilla/course/classes/local/entity/string_title.php',
    'core_course\\local\\entity\\title' => '/var/www/html/plantilla/course/classes/local/entity/title.php',
    'core_course\\local\\exporters\\course_content_item_exporter' => '/var/www/html/plantilla/course/classes/local/exporters/course_content_item_exporter.php',
    'core_course\\local\\exporters\\course_content_items_exporter' => '/var/www/html/plantilla/course/classes/local/exporters/course_content_items_exporter.php',
    'core_course\\local\\factory\\content_item_service_factory' => '/var/www/html/plantilla/course/classes/local/factory/content_item_service_factory.php',
    'core_course\\local\\repository\\caching_content_item_readonly_repository' => '/var/www/html/plantilla/course/classes/local/repository/caching_content_item_readonly_repository.php',
    'core_course\\local\\repository\\content_item_readonly_repository' => '/var/www/html/plantilla/course/classes/local/repository/content_item_readonly_repository.php',
    'core_course\\local\\repository\\content_item_readonly_repository_interface' => '/var/www/html/plantilla/course/classes/local/repository/content_item_readonly_repository_interface.php',
    'core_course\\local\\service\\content_item_service' => '/var/www/html/plantilla/course/classes/local/service/content_item_service.php',
    'core_course\\management\\helper' => '/var/www/html/plantilla/course/classes/management/helper.php',
    'core_course\\management_renderer' => '/var/www/html/plantilla/course/classes/management_renderer.php',
    'core_course\\output\\actionbar\\group_selector' => '/var/www/html/plantilla/course/classes/output/actionbar/group_selector.php',
    'core_course\\output\\actionbar\\group_selector_button' => '/var/www/html/plantilla/course/classes/output/actionbar/group_selector_button.php',
    'core_course\\output\\actionbar\\group_selector_dropdown_form' => '/var/www/html/plantilla/course/classes/output/actionbar/group_selector_dropdown_form.php',
    'core_course\\output\\actionbar\\initials_dropdown_form' => '/var/www/html/plantilla/course/classes/output/actionbar/initials_dropdown_form.php',
    'core_course\\output\\actionbar\\initials_selector' => '/var/www/html/plantilla/course/classes/output/actionbar/initials_selector.php',
    'core_course\\output\\actionbar\\user_selector' => '/var/www/html/plantilla/course/classes/output/actionbar/user_selector.php',
    'core_course\\output\\actionbar\\user_selector_button' => '/var/www/html/plantilla/course/classes/output/actionbar/user_selector_button.php',
    'core_course\\output\\activity_completion' => '/var/www/html/plantilla/course/classes/output/activity_completion.php',
    'core_course\\output\\activity_dates' => '/var/www/html/plantilla/course/classes/output/activity_dates.php',
    'core_course\\output\\activity_icon' => '/var/www/html/plantilla/course/classes/output/activity_icon.php',
    'core_course\\output\\activity_navigation' => '/var/www/html/plantilla/course/classes/output/activity_navigation.php',
    'core_course\\output\\activitychooserbutton' => '/var/www/html/plantilla/course/classes/output/activitychooserbutton.php',
    'core_course\\output\\bulk_activity_completion_renderer' => '/var/www/html/plantilla/course/classes/output/bulk_activity_completion_renderer.php',
    'core_course\\output\\category_action_bar' => '/var/www/html/plantilla/course/classes/output/category_action_bar.php',
    'core_course\\output\\completion_action_bar' => '/var/www/html/plantilla/course/classes/output/completion_action_bar.php',
    'core_course\\output\\content_export_link' => '/var/www/html/plantilla/course/classes/output/content_export_link.php',
    'core_course\\output\\manage_categories_action_bar' => '/var/www/html/plantilla/course/classes/output/manage_categories_action_bar.php',
    'core_course\\output\\recommendations\\activity_list' => '/var/www/html/plantilla/course/classes/output/recommendations/activity_list.php',
    'core_course\\output\\recommendations\\renderer' => '/var/www/html/plantilla/course/classes/output/recommendations/renderer.php',
    'core_course\\privacy\\provider' => '/var/www/html/plantilla/course/classes/privacy/provider.php',
    'core_course\\reportbuilder\\datasource\\categories' => '/var/www/html/plantilla/course/classes/reportbuilder/datasource/categories.php',
    'core_course\\reportbuilder\\datasource\\courses' => '/var/www/html/plantilla/course/classes/reportbuilder/datasource/courses.php',
    'core_course\\reportbuilder\\datasource\\participants' => '/var/www/html/plantilla/course/classes/reportbuilder/datasource/participants.php',
    'core_course\\reportbuilder\\local\\entities\\access' => '/var/www/html/plantilla/course/classes/reportbuilder/local/entities/access.php',
    'core_course\\reportbuilder\\local\\entities\\completion' => '/var/www/html/plantilla/course/classes/reportbuilder/local/entities/completion.php',
    'core_course\\reportbuilder\\local\\entities\\course_category' => '/var/www/html/plantilla/course/classes/reportbuilder/local/entities/course_category.php',
    'core_course\\reportbuilder\\local\\entities\\enrolment' => '/var/www/html/plantilla/course/classes/reportbuilder/local/entities/enrolment.php',
    'core_course\\reportbuilder\\local\\formatters\\completion' => '/var/www/html/plantilla/course/classes/reportbuilder/local/formatters/completion.php',
    'core_course\\reportbuilder\\local\\formatters\\enrolment' => '/var/www/html/plantilla/course/classes/reportbuilder/local/formatters/enrolment.php',
    'core_course\\route\\controller\\course_management' => '/var/www/html/plantilla/course/classes/route/controller/course_management.php',
    'core_course\\route\\controller\\tags_controller' => '/var/www/html/plantilla/course/classes/route/controller/tags_controller.php',
    'core_course\\route\\shim\\course_routes' => '/var/www/html/plantilla/course/classes/route/shim/course_routes.php',
    'core_course\\search\\course' => '/var/www/html/plantilla/course/classes/search/course.php',
    'core_course\\search\\customfield' => '/var/www/html/plantilla/course/classes/search/customfield.php',
    'core_course\\search\\section' => '/var/www/html/plantilla/course/classes/search/section.php',
    'core_course\\task\\content_notification_task' => '/var/www/html/plantilla/course/classes/task/content_notification_task.php',
    'core_course\\task\\course_delete_modules' => '/var/www/html/plantilla/course/classes/task/course_delete_modules.php',
    'core_course\\task\\regrade_final_grades' => '/var/www/html/plantilla/course/classes/task/regrade_final_grades.php',
    'core_course_category' => '/var/www/html/plantilla/course/classes/category.php',
    'core_course_constants' => '/var/www/html/plantilla/course/classes/constants.php',
    'core_course_deletecategory_form' => '/var/www/html/plantilla/course/classes/deletecategory_form.php',
    'core_course_editcategory_form' => '/var/www/html/plantilla/course/classes/editcategory_form.php',
    'core_course_list_element' => '/var/www/html/plantilla/course/classes/list_element.php',
    'core_course_management_renderer' => '/var/www/html/plantilla/course/classes/management_renderer.php',
    'core_courseformat\\activityoverviewbase' => '/var/www/html/plantilla/course/format/classes/activityoverviewbase.php',
    'core_courseformat\\base' => '/var/www/html/plantilla/course/format/classes/base.php',
    'core_courseformat\\external\\create_module' => '/var/www/html/plantilla/course/format/classes/external/create_module.php',
    'core_courseformat\\external\\file_handlers' => '/var/www/html/plantilla/course/format/classes/external/file_handlers.php',
    'core_courseformat\\external\\get_state' => '/var/www/html/plantilla/course/format/classes/external/get_state.php',
    'core_courseformat\\external\\new_module' => '/var/www/html/plantilla/course/format/classes/external/new_module.php',
    'core_courseformat\\external\\update_course' => '/var/www/html/plantilla/course/format/classes/external/update_course.php',
    'core_courseformat\\formatactions' => '/var/www/html/plantilla/course/format/classes/formatactions.php',
    'core_courseformat\\hook\\after_cm_name_edited' => '/var/www/html/plantilla/course/format/classes/hook/after_cm_name_edited.php',
    'core_courseformat\\hook\\after_course_content_updated' => '/var/www/html/plantilla/course/format/classes/hook/after_course_content_updated.php',
    'core_courseformat\\hook_listener' => '/var/www/html/plantilla/course/format/classes/hook_listener.php',
    'core_courseformat\\local\\baseactions' => '/var/www/html/plantilla/course/format/classes/local/baseactions.php',
    'core_courseformat\\local\\cmactions' => '/var/www/html/plantilla/course/format/classes/local/cmactions.php',
    'core_courseformat\\local\\courseactions' => '/var/www/html/plantilla/course/format/classes/local/courseactions.php',
    'core_courseformat\\local\\overview\\overviewfactory' => '/var/www/html/plantilla/course/format/classes/local/overview/overviewfactory.php',
    'core_courseformat\\local\\overview\\overviewitem' => '/var/www/html/plantilla/course/format/classes/local/overview/overviewitem.php',
    'core_courseformat\\local\\overview\\resourceoverview' => '/var/www/html/plantilla/course/format/classes/local/overview/resourceoverview.php',
    'core_courseformat\\local\\sectionactions' => '/var/www/html/plantilla/course/format/classes/local/sectionactions.php',
    'core_courseformat\\output\\activitybadge' => '/var/www/html/plantilla/course/format/classes/output/activitybadge.php',
    'core_courseformat\\output\\legacy_renderer' => '/var/www/html/plantilla/course/format/classes/output/legacy_renderer.php',
    'core_courseformat\\output\\local\\content' => '/var/www/html/plantilla/course/format/classes/output/local/content.php',
    'core_courseformat\\output\\local\\content\\addsection' => '/var/www/html/plantilla/course/format/classes/output/local/content/addsection.php',
    'core_courseformat\\output\\local\\content\\basecontrolmenu' => '/var/www/html/plantilla/course/format/classes/output/local/content/basecontrolmenu.php',
    'core_courseformat\\output\\local\\content\\bulkedittoggler' => '/var/www/html/plantilla/course/format/classes/output/local/content/bulkedittoggler.php',
    'core_courseformat\\output\\local\\content\\bulkedittools' => '/var/www/html/plantilla/course/format/classes/output/local/content/bulkedittools.php',
    'core_courseformat\\output\\local\\content\\cm' => '/var/www/html/plantilla/course/format/classes/output/local/content/cm.php',
    'core_courseformat\\output\\local\\content\\cm\\availability' => '/var/www/html/plantilla/course/format/classes/output/local/content/cm/availability.php',
    'core_courseformat\\output\\local\\content\\cm\\cmicon' => '/var/www/html/plantilla/course/format/classes/output/local/content/cm/cmicon.php',
    'core_courseformat\\output\\local\\content\\cm\\cmname' => '/var/www/html/plantilla/course/format/classes/output/local/content/cm/cmname.php',
    'core_courseformat\\output\\local\\content\\cm\\completion' => '/var/www/html/plantilla/course/format/classes/output/local/content/cm/completion.php',
    'core_courseformat\\output\\local\\content\\cm\\controlmenu' => '/var/www/html/plantilla/course/format/classes/output/local/content/cm/controlmenu.php',
    'core_courseformat\\output\\local\\content\\cm\\delegatedcontrolmenu' => '/var/www/html/plantilla/course/format/classes/output/local/content/cm/delegatedcontrolmenu.php',
    'core_courseformat\\output\\local\\content\\cm\\groupmode' => '/var/www/html/plantilla/course/format/classes/output/local/content/cm/groupmode.php',
    'core_courseformat\\output\\local\\content\\cm\\title' => '/var/www/html/plantilla/course/format/classes/output/local/content/cm/title.php',
    'core_courseformat\\output\\local\\content\\cm\\visibility' => '/var/www/html/plantilla/course/format/classes/output/local/content/cm/visibility.php',
    'core_courseformat\\output\\local\\content\\delegatedsection' => '/var/www/html/plantilla/course/format/classes/output/local/content/delegatedsection.php',
    'core_courseformat\\output\\local\\content\\frontpagesection' => '/var/www/html/plantilla/course/format/classes/output/local/content/frontpagesection.php',
    'core_courseformat\\output\\local\\content\\section' => '/var/www/html/plantilla/course/format/classes/output/local/content/section.php',
    'core_courseformat\\output\\local\\content\\section\\availability' => '/var/www/html/plantilla/course/format/classes/output/local/content/section/availability.php',
    'core_courseformat\\output\\local\\content\\section\\cmitem' => '/var/www/html/plantilla/course/format/classes/output/local/content/section/cmitem.php',
    'core_courseformat\\output\\local\\content\\section\\cmlist' => '/var/www/html/plantilla/course/format/classes/output/local/content/section/cmlist.php',
    'core_courseformat\\output\\local\\content\\section\\cmsummary' => '/var/www/html/plantilla/course/format/classes/output/local/content/section/cmsummary.php',
    'core_courseformat\\output\\local\\content\\section\\controlmenu' => '/var/www/html/plantilla/course/format/classes/output/local/content/section/controlmenu.php',
    'core_courseformat\\output\\local\\content\\section\\header' => '/var/www/html/plantilla/course/format/classes/output/local/content/section/header.php',
    'core_courseformat\\output\\local\\content\\section\\summary' => '/var/www/html/plantilla/course/format/classes/output/local/content/section/summary.php',
    'core_courseformat\\output\\local\\content\\section\\visibility' => '/var/www/html/plantilla/course/format/classes/output/local/content/section/visibility.php',
    'core_courseformat\\output\\local\\content\\sectionnavigation' => '/var/www/html/plantilla/course/format/classes/output/local/content/sectionnavigation.php',
    'core_courseformat\\output\\local\\content\\sectionselector' => '/var/www/html/plantilla/course/format/classes/output/local/content/sectionselector.php',
    'core_courseformat\\output\\local\\courseformat_named_templatable' => '/var/www/html/plantilla/course/format/classes/output/local/courseformat_named_templatable.php',
    'core_courseformat\\output\\local\\courseupdate' => '/var/www/html/plantilla/course/format/classes/output/local/courseupdate.php',
    'core_courseformat\\output\\local\\overview\\activityname' => '/var/www/html/plantilla/course/format/classes/output/local/overview/activityname.php',
    'core_courseformat\\output\\local\\overview\\missingoverviewnotice' => '/var/www/html/plantilla/course/format/classes/output/local/overview/missingoverviewnotice.php',
    'core_courseformat\\output\\local\\overview\\overviewpage' => '/var/www/html/plantilla/course/format/classes/output/local/overview/overviewpage.php',
    'core_courseformat\\output\\local\\overview\\overviewtable' => '/var/www/html/plantilla/course/format/classes/output/local/overview/overviewtable.php',
    'core_courseformat\\output\\local\\state\\cm' => '/var/www/html/plantilla/course/format/classes/output/local/state/cm.php',
    'core_courseformat\\output\\local\\state\\course' => '/var/www/html/plantilla/course/format/classes/output/local/state/course.php',
    'core_courseformat\\output\\local\\state\\section' => '/var/www/html/plantilla/course/format/classes/output/local/state/section.php',
    'core_courseformat\\output\\section_renderer' => '/var/www/html/plantilla/course/format/classes/output/section_renderer.php',
    'core_courseformat\\output\\site_renderer' => '/var/www/html/plantilla/course/format/classes/output/site_renderer.php',
    'core_courseformat\\privacy\\provider' => '/var/www/html/plantilla/course/format/classes/privacy/provider.php',
    'core_courseformat\\sectiondelegate' => '/var/www/html/plantilla/course/format/classes/sectiondelegate.php',
    'core_courseformat\\sectiondelegatemodule' => '/var/www/html/plantilla/course/format/classes/sectiondelegatemodule.php',
    'core_courseformat\\stateactions' => '/var/www/html/plantilla/course/format/classes/stateactions.php',
    'core_courseformat\\stateupdates' => '/var/www/html/plantilla/course/format/classes/stateupdates.php',
    'core_courseformat_activityoverviewbase' => '/var/www/html/plantilla/course/format/classes/activityoverviewbase.php',
    'core_courseformat_base' => '/var/www/html/plantilla/course/format/classes/base.php',
    'core_courseformat_formatactions' => '/var/www/html/plantilla/course/format/classes/formatactions.php',
    'core_courseformat_hook_listener' => '/var/www/html/plantilla/course/format/classes/hook_listener.php',
    'core_courseformat_sectiondelegate' => '/var/www/html/plantilla/course/format/classes/sectiondelegate.php',
    'core_courseformat_sectiondelegatemodule' => '/var/www/html/plantilla/course/format/classes/sectiondelegatemodule.php',
    'core_courseformat_stateactions' => '/var/www/html/plantilla/course/format/classes/stateactions.php',
    'core_courseformat_stateupdates' => '/var/www/html/plantilla/course/format/classes/stateupdates.php',
    'core_cron' => '/var/www/html/plantilla/lib/classes/cron.php',
    'core_cssparser' => '/var/www/html/plantilla/lib/classes/cssparser.php',
    'core_customfield\\api' => '/var/www/html/plantilla/customfield/classes/api.php',
    'core_customfield\\category' => '/var/www/html/plantilla/customfield/classes/category.php',
    'core_customfield\\category_controller' => '/var/www/html/plantilla/customfield/classes/category_controller.php',
    'core_customfield\\data' => '/var/www/html/plantilla/customfield/classes/data.php',
    'core_customfield\\data_controller' => '/var/www/html/plantilla/customfield/classes/data_controller.php',
    'core_customfield\\event\\category_created' => '/var/www/html/plantilla/customfield/classes/event/category_created.php',
    'core_customfield\\event\\category_deleted' => '/var/www/html/plantilla/customfield/classes/event/category_deleted.php',
    'core_customfield\\event\\category_updated' => '/var/www/html/plantilla/customfield/classes/event/category_updated.php',
    'core_customfield\\event\\field_created' => '/var/www/html/plantilla/customfield/classes/event/field_created.php',
    'core_customfield\\event\\field_deleted' => '/var/www/html/plantilla/customfield/classes/event/field_deleted.php',
    'core_customfield\\event\\field_updated' => '/var/www/html/plantilla/customfield/classes/event/field_updated.php',
    'core_customfield\\external\\field_data_exporter' => '/var/www/html/plantilla/customfield/classes/external/field_data_exporter.php',
    'core_customfield\\field' => '/var/www/html/plantilla/customfield/classes/field.php',
    'core_customfield\\field_config_form' => '/var/www/html/plantilla/customfield/classes/field_config_form.php',
    'core_customfield\\field_controller' => '/var/www/html/plantilla/customfield/classes/field_controller.php',
    'core_customfield\\handler' => '/var/www/html/plantilla/customfield/classes/handler.php',
    'core_customfield\\output\\field_data' => '/var/www/html/plantilla/customfield/classes/output/field_data.php',
    'core_customfield\\output\\management' => '/var/www/html/plantilla/customfield/classes/output/management.php',
    'core_customfield\\output\\renderer' => '/var/www/html/plantilla/customfield/classes/output/renderer.php',
    'core_customfield\\privacy\\customfield_provider' => '/var/www/html/plantilla/customfield/classes/privacy/customfield_provider.php',
    'core_customfield\\privacy\\provider' => '/var/www/html/plantilla/customfield/classes/privacy/provider.php',
    'core_customfield_api' => '/var/www/html/plantilla/customfield/classes/api.php',
    'core_customfield_category' => '/var/www/html/plantilla/customfield/classes/category.php',
    'core_customfield_category_controller' => '/var/www/html/plantilla/customfield/classes/category_controller.php',
    'core_customfield_data' => '/var/www/html/plantilla/customfield/classes/data.php',
    'core_customfield_data_controller' => '/var/www/html/plantilla/customfield/classes/data_controller.php',
    'core_customfield_field' => '/var/www/html/plantilla/customfield/classes/field.php',
    'core_customfield_field_config_form' => '/var/www/html/plantilla/customfield/classes/field_config_form.php',
    'core_customfield_field_controller' => '/var/www/html/plantilla/customfield/classes/field_controller.php',
    'core_customfield_handler' => '/var/www/html/plantilla/customfield/classes/handler.php',
    'core_dataformat' => '/var/www/html/plantilla/lib/classes/dataformat.php',
    'core_date' => '/var/www/html/plantilla/lib/classes/date.php',
    'core_deprecation' => '/var/www/html/plantilla/lib/classes/deprecation.php',
    'core_di' => '/var/www/html/plantilla/lib/classes/di.php',
    'core_editor\\privacy\\provider' => '/var/www/html/plantilla/lib/editor/classes/privacy/provider.php',
    'core_emoticon_manager' => '/var/www/html/plantilla/lib/classes/emoticon_manager.php',
    'core_encryption' => '/var/www/html/plantilla/lib/classes/encryption.php',
    'core_enrol\\form\\renameroles' => '/var/www/html/plantilla/enrol/classes/form/renameroles.php',
    'core_enrol\\hook\\after_enrol_instance_status_updated' => '/var/www/html/plantilla/enrol/classes/hook/after_enrol_instance_status_updated.php',
    'core_enrol\\hook\\after_user_enrolled' => '/var/www/html/plantilla/enrol/classes/hook/after_user_enrolled.php',
    'core_enrol\\hook\\before_enrol_instance_deleted' => '/var/www/html/plantilla/enrol/classes/hook/before_enrol_instance_deleted.php',
    'core_enrol\\hook\\before_user_enrolment_removed' => '/var/www/html/plantilla/enrol/classes/hook/before_user_enrolment_removed.php',
    'core_enrol\\hook\\before_user_enrolment_updated' => '/var/www/html/plantilla/enrol/classes/hook/before_user_enrolment_updated.php',
    'core_enrol\\output\\enrol_page' => '/var/www/html/plantilla/enrol/classes/output/enrol_page.php',
    'core_enrol\\privacy\\provider' => '/var/www/html/plantilla/enrol/classes/privacy/provider.php',
    'core_enrol\\reportbuilder\\local\\entities\\enrol' => '/var/www/html/plantilla/enrol/classes/reportbuilder/local/entities/enrol.php',
    'core_external\\external_api' => '/var/www/html/plantilla/lib/external/classes/external_api.php',
    'core_external\\external_description' => '/var/www/html/plantilla/lib/external/classes/external_description.php',
    'core_external\\external_files' => '/var/www/html/plantilla/lib/external/classes/external_files.php',
    'core_external\\external_format_value' => '/var/www/html/plantilla/lib/external/classes/external_format_value.php',
    'core_external\\external_function_parameters' => '/var/www/html/plantilla/lib/external/classes/external_function_parameters.php',
    'core_external\\external_multiple_structure' => '/var/www/html/plantilla/lib/external/classes/external_multiple_structure.php',
    'core_external\\external_settings' => '/var/www/html/plantilla/lib/external/classes/external_settings.php',
    'core_external\\external_single_structure' => '/var/www/html/plantilla/lib/external/classes/external_single_structure.php',
    'core_external\\external_value' => '/var/www/html/plantilla/lib/external/classes/external_value.php',
    'core_external\\external_warnings' => '/var/www/html/plantilla/lib/external/classes/external_warnings.php',
    'core_external\\privacy\\provider' => '/var/www/html/plantilla/lib/external/classes/privacy/provider.php',
    'core_external\\restricted_context_exception' => '/var/www/html/plantilla/lib/external/classes/restricted_context_exception.php',
    'core_external\\util' => '/var/www/html/plantilla/lib/external/classes/util.php',
    'core_external_external_api' => '/var/www/html/plantilla/lib/external/classes/external_api.php',
    'core_external_external_description' => '/var/www/html/plantilla/lib/external/classes/external_description.php',
    'core_external_external_files' => '/var/www/html/plantilla/lib/external/classes/external_files.php',
    'core_external_external_format_value' => '/var/www/html/plantilla/lib/external/classes/external_format_value.php',
    'core_external_external_function_parameters' => '/var/www/html/plantilla/lib/external/classes/external_function_parameters.php',
    'core_external_external_multiple_structure' => '/var/www/html/plantilla/lib/external/classes/external_multiple_structure.php',
    'core_external_external_settings' => '/var/www/html/plantilla/lib/external/classes/external_settings.php',
    'core_external_external_single_structure' => '/var/www/html/plantilla/lib/external/classes/external_single_structure.php',
    'core_external_external_value' => '/var/www/html/plantilla/lib/external/classes/external_value.php',
    'core_external_external_warnings' => '/var/www/html/plantilla/lib/external/classes/external_warnings.php',
    'core_external_restricted_context_exception' => '/var/www/html/plantilla/lib/external/classes/restricted_context_exception.php',
    'core_external_util' => '/var/www/html/plantilla/lib/external/classes/util.php',
    'core_favourites\\local\\entity\\favourite' => '/var/www/html/plantilla/favourites/classes/local/entity/favourite.php',
    'core_favourites\\local\\repository\\favourite_repository' => '/var/www/html/plantilla/favourites/classes/local/repository/favourite_repository.php',
    'core_favourites\\local\\repository\\favourite_repository_interface' => '/var/www/html/plantilla/favourites/classes/local/repository/favourite_repository_interface.php',
    'core_favourites\\local\\service\\component_favourite_service' => '/var/www/html/plantilla/favourites/classes/local/service/component_favourite_service.php',
    'core_favourites\\local\\service\\user_favourite_service' => '/var/www/html/plantilla/favourites/classes/local/service/user_favourite_service.php',
    'core_favourites\\privacy\\provider' => '/var/www/html/plantilla/favourites/classes/privacy/provider.php',
    'core_favourites\\service_factory' => '/var/www/html/plantilla/favourites/classes/service_factory.php',
    'core_favourites_service_factory' => '/var/www/html/plantilla/favourites/classes/service_factory.php',
    'core_fileconverter\\privacy\\provider' => '/var/www/html/plantilla/files/converter/classes/privacy/provider.php',
    'core_files\\archive_writer' => '/var/www/html/plantilla/files/classes/archive_writer.php',
    'core_files\\conversion' => '/var/www/html/plantilla/files/classes/conversion.php',
    'core_files\\converter' => '/var/www/html/plantilla/files/classes/converter.php',
    'core_files\\converter_interface' => '/var/www/html/plantilla/files/classes/converter_interface.php',
    'core_files\\external\\delete\\draft' => '/var/www/html/plantilla/files/classes/external/delete/draft.php',
    'core_files\\external\\get\\unused_draft' => '/var/www/html/plantilla/files/classes/external/get/unused_draft.php',
    'core_files\\external\\stored_file_exporter' => '/var/www/html/plantilla/files/classes/external/stored_file_exporter.php',
    'core_files\\hook\\after_file_created' => '/var/www/html/plantilla/files/classes/hook/after_file_created.php',
    'core_files\\hook\\before_file_created' => '/var/www/html/plantilla/files/classes/hook/before_file_created.php',
    'core_files\\local\\archive_writer\\file_writer_interface' => '/var/www/html/plantilla/files/classes/local/archive_writer/file_writer_interface.php',
    'core_files\\local\\archive_writer\\stream_writer_interface' => '/var/www/html/plantilla/files/classes/local/archive_writer/stream_writer_interface.php',
    'core_files\\local\\archive_writer\\zip_writer' => '/var/www/html/plantilla/files/classes/local/archive_writer/zip_writer.php',
    'core_files\\privacy\\provider' => '/var/www/html/plantilla/files/classes/privacy/provider.php',
    'core_files\\redactor\\hook_listener' => '/var/www/html/plantilla/files/classes/redactor/hook_listener.php',
    'core_files\\redactor\\manager' => '/var/www/html/plantilla/files/classes/redactor/manager.php',
    'core_files\\redactor\\services\\exifremover_service' => '/var/www/html/plantilla/files/classes/redactor/services/exifremover_service.php',
    'core_files\\redactor\\services\\file_redactor_service_interface' => '/var/www/html/plantilla/files/classes/redactor/services/file_redactor_service_interface.php',
    'core_files\\redactor\\services\\service' => '/var/www/html/plantilla/files/classes/redactor/services/service.php',
    'core_files\\reportbuilder\\datasource\\files' => '/var/www/html/plantilla/files/classes/reportbuilder/datasource/files.php',
    'core_files\\reportbuilder\\local\\entities\\file' => '/var/www/html/plantilla/files/classes/reportbuilder/local/entities/file.php',
    'core_files\\task\\asynchronous_mimetype_upgrade_task' => '/var/www/html/plantilla/files/classes/task/asynchronous_mimetype_upgrade_task.php',
    'core_files\\task\\conversion_cleanup_task' => '/var/www/html/plantilla/files/classes/task/conversion_cleanup_task.php',
    'core_files_archive_writer' => '/var/www/html/plantilla/files/classes/archive_writer.php',
    'core_files_conversion' => '/var/www/html/plantilla/files/classes/conversion.php',
    'core_files_converter' => '/var/www/html/plantilla/files/classes/converter.php',
    'core_files_converter_interface' => '/var/www/html/plantilla/files/classes/converter_interface.php',
    'core_filetypes' => '/var/www/html/plantilla/lib/classes/filetypes.php',
    'core_filters\\external\\get_all_states' => '/var/www/html/plantilla/filter/classes/external/get_all_states.php',
    'core_filters\\external\\get_available_in_context' => '/var/www/html/plantilla/filter/classes/external/get_available_in_context.php',
    'core_filters\\filter_manager' => '/var/www/html/plantilla/filter/classes/filter_manager.php',
    'core_filters\\filter_object' => '/var/www/html/plantilla/filter/classes/filter_object.php',
    'core_filters\\form\\local_settings_form' => '/var/www/html/plantilla/filter/classes/form/local_settings_form.php',
    'core_filters\\null_filter_manager' => '/var/www/html/plantilla/filter/classes/null_filter_manager.php',
    'core_filters\\performance_measuring_filter_manager' => '/var/www/html/plantilla/filter/classes/performance_measuring_filter_manager.php',
    'core_filters\\privacy\\provider' => '/var/www/html/plantilla/filter/classes/privacy/provider.php',
    'core_filters\\text_filter' => '/var/www/html/plantilla/filter/classes/text_filter.php',
    'core_filters_filter_manager' => '/var/www/html/plantilla/filter/classes/filter_manager.php',
    'core_filters_filter_object' => '/var/www/html/plantilla/filter/classes/filter_object.php',
    'core_filters_null_filter_manager' => '/var/www/html/plantilla/filter/classes/null_filter_manager.php',
    'core_filters_performance_measuring_filter_manager' => '/var/www/html/plantilla/filter/classes/performance_measuring_filter_manager.php',
    'core_filters_text_filter' => '/var/www/html/plantilla/filter/classes/text_filter.php',
    'core_form\\dynamic_form' => '/var/www/html/plantilla/lib/form/classes/dynamic_form.php',
    'core_form\\external' => '/var/www/html/plantilla/lib/form/classes/external.php',
    'core_form\\external\\dynamic_form' => '/var/www/html/plantilla/lib/form/classes/external/dynamic_form.php',
    'core_form\\filetypes_util' => '/var/www/html/plantilla/lib/form/classes/filetypes_util.php',
    'core_form\\privacy\\provider' => '/var/www/html/plantilla/lib/form/classes/privacy/provider.php',
    'core_form\\util' => '/var/www/html/plantilla/lib/form/classes/util.php',
    'core_form_dynamic_form' => '/var/www/html/plantilla/lib/form/classes/dynamic_form.php',
    'core_form_external' => '/var/www/html/plantilla/lib/form/classes/external.php',
    'core_form_filetypes_util' => '/var/www/html/plantilla/lib/form/classes/filetypes_util.php',
    'core_form_util' => '/var/www/html/plantilla/lib/form/classes/util.php',
    'core_formatting' => '/var/www/html/plantilla/lib/classes/formatting.php',
    'core_geopattern' => '/var/www/html/plantilla/lib/classes/geopattern.php',
    'core_grades\\component_gradeitem' => '/var/www/html/plantilla/grade/classes/component_gradeitem.php',
    'core_grades\\component_gradeitems' => '/var/www/html/plantilla/grade/classes/component_gradeitems.php',
    'core_grades\\external\\create_gradecategories' => '/var/www/html/plantilla/grade/classes/external/create_gradecategories.php',
    'core_grades\\external\\get_enrolled_users_for_selector' => '/var/www/html/plantilla/grade/classes/external/get_enrolled_users_for_selector.php',
    'core_grades\\external\\get_feedback' => '/var/www/html/plantilla/grade/classes/external/get_feedback.php',
    'core_grades\\external\\get_gradable_users' => '/var/www/html/plantilla/grade/classes/external/get_gradable_users.php',
    'core_grades\\external\\get_grade_tree' => '/var/www/html/plantilla/grade/classes/external/get_grade_tree.php',
    'core_grades\\external\\get_gradeitems' => '/var/www/html/plantilla/grade/classes/external/get_gradeitems.php',
    'core_grades\\form\\add_category' => '/var/www/html/plantilla/grade/classes/form/add_category.php',
    'core_grades\\form\\add_item' => '/var/www/html/plantilla/grade/classes/form/add_item.php',
    'core_grades\\form\\add_outcome' => '/var/www/html/plantilla/grade/classes/form/add_outcome.php',
    'core_grades\\grades\\grader\\gradingpanel\\point\\external\\fetch' => '/var/www/html/plantilla/grade/classes/grades/grader/gradingpanel/point/external/fetch.php',
    'core_grades\\grades\\grader\\gradingpanel\\point\\external\\store' => '/var/www/html/plantilla/grade/classes/grades/grader/gradingpanel/point/external/store.php',
    'core_grades\\grades\\grader\\gradingpanel\\scale\\external\\fetch' => '/var/www/html/plantilla/grade/classes/grades/grader/gradingpanel/scale/external/fetch.php',
    'core_grades\\grades\\grader\\gradingpanel\\scale\\external\\store' => '/var/www/html/plantilla/grade/classes/grades/grader/gradingpanel/scale/external/store.php',
    'core_grades\\local\\gradeitem\\advancedgrading_mapping' => '/var/www/html/plantilla/grade/classes/local/gradeitem/advancedgrading_mapping.php',
    'core_grades\\local\\gradeitem\\fieldname_mapping' => '/var/www/html/plantilla/grade/classes/local/gradeitem/fieldname_mapping.php',
    'core_grades\\local\\gradeitem\\itemnumber_mapping' => '/var/www/html/plantilla/grade/classes/local/gradeitem/itemnumber_mapping.php',
    'core_grades\\output\\action_bar' => '/var/www/html/plantilla/grade/classes/output/action_bar.php',
    'core_grades\\output\\course_outcomes_action_bar' => '/var/www/html/plantilla/grade/classes/output/course_outcomes_action_bar.php',
    'core_grades\\output\\export_action_bar' => '/var/www/html/plantilla/grade/classes/output/export_action_bar.php',
    'core_grades\\output\\export_key_manager_action_bar' => '/var/www/html/plantilla/grade/classes/output/export_key_manager_action_bar.php',
    'core_grades\\output\\export_publish_action_bar' => '/var/www/html/plantilla/grade/classes/output/export_publish_action_bar.php',
    'core_grades\\output\\general_action_bar' => '/var/www/html/plantilla/grade/classes/output/general_action_bar.php',
    'core_grades\\output\\grade_letters_action_bar' => '/var/www/html/plantilla/grade/classes/output/grade_letters_action_bar.php',
    'core_grades\\output\\gradebook_setup_action_bar' => '/var/www/html/plantilla/grade/classes/output/gradebook_setup_action_bar.php',
    'core_grades\\output\\import_action_bar' => '/var/www/html/plantilla/grade/classes/output/import_action_bar.php',
    'core_grades\\output\\import_key_manager_action_bar' => '/var/www/html/plantilla/grade/classes/output/import_key_manager_action_bar.php',
    'core_grades\\output\\manage_outcomes_action_bar' => '/var/www/html/plantilla/grade/classes/output/manage_outcomes_action_bar.php',
    'core_grades\\output\\penalty_indicator' => '/var/www/html/plantilla/grade/classes/output/penalty_indicator.php',
    'core_grades\\output\\scales_action_bar' => '/var/www/html/plantilla/grade/classes/output/scales_action_bar.php',
    'core_grades\\penalty_calculator' => '/var/www/html/plantilla/grade/classes/penalty_calculator.php',
    'core_grades\\penalty_container' => '/var/www/html/plantilla/grade/classes/penalty_container.php',
    'core_grades\\penalty_manager' => '/var/www/html/plantilla/grade/classes/penalty_manager.php',
    'core_grades\\penalty_recalculator' => '/var/www/html/plantilla/grade/classes/penalty_recalculator.php',
    'core_grades\\privacy\\grade_grade_with_history' => '/var/www/html/plantilla/grade/classes/privacy/grade_grade_with_history.php',
    'core_grades\\privacy\\provider' => '/var/www/html/plantilla/grade/classes/privacy/provider.php',
    'core_grades\\table\\gradepenalty_management_table' => '/var/www/html/plantilla/grade/classes/table/gradepenalty_management_table.php',
    'core_grades_component_gradeitem' => '/var/www/html/plantilla/grade/classes/component_gradeitem.php',
    'core_grades_component_gradeitems' => '/var/www/html/plantilla/grade/classes/component_gradeitems.php',
    'core_grades_external' => '/var/www/html/plantilla/lib/classes/grades_external.php',
    'core_grades_penalty_calculator' => '/var/www/html/plantilla/grade/classes/penalty_calculator.php',
    'core_grades_penalty_container' => '/var/www/html/plantilla/grade/classes/penalty_container.php',
    'core_grades_penalty_manager' => '/var/www/html/plantilla/grade/classes/penalty_manager.php',
    'core_grades_penalty_recalculator' => '/var/www/html/plantilla/grade/classes/penalty_recalculator.php',
    'core_grading\\privacy\\gradingform_legacy_polyfill' => '/var/www/html/plantilla/grade/grading/classes/privacy/gradingform_legacy_polyfill.php',
    'core_grading\\privacy\\gradingform_provider_v2' => '/var/www/html/plantilla/grade/grading/classes/privacy/gradingform_provider_v2.php',
    'core_grading\\privacy\\provider' => '/var/www/html/plantilla/grade/grading/classes/privacy/provider.php',
    'core_grading_external' => '/var/www/html/plantilla/lib/classes/grading_external.php',
    'core_group\\customfield\\group_handler' => '/var/www/html/plantilla/group/classes/customfield/group_handler.php',
    'core_group\\customfield\\grouping_handler' => '/var/www/html/plantilla/group/classes/customfield/grouping_handler.php',
    'core_group\\external\\get_groups_for_selector' => '/var/www/html/plantilla/group/classes/external/get_groups_for_selector.php',
    'core_group\\hook\\after_group_created' => '/var/www/html/plantilla/group/classes/hook/after_group_created.php',
    'core_group\\hook\\after_group_deleted' => '/var/www/html/plantilla/group/classes/hook/after_group_deleted.php',
    'core_group\\hook\\after_group_membership_added' => '/var/www/html/plantilla/group/classes/hook/after_group_membership_added.php',
    'core_group\\hook\\after_group_membership_removed' => '/var/www/html/plantilla/group/classes/hook/after_group_membership_removed.php',
    'core_group\\hook\\after_group_updated' => '/var/www/html/plantilla/group/classes/hook/after_group_updated.php',
    'core_group\\output\\group_details' => '/var/www/html/plantilla/group/classes/output/group_details.php',
    'core_group\\output\\index_page' => '/var/www/html/plantilla/group/classes/output/index_page.php',
    'core_group\\output\\renderer' => '/var/www/html/plantilla/group/classes/output/renderer.php',
    'core_group\\output\\user_groups_editable' => '/var/www/html/plantilla/group/classes/output/user_groups_editable.php',
    'core_group\\privacy\\provider' => '/var/www/html/plantilla/group/classes/privacy/provider.php',
    'core_group\\reportbuilder\\datasource\\groups' => '/var/www/html/plantilla/group/classes/reportbuilder/datasource/groups.php',
    'core_group\\reportbuilder\\local\\entities\\group' => '/var/www/html/plantilla/group/classes/reportbuilder/local/entities/group.php',
    'core_group\\reportbuilder\\local\\entities\\group_member' => '/var/www/html/plantilla/group/classes/reportbuilder/local/entities/group_member.php',
    'core_group\\reportbuilder\\local\\entities\\grouping' => '/var/www/html/plantilla/group/classes/reportbuilder/local/entities/grouping.php',
    'core_group\\visibility' => '/var/www/html/plantilla/group/classes/visibility.php',
    'core_group_visibility' => '/var/www/html/plantilla/group/classes/visibility.php',
    'core_h5p\\api' => '/var/www/html/plantilla/h5p/classes/api.php',
    'core_h5p\\core' => '/var/www/html/plantilla/h5p/classes/core.php',
    'core_h5p\\editor' => '/var/www/html/plantilla/h5p/classes/editor.php',
    'core_h5p\\editor_ajax' => '/var/www/html/plantilla/h5p/classes/editor_ajax.php',
    'core_h5p\\editor_framework' => '/var/www/html/plantilla/h5p/classes/editor_framework.php',
    'core_h5p\\event\\h5p_deleted' => '/var/www/html/plantilla/h5p/classes/event/h5p_deleted.php',
    'core_h5p\\event\\h5p_viewed' => '/var/www/html/plantilla/h5p/classes/event/h5p_viewed.php',
    'core_h5p\\external' => '/var/www/html/plantilla/h5p/classes/external.php',
    'core_h5p\\factory' => '/var/www/html/plantilla/h5p/classes/factory.php',
    'core_h5p\\file_storage' => '/var/www/html/plantilla/h5p/classes/file_storage.php',
    'core_h5p\\form\\editcontent_form' => '/var/www/html/plantilla/h5p/classes/form/editcontent_form.php',
    'core_h5p\\form\\uploadlibraries_form' => '/var/www/html/plantilla/h5p/classes/form/uploadlibraries_form.php',
    'core_h5p\\framework' => '/var/www/html/plantilla/h5p/classes/framework.php',
    'core_h5p\\helper' => '/var/www/html/plantilla/h5p/classes/helper.php',
    'core_h5p\\local\\library\\autoloader' => '/var/www/html/plantilla/h5p/classes/local/library/autoloader.php',
    'core_h5p\\local\\library\\handler' => '/var/www/html/plantilla/h5p/classes/local/library/handler.php',
    'core_h5p\\output\\h5peditor' => '/var/www/html/plantilla/h5p/classes/output/h5peditor.php',
    'core_h5p\\output\\libraries' => '/var/www/html/plantilla/h5p/classes/output/libraries.php',
    'core_h5p\\output\\renderer' => '/var/www/html/plantilla/h5p/classes/output/renderer.php',
    'core_h5p\\player' => '/var/www/html/plantilla/h5p/classes/player.php',
    'core_h5p\\privacy\\provider' => '/var/www/html/plantilla/h5p/classes/privacy/provider.php',
    'core_h5p_api' => '/var/www/html/plantilla/h5p/classes/api.php',
    'core_h5p_core' => '/var/www/html/plantilla/h5p/classes/core.php',
    'core_h5p_editor' => '/var/www/html/plantilla/h5p/classes/editor.php',
    'core_h5p_editor_ajax' => '/var/www/html/plantilla/h5p/classes/editor_ajax.php',
    'core_h5p_editor_framework' => '/var/www/html/plantilla/h5p/classes/editor_framework.php',
    'core_h5p_external' => '/var/www/html/plantilla/h5p/classes/external.php',
    'core_h5p_factory' => '/var/www/html/plantilla/h5p/classes/factory.php',
    'core_h5p_file_storage' => '/var/www/html/plantilla/h5p/classes/file_storage.php',
    'core_h5p_framework' => '/var/www/html/plantilla/h5p/classes/framework.php',
    'core_h5p_helper' => '/var/www/html/plantilla/h5p/classes/helper.php',
    'core_h5p_player' => '/var/www/html/plantilla/h5p/classes/player.php',
    'core_hooks' => '/var/www/html/plantilla/lib/classes/hooks.php',
    'core_http_client' => '/var/www/html/plantilla/lib/classes/http_client.php',
    'core_invalid_persistent_exception' => '/var/www/html/plantilla/lib/classes/invalid_persistent_exception.php',
    'core_ip_utils' => '/var/www/html/plantilla/lib/classes/ip_utils.php',
    'core_lang_string' => '/var/www/html/plantilla/lib/classes/lang_string.php',
    'core_locale' => '/var/www/html/plantilla/lib/classes/locale.php',
    'core_media\\manager' => '/var/www/html/plantilla/media/classes/manager.php',
    'core_media\\player' => '/var/www/html/plantilla/media/classes/player.php',
    'core_media\\player_external' => '/var/www/html/plantilla/media/classes/player_external.php',
    'core_media\\player_native' => '/var/www/html/plantilla/media/classes/player_native.php',
    'core_media\\privacy\\provider' => '/var/www/html/plantilla/media/classes/privacy/provider.php',
    'core_media_manager' => '/var/www/html/plantilla/media/classes/manager.php',
    'core_media_player' => '/var/www/html/plantilla/media/classes/player.php',
    'core_media_player_external' => '/var/www/html/plantilla/media/classes/player_external.php',
    'core_media_player_native' => '/var/www/html/plantilla/media/classes/player_native.php',
    'core_message\\api' => '/var/www/html/plantilla/message/classes/api.php',
    'core_message\\external\\get_unread_notification_count' => '/var/www/html/plantilla/message/classes/external/get_unread_notification_count.php',
    'core_message\\external\\get_unsent_message' => '/var/www/html/plantilla/message/classes/external/get_unsent_message.php',
    'core_message\\external\\message_set_default_notification' => '/var/www/html/plantilla/message/classes/external/message_set_default_notification.php',
    'core_message\\external\\set_unsent_message' => '/var/www/html/plantilla/message/classes/external/set_unsent_message.php',
    'core_message\\helper' => '/var/www/html/plantilla/message/classes/helper.php',
    'core_message\\hook_callbacks' => '/var/www/html/plantilla/message/classes/hook_callbacks.php',
    'core_message\\output\\preferences\\message_notification_list' => '/var/www/html/plantilla/message/classes/output/preferences/message_notification_list.php',
    'core_message\\output\\preferences\\message_notification_list_component' => '/var/www/html/plantilla/message/classes/output/preferences/message_notification_list_component.php',
    'core_message\\output\\preferences\\notification_list' => '/var/www/html/plantilla/message/classes/output/preferences/notification_list.php',
    'core_message\\output\\preferences\\notification_list_component' => '/var/www/html/plantilla/message/classes/output/preferences/notification_list_component.php',
    'core_message\\output\\preferences\\notification_list_processor' => '/var/www/html/plantilla/message/classes/output/preferences/notification_list_processor.php',
    'core_message\\output\\preferences\\processor' => '/var/www/html/plantilla/message/classes/output/preferences/processor.php',
    'core_message\\output\\processor' => '/var/www/html/plantilla/message/classes/output/processor.php',
    'core_message\\privacy\\provider' => '/var/www/html/plantilla/message/classes/privacy/provider.php',
    'core_message\\search\\base_message' => '/var/www/html/plantilla/message/classes/search/base_message.php',
    'core_message\\search\\message_received' => '/var/www/html/plantilla/message/classes/search/message_received.php',
    'core_message\\search\\message_sent' => '/var/www/html/plantilla/message/classes/search/message_sent.php',
    'core_message\\task\\migrate_message_data' => '/var/www/html/plantilla/message/classes/task/migrate_message_data.php',
    'core_message\\tests\\helper' => '/var/www/html/plantilla/message/classes/tests/helper.php',
    'core_message\\time_last_message_between_users' => '/var/www/html/plantilla/message/classes/time_last_message_between_users.php',
    'core_message_api' => '/var/www/html/plantilla/message/classes/api.php',
    'core_message_helper' => '/var/www/html/plantilla/message/classes/helper.php',
    'core_message_hook_callbacks' => '/var/www/html/plantilla/message/classes/hook_callbacks.php',
    'core_message_time_last_message_between_users' => '/var/www/html/plantilla/message/classes/time_last_message_between_users.php',
    'core_minify' => '/var/www/html/plantilla/lib/classes/minify.php',
    'core_mnet\\privacy\\provider' => '/var/www/html/plantilla/mnet/classes/privacy/provider.php',
    'core_my\\external\\view_page' => '/var/www/html/plantilla/my/classes/external/view_page.php',
    'core_my\\privacy\\provider' => '/var/www/html/plantilla/my/classes/privacy/provider.php',
    'core_notes\\privacy\\provider' => '/var/www/html/plantilla/notes/classes/privacy/provider.php',
    'core_notes\\reportbuilder\\datasource\\notes' => '/var/www/html/plantilla/notes/classes/reportbuilder/datasource/notes.php',
    'core_notes\\reportbuilder\\local\\entities\\note' => '/var/www/html/plantilla/notes/classes/reportbuilder/local/entities/note.php',
    'core_notification' => '/var/www/html/plantilla/lib/classes/notification.php',
    'core_param' => '/var/www/html/plantilla/lib/classes/param.php',
    'core_param_clientside_regex' => '/var/www/html/plantilla/lib/classes/param_clientside_regex.php',
    'core_payment\\account' => '/var/www/html/plantilla/payment/classes/account.php',
    'core_payment\\account_gateway' => '/var/www/html/plantilla/payment/classes/account_gateway.php',
    'core_payment\\event\\account_created' => '/var/www/html/plantilla/payment/classes/event/account_created.php',
    'core_payment\\event\\account_deleted' => '/var/www/html/plantilla/payment/classes/event/account_deleted.php',
    'core_payment\\event\\account_updated' => '/var/www/html/plantilla/payment/classes/event/account_updated.php',
    'core_payment\\external\\get_available_gateways' => '/var/www/html/plantilla/payment/classes/external/get_available_gateways.php',
    'core_payment\\form\\account' => '/var/www/html/plantilla/payment/classes/form/account.php',
    'core_payment\\form\\account_gateway' => '/var/www/html/plantilla/payment/classes/form/account_gateway.php',
    'core_payment\\gateway' => '/var/www/html/plantilla/payment/classes/gateway.php',
    'core_payment\\helper' => '/var/www/html/plantilla/payment/classes/helper.php',
    'core_payment\\local\\callback\\service_provider' => '/var/www/html/plantilla/payment/classes/local/callback/service_provider.php',
    'core_payment\\local\\entities\\payable' => '/var/www/html/plantilla/payment/classes/local/entities/payable.php',
    'core_payment\\privacy\\consumer_provider' => '/var/www/html/plantilla/payment/classes/privacy/consumer_provider.php',
    'core_payment\\privacy\\paygw_provider' => '/var/www/html/plantilla/payment/classes/privacy/paygw_provider.php',
    'core_payment\\privacy\\provider' => '/var/www/html/plantilla/payment/classes/privacy/provider.php',
    'core_payment_account' => '/var/www/html/plantilla/payment/classes/account.php',
    'core_payment_account_gateway' => '/var/www/html/plantilla/payment/classes/account_gateway.php',
    'core_payment_gateway' => '/var/www/html/plantilla/payment/classes/gateway.php',
    'core_payment_helper' => '/var/www/html/plantilla/payment/classes/helper.php',
    'core_persistent' => '/var/www/html/plantilla/lib/classes/persistent.php',
    'core_php_time_limit' => '/var/www/html/plantilla/lib/classes/php_time_limit.php',
    'core_plagiarism\\privacy\\legacy_polyfill' => '/var/www/html/plantilla/plagiarism/classes/privacy/legacy_polyfill.php',
    'core_plagiarism\\privacy\\plagiarism_provider' => '/var/www/html/plantilla/plagiarism/classes/privacy/plagiarism_provider.php',
    'core_plagiarism\\privacy\\plagiarism_user_provider' => '/var/www/html/plantilla/plagiarism/classes/privacy/plagiarism_user_provider.php',
    'core_plagiarism\\privacy\\provider' => '/var/www/html/plantilla/plagiarism/classes/privacy/provider.php',
    'core_plugin_manager' => '/var/www/html/plantilla/lib/classes/plugin_manager.php',
    'core_portfolio\\privacy\\legacy_polyfill' => '/var/www/html/plantilla/portfolio/classes/privacy/legacy_polyfill.php',
    'core_portfolio\\privacy\\portfolio_provider' => '/var/www/html/plantilla/portfolio/classes/privacy/portfolio_provider.php',
    'core_portfolio\\privacy\\provider' => '/var/www/html/plantilla/portfolio/classes/privacy/provider.php',
    'core_privacy\\local\\deprecated' => '/var/www/html/plantilla/privacy/classes/local/deprecated.php',
    'core_privacy\\local\\legacy_polyfill' => '/var/www/html/plantilla/privacy/classes/local/legacy_polyfill.php',
    'core_privacy\\local\\metadata\\collection' => '/var/www/html/plantilla/privacy/classes/local/metadata/collection.php',
    'core_privacy\\local\\metadata\\null_provider' => '/var/www/html/plantilla/privacy/classes/local/metadata/null_provider.php',
    'core_privacy\\local\\metadata\\provider' => '/var/www/html/plantilla/privacy/classes/local/metadata/provider.php',
    'core_privacy\\local\\metadata\\types\\database_table' => '/var/www/html/plantilla/privacy/classes/local/metadata/types/database_table.php',
    'core_privacy\\local\\metadata\\types\\external_location' => '/var/www/html/plantilla/privacy/classes/local/metadata/types/external_location.php',
    'core_privacy\\local\\metadata\\types\\plugintype_link' => '/var/www/html/plantilla/privacy/classes/local/metadata/types/plugintype_link.php',
    'core_privacy\\local\\metadata\\types\\subsystem_link' => '/var/www/html/plantilla/privacy/classes/local/metadata/types/subsystem_link.php',
    'core_privacy\\local\\metadata\\types\\type' => '/var/www/html/plantilla/privacy/classes/local/metadata/types/type.php',
    'core_privacy\\local\\metadata\\types\\user_preference' => '/var/www/html/plantilla/privacy/classes/local/metadata/types/user_preference.php',
    'core_privacy\\local\\request\\approved_contextlist' => '/var/www/html/plantilla/privacy/classes/local/request/approved_contextlist.php',
    'core_privacy\\local\\request\\approved_userlist' => '/var/www/html/plantilla/privacy/classes/local/request/approved_userlist.php',
    'core_privacy\\local\\request\\content_writer' => '/var/www/html/plantilla/privacy/classes/local/request/content_writer.php',
    'core_privacy\\local\\request\\context_aware_provider' => '/var/www/html/plantilla/privacy/classes/local/request/context_aware_provider.php',
    'core_privacy\\local\\request\\contextlist' => '/var/www/html/plantilla/privacy/classes/local/request/contextlist.php',
    'core_privacy\\local\\request\\contextlist_base' => '/var/www/html/plantilla/privacy/classes/local/request/contextlist_base.php',
    'core_privacy\\local\\request\\contextlist_collection' => '/var/www/html/plantilla/privacy/classes/local/request/contextlist_collection.php',
    'core_privacy\\local\\request\\core_data_provider' => '/var/www/html/plantilla/privacy/classes/local/request/core_data_provider.php',
    'core_privacy\\local\\request\\core_user_data_provider' => '/var/www/html/plantilla/privacy/classes/local/request/core_user_data_provider.php',
    'core_privacy\\local\\request\\core_userlist_provider' => '/var/www/html/plantilla/privacy/classes/local/request/core_userlist_provider.php',
    'core_privacy\\local\\request\\data_provider' => '/var/www/html/plantilla/privacy/classes/local/request/data_provider.php',
    'core_privacy\\local\\request\\helper' => '/var/www/html/plantilla/privacy/classes/local/request/helper.php',
    'core_privacy\\local\\request\\moodle_content_writer' => '/var/www/html/plantilla/privacy/classes/local/request/moodle_content_writer.php',
    'core_privacy\\local\\request\\plugin\\provider' => '/var/www/html/plantilla/privacy/classes/local/request/plugin/provider.php',
    'core_privacy\\local\\request\\plugin\\subplugin_provider' => '/var/www/html/plantilla/privacy/classes/local/request/plugin/subplugin_provider.php',
    'core_privacy\\local\\request\\plugin\\subsystem_provider' => '/var/www/html/plantilla/privacy/classes/local/request/plugin/subsystem_provider.php',
    'core_privacy\\local\\request\\shared_data_provider' => '/var/www/html/plantilla/privacy/classes/local/request/shared_data_provider.php',
    'core_privacy\\local\\request\\shared_userlist_provider' => '/var/www/html/plantilla/privacy/classes/local/request/shared_userlist_provider.php',
    'core_privacy\\local\\request\\subsystem\\plugin_provider' => '/var/www/html/plantilla/privacy/classes/local/request/subsystem/plugin_provider.php',
    'core_privacy\\local\\request\\subsystem\\provider' => '/var/www/html/plantilla/privacy/classes/local/request/subsystem/provider.php',
    'core_privacy\\local\\request\\transform' => '/var/www/html/plantilla/privacy/classes/local/request/transform.php',
    'core_privacy\\local\\request\\user_preference_provider' => '/var/www/html/plantilla/privacy/classes/local/request/user_preference_provider.php',
    'core_privacy\\local\\request\\userlist' => '/var/www/html/plantilla/privacy/classes/local/request/userlist.php',
    'core_privacy\\local\\request\\userlist_base' => '/var/www/html/plantilla/privacy/classes/local/request/userlist_base.php',
    'core_privacy\\local\\request\\userlist_collection' => '/var/www/html/plantilla/privacy/classes/local/request/userlist_collection.php',
    'core_privacy\\local\\request\\userlist_provider' => '/var/www/html/plantilla/privacy/classes/local/request/userlist_provider.php',
    'core_privacy\\local\\request\\writer' => '/var/www/html/plantilla/privacy/classes/local/request/writer.php',
    'core_privacy\\local\\sitepolicy\\default_handler' => '/var/www/html/plantilla/privacy/classes/local/sitepolicy/default_handler.php',
    'core_privacy\\local\\sitepolicy\\handler' => '/var/www/html/plantilla/privacy/classes/local/sitepolicy/handler.php',
    'core_privacy\\local\\sitepolicy\\manager' => '/var/www/html/plantilla/privacy/classes/local/sitepolicy/manager.php',
    'core_privacy\\manager' => '/var/www/html/plantilla/privacy/classes/manager.php',
    'core_privacy\\manager_observer' => '/var/www/html/plantilla/privacy/classes/manager_observer.php',
    'core_privacy\\output\\exported_html_page' => '/var/www/html/plantilla/privacy/classes/output/exported_html_page.php',
    'core_privacy\\output\\exported_navigation_page' => '/var/www/html/plantilla/privacy/classes/output/exported_navigation_page.php',
    'core_privacy\\output\\renderer' => '/var/www/html/plantilla/privacy/classes/output/renderer.php',
    'core_privacy\\privacy\\provider' => '/var/www/html/plantilla/privacy/classes/privacy/provider.php',
    'core_privacy\\tests\\provider_testcase' => '/var/www/html/plantilla/privacy/classes/tests/provider_testcase.php',
    'core_privacy\\tests\\request\\approved_contextlist' => '/var/www/html/plantilla/privacy/classes/tests/request/approved_contextlist.php',
    'core_privacy\\tests\\request\\content_writer' => '/var/www/html/plantilla/privacy/classes/tests/request/content_writer.php',
    'core_privacy_manager' => '/var/www/html/plantilla/privacy/classes/manager.php',
    'core_privacy_manager_observer' => '/var/www/html/plantilla/privacy/classes/manager_observer.php',
    'core_qrcode' => '/var/www/html/plantilla/lib/classes/qrcode.php',
    'core_question\\admin\\manage_qbank_plugins_page' => '/var/www/html/plantilla/question/classes/admin/manage_qbank_plugins_page.php',
    'core_question\\category_manager' => '/var/www/html/plantilla/question/classes/category_manager.php',
    'core_question\\engine\\variants\\least_used_strategy' => '/var/www/html/plantilla/question/classes/engine/variants/least_used_strategy.php',
    'core_question\\external' => '/var/www/html/plantilla/question/classes/external.php',
    'core_question\\external\\move_questions' => '/var/www/html/plantilla/question/classes/external/move_questions.php',
    'core_question\\external\\question_icon_exporter' => '/var/www/html/plantilla/question/classes/external/question_icon_exporter.php',
    'core_question\\external\\question_summary_exporter' => '/var/www/html/plantilla/question/classes/external/question_summary_exporter.php',
    'core_question\\external\\search_shared_banks' => '/var/www/html/plantilla/question/classes/external/search_shared_banks.php',
    'core_question\\local\\bank\\bulk_action_base' => '/var/www/html/plantilla/question/classes/local/bank/bulk_action_base.php',
    'core_question\\local\\bank\\checkbox_column' => '/var/www/html/plantilla/question/classes/local/bank/checkbox_column.php',
    'core_question\\local\\bank\\column_action_base' => '/var/www/html/plantilla/question/classes/local/bank/column_action_base.php',
    'core_question\\local\\bank\\column_base' => '/var/www/html/plantilla/question/classes/local/bank/column_base.php',
    'core_question\\local\\bank\\column_manager_base' => '/var/www/html/plantilla/question/classes/local/bank/column_manager_base.php',
    'core_question\\local\\bank\\condition' => '/var/www/html/plantilla/question/classes/local/bank/condition.php',
    'core_question\\local\\bank\\context_to_string_translator' => '/var/www/html/plantilla/question/classes/local/bank/context_to_string_translator.php',
    'core_question\\local\\bank\\edit_menu_column' => '/var/www/html/plantilla/question/classes/local/bank/edit_menu_column.php',
    'core_question\\local\\bank\\filter_condition_manager' => '/var/www/html/plantilla/question/classes/local/bank/filter_condition_manager.php',
    'core_question\\local\\bank\\helper' => '/var/www/html/plantilla/question/classes/local/bank/helper.php',
    'core_question\\local\\bank\\navigation_node_base' => '/var/www/html/plantilla/question/classes/local/bank/navigation_node_base.php',
    'core_question\\local\\bank\\plugin_features_base' => '/var/www/html/plantilla/question/classes/local/bank/plugin_features_base.php',
    'core_question\\local\\bank\\question_action_base' => '/var/www/html/plantilla/question/classes/local/bank/question_action_base.php',
    'core_question\\local\\bank\\question_bank_helper' => '/var/www/html/plantilla/question/classes/local/bank/question_bank_helper.php',
    'core_question\\local\\bank\\question_edit_contexts' => '/var/www/html/plantilla/question/classes/local/bank/question_edit_contexts.php',
    'core_question\\local\\bank\\question_version_status' => '/var/www/html/plantilla/question/classes/local/bank/question_version_status.php',
    'core_question\\local\\bank\\random_question_loader' => '/var/www/html/plantilla/question/classes/local/bank/random_question_loader.php',
    'core_question\\local\\bank\\row_base' => '/var/www/html/plantilla/question/classes/local/bank/row_base.php',
    'core_question\\local\\bank\\version_options' => '/var/www/html/plantilla/question/classes/local/bank/version_options.php',
    'core_question\\local\\bank\\view' => '/var/www/html/plantilla/question/classes/local/bank/view.php',
    'core_question\\local\\bank\\view_component' => '/var/www/html/plantilla/question/classes/local/bank/view_component.php',
    'core_question\\local\\statistics\\statistics_bulk_loader' => '/var/www/html/plantilla/question/classes/local/statistics/statistics_bulk_loader.php',
    'core_question\\output\\add_bank_list' => '/var/www/html/plantilla/question/classes/output/add_bank_list.php',
    'core_question\\output\\qbank_action_menu' => '/var/www/html/plantilla/question/classes/output/qbank_action_menu.php',
    'core_question\\output\\question_bank_filter_ui' => '/var/www/html/plantilla/question/classes/output/question_bank_filter_ui.php',
    'core_question\\output\\question_bank_list' => '/var/www/html/plantilla/question/classes/output/question_bank_list.php',
    'core_question\\output\\question_category_selector' => '/var/www/html/plantilla/question/classes/output/question_category_selector.php',
    'core_question\\output\\question_version_info' => '/var/www/html/plantilla/question/classes/output/question_version_info.php',
    'core_question\\output\\question_version_selection' => '/var/www/html/plantilla/question/classes/output/question_version_selection.php',
    'core_question\\output\\switch_question_bank' => '/var/www/html/plantilla/question/classes/output/switch_question_bank.php',
    'core_question\\output\\view_banks' => '/var/www/html/plantilla/question/classes/output/view_banks.php',
    'core_question\\privacy\\provider' => '/var/www/html/plantilla/question/classes/privacy/provider.php',
    'core_question\\question_reference_manager' => '/var/www/html/plantilla/question/classes/question_reference_manager.php',
    'core_question\\statistics\\questions\\all_calculated_for_qubaid_condition' => '/var/www/html/plantilla/question/classes/statistics/questions/all_calculated_for_qubaid_condition.php',
    'core_question\\statistics\\questions\\calculated' => '/var/www/html/plantilla/question/classes/statistics/questions/calculated.php',
    'core_question\\statistics\\questions\\calculated_for_subquestion' => '/var/www/html/plantilla/question/classes/statistics/questions/calculated_for_subquestion.php',
    'core_question\\statistics\\questions\\calculated_question_summary' => '/var/www/html/plantilla/question/classes/statistics/questions/calculated_question_summary.php',
    'core_question\\statistics\\questions\\calculator' => '/var/www/html/plantilla/question/classes/statistics/questions/calculator.php',
    'core_question\\statistics\\responses\\analyser' => '/var/www/html/plantilla/question/classes/statistics/responses/analyser.php',
    'core_question\\statistics\\responses\\analysis_for_actual_response' => '/var/www/html/plantilla/question/classes/statistics/responses/analysis_for_actual_response.php',
    'core_question\\statistics\\responses\\analysis_for_class' => '/var/www/html/plantilla/question/classes/statistics/responses/analysis_for_class.php',
    'core_question\\statistics\\responses\\analysis_for_question' => '/var/www/html/plantilla/question/classes/statistics/responses/analysis_for_question.php',
    'core_question\\statistics\\responses\\analysis_for_question_all_tries' => '/var/www/html/plantilla/question/classes/statistics/responses/analysis_for_question_all_tries.php',
    'core_question\\statistics\\responses\\analysis_for_subpart' => '/var/www/html/plantilla/question/classes/statistics/responses/analysis_for_subpart.php',
    'core_question_category_manager' => '/var/www/html/plantilla/question/classes/category_manager.php',
    'core_question_external' => '/var/www/html/plantilla/question/classes/external.php',
    'core_question_question_reference_manager' => '/var/www/html/plantilla/question/classes/question_reference_manager.php',
    'core_rating\\external' => '/var/www/html/plantilla/rating/classes/external.php',
    'core_rating\\external\\util' => '/var/www/html/plantilla/rating/classes/external/util.php',
    'core_rating\\phpunit\\privacy_helper' => '/var/www/html/plantilla/rating/classes/phpunit/privacy_helper.php',
    'core_rating\\privacy\\provider' => '/var/www/html/plantilla/rating/classes/privacy/provider.php',
    'core_rating_external' => '/var/www/html/plantilla/rating/classes/external.php',
    'core_renderer' => '/var/www/html/plantilla/lib/classes/output/core_renderer.php',
    'core_renderer_ajax' => '/var/www/html/plantilla/lib/classes/output/core_renderer_ajax.php',
    'core_renderer_cli' => '/var/www/html/plantilla/lib/classes/output/core_renderer_cli.php',
    'core_renderer_maintenance' => '/var/www/html/plantilla/lib/classes/output/core_renderer_maintenance.php',
    'core_report\\output\\coursestructure' => '/var/www/html/plantilla/report/classes/output/coursestructure.php',
    'core_report\\privacy\\provider' => '/var/www/html/plantilla/report/classes/privacy/provider.php',
    'core_report_helper' => '/var/www/html/plantilla/lib/classes/report_helper.php',
    'core_reportbuilder\\customfield\\report_handler' => '/var/www/html/plantilla/reportbuilder/classes/customfield/report_handler.php',
    'core_reportbuilder\\datasource' => '/var/www/html/plantilla/reportbuilder/classes/datasource.php',
    'core_reportbuilder\\event\\audience_created' => '/var/www/html/plantilla/reportbuilder/classes/event/audience_created.php',
    'core_reportbuilder\\event\\audience_deleted' => '/var/www/html/plantilla/reportbuilder/classes/event/audience_deleted.php',
    'core_reportbuilder\\event\\audience_updated' => '/var/www/html/plantilla/reportbuilder/classes/event/audience_updated.php',
    'core_reportbuilder\\event\\report_created' => '/var/www/html/plantilla/reportbuilder/classes/event/report_created.php',
    'core_reportbuilder\\event\\report_deleted' => '/var/www/html/plantilla/reportbuilder/classes/event/report_deleted.php',
    'core_reportbuilder\\event\\report_updated' => '/var/www/html/plantilla/reportbuilder/classes/event/report_updated.php',
    'core_reportbuilder\\event\\report_viewed' => '/var/www/html/plantilla/reportbuilder/classes/event/report_viewed.php',
    'core_reportbuilder\\event\\schedule_created' => '/var/www/html/plantilla/reportbuilder/classes/event/schedule_created.php',
    'core_reportbuilder\\event\\schedule_deleted' => '/var/www/html/plantilla/reportbuilder/classes/event/schedule_deleted.php',
    'core_reportbuilder\\event\\schedule_updated' => '/var/www/html/plantilla/reportbuilder/classes/event/schedule_updated.php',
    'core_reportbuilder\\exception\\report_access_exception' => '/var/www/html/plantilla/reportbuilder/classes/exception/report_access_exception.php',
    'core_reportbuilder\\exception\\source_invalid_exception' => '/var/www/html/plantilla/reportbuilder/classes/exception/source_invalid_exception.php',
    'core_reportbuilder\\exception\\source_unavailable_exception' => '/var/www/html/plantilla/reportbuilder/classes/exception/source_unavailable_exception.php',
    'core_reportbuilder\\external\\audiences\\delete' => '/var/www/html/plantilla/reportbuilder/classes/external/audiences/delete.php',
    'core_reportbuilder\\external\\columns\\add' => '/var/www/html/plantilla/reportbuilder/classes/external/columns/add.php',
    'core_reportbuilder\\external\\columns\\delete' => '/var/www/html/plantilla/reportbuilder/classes/external/columns/delete.php',
    'core_reportbuilder\\external\\columns\\reorder' => '/var/www/html/plantilla/reportbuilder/classes/external/columns/reorder.php',
    'core_reportbuilder\\external\\columns\\sort\\get' => '/var/www/html/plantilla/reportbuilder/classes/external/columns/sort/get.php',
    'core_reportbuilder\\external\\columns\\sort\\reorder' => '/var/www/html/plantilla/reportbuilder/classes/external/columns/sort/reorder.php',
    'core_reportbuilder\\external\\columns\\sort\\toggle' => '/var/www/html/plantilla/reportbuilder/classes/external/columns/sort/toggle.php',
    'core_reportbuilder\\external\\conditions\\add' => '/var/www/html/plantilla/reportbuilder/classes/external/conditions/add.php',
    'core_reportbuilder\\external\\conditions\\delete' => '/var/www/html/plantilla/reportbuilder/classes/external/conditions/delete.php',
    'core_reportbuilder\\external\\conditions\\reorder' => '/var/www/html/plantilla/reportbuilder/classes/external/conditions/reorder.php',
    'core_reportbuilder\\external\\conditions\\reset' => '/var/www/html/plantilla/reportbuilder/classes/external/conditions/reset.php',
    'core_reportbuilder\\external\\custom_report_audience_cards_exporter' => '/var/www/html/plantilla/reportbuilder/classes/external/custom_report_audience_cards_exporter.php',
    'core_reportbuilder\\external\\custom_report_card_view_exporter' => '/var/www/html/plantilla/reportbuilder/classes/external/custom_report_card_view_exporter.php',
    'core_reportbuilder\\external\\custom_report_column_cards_exporter' => '/var/www/html/plantilla/reportbuilder/classes/external/custom_report_column_cards_exporter.php',
    'core_reportbuilder\\external\\custom_report_columns_sorting_exporter' => '/var/www/html/plantilla/reportbuilder/classes/external/custom_report_columns_sorting_exporter.php',
    'core_reportbuilder\\external\\custom_report_conditions_exporter' => '/var/www/html/plantilla/reportbuilder/classes/external/custom_report_conditions_exporter.php',
    'core_reportbuilder\\external\\custom_report_data_exporter' => '/var/www/html/plantilla/reportbuilder/classes/external/custom_report_data_exporter.php',
    'core_reportbuilder\\external\\custom_report_details_exporter' => '/var/www/html/plantilla/reportbuilder/classes/external/custom_report_details_exporter.php',
    'core_reportbuilder\\external\\custom_report_exporter' => '/var/www/html/plantilla/reportbuilder/classes/external/custom_report_exporter.php',
    'core_reportbuilder\\external\\custom_report_filters_exporter' => '/var/www/html/plantilla/reportbuilder/classes/external/custom_report_filters_exporter.php',
    'core_reportbuilder\\external\\custom_report_menu_cards_exporter' => '/var/www/html/plantilla/reportbuilder/classes/external/custom_report_menu_cards_exporter.php',
    'core_reportbuilder\\external\\filters\\add' => '/var/www/html/plantilla/reportbuilder/classes/external/filters/add.php',
    'core_reportbuilder\\external\\filters\\delete' => '/var/www/html/plantilla/reportbuilder/classes/external/filters/delete.php',
    'core_reportbuilder\\external\\filters\\reorder' => '/var/www/html/plantilla/reportbuilder/classes/external/filters/reorder.php',
    'core_reportbuilder\\external\\filters\\reset' => '/var/www/html/plantilla/reportbuilder/classes/external/filters/reset.php',
    'core_reportbuilder\\external\\filters\\set' => '/var/www/html/plantilla/reportbuilder/classes/external/filters/set.php',
    'core_reportbuilder\\external\\report_action_exporter' => '/var/www/html/plantilla/reportbuilder/classes/external/report_action_exporter.php',
    'core_reportbuilder\\external\\reports\\delete' => '/var/www/html/plantilla/reportbuilder/classes/external/reports/delete.php',
    'core_reportbuilder\\external\\reports\\get' => '/var/www/html/plantilla/reportbuilder/classes/external/reports/get.php',
    'core_reportbuilder\\external\\reports\\listing' => '/var/www/html/plantilla/reportbuilder/classes/external/reports/listing.php',
    'core_reportbuilder\\external\\reports\\retrieve' => '/var/www/html/plantilla/reportbuilder/classes/external/reports/retrieve.php',
    'core_reportbuilder\\external\\reports\\view' => '/var/www/html/plantilla/reportbuilder/classes/external/reports/view.php',
    'core_reportbuilder\\external\\schedules\\delete' => '/var/www/html/plantilla/reportbuilder/classes/external/schedules/delete.php',
    'core_reportbuilder\\external\\schedules\\send' => '/var/www/html/plantilla/reportbuilder/classes/external/schedules/send.php',
    'core_reportbuilder\\external\\schedules\\toggle' => '/var/www/html/plantilla/reportbuilder/classes/external/schedules/toggle.php',
    'core_reportbuilder\\external\\system_report_data_exporter' => '/var/www/html/plantilla/reportbuilder/classes/external/system_report_data_exporter.php',
    'core_reportbuilder\\external\\system_report_exporter' => '/var/www/html/plantilla/reportbuilder/classes/external/system_report_exporter.php',
    'core_reportbuilder\\external\\systemreports\\can_view' => '/var/www/html/plantilla/reportbuilder/classes/external/systemreports/can_view.php',
    'core_reportbuilder\\external\\systemreports\\retrieve' => '/var/www/html/plantilla/reportbuilder/classes/external/systemreports/retrieve.php',
    'core_reportbuilder\\form\\audience' => '/var/www/html/plantilla/reportbuilder/classes/form/audience.php',
    'core_reportbuilder\\form\\card_view' => '/var/www/html/plantilla/reportbuilder/classes/form/card_view.php',
    'core_reportbuilder\\form\\condition' => '/var/www/html/plantilla/reportbuilder/classes/form/condition.php',
    'core_reportbuilder\\form\\duplicate_report' => '/var/www/html/plantilla/reportbuilder/classes/form/duplicate_report.php',
    'core_reportbuilder\\form\\filter' => '/var/www/html/plantilla/reportbuilder/classes/form/filter.php',
    'core_reportbuilder\\form\\report' => '/var/www/html/plantilla/reportbuilder/classes/form/report.php',
    'core_reportbuilder\\form\\schedule' => '/var/www/html/plantilla/reportbuilder/classes/form/schedule.php',
    'core_reportbuilder\\local\\aggregation\\avg' => '/var/www/html/plantilla/reportbuilder/classes/local/aggregation/avg.php',
    'core_reportbuilder\\local\\aggregation\\base' => '/var/www/html/plantilla/reportbuilder/classes/local/aggregation/base.php',
    'core_reportbuilder\\local\\aggregation\\count' => '/var/www/html/plantilla/reportbuilder/classes/local/aggregation/count.php',
    'core_reportbuilder\\local\\aggregation\\countdistinct' => '/var/www/html/plantilla/reportbuilder/classes/local/aggregation/countdistinct.php',
    'core_reportbuilder\\local\\aggregation\\date' => '/var/www/html/plantilla/reportbuilder/classes/local/aggregation/date.php',
    'core_reportbuilder\\local\\aggregation\\groupconcat' => '/var/www/html/plantilla/reportbuilder/classes/local/aggregation/groupconcat.php',
    'core_reportbuilder\\local\\aggregation\\groupconcatdistinct' => '/var/www/html/plantilla/reportbuilder/classes/local/aggregation/groupconcatdistinct.php',
    'core_reportbuilder\\local\\aggregation\\max' => '/var/www/html/plantilla/reportbuilder/classes/local/aggregation/max.php',
    'core_reportbuilder\\local\\aggregation\\min' => '/var/www/html/plantilla/reportbuilder/classes/local/aggregation/min.php',
    'core_reportbuilder\\local\\aggregation\\percent' => '/var/www/html/plantilla/reportbuilder/classes/local/aggregation/percent.php',
    'core_reportbuilder\\local\\aggregation\\sum' => '/var/www/html/plantilla/reportbuilder/classes/local/aggregation/sum.php',
    'core_reportbuilder\\local\\audiences\\base' => '/var/www/html/plantilla/reportbuilder/classes/local/audiences/base.php',
    'core_reportbuilder\\local\\entities\\base' => '/var/www/html/plantilla/reportbuilder/classes/local/entities/base.php',
    'core_reportbuilder\\local\\entities\\course' => '/var/www/html/plantilla/reportbuilder/classes/local/entities/course.php',
    'core_reportbuilder\\local\\entities\\user' => '/var/www/html/plantilla/reportbuilder/classes/local/entities/user.php',
    'core_reportbuilder\\local\\filters\\audience' => '/var/www/html/plantilla/reportbuilder/classes/local/filters/audience.php',
    'core_reportbuilder\\local\\filters\\autocomplete' => '/var/www/html/plantilla/reportbuilder/classes/local/filters/autocomplete.php',
    'core_reportbuilder\\local\\filters\\base' => '/var/www/html/plantilla/reportbuilder/classes/local/filters/base.php',
    'core_reportbuilder\\local\\filters\\boolean_select' => '/var/www/html/plantilla/reportbuilder/classes/local/filters/boolean_select.php',
    'core_reportbuilder\\local\\filters\\category' => '/var/www/html/plantilla/reportbuilder/classes/local/filters/category.php',
    'core_reportbuilder\\local\\filters\\cohort' => '/var/www/html/plantilla/reportbuilder/classes/local/filters/cohort.php',
    'core_reportbuilder\\local\\filters\\course_selector' => '/var/www/html/plantilla/reportbuilder/classes/local/filters/course_selector.php',
    'core_reportbuilder\\local\\filters\\date' => '/var/www/html/plantilla/reportbuilder/classes/local/filters/date.php',
    'core_reportbuilder\\local\\filters\\duration' => '/var/www/html/plantilla/reportbuilder/classes/local/filters/duration.php',
    'core_reportbuilder\\local\\filters\\filesize' => '/var/www/html/plantilla/reportbuilder/classes/local/filters/filesize.php',
    'core_reportbuilder\\local\\filters\\number' => '/var/www/html/plantilla/reportbuilder/classes/local/filters/number.php',
    'core_reportbuilder\\local\\filters\\select' => '/var/www/html/plantilla/reportbuilder/classes/local/filters/select.php',
    'core_reportbuilder\\local\\filters\\tags' => '/var/www/html/plantilla/reportbuilder/classes/local/filters/tags.php',
    'core_reportbuilder\\local\\filters\\text' => '/var/www/html/plantilla/reportbuilder/classes/local/filters/text.php',
    'core_reportbuilder\\local\\filters\\user' => '/var/www/html/plantilla/reportbuilder/classes/local/filters/user.php',
    'core_reportbuilder\\local\\helpers\\aggregation' => '/var/www/html/plantilla/reportbuilder/classes/local/helpers/aggregation.php',
    'core_reportbuilder\\local\\helpers\\audience' => '/var/www/html/plantilla/reportbuilder/classes/local/helpers/audience.php',
    'core_reportbuilder\\local\\helpers\\custom_fields' => '/var/www/html/plantilla/reportbuilder/classes/local/helpers/custom_fields.php',
    'core_reportbuilder\\local\\helpers\\database' => '/var/www/html/plantilla/reportbuilder/classes/local/helpers/database.php',
    'core_reportbuilder\\local\\helpers\\format' => '/var/www/html/plantilla/reportbuilder/classes/local/helpers/format.php',
    'core_reportbuilder\\local\\helpers\\join_trait' => '/var/www/html/plantilla/reportbuilder/classes/local/helpers/join_trait.php',
    'core_reportbuilder\\local\\helpers\\report' => '/var/www/html/plantilla/reportbuilder/classes/local/helpers/report.php',
    'core_reportbuilder\\local\\helpers\\schedule' => '/var/www/html/plantilla/reportbuilder/classes/local/helpers/schedule.php',
    'core_reportbuilder\\local\\helpers\\user_filter_manager' => '/var/www/html/plantilla/reportbuilder/classes/local/helpers/user_filter_manager.php',
    'core_reportbuilder\\local\\helpers\\user_profile_fields' => '/var/www/html/plantilla/reportbuilder/classes/local/helpers/user_profile_fields.php',
    'core_reportbuilder\\local\\models\\audience' => '/var/www/html/plantilla/reportbuilder/classes/local/models/audience.php',
    'core_reportbuilder\\local\\models\\column' => '/var/www/html/plantilla/reportbuilder/classes/local/models/column.php',
    'core_reportbuilder\\local\\models\\filter' => '/var/www/html/plantilla/reportbuilder/classes/local/models/filter.php',
    'core_reportbuilder\\local\\models\\report' => '/var/www/html/plantilla/reportbuilder/classes/local/models/report.php',
    'core_reportbuilder\\local\\models\\schedule' => '/var/www/html/plantilla/reportbuilder/classes/local/models/schedule.php',
    'core_reportbuilder\\local\\models\\user_filter' => '/var/www/html/plantilla/reportbuilder/classes/local/models/user_filter.php',
    'core_reportbuilder\\local\\report\\action' => '/var/www/html/plantilla/reportbuilder/classes/local/report/action.php',
    'core_reportbuilder\\local\\report\\base' => '/var/www/html/plantilla/reportbuilder/classes/local/report/base.php',
    'core_reportbuilder\\local\\report\\column' => '/var/www/html/plantilla/reportbuilder/classes/local/report/column.php',
    'core_reportbuilder\\local\\report\\filter' => '/var/www/html/plantilla/reportbuilder/classes/local/report/filter.php',
    'core_reportbuilder\\local\\systemreports\\report_access_list' => '/var/www/html/plantilla/reportbuilder/classes/local/systemreports/report_access_list.php',
    'core_reportbuilder\\local\\systemreports\\report_schedules' => '/var/www/html/plantilla/reportbuilder/classes/local/systemreports/report_schedules.php',
    'core_reportbuilder\\local\\systemreports\\reports_list' => '/var/www/html/plantilla/reportbuilder/classes/local/systemreports/reports_list.php',
    'core_reportbuilder\\manager' => '/var/www/html/plantilla/reportbuilder/classes/manager.php',
    'core_reportbuilder\\output\\audience_heading_editable' => '/var/www/html/plantilla/reportbuilder/classes/output/audience_heading_editable.php',
    'core_reportbuilder\\output\\column_aggregation_editable' => '/var/www/html/plantilla/reportbuilder/classes/output/column_aggregation_editable.php',
    'core_reportbuilder\\output\\column_heading_editable' => '/var/www/html/plantilla/reportbuilder/classes/output/column_heading_editable.php',
    'core_reportbuilder\\output\\custom_report' => '/var/www/html/plantilla/reportbuilder/classes/output/custom_report.php',
    'core_reportbuilder\\output\\dynamictabs\\access' => '/var/www/html/plantilla/reportbuilder/classes/output/dynamictabs/access.php',
    'core_reportbuilder\\output\\dynamictabs\\audience' => '/var/www/html/plantilla/reportbuilder/classes/output/dynamictabs/audience.php',
    'core_reportbuilder\\output\\dynamictabs\\editor' => '/var/www/html/plantilla/reportbuilder/classes/output/dynamictabs/editor.php',
    'core_reportbuilder\\output\\dynamictabs\\schedules' => '/var/www/html/plantilla/reportbuilder/classes/output/dynamictabs/schedules.php',
    'core_reportbuilder\\output\\filter_heading_editable' => '/var/www/html/plantilla/reportbuilder/classes/output/filter_heading_editable.php',
    'core_reportbuilder\\output\\renderer' => '/var/www/html/plantilla/reportbuilder/classes/output/renderer.php',
    'core_reportbuilder\\output\\report_action' => '/var/www/html/plantilla/reportbuilder/classes/output/report_action.php',
    'core_reportbuilder\\output\\report_name_editable' => '/var/www/html/plantilla/reportbuilder/classes/output/report_name_editable.php',
    'core_reportbuilder\\output\\schedule_name_editable' => '/var/www/html/plantilla/reportbuilder/classes/output/schedule_name_editable.php',
    'core_reportbuilder\\output\\system_report' => '/var/www/html/plantilla/reportbuilder/classes/output/system_report.php',
    'core_reportbuilder\\permission' => '/var/www/html/plantilla/reportbuilder/classes/permission.php',
    'core_reportbuilder\\privacy\\provider' => '/var/www/html/plantilla/reportbuilder/classes/privacy/provider.php',
    'core_reportbuilder\\reportbuilder\\audience\\admins' => '/var/www/html/plantilla/reportbuilder/classes/reportbuilder/audience/admins.php',
    'core_reportbuilder\\reportbuilder\\audience\\allusers' => '/var/www/html/plantilla/reportbuilder/classes/reportbuilder/audience/allusers.php',
    'core_reportbuilder\\reportbuilder\\audience\\manual' => '/var/www/html/plantilla/reportbuilder/classes/reportbuilder/audience/manual.php',
    'core_reportbuilder\\reportbuilder\\audience\\systemrole' => '/var/www/html/plantilla/reportbuilder/classes/reportbuilder/audience/systemrole.php',
    'core_reportbuilder\\system_report' => '/var/www/html/plantilla/reportbuilder/classes/system_report.php',
    'core_reportbuilder\\system_report_factory' => '/var/www/html/plantilla/reportbuilder/classes/system_report_factory.php',
    'core_reportbuilder\\table\\base_report_table' => '/var/www/html/plantilla/reportbuilder/classes/table/base_report_table.php',
    'core_reportbuilder\\table\\custom_report_table' => '/var/www/html/plantilla/reportbuilder/classes/table/custom_report_table.php',
    'core_reportbuilder\\table\\custom_report_table_filterset' => '/var/www/html/plantilla/reportbuilder/classes/table/custom_report_table_filterset.php',
    'core_reportbuilder\\table\\custom_report_table_view' => '/var/www/html/plantilla/reportbuilder/classes/table/custom_report_table_view.php',
    'core_reportbuilder\\table\\custom_report_table_view_filterset' => '/var/www/html/plantilla/reportbuilder/classes/table/custom_report_table_view_filterset.php',
    'core_reportbuilder\\table\\system_report_table' => '/var/www/html/plantilla/reportbuilder/classes/table/system_report_table.php',
    'core_reportbuilder\\table\\system_report_table_filterset' => '/var/www/html/plantilla/reportbuilder/classes/table/system_report_table_filterset.php',
    'core_reportbuilder\\task\\send_schedule' => '/var/www/html/plantilla/reportbuilder/classes/task/send_schedule.php',
    'core_reportbuilder\\task\\send_schedules' => '/var/www/html/plantilla/reportbuilder/classes/task/send_schedules.php',
    'core_reportbuilder_datasource' => '/var/www/html/plantilla/reportbuilder/classes/datasource.php',
    'core_reportbuilder_manager' => '/var/www/html/plantilla/reportbuilder/classes/manager.php',
    'core_reportbuilder_permission' => '/var/www/html/plantilla/reportbuilder/classes/permission.php',
    'core_reportbuilder_system_report' => '/var/www/html/plantilla/reportbuilder/classes/system_report.php',
    'core_reportbuilder_system_report_factory' => '/var/www/html/plantilla/reportbuilder/classes/system_report_factory.php',
    'core_repository\\privacy\\provider' => '/var/www/html/plantilla/repository/classes/privacy/provider.php',
    'core_requirejs' => '/var/www/html/plantilla/lib/classes/requirejs.php',
    'core_role\\admins_existing_selector' => '/var/www/html/plantilla/admin/roles/classes/admins_existing_selector.php',
    'core_role\\admins_potential_selector' => '/var/www/html/plantilla/admin/roles/classes/admins_potential_selector.php',
    'core_role\\allow_assign_page' => '/var/www/html/plantilla/admin/roles/classes/allow_assign_page.php',
    'core_role\\allow_override_page' => '/var/www/html/plantilla/admin/roles/classes/allow_override_page.php',
    'core_role\\allow_role_page' => '/var/www/html/plantilla/admin/roles/classes/allow_role_page.php',
    'core_role\\allow_switch_page' => '/var/www/html/plantilla/admin/roles/classes/allow_switch_page.php',
    'core_role\\allow_view_page' => '/var/www/html/plantilla/admin/roles/classes/allow_view_page.php',
    'core_role\\assign_user_selector_base' => '/var/www/html/plantilla/admin/roles/classes/assign_user_selector_base.php',
    'core_role\\capability_table_base' => '/var/www/html/plantilla/admin/roles/classes/capability_table_base.php',
    'core_role\\capability_table_with_risks' => '/var/www/html/plantilla/admin/roles/classes/capability_table_with_risks.php',
    'core_role\\check_capability_table' => '/var/www/html/plantilla/admin/roles/classes/check_capability_table.php',
    'core_role\\check_users_selector' => '/var/www/html/plantilla/admin/roles/classes/check_users_selector.php',
    'core_role\\define_role_table_advanced' => '/var/www/html/plantilla/admin/roles/classes/define_role_table_advanced.php',
    'core_role\\define_role_table_basic' => '/var/www/html/plantilla/admin/roles/classes/define_role_table_basic.php',
    'core_role\\existing_role_holders' => '/var/www/html/plantilla/admin/roles/classes/existing_role_holders.php',
    'core_role\\override_permissions_table_advanced' => '/var/www/html/plantilla/admin/roles/classes/override_permissions_table_advanced.php',
    'core_role\\permission_allow_form' => '/var/www/html/plantilla/admin/roles/classes/permission_allow_form.php',
    'core_role\\permission_prohibit_form' => '/var/www/html/plantilla/admin/roles/classes/permission_prohibit_form.php',
    'core_role\\permissions_table' => '/var/www/html/plantilla/admin/roles/classes/permissions_table.php',
    'core_role\\potential_assignees_below_course' => '/var/www/html/plantilla/admin/roles/classes/potential_assignees_below_course.php',
    'core_role\\potential_assignees_course_and_above' => '/var/www/html/plantilla/admin/roles/classes/potential_assignees_course_and_above.php',
    'core_role\\preset' => '/var/www/html/plantilla/admin/roles/classes/preset.php',
    'core_role\\preset_form' => '/var/www/html/plantilla/admin/roles/classes/preset_form.php',
    'core_role\\privacy\\provider' => '/var/www/html/plantilla/admin/roles/classes/privacy/provider.php',
    'core_role\\reportbuilder\\datasource\\roles' => '/var/www/html/plantilla/admin/roles/classes/reportbuilder/datasource/roles.php',
    'core_role\\reportbuilder\\local\\entities\\role' => '/var/www/html/plantilla/admin/roles/classes/reportbuilder/local/entities/role.php',
    'core_role\\reportbuilder\\local\\entities\\role_assignment' => '/var/www/html/plantilla/admin/roles/classes/reportbuilder/local/entities/role_assignment.php',
    'core_role\\view_role_definition_table' => '/var/www/html/plantilla/admin/roles/classes/view_role_definition_table.php',
    'core_role_admins_existing_selector' => '/var/www/html/plantilla/admin/roles/classes/admins_existing_selector.php',
    'core_role_admins_potential_selector' => '/var/www/html/plantilla/admin/roles/classes/admins_potential_selector.php',
    'core_role_allow_assign_page' => '/var/www/html/plantilla/admin/roles/classes/allow_assign_page.php',
    'core_role_allow_override_page' => '/var/www/html/plantilla/admin/roles/classes/allow_override_page.php',
    'core_role_allow_role_page' => '/var/www/html/plantilla/admin/roles/classes/allow_role_page.php',
    'core_role_allow_switch_page' => '/var/www/html/plantilla/admin/roles/classes/allow_switch_page.php',
    'core_role_allow_view_page' => '/var/www/html/plantilla/admin/roles/classes/allow_view_page.php',
    'core_role_assign_user_selector_base' => '/var/www/html/plantilla/admin/roles/classes/assign_user_selector_base.php',
    'core_role_capability_table_base' => '/var/www/html/plantilla/admin/roles/classes/capability_table_base.php',
    'core_role_capability_table_with_risks' => '/var/www/html/plantilla/admin/roles/classes/capability_table_with_risks.php',
    'core_role_check_capability_table' => '/var/www/html/plantilla/admin/roles/classes/check_capability_table.php',
    'core_role_check_users_selector' => '/var/www/html/plantilla/admin/roles/classes/check_users_selector.php',
    'core_role_define_role_table_advanced' => '/var/www/html/plantilla/admin/roles/classes/define_role_table_advanced.php',
    'core_role_define_role_table_basic' => '/var/www/html/plantilla/admin/roles/classes/define_role_table_basic.php',
    'core_role_existing_role_holders' => '/var/www/html/plantilla/admin/roles/classes/existing_role_holders.php',
    'core_role_override_permissions_table_advanced' => '/var/www/html/plantilla/admin/roles/classes/override_permissions_table_advanced.php',
    'core_role_permission_allow_form' => '/var/www/html/plantilla/admin/roles/classes/permission_allow_form.php',
    'core_role_permission_prohibit_form' => '/var/www/html/plantilla/admin/roles/classes/permission_prohibit_form.php',
    'core_role_permissions_table' => '/var/www/html/plantilla/admin/roles/classes/permissions_table.php',
    'core_role_potential_assignees_below_course' => '/var/www/html/plantilla/admin/roles/classes/potential_assignees_below_course.php',
    'core_role_potential_assignees_course_and_above' => '/var/www/html/plantilla/admin/roles/classes/potential_assignees_course_and_above.php',
    'core_role_preset' => '/var/www/html/plantilla/admin/roles/classes/preset.php',
    'core_role_preset_form' => '/var/www/html/plantilla/admin/roles/classes/preset_form.php',
    'core_role_view_role_definition_table' => '/var/www/html/plantilla/admin/roles/classes/view_role_definition_table.php',
    'core_router' => '/var/www/html/plantilla/lib/classes/router.php',
    'core_rss\\privacy\\provider' => '/var/www/html/plantilla/rss/classes/privacy/provider.php',
    'core_rtlcss' => '/var/www/html/plantilla/lib/classes/rtlcss.php',
    'core_scss' => '/var/www/html/plantilla/lib/classes/scss.php',
    'core_search\\area_category' => '/var/www/html/plantilla/search/classes/area_category.php',
    'core_search\\base' => '/var/www/html/plantilla/search/classes/base.php',
    'core_search\\base_activity' => '/var/www/html/plantilla/search/classes/base_activity.php',
    'core_search\\base_block' => '/var/www/html/plantilla/search/classes/base_block.php',
    'core_search\\base_mod' => '/var/www/html/plantilla/search/classes/base_mod.php',
    'core_search\\document' => '/var/www/html/plantilla/search/classes/document.php',
    'core_search\\document_factory' => '/var/www/html/plantilla/search/classes/document_factory.php',
    'core_search\\document_icon' => '/var/www/html/plantilla/search/classes/document_icon.php',
    'core_search\\engine' => '/var/www/html/plantilla/search/classes/engine.php',
    'core_search\\engine_exception' => '/var/www/html/plantilla/search/classes/engine_exception.php',
    'core_search\\external' => '/var/www/html/plantilla/search/classes/external.php',
    'core_search\\external\\document_exporter' => '/var/www/html/plantilla/search/classes/external/document_exporter.php',
    'core_search\\external\\get_results' => '/var/www/html/plantilla/search/classes/external/get_results.php',
    'core_search\\external\\get_search_areas_list' => '/var/www/html/plantilla/search/classes/external/get_search_areas_list.php',
    'core_search\\external\\get_top_results' => '/var/www/html/plantilla/search/classes/external/get_top_results.php',
    'core_search\\external\\view_results' => '/var/www/html/plantilla/search/classes/external/view_results.php',
    'core_search\\manager' => '/var/www/html/plantilla/search/classes/manager.php',
    'core_search\\output\\form\\search' => '/var/www/html/plantilla/search/classes/output/form/search.php',
    'core_search\\output\\renderer' => '/var/www/html/plantilla/search/classes/output/renderer.php',
    'core_search\\privacy\\provider' => '/var/www/html/plantilla/search/classes/privacy/provider.php',
    'core_search\\skip_future_documents_iterator' => '/var/www/html/plantilla/search/classes/skip_future_documents_iterator.php',
    'core_search_area_category' => '/var/www/html/plantilla/search/classes/area_category.php',
    'core_search_base' => '/var/www/html/plantilla/search/classes/base.php',
    'core_search_base_activity' => '/var/www/html/plantilla/search/classes/base_activity.php',
    'core_search_base_block' => '/var/www/html/plantilla/search/classes/base_block.php',
    'core_search_base_mod' => '/var/www/html/plantilla/search/classes/base_mod.php',
    'core_search_document' => '/var/www/html/plantilla/search/classes/document.php',
    'core_search_document_factory' => '/var/www/html/plantilla/search/classes/document_factory.php',
    'core_search_document_icon' => '/var/www/html/plantilla/search/classes/document_icon.php',
    'core_search_engine' => '/var/www/html/plantilla/search/classes/engine.php',
    'core_search_engine_exception' => '/var/www/html/plantilla/search/classes/engine_exception.php',
    'core_search_external' => '/var/www/html/plantilla/search/classes/external.php',
    'core_search_manager' => '/var/www/html/plantilla/search/classes/manager.php',
    'core_search_skip_future_documents_iterator' => '/var/www/html/plantilla/search/classes/skip_future_documents_iterator.php',
    'core_shutdown_manager' => '/var/www/html/plantilla/lib/classes/shutdown_manager.php',
    'core_sms\\description' => '/var/www/html/plantilla/sms/classes/description.php',
    'core_sms\\external\\sms_gateway_status' => '/var/www/html/plantilla/sms/classes/external/sms_gateway_status.php',
    'core_sms\\form\\sms_gateway_form' => '/var/www/html/plantilla/sms/classes/form/sms_gateway_form.php',
    'core_sms\\gateway' => '/var/www/html/plantilla/sms/classes/gateway.php',
    'core_sms\\hook\\after_sms_gateway_form_hook' => '/var/www/html/plantilla/sms/classes/hook/after_sms_gateway_form_hook.php',
    'core_sms\\hook\\before_gateway_deleted' => '/var/www/html/plantilla/sms/classes/hook/before_gateway_deleted.php',
    'core_sms\\hook\\before_gateway_disabled' => '/var/www/html/plantilla/sms/classes/hook/before_gateway_disabled.php',
    'core_sms\\manager' => '/var/www/html/plantilla/sms/classes/manager.php',
    'core_sms\\message' => '/var/www/html/plantilla/sms/classes/message.php',
    'core_sms\\message_status' => '/var/www/html/plantilla/sms/classes/message_status.php',
    'core_sms\\privacy\\provider' => '/var/www/html/plantilla/sms/classes/privacy/provider.php',
    'core_sms\\status' => '/var/www/html/plantilla/sms/classes/status.php',
    'core_sms\\table\\sms_gateway_table' => '/var/www/html/plantilla/sms/classes/table/sms_gateway_table.php',
    'core_sms\\table\\sms_gateway_table_filterset' => '/var/www/html/plantilla/sms/classes/table/sms_gateway_table_filterset.php',
    'core_sms\\task\\send_sms_task' => '/var/www/html/plantilla/sms/classes/task/send_sms_task.php',
    'core_sms_description' => '/var/www/html/plantilla/sms/classes/description.php',
    'core_sms_gateway' => '/var/www/html/plantilla/sms/classes/gateway.php',
    'core_sms_manager' => '/var/www/html/plantilla/sms/classes/manager.php',
    'core_sms_message' => '/var/www/html/plantilla/sms/classes/message.php',
    'core_sms_message_status' => '/var/www/html/plantilla/sms/classes/message_status.php',
    'core_sms_status' => '/var/www/html/plantilla/sms/classes/status.php',
    'core_string_manager' => '/var/www/html/plantilla/lib/classes/string_manager.php',
    'core_string_manager_install' => '/var/www/html/plantilla/lib/classes/string_manager_install.php',
    'core_string_manager_standard' => '/var/www/html/plantilla/lib/classes/string_manager_standard.php',
    'core_system_clock' => '/var/www/html/plantilla/lib/classes/system_clock.php',
    'core_table\\base_export_format' => '/var/www/html/plantilla/lib/table/classes/base_export_format.php',
    'core_table\\dataformat_export_format' => '/var/www/html/plantilla/lib/table/classes/dataformat_export_format.php',
    'core_table\\dynamic' => '/var/www/html/plantilla/lib/table/classes/dynamic.php',
    'core_table\\external\\dynamic\\get' => '/var/www/html/plantilla/lib/table/classes/external/dynamic/get.php',
    'core_table\\flexible_table' => '/var/www/html/plantilla/lib/table/classes/flexible_table.php',
    'core_table\\local\\filter\\filter' => '/var/www/html/plantilla/lib/table/classes/local/filter/filter.php',
    'core_table\\local\\filter\\filterset' => '/var/www/html/plantilla/lib/table/classes/local/filter/filterset.php',
    'core_table\\local\\filter\\integer_filter' => '/var/www/html/plantilla/lib/table/classes/local/filter/integer_filter.php',
    'core_table\\local\\filter\\numeric_comparison_filter' => '/var/www/html/plantilla/lib/table/classes/local/filter/numeric_comparison_filter.php',
    'core_table\\local\\filter\\string_filter' => '/var/www/html/plantilla/lib/table/classes/local/filter/string_filter.php',
    'core_table\\output\\html_table' => '/var/www/html/plantilla/lib/table/classes/output/html_table.php',
    'core_table\\output\\html_table_cell' => '/var/www/html/plantilla/lib/table/classes/output/html_table_cell.php',
    'core_table\\output\\html_table_row' => '/var/www/html/plantilla/lib/table/classes/output/html_table_row.php',
    'core_table\\privacy\\provider' => '/var/www/html/plantilla/lib/table/classes/privacy/provider.php',
    'core_table\\sql_table' => '/var/www/html/plantilla/lib/table/classes/sql_table.php',
    'core_table_base_export_format' => '/var/www/html/plantilla/lib/table/classes/base_export_format.php',
    'core_table_dataformat_export_format' => '/var/www/html/plantilla/lib/table/classes/dataformat_export_format.php',
    'core_table_dynamic' => '/var/www/html/plantilla/lib/table/classes/dynamic.php',
    'core_table_flexible_table' => '/var/www/html/plantilla/lib/table/classes/flexible_table.php',
    'core_table_sql_table' => '/var/www/html/plantilla/lib/table/classes/sql_table.php',
    'core_tag\\area' => '/var/www/html/plantilla/tag/classes/area.php',
    'core_tag\\areas_table' => '/var/www/html/plantilla/tag/classes/areas_table.php',
    'core_tag\\collection' => '/var/www/html/plantilla/tag/classes/collection.php',
    'core_tag\\collections_table' => '/var/www/html/plantilla/tag/classes/collections_table.php',
    'core_tag\\external' => '/var/www/html/plantilla/tag/classes/external.php',
    'core_tag\\external\\tag_area_exporter' => '/var/www/html/plantilla/tag/classes/external/tag_area_exporter.php',
    'core_tag\\external\\tag_collection_exporter' => '/var/www/html/plantilla/tag/classes/external/tag_collection_exporter.php',
    'core_tag\\external\\tag_item_exporter' => '/var/www/html/plantilla/tag/classes/external/tag_item_exporter.php',
    'core_tag\\external\\util' => '/var/www/html/plantilla/tag/classes/external/util.php',
    'core_tag\\index_builder' => '/var/www/html/plantilla/tag/classes/index_builder.php',
    'core_tag\\manage_table' => '/var/www/html/plantilla/tag/classes/manage_table.php',
    'core_tag\\output\\tag' => '/var/www/html/plantilla/tag/classes/output/tag.php',
    'core_tag\\output\\tagareacollection' => '/var/www/html/plantilla/tag/classes/output/tagareacollection.php',
    'core_tag\\output\\tagareaenabled' => '/var/www/html/plantilla/tag/classes/output/tagareaenabled.php',
    'core_tag\\output\\tagareashowstandard' => '/var/www/html/plantilla/tag/classes/output/tagareashowstandard.php',
    'core_tag\\output\\tagcloud' => '/var/www/html/plantilla/tag/classes/output/tagcloud.php',
    'core_tag\\output\\tagcollname' => '/var/www/html/plantilla/tag/classes/output/tagcollname.php',
    'core_tag\\output\\tagcollsearchable' => '/var/www/html/plantilla/tag/classes/output/tagcollsearchable.php',
    'core_tag\\output\\tagfeed' => '/var/www/html/plantilla/tag/classes/output/tagfeed.php',
    'core_tag\\output\\tagflag' => '/var/www/html/plantilla/tag/classes/output/tagflag.php',
    'core_tag\\output\\tagindex' => '/var/www/html/plantilla/tag/classes/output/tagindex.php',
    'core_tag\\output\\tagisstandard' => '/var/www/html/plantilla/tag/classes/output/tagisstandard.php',
    'core_tag\\output\\taglist' => '/var/www/html/plantilla/tag/classes/output/taglist.php',
    'core_tag\\output\\tagname' => '/var/www/html/plantilla/tag/classes/output/tagname.php',
    'core_tag\\privacy\\provider' => '/var/www/html/plantilla/tag/classes/privacy/provider.php',
    'core_tag\\renderer' => '/var/www/html/plantilla/tag/classes/renderer.php',
    'core_tag\\reportbuilder\\datasource\\tags' => '/var/www/html/plantilla/tag/classes/reportbuilder/datasource/tags.php',
    'core_tag\\reportbuilder\\local\\entities\\collection' => '/var/www/html/plantilla/tag/classes/reportbuilder/local/entities/collection.php',
    'core_tag\\reportbuilder\\local\\entities\\instance' => '/var/www/html/plantilla/tag/classes/reportbuilder/local/entities/instance.php',
    'core_tag\\reportbuilder\\local\\entities\\tag' => '/var/www/html/plantilla/tag/classes/reportbuilder/local/entities/tag.php',
    'core_tag\\reportbuilder\\local\\systemreports\\tags' => '/var/www/html/plantilla/tag/classes/reportbuilder/local/systemreports/tags.php',
    'core_tag\\tag' => '/var/www/html/plantilla/tag/classes/tag.php',
    'core_tag\\tests\\privacy_helper' => '/var/www/html/plantilla/tag/classes/tests/privacy_helper.php',
    'core_tag_area' => '/var/www/html/plantilla/tag/classes/area.php',
    'core_tag_areas_table' => '/var/www/html/plantilla/tag/classes/areas_table.php',
    'core_tag_collection' => '/var/www/html/plantilla/tag/classes/collection.php',
    'core_tag_collections_table' => '/var/www/html/plantilla/tag/classes/collections_table.php',
    'core_tag_external' => '/var/www/html/plantilla/tag/classes/external.php',
    'core_tag_index_builder' => '/var/www/html/plantilla/tag/classes/index_builder.php',
    'core_tag_manage_table' => '/var/www/html/plantilla/tag/classes/manage_table.php',
    'core_tag_renderer' => '/var/www/html/plantilla/tag/classes/renderer.php',
    'core_tag_tag' => '/var/www/html/plantilla/tag/classes/tag.php',
    'core_text' => '/var/www/html/plantilla/lib/classes/text.php',
    'core_url' => '/var/www/html/plantilla/lib/classes/url.php',
    'core_user' => '/var/www/html/plantilla/lib/classes/user.php',
    'core_user\\analytics\\indicator\\user_profile_set' => '/var/www/html/plantilla/user/classes/analytics/indicator/user_profile_set.php',
    'core_user\\analytics\\indicator\\user_track_forums' => '/var/www/html/plantilla/user/classes/analytics/indicator/user_track_forums.php',
    'core_user\\analytics\\target\\upcoming_activities_due' => '/var/www/html/plantilla/user/classes/analytics/target/upcoming_activities_due.php',
    'core_user\\devicekey' => '/var/www/html/plantilla/user/classes/devicekey.php',
    'core_user\\external\\prepare_private_files_for_edition' => '/var/www/html/plantilla/user/classes/external/prepare_private_files_for_edition.php',
    'core_user\\external\\search_identity' => '/var/www/html/plantilla/user/classes/external/search_identity.php',
    'core_user\\external\\update_private_files' => '/var/www/html/plantilla/user/classes/external/update_private_files.php',
    'core_user\\external\\update_user_device_public_key' => '/var/www/html/plantilla/user/classes/external/update_user_device_public_key.php',
    'core_user\\external\\user_summary_exporter' => '/var/www/html/plantilla/user/classes/external/user_summary_exporter.php',
    'core_user\\fields' => '/var/www/html/plantilla/user/classes/fields.php',
    'core_user\\form\\calendar_form' => '/var/www/html/plantilla/user/classes/form/calendar_form.php',
    'core_user\\form\\contactsitesupport_form' => '/var/www/html/plantilla/user/classes/form/contactsitesupport_form.php',
    'core_user\\form\\contentbank_user_preferences_form' => '/var/www/html/plantilla/user/classes/form/contentbank_user_preferences_form.php',
    'core_user\\form\\defaulthomepage_form' => '/var/www/html/plantilla/user/classes/form/defaulthomepage_form.php',
    'core_user\\form\\private_files' => '/var/www/html/plantilla/user/classes/form/private_files.php',
    'core_user\\form\\profile_category_form' => '/var/www/html/plantilla/user/classes/form/profile_category_form.php',
    'core_user\\form\\profile_field_form' => '/var/www/html/plantilla/user/classes/form/profile_field_form.php',
    'core_user\\hook\\after_login_completed' => '/var/www/html/plantilla/user/classes/hook/after_login_completed.php',
    'core_user\\hook\\before_user_deleted' => '/var/www/html/plantilla/user/classes/hook/before_user_deleted.php',
    'core_user\\hook\\before_user_updated' => '/var/www/html/plantilla/user/classes/hook/before_user_updated.php',
    'core_user\\hook\\extend_bulk_user_actions' => '/var/www/html/plantilla/user/classes/hook/extend_bulk_user_actions.php',
    'core_user\\hook\\extend_default_homepage' => '/var/www/html/plantilla/user/classes/hook/extend_default_homepage.php',
    'core_user\\hook\\extend_user_menu' => '/var/www/html/plantilla/user/classes/hook/extend_user_menu.php',
    'core_user\\output\\myprofile\\category' => '/var/www/html/plantilla/user/classes/output/myprofile/category.php',
    'core_user\\output\\myprofile\\manager' => '/var/www/html/plantilla/user/classes/output/myprofile/manager.php',
    'core_user\\output\\myprofile\\node' => '/var/www/html/plantilla/user/classes/output/myprofile/node.php',
    'core_user\\output\\myprofile\\renderer' => '/var/www/html/plantilla/user/classes/output/myprofile/renderer.php',
    'core_user\\output\\myprofile\\tree' => '/var/www/html/plantilla/user/classes/output/myprofile/tree.php',
    'core_user\\output\\participants_filter' => '/var/www/html/plantilla/user/classes/output/participants_filter.php',
    'core_user\\output\\status_field' => '/var/www/html/plantilla/user/classes/output/status_field.php',
    'core_user\\output\\user_roles_editable' => '/var/www/html/plantilla/user/classes/output/user_roles_editable.php',
    'core_user\\privacy\\provider' => '/var/www/html/plantilla/user/classes/privacy/provider.php',
    'core_user\\reportbuilder\\datasource\\users' => '/var/www/html/plantilla/user/classes/reportbuilder/datasource/users.php',
    'core_user\\route\\api\\preferences' => '/var/www/html/plantilla/user/classes/route/api/preferences.php',
    'core_user\\route\\responses\\user_preferences_response' => '/var/www/html/plantilla/user/classes/route/responses/user_preferences_response.php',
    'core_user\\search\\course_teacher' => '/var/www/html/plantilla/user/classes/search/course_teacher.php',
    'core_user\\search\\user' => '/var/www/html/plantilla/user/classes/search/user.php',
    'core_user\\table\\participants' => '/var/www/html/plantilla/user/classes/table/participants.php',
    'core_user\\table\\participants_filterset' => '/var/www/html/plantilla/user/classes/table/participants_filterset.php',
    'core_user\\table\\participants_search' => '/var/www/html/plantilla/user/classes/table/participants_search.php',
    'core_user_devicekey' => '/var/www/html/plantilla/user/classes/devicekey.php',
    'core_user_fields' => '/var/www/html/plantilla/user/classes/fields.php',
    'core_useragent' => '/var/www/html/plantilla/lib/classes/useragent.php',
    'core_userfeedback' => '/var/www/html/plantilla/lib/classes/userfeedback.php',
    'core_userkey\\privacy\\provider' => '/var/www/html/plantilla/lib/userkey/classes/privacy/provider.php',
    'core_uuid' => '/var/www/html/plantilla/lib/classes/uuid.php',
    'core_webservice\\privacy\\provider' => '/var/www/html/plantilla/webservice/classes/privacy/provider.php',
    'core_webservice\\reportbuilder\\local\\entities\\service' => '/var/www/html/plantilla/webservice/classes/reportbuilder/local/entities/service.php',
    'core_webservice\\reportbuilder\\local\\entities\\token' => '/var/www/html/plantilla/webservice/classes/reportbuilder/local/entities/token.php',
    'core_webservice\\reportbuilder\\local\\systemreports\\tokens' => '/var/www/html/plantilla/webservice/classes/reportbuilder/local/systemreports/tokens.php',
    'core_webservice\\token_filter' => '/var/www/html/plantilla/webservice/classes/token_filter.php',
    'core_webservice\\token_form' => '/var/www/html/plantilla/webservice/classes/token_form.php',
    'core_webservice\\token_table' => '/var/www/html/plantilla/webservice/classes/token_table.php',
    'core_webservice_token_filter' => '/var/www/html/plantilla/webservice/classes/token_filter.php',
    'core_webservice_token_form' => '/var/www/html/plantilla/webservice/classes/token_form.php',
    'core_webservice_token_table' => '/var/www/html/plantilla/webservice/classes/token_table.php',
    'core_xapi\\api' => '/var/www/html/plantilla/lib/xapi/classes/api.php',
    'core_xapi\\external\\delete_state' => '/var/www/html/plantilla/lib/xapi/classes/external/delete_state.php',
    'core_xapi\\external\\delete_states' => '/var/www/html/plantilla/lib/xapi/classes/external/delete_states.php',
    'core_xapi\\external\\get_state' => '/var/www/html/plantilla/lib/xapi/classes/external/get_state.php',
    'core_xapi\\external\\get_states' => '/var/www/html/plantilla/lib/xapi/classes/external/get_states.php',
    'core_xapi\\external\\post_state' => '/var/www/html/plantilla/lib/xapi/classes/external/post_state.php',
    'core_xapi\\external\\post_statement' => '/var/www/html/plantilla/lib/xapi/classes/external/post_statement.php',
    'core_xapi\\handler' => '/var/www/html/plantilla/lib/xapi/classes/handler.php',
    'core_xapi\\iri' => '/var/www/html/plantilla/lib/xapi/classes/iri.php',
    'core_xapi\\local\\helper\\state_trait' => '/var/www/html/plantilla/lib/xapi/classes/local/helper/state_trait.php',
    'core_xapi\\local\\state' => '/var/www/html/plantilla/lib/xapi/classes/local/state.php',
    'core_xapi\\local\\statement' => '/var/www/html/plantilla/lib/xapi/classes/local/statement.php',
    'core_xapi\\local\\statement\\item' => '/var/www/html/plantilla/lib/xapi/classes/local/statement/item.php',
    'core_xapi\\local\\statement\\item_activity' => '/var/www/html/plantilla/lib/xapi/classes/local/statement/item_activity.php',
    'core_xapi\\local\\statement\\item_actor' => '/var/www/html/plantilla/lib/xapi/classes/local/statement/item_actor.php',
    'core_xapi\\local\\statement\\item_agent' => '/var/www/html/plantilla/lib/xapi/classes/local/statement/item_agent.php',
    'core_xapi\\local\\statement\\item_attachment' => '/var/www/html/plantilla/lib/xapi/classes/local/statement/item_attachment.php',
    'core_xapi\\local\\statement\\item_context' => '/var/www/html/plantilla/lib/xapi/classes/local/statement/item_context.php',
    'core_xapi\\local\\statement\\item_definition' => '/var/www/html/plantilla/lib/xapi/classes/local/statement/item_definition.php',
    'core_xapi\\local\\statement\\item_group' => '/var/www/html/plantilla/lib/xapi/classes/local/statement/item_group.php',
    'core_xapi\\local\\statement\\item_object' => '/var/www/html/plantilla/lib/xapi/classes/local/statement/item_object.php',
    'core_xapi\\local\\statement\\item_result' => '/var/www/html/plantilla/lib/xapi/classes/local/statement/item_result.php',
    'core_xapi\\local\\statement\\item_score' => '/var/www/html/plantilla/lib/xapi/classes/local/statement/item_score.php',
    'core_xapi\\local\\statement\\item_verb' => '/var/www/html/plantilla/lib/xapi/classes/local/statement/item_verb.php',
    'core_xapi\\privacy\\provider' => '/var/www/html/plantilla/lib/xapi/classes/privacy/provider.php',
    'core_xapi\\state_store' => '/var/www/html/plantilla/lib/xapi/classes/state_store.php',
    'core_xapi\\task\\state_cleanup_task' => '/var/www/html/plantilla/lib/xapi/classes/task/state_cleanup_task.php',
    'core_xapi\\xapi_exception' => '/var/www/html/plantilla/lib/xapi/classes/xapi_exception.php',
    'core_xapi_api' => '/var/www/html/plantilla/lib/xapi/classes/api.php',
    'core_xapi_handler' => '/var/www/html/plantilla/lib/xapi/classes/handler.php',
    'core_xapi_iri' => '/var/www/html/plantilla/lib/xapi/classes/iri.php',
    'core_xapi_state_store' => '/var/www/html/plantilla/lib/xapi/classes/state_store.php',
    'core_xapi_xapi_exception' => '/var/www/html/plantilla/lib/xapi/classes/xapi_exception.php',
    'custom_menu' => '/var/www/html/plantilla/lib/classes/output/custom_menu.php',
    'custom_menu_item' => '/var/www/html/plantilla/lib/classes/output/custom_menu_item.php',
    'customfield_checkbox\\data_controller' => '/var/www/html/plantilla/customfield/field/checkbox/classes/data_controller.php',
    'customfield_checkbox\\field_controller' => '/var/www/html/plantilla/customfield/field/checkbox/classes/field_controller.php',
    'customfield_checkbox\\privacy\\provider' => '/var/www/html/plantilla/customfield/field/checkbox/classes/privacy/provider.php',
    'customfield_checkbox_data_controller' => '/var/www/html/plantilla/customfield/field/checkbox/classes/data_controller.php',
    'customfield_checkbox_field_controller' => '/var/www/html/plantilla/customfield/field/checkbox/classes/field_controller.php',
    'customfield_date\\data_controller' => '/var/www/html/plantilla/customfield/field/date/classes/data_controller.php',
    'customfield_date\\field_controller' => '/var/www/html/plantilla/customfield/field/date/classes/field_controller.php',
    'customfield_date\\privacy\\provider' => '/var/www/html/plantilla/customfield/field/date/classes/privacy/provider.php',
    'customfield_date_data_controller' => '/var/www/html/plantilla/customfield/field/date/classes/data_controller.php',
    'customfield_date_field_controller' => '/var/www/html/plantilla/customfield/field/date/classes/field_controller.php',
    'customfield_number\\data_controller' => '/var/www/html/plantilla/customfield/field/number/classes/data_controller.php',
    'customfield_number\\external\\recalculate' => '/var/www/html/plantilla/customfield/field/number/classes/external/recalculate.php',
    'customfield_number\\field_controller' => '/var/www/html/plantilla/customfield/field/number/classes/field_controller.php',
    'customfield_number\\hook\\add_custom_providers' => '/var/www/html/plantilla/customfield/field/number/classes/hook/add_custom_providers.php',
    'customfield_number\\local\\numberproviders\\nofactivities' => '/var/www/html/plantilla/customfield/field/number/classes/local/numberproviders/nofactivities.php',
    'customfield_number\\missing_provider' => '/var/www/html/plantilla/customfield/field/number/classes/missing_provider.php',
    'customfield_number\\observer' => '/var/www/html/plantilla/customfield/field/number/classes/observer.php',
    'customfield_number\\privacy\\provider' => '/var/www/html/plantilla/customfield/field/number/classes/privacy/provider.php',
    'customfield_number\\provider_base' => '/var/www/html/plantilla/customfield/field/number/classes/provider_base.php',
    'customfield_number\\task\\cron' => '/var/www/html/plantilla/customfield/field/number/classes/task/cron.php',
    'customfield_number\\task\\recalculate' => '/var/www/html/plantilla/customfield/field/number/classes/task/recalculate.php',
    'customfield_number_data_controller' => '/var/www/html/plantilla/customfield/field/number/classes/data_controller.php',
    'customfield_number_field_controller' => '/var/www/html/plantilla/customfield/field/number/classes/field_controller.php',
    'customfield_number_missing_provider' => '/var/www/html/plantilla/customfield/field/number/classes/missing_provider.php',
    'customfield_number_observer' => '/var/www/html/plantilla/customfield/field/number/classes/observer.php',
    'customfield_number_provider_base' => '/var/www/html/plantilla/customfield/field/number/classes/provider_base.php',
    'customfield_select\\data_controller' => '/var/www/html/plantilla/customfield/field/select/classes/data_controller.php',
    'customfield_select\\field_controller' => '/var/www/html/plantilla/customfield/field/select/classes/field_controller.php',
    'customfield_select\\privacy\\provider' => '/var/www/html/plantilla/customfield/field/select/classes/privacy/provider.php',
    'customfield_select_data_controller' => '/var/www/html/plantilla/customfield/field/select/classes/data_controller.php',
    'customfield_select_field_controller' => '/var/www/html/plantilla/customfield/field/select/classes/field_controller.php',
    'customfield_text\\data_controller' => '/var/www/html/plantilla/customfield/field/text/classes/data_controller.php',
    'customfield_text\\field_controller' => '/var/www/html/plantilla/customfield/field/text/classes/field_controller.php',
    'customfield_text\\privacy\\provider' => '/var/www/html/plantilla/customfield/field/text/classes/privacy/provider.php',
    'customfield_text_data_controller' => '/var/www/html/plantilla/customfield/field/text/classes/data_controller.php',
    'customfield_text_field_controller' => '/var/www/html/plantilla/customfield/field/text/classes/field_controller.php',
    'customfield_textarea\\data_controller' => '/var/www/html/plantilla/customfield/field/textarea/classes/data_controller.php',
    'customfield_textarea\\field_controller' => '/var/www/html/plantilla/customfield/field/textarea/classes/field_controller.php',
    'customfield_textarea\\privacy\\provider' => '/var/www/html/plantilla/customfield/field/textarea/classes/privacy/provider.php',
    'customfield_textarea_data_controller' => '/var/www/html/plantilla/customfield/field/textarea/classes/data_controller.php',
    'customfield_textarea_field_controller' => '/var/www/html/plantilla/customfield/field/textarea/classes/field_controller.php',
    'datafield_checkbox\\privacy\\provider' => '/var/www/html/plantilla/mod/data/field/checkbox/classes/privacy/provider.php',
    'datafield_date\\privacy\\provider' => '/var/www/html/plantilla/mod/data/field/date/classes/privacy/provider.php',
    'datafield_file\\privacy\\provider' => '/var/www/html/plantilla/mod/data/field/file/classes/privacy/provider.php',
    'datafield_latlong\\privacy\\provider' => '/var/www/html/plantilla/mod/data/field/latlong/classes/privacy/provider.php',
    'datafield_menu\\privacy\\provider' => '/var/www/html/plantilla/mod/data/field/menu/classes/privacy/provider.php',
    'datafield_multimenu\\privacy\\provider' => '/var/www/html/plantilla/mod/data/field/multimenu/classes/privacy/provider.php',
    'datafield_number\\privacy\\provider' => '/var/www/html/plantilla/mod/data/field/number/classes/privacy/provider.php',
    'datafield_picture\\privacy\\provider' => '/var/www/html/plantilla/mod/data/field/picture/classes/privacy/provider.php',
    'datafield_radiobutton\\privacy\\provider' => '/var/www/html/plantilla/mod/data/field/radiobutton/classes/privacy/provider.php',
    'datafield_text\\privacy\\provider' => '/var/www/html/plantilla/mod/data/field/text/classes/privacy/provider.php',
    'datafield_textarea\\privacy\\provider' => '/var/www/html/plantilla/mod/data/field/textarea/classes/privacy/provider.php',
    'datafield_url\\privacy\\provider' => '/var/www/html/plantilla/mod/data/field/url/classes/privacy/provider.php',
    'dataformat_csv\\privacy\\provider' => '/var/www/html/plantilla/dataformat/csv/classes/privacy/provider.php',
    'dataformat_csv\\writer' => '/var/www/html/plantilla/dataformat/csv/classes/writer.php',
    'dataformat_csv_writer' => '/var/www/html/plantilla/dataformat/csv/classes/writer.php',
    'dataformat_excel\\privacy\\provider' => '/var/www/html/plantilla/dataformat/excel/classes/privacy/provider.php',
    'dataformat_excel\\writer' => '/var/www/html/plantilla/dataformat/excel/classes/writer.php',
    'dataformat_excel_writer' => '/var/www/html/plantilla/dataformat/excel/classes/writer.php',
    'dataformat_html\\privacy\\provider' => '/var/www/html/plantilla/dataformat/html/classes/privacy/provider.php',
    'dataformat_html\\writer' => '/var/www/html/plantilla/dataformat/html/classes/writer.php',
    'dataformat_html_writer' => '/var/www/html/plantilla/dataformat/html/classes/writer.php',
    'dataformat_json\\privacy\\provider' => '/var/www/html/plantilla/dataformat/json/classes/privacy/provider.php',
    'dataformat_json\\writer' => '/var/www/html/plantilla/dataformat/json/classes/writer.php',
    'dataformat_json_writer' => '/var/www/html/plantilla/dataformat/json/classes/writer.php',
    'dataformat_ods\\privacy\\provider' => '/var/www/html/plantilla/dataformat/ods/classes/privacy/provider.php',
    'dataformat_ods\\writer' => '/var/www/html/plantilla/dataformat/ods/classes/writer.php',
    'dataformat_ods_writer' => '/var/www/html/plantilla/dataformat/ods/classes/writer.php',
    'dataformat_pdf\\privacy\\provider' => '/var/www/html/plantilla/dataformat/pdf/classes/privacy/provider.php',
    'dataformat_pdf\\writer' => '/var/www/html/plantilla/dataformat/pdf/classes/writer.php',
    'dataformat_pdf_writer' => '/var/www/html/plantilla/dataformat/pdf/classes/writer.php',
    'datapreset_imagegallery\\privacy\\provider' => '/var/www/html/plantilla/mod/data/preset/imagegallery/classes/privacy/provider.php',
    'datapreset_journal\\privacy\\provider' => '/var/www/html/plantilla/mod/data/preset/journal/classes/privacy/provider.php',
    'datapreset_proposals\\privacy\\provider' => '/var/www/html/plantilla/mod/data/preset/proposals/classes/privacy/provider.php',
    'datapreset_resources\\privacy\\provider' => '/var/www/html/plantilla/mod/data/preset/resources/classes/privacy/provider.php',
    'editor_textarea\\privacy\\provider' => '/var/www/html/plantilla/lib/editor/textarea/classes/privacy/provider.php',
    'editor_tiny\\editor' => '/var/www/html/plantilla/lib/editor/tiny/classes/editor.php',
    'editor_tiny\\external\\get_configuration' => '/var/www/html/plantilla/lib/editor/tiny/classes/external/get_configuration.php',
    'editor_tiny\\manager' => '/var/www/html/plantilla/lib/editor/tiny/classes/manager.php',
    'editor_tiny\\plugin' => '/var/www/html/plantilla/lib/editor/tiny/classes/plugin.php',
    'editor_tiny\\plugin_with_buttons' => '/var/www/html/plantilla/lib/editor/tiny/classes/plugin_with_buttons.php',
    'editor_tiny\\plugin_with_configuration' => '/var/www/html/plantilla/lib/editor/tiny/classes/plugin_with_configuration.php',
    'editor_tiny\\plugin_with_configuration_for_external' => '/var/www/html/plantilla/lib/editor/tiny/classes/plugin_with_configuration_for_external.php',
    'editor_tiny\\plugin_with_menuitems' => '/var/www/html/plantilla/lib/editor/tiny/classes/plugin_with_menuitems.php',
    'editor_tiny\\plugininfo\\tiny' => '/var/www/html/plantilla/lib/editor/tiny/classes/plugininfo/tiny.php',
    'editor_tiny\\privacy\\provider' => '/var/www/html/plantilla/lib/editor/tiny/classes/privacy/provider.php',
    'editor_tiny\\table\\plugin_management_table' => '/var/www/html/plantilla/lib/editor/tiny/classes/table/plugin_management_table.php',
    'editor_tiny_editor' => '/var/www/html/plantilla/lib/editor/tiny/classes/editor.php',
    'editor_tiny_manager' => '/var/www/html/plantilla/lib/editor/tiny/classes/manager.php',
    'editor_tiny_plugin' => '/var/www/html/plantilla/lib/editor/tiny/classes/plugin.php',
    'editor_tiny_plugin_with_buttons' => '/var/www/html/plantilla/lib/editor/tiny/classes/plugin_with_buttons.php',
    'editor_tiny_plugin_with_configuration' => '/var/www/html/plantilla/lib/editor/tiny/classes/plugin_with_configuration.php',
    'editor_tiny_plugin_with_configuration_for_external' => '/var/www/html/plantilla/lib/editor/tiny/classes/plugin_with_configuration_for_external.php',
    'editor_tiny_plugin_with_menuitems' => '/var/www/html/plantilla/lib/editor/tiny/classes/plugin_with_menuitems.php',
    'emoticon_manager' => '/var/www/html/plantilla/lib/classes/emoticon_manager.php',
    'enrol_category\\observer' => '/var/www/html/plantilla/enrol/category/classes/observer.php',
    'enrol_category\\privacy\\provider' => '/var/www/html/plantilla/enrol/category/classes/privacy/provider.php',
    'enrol_category\\task\\enrol_category_sync' => '/var/www/html/plantilla/enrol/category/classes/task/enrol_category_sync.php',
    'enrol_category_observer' => '/var/www/html/plantilla/enrol/category/classes/observer.php',
    'enrol_cohort\\privacy\\provider' => '/var/www/html/plantilla/enrol/cohort/classes/privacy/provider.php',
    'enrol_cohort\\task\\enrol_cohort_sync' => '/var/www/html/plantilla/enrol/cohort/classes/task/enrol_cohort_sync.php',
    'enrol_database\\privacy\\provider' => '/var/www/html/plantilla/enrol/database/classes/privacy/provider.php',
    'enrol_database\\task\\sync_enrolments' => '/var/www/html/plantilla/enrol/database/classes/task/sync_enrolments.php',
    'enrol_fee\\payment\\service_provider' => '/var/www/html/plantilla/enrol/fee/classes/payment/service_provider.php',
    'enrol_fee\\plugin' => '/var/www/html/plantilla/enrol/fee/classes/plugin.php',
    'enrol_fee\\privacy\\provider' => '/var/www/html/plantilla/enrol/fee/classes/privacy/provider.php',
    'enrol_fee_plugin' => '/var/www/html/plantilla/enrol/fee/classes/plugin.php',
    'enrol_flatfile\\privacy\\provider' => '/var/www/html/plantilla/enrol/flatfile/classes/privacy/provider.php',
    'enrol_flatfile\\task\\flatfile_sync_task' => '/var/www/html/plantilla/enrol/flatfile/classes/task/flatfile_sync_task.php',
    'enrol_guest\\external' => '/var/www/html/plantilla/enrol/guest/classes/external.php',
    'enrol_guest\\external\\validate_password' => '/var/www/html/plantilla/enrol/guest/classes/external/validate_password.php',
    'enrol_guest\\form\\enrol_form' => '/var/www/html/plantilla/enrol/guest/classes/form/enrol_form.php',
    'enrol_guest\\privacy\\provider' => '/var/www/html/plantilla/enrol/guest/classes/privacy/provider.php',
    'enrol_guest_external' => '/var/www/html/plantilla/enrol/guest/classes/external.php',
    'enrol_imsenterprise\\privacy\\provider' => '/var/www/html/plantilla/enrol/imsenterprise/classes/privacy/provider.php',
    'enrol_imsenterprise\\task\\cron_task' => '/var/www/html/plantilla/enrol/imsenterprise/classes/task/cron_task.php',
    'enrol_ldap\\privacy\\provider' => '/var/www/html/plantilla/enrol/ldap/classes/privacy/provider.php',
    'enrol_ldap\\task\\sync_enrolments' => '/var/www/html/plantilla/enrol/ldap/classes/task/sync_enrolments.php',
    'enrol_lti\\data_connector' => '/var/www/html/plantilla/enrol/lti/classes/data_connector.php',
    'enrol_lti\\helper' => '/var/www/html/plantilla/enrol/lti/classes/helper.php',
    'enrol_lti\\local\\ltiadvantage\\admin\\admin_setting_registeredplatforms' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/admin/admin_setting_registeredplatforms.php',
    'enrol_lti\\local\\ltiadvantage\\entity\\ags_info' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/entity/ags_info.php',
    'enrol_lti\\local\\ltiadvantage\\entity\\application_registration' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/entity/application_registration.php',
    'enrol_lti\\local\\ltiadvantage\\entity\\context' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/entity/context.php',
    'enrol_lti\\local\\ltiadvantage\\entity\\deployment' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/entity/deployment.php',
    'enrol_lti\\local\\ltiadvantage\\entity\\migration_claim' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/entity/migration_claim.php',
    'enrol_lti\\local\\ltiadvantage\\entity\\nrps_info' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/entity/nrps_info.php',
    'enrol_lti\\local\\ltiadvantage\\entity\\resource_link' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/entity/resource_link.php',
    'enrol_lti\\local\\ltiadvantage\\entity\\user' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/entity/user.php',
    'enrol_lti\\local\\ltiadvantage\\form\\create_registration_form' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/form/create_registration_form.php',
    'enrol_lti\\local\\ltiadvantage\\form\\deployment_form' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/form/deployment_form.php',
    'enrol_lti\\local\\ltiadvantage\\form\\platform_registration_form' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/form/platform_registration_form.php',
    'enrol_lti\\local\\ltiadvantage\\lib\\issuer_database' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/lib/issuer_database.php',
    'enrol_lti\\local\\ltiadvantage\\lib\\launch_cache_session' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/lib/launch_cache_session.php',
    'enrol_lti\\local\\ltiadvantage\\lib\\lti_cookie' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/lib/lti_cookie.php',
    'enrol_lti\\local\\ltiadvantage\\repository\\application_registration_repository' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/repository/application_registration_repository.php',
    'enrol_lti\\local\\ltiadvantage\\repository\\context_repository' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/repository/context_repository.php',
    'enrol_lti\\local\\ltiadvantage\\repository\\deployment_repository' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/repository/deployment_repository.php',
    'enrol_lti\\local\\ltiadvantage\\repository\\legacy_consumer_repository' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/repository/legacy_consumer_repository.php',
    'enrol_lti\\local\\ltiadvantage\\repository\\published_resource_repository' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/repository/published_resource_repository.php',
    'enrol_lti\\local\\ltiadvantage\\repository\\resource_link_repository' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/repository/resource_link_repository.php',
    'enrol_lti\\local\\ltiadvantage\\repository\\user_repository' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/repository/user_repository.php',
    'enrol_lti\\local\\ltiadvantage\\service\\application_registration_service' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/service/application_registration_service.php',
    'enrol_lti\\local\\ltiadvantage\\service\\tool_deployment_service' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/service/tool_deployment_service.php',
    'enrol_lti\\local\\ltiadvantage\\service\\tool_launch_service' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/service/tool_launch_service.php',
    'enrol_lti\\local\\ltiadvantage\\table\\published_resources_table' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/table/published_resources_table.php',
    'enrol_lti\\local\\ltiadvantage\\task\\sync_grades' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/task/sync_grades.php',
    'enrol_lti\\local\\ltiadvantage\\task\\sync_members' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/task/sync_members.php',
    'enrol_lti\\local\\ltiadvantage\\task\\sync_tool_grades' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/task/sync_tool_grades.php',
    'enrol_lti\\local\\ltiadvantage\\utility\\message_helper' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/utility/message_helper.php',
    'enrol_lti\\local\\ltiadvantage\\viewobject\\published_resource' => '/var/www/html/plantilla/enrol/lti/classes/local/ltiadvantage/viewobject/published_resource.php',
    'enrol_lti\\manage_table' => '/var/www/html/plantilla/enrol/lti/classes/manage_table.php',
    'enrol_lti\\output\\registration' => '/var/www/html/plantilla/enrol/lti/classes/output/registration.php',
    'enrol_lti\\output\\renderer' => '/var/www/html/plantilla/enrol/lti/classes/output/renderer.php',
    'enrol_lti\\privacy\\provider' => '/var/www/html/plantilla/enrol/lti/classes/privacy/provider.php',
    'enrol_lti\\task\\sync_grades' => '/var/www/html/plantilla/enrol/lti/classes/task/sync_grades.php',
    'enrol_lti\\task\\sync_members' => '/var/www/html/plantilla/enrol/lti/classes/task/sync_members.php',
    'enrol_lti\\tool_provider' => '/var/www/html/plantilla/enrol/lti/classes/tool_provider.php',
    'enrol_lti_data_connector' => '/var/www/html/plantilla/enrol/lti/classes/data_connector.php',
    'enrol_lti_helper' => '/var/www/html/plantilla/enrol/lti/classes/helper.php',
    'enrol_lti_manage_table' => '/var/www/html/plantilla/enrol/lti/classes/manage_table.php',
    'enrol_lti_tool_provider' => '/var/www/html/plantilla/enrol/lti/classes/tool_provider.php',
    'enrol_manual\\enrol_users_form' => '/var/www/html/plantilla/enrol/manual/classes/enrol_users_form.php',
    'enrol_manual\\privacy\\provider' => '/var/www/html/plantilla/enrol/manual/classes/privacy/provider.php',
    'enrol_manual\\task\\send_expiry_notifications' => '/var/www/html/plantilla/enrol/manual/classes/task/send_expiry_notifications.php',
    'enrol_manual\\task\\sync_enrolments' => '/var/www/html/plantilla/enrol/manual/classes/task/sync_enrolments.php',
    'enrol_manual\\user_enrolment_callbacks' => '/var/www/html/plantilla/enrol/manual/classes/user_enrolment_callbacks.php',
    'enrol_manual_enrol_users_form' => '/var/www/html/plantilla/enrol/manual/classes/enrol_users_form.php',
    'enrol_manual_user_enrolment_callbacks' => '/var/www/html/plantilla/enrol/manual/classes/user_enrolment_callbacks.php',
    'enrol_meta\\external\\add_instances' => '/var/www/html/plantilla/enrol/meta/classes/external/add_instances.php',
    'enrol_meta\\external\\delete_instances' => '/var/www/html/plantilla/enrol/meta/classes/external/delete_instances.php',
    'enrol_meta\\observer' => '/var/www/html/plantilla/enrol/meta/classes/observer.php',
    'enrol_meta\\privacy\\provider' => '/var/www/html/plantilla/enrol/meta/classes/privacy/provider.php',
    'enrol_meta\\task\\enrol_meta_sync' => '/var/www/html/plantilla/enrol/meta/classes/task/enrol_meta_sync.php',
    'enrol_meta_observer' => '/var/www/html/plantilla/enrol/meta/classes/observer.php',
    'enrol_paypal\\privacy\\provider' => '/var/www/html/plantilla/enrol/paypal/classes/privacy/provider.php',
    'enrol_paypal\\task\\process_expirations' => '/var/www/html/plantilla/enrol/paypal/classes/task/process_expirations.php',
    'enrol_paypal\\util' => '/var/www/html/plantilla/enrol/paypal/classes/util.php',
    'enrol_paypal_util' => '/var/www/html/plantilla/enrol/paypal/classes/util.php',
    'enrol_self\\deleteselectedusers_form' => '/var/www/html/plantilla/enrol/self/classes/deleteselectedusers_form.php',
    'enrol_self\\deleteselectedusers_operation' => '/var/www/html/plantilla/enrol/self/classes/deleteselectedusers_operation.php',
    'enrol_self\\editselectedusers_form' => '/var/www/html/plantilla/enrol/self/classes/editselectedusers_form.php',
    'enrol_self\\editselectedusers_operation' => '/var/www/html/plantilla/enrol/self/classes/editselectedusers_operation.php',
    'enrol_self\\empty_form' => '/var/www/html/plantilla/enrol/self/classes/empty_form.php',
    'enrol_self\\form\\enrol_form' => '/var/www/html/plantilla/enrol/self/classes/form/enrol_form.php',
    'enrol_self\\privacy\\provider' => '/var/www/html/plantilla/enrol/self/classes/privacy/provider.php',
    'enrol_self\\task\\send_expiry_notifications' => '/var/www/html/plantilla/enrol/self/classes/task/send_expiry_notifications.php',
    'enrol_self\\task\\sync_enrolments' => '/var/www/html/plantilla/enrol/self/classes/task/sync_enrolments.php',
    'enrol_self\\user_enrolment_callbacks' => '/var/www/html/plantilla/enrol/self/classes/user_enrolment_callbacks.php',
    'enrol_self_deleteselectedusers_form' => '/var/www/html/plantilla/enrol/self/classes/deleteselectedusers_form.php',
    'enrol_self_deleteselectedusers_operation' => '/var/www/html/plantilla/enrol/self/classes/deleteselectedusers_operation.php',
    'enrol_self_editselectedusers_form' => '/var/www/html/plantilla/enrol/self/classes/editselectedusers_form.php',
    'enrol_self_editselectedusers_operation' => '/var/www/html/plantilla/enrol/self/classes/editselectedusers_operation.php',
    'enrol_self_empty_form' => '/var/www/html/plantilla/enrol/self/classes/empty_form.php',
    'enrol_self_user_enrolment_callbacks' => '/var/www/html/plantilla/enrol/self/classes/user_enrolment_callbacks.php',
    'error_log_progress_trace' => '/var/www/html/plantilla/lib/classes/output/progress_trace/error_log_progress_trace.php',
    'factor_admin\\factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/admin/classes/factor.php',
    'factor_admin\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/mfa/factor/admin/classes/privacy/provider.php',
    'factor_admin_factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/admin/classes/factor.php',
    'factor_auth\\factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/auth/classes/factor.php',
    'factor_auth\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/mfa/factor/auth/classes/privacy/provider.php',
    'factor_auth_factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/auth/classes/factor.php',
    'factor_capability\\factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/capability/classes/factor.php',
    'factor_capability\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/mfa/factor/capability/classes/privacy/provider.php',
    'factor_capability_factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/capability/classes/factor.php',
    'factor_cohort\\factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/cohort/classes/factor.php',
    'factor_cohort\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/mfa/factor/cohort/classes/privacy/provider.php',
    'factor_cohort_factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/cohort/classes/factor.php',
    'factor_email\\event\\unauth_email' => '/var/www/html/plantilla/admin/tool/mfa/factor/email/classes/event/unauth_email.php',
    'factor_email\\factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/email/classes/factor.php',
    'factor_email\\form\\email' => '/var/www/html/plantilla/admin/tool/mfa/factor/email/classes/form/email.php',
    'factor_email\\output\\renderer' => '/var/www/html/plantilla/admin/tool/mfa/factor/email/classes/output/renderer.php',
    'factor_email\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/mfa/factor/email/classes/privacy/provider.php',
    'factor_email_factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/email/classes/factor.php',
    'factor_grace\\factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/grace/classes/factor.php',
    'factor_grace\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/mfa/factor/grace/classes/privacy/provider.php',
    'factor_grace\\task\\revoke_expired_factors' => '/var/www/html/plantilla/admin/tool/mfa/factor/grace/classes/task/revoke_expired_factors.php',
    'factor_grace_factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/grace/classes/factor.php',
    'factor_iprange\\factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/iprange/classes/factor.php',
    'factor_iprange\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/mfa/factor/iprange/classes/privacy/provider.php',
    'factor_iprange_factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/iprange/classes/factor.php',
    'factor_nosetup\\factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/nosetup/classes/factor.php',
    'factor_nosetup\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/mfa/factor/nosetup/classes/privacy/provider.php',
    'factor_nosetup\\task\\delete_unusable_factors' => '/var/www/html/plantilla/admin/tool/mfa/factor/nosetup/classes/task/delete_unusable_factors.php',
    'factor_nosetup_factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/nosetup/classes/factor.php',
    'factor_role\\factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/role/classes/factor.php',
    'factor_role\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/mfa/factor/role/classes/privacy/provider.php',
    'factor_role_factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/role/classes/factor.php',
    'factor_sms\\factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/sms/classes/factor.php',
    'factor_sms\\helper' => '/var/www/html/plantilla/admin/tool/mfa/factor/sms/classes/helper.php',
    'factor_sms\\hook_listener' => '/var/www/html/plantilla/admin/tool/mfa/factor/sms/classes/hook_listener.php',
    'factor_sms\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/mfa/factor/sms/classes/privacy/provider.php',
    'factor_sms\\task\\sms_gateway_migration_notification' => '/var/www/html/plantilla/admin/tool/mfa/factor/sms/classes/task/sms_gateway_migration_notification.php',
    'factor_sms_factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/sms/classes/factor.php',
    'factor_sms_helper' => '/var/www/html/plantilla/admin/tool/mfa/factor/sms/classes/helper.php',
    'factor_sms_hook_listener' => '/var/www/html/plantilla/admin/tool/mfa/factor/sms/classes/hook_listener.php',
    'factor_token\\event\\token_created' => '/var/www/html/plantilla/admin/tool/mfa/factor/token/classes/event/token_created.php',
    'factor_token\\factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/token/classes/factor.php',
    'factor_token\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/mfa/factor/token/classes/privacy/provider.php',
    'factor_token_factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/token/classes/factor.php',
    'factor_totp\\factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/totp/classes/factor.php',
    'factor_totp\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/mfa/factor/totp/classes/privacy/provider.php',
    'factor_totp_factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/totp/classes/factor.php',
    'factor_webauthn\\factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/webauthn/classes/factor.php',
    'factor_webauthn\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/mfa/factor/webauthn/classes/privacy/provider.php',
    'factor_webauthn_factor' => '/var/www/html/plantilla/admin/tool/mfa/factor/webauthn/classes/factor.php',
    'file_picker' => '/var/www/html/plantilla/lib/classes/output/file_picker.php',
    'file_serving_exception' => '/var/www/html/plantilla/lib/classes/exception/file_serving_exception.php',
    'fileconverter_googledrive\\converter' => '/var/www/html/plantilla/files/converter/googledrive/classes/converter.php',
    'fileconverter_googledrive\\privacy\\provider' => '/var/www/html/plantilla/files/converter/googledrive/classes/privacy/provider.php',
    'fileconverter_googledrive\\rest' => '/var/www/html/plantilla/files/converter/googledrive/classes/rest.php',
    'fileconverter_googledrive_converter' => '/var/www/html/plantilla/files/converter/googledrive/classes/converter.php',
    'fileconverter_googledrive_rest' => '/var/www/html/plantilla/files/converter/googledrive/classes/rest.php',
    'fileconverter_unoconv\\converter' => '/var/www/html/plantilla/files/converter/unoconv/classes/converter.php',
    'fileconverter_unoconv\\privacy\\provider' => '/var/www/html/plantilla/files/converter/unoconv/classes/privacy/provider.php',
    'fileconverter_unoconv_converter' => '/var/www/html/plantilla/files/converter/unoconv/classes/converter.php',
    'filter_activitynames\\privacy\\provider' => '/var/www/html/plantilla/filter/activitynames/classes/privacy/provider.php',
    'filter_activitynames\\text_filter' => '/var/www/html/plantilla/filter/activitynames/classes/text_filter.php',
    'filter_activitynames_text_filter' => '/var/www/html/plantilla/filter/activitynames/classes/text_filter.php',
    'filter_algebra\\privacy\\provider' => '/var/www/html/plantilla/filter/algebra/classes/privacy/provider.php',
    'filter_algebra\\text_filter' => '/var/www/html/plantilla/filter/algebra/classes/text_filter.php',
    'filter_algebra_text_filter' => '/var/www/html/plantilla/filter/algebra/classes/text_filter.php',
    'filter_codehighlighter\\privacy\\provider' => '/var/www/html/plantilla/filter/codehighlighter/classes/privacy/provider.php',
    'filter_codehighlighter\\text_filter' => '/var/www/html/plantilla/filter/codehighlighter/classes/text_filter.php',
    'filter_codehighlighter_text_filter' => '/var/www/html/plantilla/filter/codehighlighter/classes/text_filter.php',
    'filter_data\\privacy\\provider' => '/var/www/html/plantilla/filter/data/classes/privacy/provider.php',
    'filter_data\\text_filter' => '/var/www/html/plantilla/filter/data/classes/text_filter.php',
    'filter_data_text_filter' => '/var/www/html/plantilla/filter/data/classes/text_filter.php',
    'filter_displayh5p\\privacy\\provider' => '/var/www/html/plantilla/filter/displayh5p/classes/privacy/provider.php',
    'filter_displayh5p\\text_filter' => '/var/www/html/plantilla/filter/displayh5p/classes/text_filter.php',
    'filter_displayh5p_text_filter' => '/var/www/html/plantilla/filter/displayh5p/classes/text_filter.php',
    'filter_emailprotect\\privacy\\provider' => '/var/www/html/plantilla/filter/emailprotect/classes/privacy/provider.php',
    'filter_emailprotect\\text_filter' => '/var/www/html/plantilla/filter/emailprotect/classes/text_filter.php',
    'filter_emailprotect_text_filter' => '/var/www/html/plantilla/filter/emailprotect/classes/text_filter.php',
    'filter_emoticon\\privacy\\provider' => '/var/www/html/plantilla/filter/emoticon/classes/privacy/provider.php',
    'filter_emoticon\\text_filter' => '/var/www/html/plantilla/filter/emoticon/classes/text_filter.php',
    'filter_emoticon_text_filter' => '/var/www/html/plantilla/filter/emoticon/classes/text_filter.php',
    'filter_glossary\\privacy\\provider' => '/var/www/html/plantilla/filter/glossary/classes/privacy/provider.php',
    'filter_glossary\\text_filter' => '/var/www/html/plantilla/filter/glossary/classes/text_filter.php',
    'filter_glossary_text_filter' => '/var/www/html/plantilla/filter/glossary/classes/text_filter.php',
    'filter_local_settings_form' => '/var/www/html/plantilla/filter/classes/form/local_settings_form.php',
    'filter_manager' => '/var/www/html/plantilla/filter/classes/filter_manager.php',
    'filter_mathjaxloader\\privacy\\provider' => '/var/www/html/plantilla/filter/mathjaxloader/classes/privacy/provider.php',
    'filter_mathjaxloader\\text_filter' => '/var/www/html/plantilla/filter/mathjaxloader/classes/text_filter.php',
    'filter_mathjaxloader_text_filter' => '/var/www/html/plantilla/filter/mathjaxloader/classes/text_filter.php',
    'filter_mediaplugin\\privacy\\provider' => '/var/www/html/plantilla/filter/mediaplugin/classes/privacy/provider.php',
    'filter_mediaplugin\\text_filter' => '/var/www/html/plantilla/filter/mediaplugin/classes/text_filter.php',
    'filter_mediaplugin_text_filter' => '/var/www/html/plantilla/filter/mediaplugin/classes/text_filter.php',
    'filter_multilang\\privacy\\provider' => '/var/www/html/plantilla/filter/multilang/classes/privacy/provider.php',
    'filter_multilang\\text_filter' => '/var/www/html/plantilla/filter/multilang/classes/text_filter.php',
    'filter_multilang_text_filter' => '/var/www/html/plantilla/filter/multilang/classes/text_filter.php',
    'filter_tex\\privacy\\provider' => '/var/www/html/plantilla/filter/tex/classes/privacy/provider.php',
    'filter_tex\\text_filter' => '/var/www/html/plantilla/filter/tex/classes/text_filter.php',
    'filter_tex_text_filter' => '/var/www/html/plantilla/filter/tex/classes/text_filter.php',
    'filter_urltolink\\privacy\\provider' => '/var/www/html/plantilla/filter/urltolink/classes/privacy/provider.php',
    'filter_urltolink\\text_filter' => '/var/www/html/plantilla/filter/urltolink/classes/text_filter.php',
    'filter_urltolink_text_filter' => '/var/www/html/plantilla/filter/urltolink/classes/text_filter.php',
    'filterobject' => '/var/www/html/plantilla/filter/classes/filter_object.php',
    'flexible_table' => '/var/www/html/plantilla/lib/table/classes/flexible_table.php',
    'format_singleactivity\\output\\renderer' => '/var/www/html/plantilla/course/format/singleactivity/classes/output/renderer.php',
    'format_singleactivity\\privacy\\provider' => '/var/www/html/plantilla/course/format/singleactivity/classes/privacy/provider.php',
    'format_social\\output\\renderer' => '/var/www/html/plantilla/course/format/social/classes/output/renderer.php',
    'format_social\\privacy\\provider' => '/var/www/html/plantilla/course/format/social/classes/privacy/provider.php',
    'format_tiles\\courseformat\\stateactions' => '/var/www/html/plantilla/course/format/tiles/classes/courseformat/stateactions.php',
    'format_tiles\\external\\external' => '/var/www/html/plantilla/course/format/tiles/classes/external/external.php',
    'format_tiles\\form\\upload_image_form' => '/var/www/html/plantilla/course/format/tiles/classes/form/upload_image_form.php',
    'format_tiles\\hooks\\output\\before_footer_html_generation' => '/var/www/html/plantilla/course/format/tiles/classes/hooks/output/before_footer_html_generation.php',
    'format_tiles\\hooks\\output\\standard_head_html_prepend' => '/var/www/html/plantilla/course/format/tiles/classes/hooks/output/standard_head_html_prepend.php',
    'format_tiles\\local\\admin_settingspage_tabs' => '/var/www/html/plantilla/course/format/tiles/classes/local/admin_settingspage_tabs.php',
    'format_tiles\\local\\course_section_manager' => '/var/www/html/plantilla/course/format/tiles/classes/local/course_section_manager.php',
    'format_tiles\\local\\dynamic_styles' => '/var/www/html/plantilla/course/format/tiles/classes/local/dynamic_styles.php',
    'format_tiles\\local\\filters' => '/var/www/html/plantilla/course/format/tiles/classes/local/filters.php',
    'format_tiles\\local\\format_option' => '/var/www/html/plantilla/course/format/tiles/classes/local/format_option.php',
    'format_tiles\\local\\icon_set' => '/var/www/html/plantilla/course/format/tiles/classes/local/icon_set.php',
    'format_tiles\\local\\image_processor' => '/var/www/html/plantilla/course/format/tiles/classes/local/image_processor.php',
    'format_tiles\\local\\modal_helper' => '/var/www/html/plantilla/course/format/tiles/classes/local/modal_helper.php',
    'format_tiles\\local\\tile_photo' => '/var/www/html/plantilla/course/format/tiles/classes/local/tile_photo.php',
    'format_tiles\\local\\util' => '/var/www/html/plantilla/course/format/tiles/classes/local/util.php',
    'format_tiles\\local\\video_cm' => '/var/www/html/plantilla/course/format/tiles/classes/local/video_cm.php',
    'format_tiles\\observer' => '/var/www/html/plantilla/course/format/tiles/classes/observer.php',
    'format_tiles\\output\\course_header_content' => '/var/www/html/plantilla/course/format/tiles/classes/output/course_header_content.php',
    'format_tiles\\output\\course_output' => '/var/www/html/plantilla/course/format/tiles/classes/output/course_output.php',
    'format_tiles\\output\\courseformat\\content' => '/var/www/html/plantilla/course/format/tiles/classes/output/courseformat/content.php',
    'format_tiles\\output\\courseformat\\content\\cm' => '/var/www/html/plantilla/course/format/tiles/classes/output/courseformat/content/cm.php',
    'format_tiles\\output\\courseformat\\content\\cm\\cmicon' => '/var/www/html/plantilla/course/format/tiles/classes/output/courseformat/content/cm/cmicon.php',
    'format_tiles\\output\\courseformat\\content\\cm\\controlmenu' => '/var/www/html/plantilla/course/format/tiles/classes/output/courseformat/content/cm/controlmenu.php',
    'format_tiles\\output\\courseformat\\content\\section' => '/var/www/html/plantilla/course/format/tiles/classes/output/courseformat/content/section.php',
    'format_tiles\\output\\courseformat\\content\\section\\cmitem' => '/var/www/html/plantilla/course/format/tiles/classes/output/courseformat/content/section/cmitem.php',
    'format_tiles\\output\\courseformat\\content\\section\\controlmenu' => '/var/www/html/plantilla/course/format/tiles/classes/output/courseformat/content/section/controlmenu.php',
    'format_tiles\\output\\courseformat\\content\\section\\header' => '/var/www/html/plantilla/course/format/tiles/classes/output/courseformat/content/section/header.php',
    'format_tiles\\output\\renderer' => '/var/www/html/plantilla/course/format/tiles/classes/output/renderer.php',
    'format_tiles\\output\\section_renderer' => '/var/www/html/plantilla/course/format/tiles/classes/output/section_renderer.php',
    'format_tiles\\privacy\\provider' => '/var/www/html/plantilla/course/format/tiles/classes/privacy/provider.php',
    'format_tiles\\task\\migrate_legacy_data' => '/var/www/html/plantilla/course/format/tiles/classes/task/migrate_legacy_data.php',
    'format_tiles_observer' => '/var/www/html/plantilla/course/format/tiles/classes/observer.php',
    'format_topics\\courseformat\\stateactions' => '/var/www/html/plantilla/course/format/topics/classes/courseformat/stateactions.php',
    'format_topics\\output\\courseformat\\content' => '/var/www/html/plantilla/course/format/topics/classes/output/courseformat/content.php',
    'format_topics\\output\\courseformat\\content\\section' => '/var/www/html/plantilla/course/format/topics/classes/output/courseformat/content/section.php',
    'format_topics\\output\\courseformat\\content\\section\\controlmenu' => '/var/www/html/plantilla/course/format/topics/classes/output/courseformat/content/section/controlmenu.php',
    'format_topics\\output\\renderer' => '/var/www/html/plantilla/course/format/topics/classes/output/renderer.php',
    'format_topics\\privacy\\provider' => '/var/www/html/plantilla/course/format/topics/classes/privacy/provider.php',
    'format_weeks\\observer' => '/var/www/html/plantilla/course/format/weeks/classes/observer.php',
    'format_weeks\\output\\renderer' => '/var/www/html/plantilla/course/format/weeks/classes/output/renderer.php',
    'format_weeks\\privacy\\provider' => '/var/www/html/plantilla/course/format/weeks/classes/privacy/provider.php',
    'format_weeks_observer' => '/var/www/html/plantilla/course/format/weeks/classes/observer.php',
    'forumreport_summary\\event\\report_downloaded' => '/var/www/html/plantilla/mod/forum/report/summary/classes/event/report_downloaded.php',
    'forumreport_summary\\event\\report_viewed' => '/var/www/html/plantilla/mod/forum/report/summary/classes/event/report_viewed.php',
    'forumreport_summary\\form\\dates_filter_form' => '/var/www/html/plantilla/mod/forum/report/summary/classes/form/dates_filter_form.php',
    'forumreport_summary\\output\\filters' => '/var/www/html/plantilla/mod/forum/report/summary/classes/output/filters.php',
    'forumreport_summary\\privacy\\provider' => '/var/www/html/plantilla/mod/forum/report/summary/classes/privacy/provider.php',
    'forumreport_summary\\summary_table' => '/var/www/html/plantilla/mod/forum/report/summary/classes/summary_table.php',
    'forumreport_summary_summary_table' => '/var/www/html/plantilla/mod/forum/report/summary/classes/summary_table.php',
    'fragment_requirements_manager' => '/var/www/html/plantilla/lib/classes/output/requirements/fragment_requirements_manager.php',
    'gradeexport_ods\\event\\grade_exported' => '/var/www/html/plantilla/grade/export/ods/classes/event/grade_exported.php',
    'gradeexport_ods\\privacy\\provider' => '/var/www/html/plantilla/grade/export/ods/classes/privacy/provider.php',
    'gradeexport_txt\\event\\grade_exported' => '/var/www/html/plantilla/grade/export/txt/classes/event/grade_exported.php',
    'gradeexport_txt\\privacy\\provider' => '/var/www/html/plantilla/grade/export/txt/classes/privacy/provider.php',
    'gradeexport_xls\\event\\grade_exported' => '/var/www/html/plantilla/grade/export/xls/classes/event/grade_exported.php',
    'gradeexport_xls\\privacy\\provider' => '/var/www/html/plantilla/grade/export/xls/classes/privacy/provider.php',
    'gradeexport_xml\\event\\grade_exported' => '/var/www/html/plantilla/grade/export/xml/classes/event/grade_exported.php',
    'gradeexport_xml\\privacy\\provider' => '/var/www/html/plantilla/grade/export/xml/classes/privacy/provider.php',
    'gradeimport_csv\\load_data' => '/var/www/html/plantilla/grade/import/csv/classes/load_data.php',
    'gradeimport_csv\\output\\renderer' => '/var/www/html/plantilla/grade/import/csv/classes/output/renderer.php',
    'gradeimport_csv\\privacy\\provider' => '/var/www/html/plantilla/grade/import/csv/classes/privacy/provider.php',
    'gradeimport_csv_load_data' => '/var/www/html/plantilla/grade/import/csv/classes/load_data.php',
    'gradeimport_direct\\import_form' => '/var/www/html/plantilla/grade/import/direct/classes/import_form.php',
    'gradeimport_direct\\mapping_form' => '/var/www/html/plantilla/grade/import/direct/classes/mapping_form.php',
    'gradeimport_direct\\privacy\\provider' => '/var/www/html/plantilla/grade/import/direct/classes/privacy/provider.php',
    'gradeimport_direct_import_form' => '/var/www/html/plantilla/grade/import/direct/classes/import_form.php',
    'gradeimport_direct_mapping_form' => '/var/www/html/plantilla/grade/import/direct/classes/mapping_form.php',
    'gradeimport_xml\\privacy\\provider' => '/var/www/html/plantilla/grade/import/xml/classes/privacy/provider.php',
    'gradepenalty_duedate\\constants' => '/var/www/html/plantilla/grade/penalty/duedate/classes/constants.php',
    'gradepenalty_duedate\\output\\edit_penalty_rule_action_bar' => '/var/www/html/plantilla/grade/penalty/duedate/classes/output/edit_penalty_rule_action_bar.php',
    'gradepenalty_duedate\\output\\form\\edit_penalty_form' => '/var/www/html/plantilla/grade/penalty/duedate/classes/output/form/edit_penalty_form.php',
    'gradepenalty_duedate\\output\\view_penalty_rule_action_bar' => '/var/www/html/plantilla/grade/penalty/duedate/classes/output/view_penalty_rule_action_bar.php',
    'gradepenalty_duedate\\penalty_calculator' => '/var/www/html/plantilla/grade/penalty/duedate/classes/penalty_calculator.php',
    'gradepenalty_duedate\\penalty_rule' => '/var/www/html/plantilla/grade/penalty/duedate/classes/penalty_rule.php',
    'gradepenalty_duedate\\privacy\\provider' => '/var/www/html/plantilla/grade/penalty/duedate/classes/privacy/provider.php',
    'gradepenalty_duedate\\table\\penalty_rule_table' => '/var/www/html/plantilla/grade/penalty/duedate/classes/table/penalty_rule_table.php',
    'gradepenalty_duedate_constants' => '/var/www/html/plantilla/grade/penalty/duedate/classes/constants.php',
    'gradepenalty_duedate_penalty_calculator' => '/var/www/html/plantilla/grade/penalty/duedate/classes/penalty_calculator.php',
    'gradepenalty_duedate_penalty_rule' => '/var/www/html/plantilla/grade/penalty/duedate/classes/penalty_rule.php',
    'gradereport_grader\\event\\grade_report_viewed' => '/var/www/html/plantilla/grade/report/grader/classes/event/grade_report_viewed.php',
    'gradereport_grader\\external\\get_users_in_report' => '/var/www/html/plantilla/grade/report/grader/classes/external/get_users_in_report.php',
    'gradereport_grader\\output\\action_bar' => '/var/www/html/plantilla/grade/report/grader/classes/output/action_bar.php',
    'gradereport_grader\\privacy\\provider' => '/var/www/html/plantilla/grade/report/grader/classes/privacy/provider.php',
    'gradereport_history\\event\\grade_report_viewed' => '/var/www/html/plantilla/grade/report/history/classes/event/grade_report_viewed.php',
    'gradereport_history\\filter_form' => '/var/www/html/plantilla/grade/report/history/classes/filter_form.php',
    'gradereport_history\\helper' => '/var/www/html/plantilla/grade/report/history/classes/helper.php',
    'gradereport_history\\output\\renderer' => '/var/www/html/plantilla/grade/report/history/classes/output/renderer.php',
    'gradereport_history\\output\\tablelog' => '/var/www/html/plantilla/grade/report/history/classes/output/tablelog.php',
    'gradereport_history\\output\\user_button' => '/var/www/html/plantilla/grade/report/history/classes/output/user_button.php',
    'gradereport_history\\privacy\\provider' => '/var/www/html/plantilla/grade/report/history/classes/privacy/provider.php',
    'gradereport_history_filter_form' => '/var/www/html/plantilla/grade/report/history/classes/filter_form.php',
    'gradereport_history_helper' => '/var/www/html/plantilla/grade/report/history/classes/helper.php',
    'gradereport_outcomes\\event\\grade_report_viewed' => '/var/www/html/plantilla/grade/report/outcomes/classes/event/grade_report_viewed.php',
    'gradereport_outcomes\\privacy\\provider' => '/var/www/html/plantilla/grade/report/outcomes/classes/privacy/provider.php',
    'gradereport_overview\\event\\grade_report_viewed' => '/var/www/html/plantilla/grade/report/overview/classes/event/grade_report_viewed.php',
    'gradereport_overview\\external' => '/var/www/html/plantilla/grade/report/overview/classes/external.php',
    'gradereport_overview\\privacy\\provider' => '/var/www/html/plantilla/grade/report/overview/classes/privacy/provider.php',
    'gradereport_overview_external' => '/var/www/html/plantilla/grade/report/overview/classes/external.php',
    'gradereport_singleview\\event\\grade_report_viewed' => '/var/www/html/plantilla/grade/report/singleview/classes/event/grade_report_viewed.php',
    'gradereport_singleview\\external\\singleview' => '/var/www/html/plantilla/grade/report/singleview/classes/external/singleview.php',
    'gradereport_singleview\\local\\screen\\filterable_items' => '/var/www/html/plantilla/grade/report/singleview/classes/local/screen/filterable_items.php',
    'gradereport_singleview\\local\\screen\\grade' => '/var/www/html/plantilla/grade/report/singleview/classes/local/screen/grade.php',
    'gradereport_singleview\\local\\screen\\grade_select' => '/var/www/html/plantilla/grade/report/singleview/classes/local/screen/grade_select.php',
    'gradereport_singleview\\local\\screen\\screen' => '/var/www/html/plantilla/grade/report/singleview/classes/local/screen/screen.php',
    'gradereport_singleview\\local\\screen\\select' => '/var/www/html/plantilla/grade/report/singleview/classes/local/screen/select.php',
    'gradereport_singleview\\local\\screen\\selectable_items' => '/var/www/html/plantilla/grade/report/singleview/classes/local/screen/selectable_items.php',
    'gradereport_singleview\\local\\screen\\tablelike' => '/var/www/html/plantilla/grade/report/singleview/classes/local/screen/tablelike.php',
    'gradereport_singleview\\local\\screen\\user' => '/var/www/html/plantilla/grade/report/singleview/classes/local/screen/user.php',
    'gradereport_singleview\\local\\screen\\user_select' => '/var/www/html/plantilla/grade/report/singleview/classes/local/screen/user_select.php',
    'gradereport_singleview\\local\\ui\\attribute_format' => '/var/www/html/plantilla/grade/report/singleview/classes/local/ui/attribute_format.php',
    'gradereport_singleview\\local\\ui\\be_checked' => '/var/www/html/plantilla/grade/report/singleview/classes/local/ui/be_checked.php',
    'gradereport_singleview\\local\\ui\\be_disabled' => '/var/www/html/plantilla/grade/report/singleview/classes/local/ui/be_disabled.php',
    'gradereport_singleview\\local\\ui\\be_readonly' => '/var/www/html/plantilla/grade/report/singleview/classes/local/ui/be_readonly.php',
    'gradereport_singleview\\local\\ui\\bulk_insert' => '/var/www/html/plantilla/grade/report/singleview/classes/local/ui/bulk_insert.php',
    'gradereport_singleview\\local\\ui\\checkbox_attribute' => '/var/www/html/plantilla/grade/report/singleview/classes/local/ui/checkbox_attribute.php',
    'gradereport_singleview\\local\\ui\\dropdown_attribute' => '/var/www/html/plantilla/grade/report/singleview/classes/local/ui/dropdown_attribute.php',
    'gradereport_singleview\\local\\ui\\element' => '/var/www/html/plantilla/grade/report/singleview/classes/local/ui/element.php',
    'gradereport_singleview\\local\\ui\\empty_element' => '/var/www/html/plantilla/grade/report/singleview/classes/local/ui/empty_element.php',
    'gradereport_singleview\\local\\ui\\exclude' => '/var/www/html/plantilla/grade/report/singleview/classes/local/ui/exclude.php',
    'gradereport_singleview\\local\\ui\\feedback' => '/var/www/html/plantilla/grade/report/singleview/classes/local/ui/feedback.php',
    'gradereport_singleview\\local\\ui\\finalgrade' => '/var/www/html/plantilla/grade/report/singleview/classes/local/ui/finalgrade.php',
    'gradereport_singleview\\local\\ui\\grade_attribute_format' => '/var/www/html/plantilla/grade/report/singleview/classes/local/ui/grade_attribute_format.php',
    'gradereport_singleview\\local\\ui\\override' => '/var/www/html/plantilla/grade/report/singleview/classes/local/ui/override.php',
    'gradereport_singleview\\local\\ui\\range' => '/var/www/html/plantilla/grade/report/singleview/classes/local/ui/range.php',
    'gradereport_singleview\\local\\ui\\text_attribute' => '/var/www/html/plantilla/grade/report/singleview/classes/local/ui/text_attribute.php',
    'gradereport_singleview\\local\\ui\\unique_name' => '/var/www/html/plantilla/grade/report/singleview/classes/local/ui/unique_name.php',
    'gradereport_singleview\\local\\ui\\unique_value' => '/var/www/html/plantilla/grade/report/singleview/classes/local/ui/unique_value.php',
    'gradereport_singleview\\output\\action_bar' => '/var/www/html/plantilla/grade/report/singleview/classes/output/action_bar.php',
    'gradereport_singleview\\privacy\\provider' => '/var/www/html/plantilla/grade/report/singleview/classes/privacy/provider.php',
    'gradereport_singleview\\report\\singleview' => '/var/www/html/plantilla/grade/report/singleview/classes/report/singleview.php',
    'gradereport_summary\\local\\entities\\grade_items' => '/var/www/html/plantilla/grade/report/summary/classes/local/entities/grade_items.php',
    'gradereport_summary\\local\\systemreports\\summary' => '/var/www/html/plantilla/grade/report/summary/classes/local/systemreports/summary.php',
    'gradereport_summary\\privacy\\provider' => '/var/www/html/plantilla/grade/report/summary/classes/privacy/provider.php',
    'gradereport_user\\event\\grade_report_viewed' => '/var/www/html/plantilla/grade/report/user/classes/event/grade_report_viewed.php',
    'gradereport_user\\external\\get_access_information' => '/var/www/html/plantilla/grade/report/user/classes/external/get_access_information.php',
    'gradereport_user\\external\\user' => '/var/www/html/plantilla/grade/report/user/classes/external/user.php',
    'gradereport_user\\output\\action_bar' => '/var/www/html/plantilla/grade/report/user/classes/output/action_bar.php',
    'gradereport_user\\privacy\\provider' => '/var/www/html/plantilla/grade/report/user/classes/privacy/provider.php',
    'gradereport_user\\report\\user' => '/var/www/html/plantilla/grade/report/user/classes/report/user.php',
    'gradingform_guide\\grades\\grader\\gradingpanel\\external\\fetch' => '/var/www/html/plantilla/grade/grading/form/guide/classes/grades/grader/gradingpanel/external/fetch.php',
    'gradingform_guide\\grades\\grader\\gradingpanel\\external\\store' => '/var/www/html/plantilla/grade/grading/form/guide/classes/grades/grader/gradingpanel/external/store.php',
    'gradingform_guide\\privacy\\provider' => '/var/www/html/plantilla/grade/grading/form/guide/classes/privacy/provider.php',
    'gradingform_rubric\\grades\\grader\\gradingpanel\\external\\fetch' => '/var/www/html/plantilla/grade/grading/form/rubric/classes/grades/grader/gradingpanel/external/fetch.php',
    'gradingform_rubric\\grades\\grader\\gradingpanel\\external\\store' => '/var/www/html/plantilla/grade/grading/form/rubric/classes/grades/grader/gradingpanel/external/store.php',
    'gradingform_rubric\\privacy\\provider' => '/var/www/html/plantilla/grade/grading/form/rubric/classes/privacy/provider.php',
    'h5plib_v127\\local\\library\\handler' => '/var/www/html/plantilla/h5p/h5plib/v127/classes/local/library/handler.php',
    'h5plib_v127\\privacy\\provider' => '/var/www/html/plantilla/h5p/h5plib/v127/classes/privacy/provider.php',
    'help_icon' => '/var/www/html/plantilla/lib/classes/output/help_icon.php',
    'html_list_progress_trace' => '/var/www/html/plantilla/lib/classes/output/progress_trace/html_list_progress_trace.php',
    'html_progress_trace' => '/var/www/html/plantilla/lib/classes/output/progress_trace/html_progress_trace.php',
    'html_table' => '/var/www/html/plantilla/lib/table/classes/output/html_table.php',
    'html_table_cell' => '/var/www/html/plantilla/lib/table/classes/output/html_table_cell.php',
    'html_table_row' => '/var/www/html/plantilla/lib/table/classes/output/html_table_row.php',
    'html_writer' => '/var/www/html/plantilla/lib/classes/output/html_writer.php',
    'image_icon' => '/var/www/html/plantilla/lib/classes/output/image_icon.php',
    'initials_bar' => '/var/www/html/plantilla/lib/classes/output/initials_bar.php',
    'invalid_dataroot_permissions' => '/var/www/html/plantilla/lib/classes/exception/invalid_dataroot_permissions.php',
    'invalid_parameter_exception' => '/var/www/html/plantilla/lib/classes/exception/invalid_parameter_exception.php',
    'invalid_response_exception' => '/var/www/html/plantilla/lib/classes/exception/invalid_response_exception.php',
    'invalid_state_exception' => '/var/www/html/plantilla/lib/classes/exception/invalid_state_exception.php',
    'js_writer' => '/var/www/html/plantilla/lib/classes/output/js_writer.php',
    'lang_string' => '/var/www/html/plantilla/lib/classes/lang_string.php',
    'logstore_database\\helper' => '/var/www/html/plantilla/admin/tool/log/store/database/classes/helper.php',
    'logstore_database\\log\\store' => '/var/www/html/plantilla/admin/tool/log/store/database/classes/log/store.php',
    'logstore_database\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/log/store/database/classes/privacy/provider.php',
    'logstore_database_helper' => '/var/www/html/plantilla/admin/tool/log/store/database/classes/helper.php',
    'logstore_standard\\log\\store' => '/var/www/html/plantilla/admin/tool/log/store/standard/classes/log/store.php',
    'logstore_standard\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/log/store/standard/classes/privacy/provider.php',
    'logstore_standard\\task\\cleanup_task' => '/var/www/html/plantilla/admin/tool/log/store/standard/classes/task/cleanup_task.php',
    'ltiservice_basicoutcomes\\local\\resources\\basicoutcomes' => '/var/www/html/plantilla/mod/lti/service/basicoutcomes/classes/local/resources/basicoutcomes.php',
    'ltiservice_basicoutcomes\\local\\service\\basicoutcomes' => '/var/www/html/plantilla/mod/lti/service/basicoutcomes/classes/local/service/basicoutcomes.php',
    'ltiservice_basicoutcomes\\privacy\\provider' => '/var/www/html/plantilla/mod/lti/service/basicoutcomes/classes/privacy/provider.php',
    'ltiservice_gradebookservices\\local\\resources\\lineitem' => '/var/www/html/plantilla/mod/lti/service/gradebookservices/classes/local/resources/lineitem.php',
    'ltiservice_gradebookservices\\local\\resources\\lineitems' => '/var/www/html/plantilla/mod/lti/service/gradebookservices/classes/local/resources/lineitems.php',
    'ltiservice_gradebookservices\\local\\resources\\results' => '/var/www/html/plantilla/mod/lti/service/gradebookservices/classes/local/resources/results.php',
    'ltiservice_gradebookservices\\local\\resources\\scores' => '/var/www/html/plantilla/mod/lti/service/gradebookservices/classes/local/resources/scores.php',
    'ltiservice_gradebookservices\\local\\service\\gradebookservices' => '/var/www/html/plantilla/mod/lti/service/gradebookservices/classes/local/service/gradebookservices.php',
    'ltiservice_gradebookservices\\privacy\\provider' => '/var/www/html/plantilla/mod/lti/service/gradebookservices/classes/privacy/provider.php',
    'ltiservice_gradebookservices\\task\\cleanup_task' => '/var/www/html/plantilla/mod/lti/service/gradebookservices/classes/task/cleanup_task.php',
    'ltiservice_memberships\\local\\resources\\contextmemberships' => '/var/www/html/plantilla/mod/lti/service/memberships/classes/local/resources/contextmemberships.php',
    'ltiservice_memberships\\local\\resources\\linkmemberships' => '/var/www/html/plantilla/mod/lti/service/memberships/classes/local/resources/linkmemberships.php',
    'ltiservice_memberships\\local\\service\\memberships' => '/var/www/html/plantilla/mod/lti/service/memberships/classes/local/service/memberships.php',
    'ltiservice_memberships\\privacy\\provider' => '/var/www/html/plantilla/mod/lti/service/memberships/classes/privacy/provider.php',
    'ltiservice_profile\\local\\resources\\profile' => '/var/www/html/plantilla/mod/lti/service/profile/classes/local/resources/profile.php',
    'ltiservice_profile\\local\\service\\profile' => '/var/www/html/plantilla/mod/lti/service/profile/classes/local/service/profile.php',
    'ltiservice_profile\\privacy\\provider' => '/var/www/html/plantilla/mod/lti/service/profile/classes/privacy/provider.php',
    'ltiservice_toolproxy\\local\\resources\\toolproxy' => '/var/www/html/plantilla/mod/lti/service/toolproxy/classes/local/resources/toolproxy.php',
    'ltiservice_toolproxy\\local\\service\\toolproxy' => '/var/www/html/plantilla/mod/lti/service/toolproxy/classes/local/service/toolproxy.php',
    'ltiservice_toolproxy\\privacy\\provider' => '/var/www/html/plantilla/mod/lti/service/toolproxy/classes/privacy/provider.php',
    'ltiservice_toolsettings\\local\\resources\\contextsettings' => '/var/www/html/plantilla/mod/lti/service/toolsettings/classes/local/resources/contextsettings.php',
    'ltiservice_toolsettings\\local\\resources\\linksettings' => '/var/www/html/plantilla/mod/lti/service/toolsettings/classes/local/resources/linksettings.php',
    'ltiservice_toolsettings\\local\\resources\\systemsettings' => '/var/www/html/plantilla/mod/lti/service/toolsettings/classes/local/resources/systemsettings.php',
    'ltiservice_toolsettings\\local\\service\\toolsettings' => '/var/www/html/plantilla/mod/lti/service/toolsettings/classes/local/service/toolsettings.php',
    'ltiservice_toolsettings\\privacy\\provider' => '/var/www/html/plantilla/mod/lti/service/toolsettings/classes/privacy/provider.php',
    'media_html5audio\\plugin' => '/var/www/html/plantilla/media/player/html5audio/classes/plugin.php',
    'media_html5audio\\privacy\\provider' => '/var/www/html/plantilla/media/player/html5audio/classes/privacy/provider.php',
    'media_html5audio_plugin' => '/var/www/html/plantilla/media/player/html5audio/classes/plugin.php',
    'media_html5video\\plugin' => '/var/www/html/plantilla/media/player/html5video/classes/plugin.php',
    'media_html5video\\privacy\\provider' => '/var/www/html/plantilla/media/player/html5video/classes/privacy/provider.php',
    'media_html5video_plugin' => '/var/www/html/plantilla/media/player/html5video/classes/plugin.php',
    'media_videojs\\external\\get_language' => '/var/www/html/plantilla/media/player/videojs/classes/external/get_language.php',
    'media_videojs\\plugin' => '/var/www/html/plantilla/media/player/videojs/classes/plugin.php',
    'media_videojs\\privacy\\provider' => '/var/www/html/plantilla/media/player/videojs/classes/privacy/provider.php',
    'media_videojs_plugin' => '/var/www/html/plantilla/media/player/videojs/classes/plugin.php',
    'media_vimeo\\plugin' => '/var/www/html/plantilla/media/player/vimeo/classes/plugin.php',
    'media_vimeo\\privacy\\provider' => '/var/www/html/plantilla/media/player/vimeo/classes/privacy/provider.php',
    'media_vimeo_plugin' => '/var/www/html/plantilla/media/player/vimeo/classes/plugin.php',
    'media_youtube\\plugin' => '/var/www/html/plantilla/media/player/youtube/classes/plugin.php',
    'media_youtube\\privacy\\provider' => '/var/www/html/plantilla/media/player/youtube/classes/privacy/provider.php',
    'media_youtube_plugin' => '/var/www/html/plantilla/media/player/youtube/classes/plugin.php',
    'message_airnotifier\\manager' => '/var/www/html/plantilla/message/output/airnotifier/classes/manager.php',
    'message_airnotifier\\privacy\\provider' => '/var/www/html/plantilla/message/output/airnotifier/classes/privacy/provider.php',
    'message_airnotifier_manager' => '/var/www/html/plantilla/message/output/airnotifier/classes/manager.php',
    'message_email\\event_observers' => '/var/www/html/plantilla/message/output/email/classes/event_observers.php',
    'message_email\\output\\email\\renderer' => '/var/www/html/plantilla/message/output/email/classes/output/email/renderer.php',
    'message_email\\output\\email\\renderer_textemail' => '/var/www/html/plantilla/message/output/email/classes/output/email/renderer_textemail.php',
    'message_email\\output\\email_digest' => '/var/www/html/plantilla/message/output/email/classes/output/email_digest.php',
    'message_email\\output\\renderer' => '/var/www/html/plantilla/message/output/email/classes/output/renderer.php',
    'message_email\\privacy\\provider' => '/var/www/html/plantilla/message/output/email/classes/privacy/provider.php',
    'message_email\\task\\send_email_task' => '/var/www/html/plantilla/message/output/email/classes/task/send_email_task.php',
    'message_email_event_observers' => '/var/www/html/plantilla/message/output/email/classes/event_observers.php',
    'message_popup\\api' => '/var/www/html/plantilla/message/output/popup/classes/api.php',
    'message_popup\\output\\popup_notification' => '/var/www/html/plantilla/message/output/popup/classes/output/popup_notification.php',
    'message_popup\\privacy\\provider' => '/var/www/html/plantilla/message/output/popup/classes/privacy/provider.php',
    'message_popup_api' => '/var/www/html/plantilla/message/output/popup/classes/api.php',
    'message_sms\\privacy\\provider' => '/var/www/html/plantilla/message/output/sms/classes/privacy/provider.php',
    'mlbackend_python\\privacy\\provider' => '/var/www/html/plantilla/lib/mlbackend/python/classes/privacy/provider.php',
    'mlbackend_python\\processor' => '/var/www/html/plantilla/lib/mlbackend/python/classes/processor.php',
    'mlbackend_python_processor' => '/var/www/html/plantilla/lib/mlbackend/python/classes/processor.php',
    'mod_assign\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/assign/classes/analytics/indicator/activity_base.php',
    'mod_assign\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/assign/classes/analytics/indicator/cognitive_depth.php',
    'mod_assign\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/assign/classes/analytics/indicator/social_breadth.php',
    'mod_assign\\cache\\overrides' => '/var/www/html/plantilla/mod/assign/classes/cache/overrides.php',
    'mod_assign\\completion\\custom_completion' => '/var/www/html/plantilla/mod/assign/classes/completion/custom_completion.php',
    'mod_assign\\courseformat\\overview' => '/var/www/html/plantilla/mod/assign/classes/courseformat/overview.php',
    'mod_assign\\dates' => '/var/www/html/plantilla/mod/assign/classes/dates.php',
    'mod_assign\\downloader' => '/var/www/html/plantilla/mod/assign/classes/downloader.php',
    'mod_assign\\event\\all_submissions_downloaded' => '/var/www/html/plantilla/mod/assign/classes/event/all_submissions_downloaded.php',
    'mod_assign\\event\\assessable_submitted' => '/var/www/html/plantilla/mod/assign/classes/event/assessable_submitted.php',
    'mod_assign\\event\\base' => '/var/www/html/plantilla/mod/assign/classes/event/base.php',
    'mod_assign\\event\\batch_set_marker_allocation_viewed' => '/var/www/html/plantilla/mod/assign/classes/event/batch_set_marker_allocation_viewed.php',
    'mod_assign\\event\\batch_set_workflow_state_viewed' => '/var/www/html/plantilla/mod/assign/classes/event/batch_set_workflow_state_viewed.php',
    'mod_assign\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/assign/classes/event/course_module_instance_list_viewed.php',
    'mod_assign\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/assign/classes/event/course_module_viewed.php',
    'mod_assign\\event\\extension_granted' => '/var/www/html/plantilla/mod/assign/classes/event/extension_granted.php',
    'mod_assign\\event\\feedback_viewed' => '/var/www/html/plantilla/mod/assign/classes/event/feedback_viewed.php',
    'mod_assign\\event\\grading_form_viewed' => '/var/www/html/plantilla/mod/assign/classes/event/grading_form_viewed.php',
    'mod_assign\\event\\grading_table_viewed' => '/var/www/html/plantilla/mod/assign/classes/event/grading_table_viewed.php',
    'mod_assign\\event\\group_override_created' => '/var/www/html/plantilla/mod/assign/classes/event/group_override_created.php',
    'mod_assign\\event\\group_override_deleted' => '/var/www/html/plantilla/mod/assign/classes/event/group_override_deleted.php',
    'mod_assign\\event\\group_override_updated' => '/var/www/html/plantilla/mod/assign/classes/event/group_override_updated.php',
    'mod_assign\\event\\identities_revealed' => '/var/www/html/plantilla/mod/assign/classes/event/identities_revealed.php',
    'mod_assign\\event\\marker_updated' => '/var/www/html/plantilla/mod/assign/classes/event/marker_updated.php',
    'mod_assign\\event\\remove_submission_form_viewed' => '/var/www/html/plantilla/mod/assign/classes/event/remove_submission_form_viewed.php',
    'mod_assign\\event\\reveal_identities_confirmation_page_viewed' => '/var/www/html/plantilla/mod/assign/classes/event/reveal_identities_confirmation_page_viewed.php',
    'mod_assign\\event\\statement_accepted' => '/var/www/html/plantilla/mod/assign/classes/event/statement_accepted.php',
    'mod_assign\\event\\submission_confirmation_form_viewed' => '/var/www/html/plantilla/mod/assign/classes/event/submission_confirmation_form_viewed.php',
    'mod_assign\\event\\submission_created' => '/var/www/html/plantilla/mod/assign/classes/event/submission_created.php',
    'mod_assign\\event\\submission_duplicated' => '/var/www/html/plantilla/mod/assign/classes/event/submission_duplicated.php',
    'mod_assign\\event\\submission_form_viewed' => '/var/www/html/plantilla/mod/assign/classes/event/submission_form_viewed.php',
    'mod_assign\\event\\submission_graded' => '/var/www/html/plantilla/mod/assign/classes/event/submission_graded.php',
    'mod_assign\\event\\submission_locked' => '/var/www/html/plantilla/mod/assign/classes/event/submission_locked.php',
    'mod_assign\\event\\submission_removed' => '/var/www/html/plantilla/mod/assign/classes/event/submission_removed.php',
    'mod_assign\\event\\submission_status_updated' => '/var/www/html/plantilla/mod/assign/classes/event/submission_status_updated.php',
    'mod_assign\\event\\submission_status_viewed' => '/var/www/html/plantilla/mod/assign/classes/event/submission_status_viewed.php',
    'mod_assign\\event\\submission_unlocked' => '/var/www/html/plantilla/mod/assign/classes/event/submission_unlocked.php',
    'mod_assign\\event\\submission_updated' => '/var/www/html/plantilla/mod/assign/classes/event/submission_updated.php',
    'mod_assign\\event\\submission_viewed' => '/var/www/html/plantilla/mod/assign/classes/event/submission_viewed.php',
    'mod_assign\\event\\user_override_created' => '/var/www/html/plantilla/mod/assign/classes/event/user_override_created.php',
    'mod_assign\\event\\user_override_deleted' => '/var/www/html/plantilla/mod/assign/classes/event/user_override_deleted.php',
    'mod_assign\\event\\user_override_updated' => '/var/www/html/plantilla/mod/assign/classes/event/user_override_updated.php',
    'mod_assign\\event\\workflow_state_updated' => '/var/www/html/plantilla/mod/assign/classes/event/workflow_state_updated.php',
    'mod_assign\\external\\external_api' => '/var/www/html/plantilla/mod/assign/classes/external/external_api.php',
    'mod_assign\\external\\remove_submission' => '/var/www/html/plantilla/mod/assign/classes/external/remove_submission.php',
    'mod_assign\\external\\start_submission' => '/var/www/html/plantilla/mod/assign/classes/external/start_submission.php',
    'mod_assign\\grades\\gradeitems' => '/var/www/html/plantilla/mod/assign/classes/grades/gradeitems.php',
    'mod_assign\\group_observers' => '/var/www/html/plantilla/mod/assign/classes/group_observers.php',
    'mod_assign\\navigation\\views\\secondary' => '/var/www/html/plantilla/mod/assign/classes/navigation/views/secondary.php',
    'mod_assign\\notification_helper' => '/var/www/html/plantilla/mod/assign/classes/notification_helper.php',
    'mod_assign\\output\\actionmenu' => '/var/www/html/plantilla/mod/assign/classes/output/actionmenu.php',
    'mod_assign\\output\\assign_header' => '/var/www/html/plantilla/mod/assign/classes/output/assign_header.php',
    'mod_assign\\output\\assign_submission_status' => '/var/www/html/plantilla/mod/assign/classes/output/assign_submission_status.php',
    'mod_assign\\output\\grading_actionmenu' => '/var/www/html/plantilla/mod/assign/classes/output/grading_actionmenu.php',
    'mod_assign\\output\\grading_app' => '/var/www/html/plantilla/mod/assign/classes/output/grading_app.php',
    'mod_assign\\output\\override_actionmenu' => '/var/www/html/plantilla/mod/assign/classes/output/override_actionmenu.php',
    'mod_assign\\output\\renderer' => '/var/www/html/plantilla/mod/assign/classes/output/renderer.php',
    'mod_assign\\output\\timelimit_panel' => '/var/www/html/plantilla/mod/assign/classes/output/timelimit_panel.php',
    'mod_assign\\output\\user_submission_actionmenu' => '/var/www/html/plantilla/mod/assign/classes/output/user_submission_actionmenu.php',
    'mod_assign\\penalty\\helper' => '/var/www/html/plantilla/mod/assign/classes/penalty/helper.php',
    'mod_assign\\penalty_recalculator' => '/var/www/html/plantilla/mod/assign/classes/penalty_recalculator.php',
    'mod_assign\\plugininfo\\assignfeedback' => '/var/www/html/plantilla/mod/assign/classes/plugininfo/assignfeedback.php',
    'mod_assign\\plugininfo\\assignsubmission' => '/var/www/html/plantilla/mod/assign/classes/plugininfo/assignsubmission.php',
    'mod_assign\\privacy\\assign_plugin_request_data' => '/var/www/html/plantilla/mod/assign/classes/privacy/assign_plugin_request_data.php',
    'mod_assign\\privacy\\assignfeedback_provider' => '/var/www/html/plantilla/mod/assign/classes/privacy/assignfeedback_provider.php',
    'mod_assign\\privacy\\assignfeedback_user_provider' => '/var/www/html/plantilla/mod/assign/classes/privacy/assignfeedback_user_provider.php',
    'mod_assign\\privacy\\assignsubmission_provider' => '/var/www/html/plantilla/mod/assign/classes/privacy/assignsubmission_provider.php',
    'mod_assign\\privacy\\assignsubmission_user_provider' => '/var/www/html/plantilla/mod/assign/classes/privacy/assignsubmission_user_provider.php',
    'mod_assign\\privacy\\feedback_legacy_polyfill' => '/var/www/html/plantilla/mod/assign/classes/privacy/feedback_legacy_polyfill.php',
    'mod_assign\\privacy\\provider' => '/var/www/html/plantilla/mod/assign/classes/privacy/provider.php',
    'mod_assign\\privacy\\submission_legacy_polyfill' => '/var/www/html/plantilla/mod/assign/classes/privacy/submission_legacy_polyfill.php',
    'mod_assign\\privacy\\useridlist' => '/var/www/html/plantilla/mod/assign/classes/privacy/useridlist.php',
    'mod_assign\\search\\activity' => '/var/www/html/plantilla/mod/assign/classes/search/activity.php',
    'mod_assign\\task\\cron_task' => '/var/www/html/plantilla/mod/assign/classes/task/cron_task.php',
    'mod_assign\\task\\queue_all_assignment_due_digest_notification_tasks' => '/var/www/html/plantilla/mod/assign/classes/task/queue_all_assignment_due_digest_notification_tasks.php',
    'mod_assign\\task\\queue_all_assignment_due_soon_notification_tasks' => '/var/www/html/plantilla/mod/assign/classes/task/queue_all_assignment_due_soon_notification_tasks.php',
    'mod_assign\\task\\queue_all_assignment_overdue_notification_tasks' => '/var/www/html/plantilla/mod/assign/classes/task/queue_all_assignment_overdue_notification_tasks.php',
    'mod_assign\\task\\queue_assignment_due_soon_notification_tasks_for_users' => '/var/www/html/plantilla/mod/assign/classes/task/queue_assignment_due_soon_notification_tasks_for_users.php',
    'mod_assign\\task\\queue_assignment_overdue_notification_tasks_for_users' => '/var/www/html/plantilla/mod/assign/classes/task/queue_assignment_overdue_notification_tasks_for_users.php',
    'mod_assign\\task\\recalculate_penalties' => '/var/www/html/plantilla/mod/assign/classes/task/recalculate_penalties.php',
    'mod_assign\\task\\send_assignment_due_digest_notification_to_user' => '/var/www/html/plantilla/mod/assign/classes/task/send_assignment_due_digest_notification_to_user.php',
    'mod_assign\\task\\send_assignment_due_soon_notification_to_user' => '/var/www/html/plantilla/mod/assign/classes/task/send_assignment_due_soon_notification_to_user.php',
    'mod_assign\\task\\send_assignment_overdue_notification_to_user' => '/var/www/html/plantilla/mod/assign/classes/task/send_assignment_overdue_notification_to_user.php',
    'mod_assign_dates' => '/var/www/html/plantilla/mod/assign/classes/dates.php',
    'mod_assign_downloader' => '/var/www/html/plantilla/mod/assign/classes/downloader.php',
    'mod_assign_group_observers' => '/var/www/html/plantilla/mod/assign/classes/group_observers.php',
    'mod_assign_notification_helper' => '/var/www/html/plantilla/mod/assign/classes/notification_helper.php',
    'mod_assign_penalty_recalculator' => '/var/www/html/plantilla/mod/assign/classes/penalty_recalculator.php',
    'mod_bigbluebuttonbn\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/analytics/indicator/activity_base.php',
    'mod_bigbluebuttonbn\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/analytics/indicator/cognitive_depth.php',
    'mod_bigbluebuttonbn\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/analytics/indicator/social_breadth.php',
    'mod_bigbluebuttonbn\\broker' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/broker.php',
    'mod_bigbluebuttonbn\\completion\\custom_completion' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/completion/custom_completion.php',
    'mod_bigbluebuttonbn\\event\\activity_management_viewed' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/event/activity_management_viewed.php',
    'mod_bigbluebuttonbn\\event\\base' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/event/base.php',
    'mod_bigbluebuttonbn\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/event/course_module_viewed.php',
    'mod_bigbluebuttonbn\\event\\events' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/event/events.php',
    'mod_bigbluebuttonbn\\event\\live_session_event' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/event/live_session_event.php',
    'mod_bigbluebuttonbn\\event\\meeting_created' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/event/meeting_created.php',
    'mod_bigbluebuttonbn\\event\\meeting_ended' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/event/meeting_ended.php',
    'mod_bigbluebuttonbn\\event\\meeting_joined' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/event/meeting_joined.php',
    'mod_bigbluebuttonbn\\event\\meeting_left' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/event/meeting_left.php',
    'mod_bigbluebuttonbn\\event\\recording_deleted' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/event/recording_deleted.php',
    'mod_bigbluebuttonbn\\event\\recording_edited' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/event/recording_edited.php',
    'mod_bigbluebuttonbn\\event\\recording_imported' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/event/recording_imported.php',
    'mod_bigbluebuttonbn\\event\\recording_protected' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/event/recording_protected.php',
    'mod_bigbluebuttonbn\\event\\recording_published' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/event/recording_published.php',
    'mod_bigbluebuttonbn\\event\\recording_unprotected' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/event/recording_unprotected.php',
    'mod_bigbluebuttonbn\\event\\recording_unpublished' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/event/recording_unpublished.php',
    'mod_bigbluebuttonbn\\event\\recording_viewed' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/event/recording_viewed.php',
    'mod_bigbluebuttonbn\\extension' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/extension.php',
    'mod_bigbluebuttonbn\\external\\can_join' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/external/can_join.php',
    'mod_bigbluebuttonbn\\external\\completion_validate' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/external/completion_validate.php',
    'mod_bigbluebuttonbn\\external\\end_meeting' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/external/end_meeting.php',
    'mod_bigbluebuttonbn\\external\\get_bigbluebuttonbns_by_courses' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/external/get_bigbluebuttonbns_by_courses.php',
    'mod_bigbluebuttonbn\\external\\get_join_url' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/external/get_join_url.php',
    'mod_bigbluebuttonbn\\external\\get_recordings' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/external/get_recordings.php',
    'mod_bigbluebuttonbn\\external\\get_recordings_to_import' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/external/get_recordings_to_import.php',
    'mod_bigbluebuttonbn\\external\\meeting_info' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/external/meeting_info.php',
    'mod_bigbluebuttonbn\\external\\update_recording' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/external/update_recording.php',
    'mod_bigbluebuttonbn\\external\\view_bigbluebuttonbn' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/external/view_bigbluebuttonbn.php',
    'mod_bigbluebuttonbn\\form\\guest_add' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/form/guest_add.php',
    'mod_bigbluebuttonbn\\form\\guest_login' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/form/guest_login.php',
    'mod_bigbluebuttonbn\\form\\text_with_copy_element' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/form/text_with_copy_element.php',
    'mod_bigbluebuttonbn\\instance' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/instance.php',
    'mod_bigbluebuttonbn\\local\\bigbluebutton\\recordings\\recording_action' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/bigbluebutton/recordings/recording_action.php',
    'mod_bigbluebuttonbn\\local\\bigbluebutton\\recordings\\recording_data' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/bigbluebutton/recordings/recording_data.php',
    'mod_bigbluebuttonbn\\local\\config' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/config.php',
    'mod_bigbluebuttonbn\\local\\exceptions\\bigbluebutton_exception' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/exceptions/bigbluebutton_exception.php',
    'mod_bigbluebuttonbn\\local\\exceptions\\meeting_join_exception' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/exceptions/meeting_join_exception.php',
    'mod_bigbluebuttonbn\\local\\exceptions\\server_not_available_exception' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/exceptions/server_not_available_exception.php',
    'mod_bigbluebuttonbn\\local\\extension\\action_url_addons' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/extension/action_url_addons.php',
    'mod_bigbluebuttonbn\\local\\extension\\broker_meeting_events_addons' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/extension/broker_meeting_events_addons.php',
    'mod_bigbluebuttonbn\\local\\extension\\custom_completion_addons' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/extension/custom_completion_addons.php',
    'mod_bigbluebuttonbn\\local\\extension\\mod_form_addons' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/extension/mod_form_addons.php',
    'mod_bigbluebuttonbn\\local\\extension\\mod_instance_helper' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/extension/mod_instance_helper.php',
    'mod_bigbluebuttonbn\\local\\helpers\\files' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/helpers/files.php',
    'mod_bigbluebuttonbn\\local\\helpers\\mod_helper' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/helpers/mod_helper.php',
    'mod_bigbluebuttonbn\\local\\helpers\\reset' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/helpers/reset.php',
    'mod_bigbluebuttonbn\\local\\helpers\\roles' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/helpers/roles.php',
    'mod_bigbluebuttonbn\\local\\helpers\\user_info' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/helpers/user_info.php',
    'mod_bigbluebuttonbn\\local\\plugins\\admin_page_manage_extensions' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/plugins/admin_page_manage_extensions.php',
    'mod_bigbluebuttonbn\\local\\plugins\\admin_plugin_manager' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/plugins/admin_plugin_manager.php',
    'mod_bigbluebuttonbn\\local\\proxy\\bigbluebutton_proxy' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/proxy/bigbluebutton_proxy.php',
    'mod_bigbluebuttonbn\\local\\proxy\\curl' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/proxy/curl.php',
    'mod_bigbluebuttonbn\\local\\proxy\\proxy_base' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/proxy/proxy_base.php',
    'mod_bigbluebuttonbn\\local\\proxy\\recording_proxy' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/local/proxy/recording_proxy.php',
    'mod_bigbluebuttonbn\\logger' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/logger.php',
    'mod_bigbluebuttonbn\\meeting' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/meeting.php',
    'mod_bigbluebuttonbn\\output\\import_view' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/output/import_view.php',
    'mod_bigbluebuttonbn\\output\\index' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/output/index.php',
    'mod_bigbluebuttonbn\\output\\instance_updated_message' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/output/instance_updated_message.php',
    'mod_bigbluebuttonbn\\output\\mobile' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/output/mobile.php',
    'mod_bigbluebuttonbn\\output\\recording_description_editable' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/output/recording_description_editable.php',
    'mod_bigbluebuttonbn\\output\\recording_editable' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/output/recording_editable.php',
    'mod_bigbluebuttonbn\\output\\recording_name_editable' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/output/recording_name_editable.php',
    'mod_bigbluebuttonbn\\output\\recording_row_actionbar' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/output/recording_row_actionbar.php',
    'mod_bigbluebuttonbn\\output\\recording_row_playback' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/output/recording_row_playback.php',
    'mod_bigbluebuttonbn\\output\\recording_row_preview' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/output/recording_row_preview.php',
    'mod_bigbluebuttonbn\\output\\recordings_session' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/output/recordings_session.php',
    'mod_bigbluebuttonbn\\output\\renderer' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/output/renderer.php',
    'mod_bigbluebuttonbn\\output\\view_page' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/output/view_page.php',
    'mod_bigbluebuttonbn\\plugin' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/plugin.php',
    'mod_bigbluebuttonbn\\plugininfo\\bbbext' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/plugininfo/bbbext.php',
    'mod_bigbluebuttonbn\\privacy\\provider' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/privacy/provider.php',
    'mod_bigbluebuttonbn\\recording' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/recording.php',
    'mod_bigbluebuttonbn\\search\\activity' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/search/activity.php',
    'mod_bigbluebuttonbn\\search\\tags' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/search/tags.php',
    'mod_bigbluebuttonbn\\setting_validator' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/setting_validator.php',
    'mod_bigbluebuttonbn\\settings' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/settings.php',
    'mod_bigbluebuttonbn\\task\\base_send_notification' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/task/base_send_notification.php',
    'mod_bigbluebuttonbn\\task\\check_dismissed_recordings' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/task/check_dismissed_recordings.php',
    'mod_bigbluebuttonbn\\task\\check_pending_recordings' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/task/check_pending_recordings.php',
    'mod_bigbluebuttonbn\\task\\completion_update_state' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/task/completion_update_state.php',
    'mod_bigbluebuttonbn\\task\\reset_recordings' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/task/reset_recordings.php',
    'mod_bigbluebuttonbn\\task\\send_guest_emails' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/task/send_guest_emails.php',
    'mod_bigbluebuttonbn\\task\\send_recording_ready_notification' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/task/send_recording_ready_notification.php',
    'mod_bigbluebuttonbn\\task\\upgrade_recordings_task' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/task/upgrade_recordings_task.php',
    'mod_bigbluebuttonbn\\test\\subplugins_test_helper_trait' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/test/subplugins_test_helper_trait.php',
    'mod_bigbluebuttonbn\\test\\testcase_helper_trait' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/test/testcase_helper_trait.php',
    'mod_bigbluebuttonbn_broker' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/broker.php',
    'mod_bigbluebuttonbn_extension' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/extension.php',
    'mod_bigbluebuttonbn_instance' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/instance.php',
    'mod_bigbluebuttonbn_logger' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/logger.php',
    'mod_bigbluebuttonbn_meeting' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/meeting.php',
    'mod_bigbluebuttonbn_plugin' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/plugin.php',
    'mod_bigbluebuttonbn_recording' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/recording.php',
    'mod_bigbluebuttonbn_setting_validator' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/setting_validator.php',
    'mod_bigbluebuttonbn_settings' => '/var/www/html/plantilla/mod/bigbluebuttonbn/classes/settings.php',
    'mod_book\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/book/classes/analytics/indicator/activity_base.php',
    'mod_book\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/book/classes/analytics/indicator/cognitive_depth.php',
    'mod_book\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/book/classes/analytics/indicator/social_breadth.php',
    'mod_book\\event\\chapter_created' => '/var/www/html/plantilla/mod/book/classes/event/chapter_created.php',
    'mod_book\\event\\chapter_deleted' => '/var/www/html/plantilla/mod/book/classes/event/chapter_deleted.php',
    'mod_book\\event\\chapter_updated' => '/var/www/html/plantilla/mod/book/classes/event/chapter_updated.php',
    'mod_book\\event\\chapter_viewed' => '/var/www/html/plantilla/mod/book/classes/event/chapter_viewed.php',
    'mod_book\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/book/classes/event/course_module_instance_list_viewed.php',
    'mod_book\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/book/classes/event/course_module_viewed.php',
    'mod_book\\external' => '/var/www/html/plantilla/mod/book/classes/external.php',
    'mod_book\\helper' => '/var/www/html/plantilla/mod/book/classes/helper.php',
    'mod_book\\output\\main_action_menu' => '/var/www/html/plantilla/mod/book/classes/output/main_action_menu.php',
    'mod_book\\output\\renderer' => '/var/www/html/plantilla/mod/book/classes/output/renderer.php',
    'mod_book\\plugininfo\\booktool' => '/var/www/html/plantilla/mod/book/classes/plugininfo/booktool.php',
    'mod_book\\privacy\\provider' => '/var/www/html/plantilla/mod/book/classes/privacy/provider.php',
    'mod_book\\search\\activity' => '/var/www/html/plantilla/mod/book/classes/search/activity.php',
    'mod_book\\search\\chapter' => '/var/www/html/plantilla/mod/book/classes/search/chapter.php',
    'mod_book_external' => '/var/www/html/plantilla/mod/book/classes/external.php',
    'mod_book_helper' => '/var/www/html/plantilla/mod/book/classes/helper.php',
    'mod_choice\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/choice/classes/analytics/indicator/activity_base.php',
    'mod_choice\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/choice/classes/analytics/indicator/cognitive_depth.php',
    'mod_choice\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/choice/classes/analytics/indicator/social_breadth.php',
    'mod_choice\\completion\\custom_completion' => '/var/www/html/plantilla/mod/choice/classes/completion/custom_completion.php',
    'mod_choice\\dates' => '/var/www/html/plantilla/mod/choice/classes/dates.php',
    'mod_choice\\event\\answer_created' => '/var/www/html/plantilla/mod/choice/classes/event/answer_created.php',
    'mod_choice\\event\\answer_deleted' => '/var/www/html/plantilla/mod/choice/classes/event/answer_deleted.php',
    'mod_choice\\event\\answer_submitted' => '/var/www/html/plantilla/mod/choice/classes/event/answer_submitted.php',
    'mod_choice\\event\\answer_updated' => '/var/www/html/plantilla/mod/choice/classes/event/answer_updated.php',
    'mod_choice\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/choice/classes/event/course_module_instance_list_viewed.php',
    'mod_choice\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/choice/classes/event/course_module_viewed.php',
    'mod_choice\\event\\report_downloaded' => '/var/www/html/plantilla/mod/choice/classes/event/report_downloaded.php',
    'mod_choice\\event\\report_viewed' => '/var/www/html/plantilla/mod/choice/classes/event/report_viewed.php',
    'mod_choice\\external' => '/var/www/html/plantilla/mod/choice/classes/external.php',
    'mod_choice\\privacy\\provider' => '/var/www/html/plantilla/mod/choice/classes/privacy/provider.php',
    'mod_choice\\search\\activity' => '/var/www/html/plantilla/mod/choice/classes/search/activity.php',
    'mod_choice_dates' => '/var/www/html/plantilla/mod/choice/classes/dates.php',
    'mod_choice_external' => '/var/www/html/plantilla/mod/choice/classes/external.php',
    'mod_data\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/data/classes/analytics/indicator/activity_base.php',
    'mod_data\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/data/classes/analytics/indicator/cognitive_depth.php',
    'mod_data\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/data/classes/analytics/indicator/social_breadth.php',
    'mod_data\\completion\\custom_completion' => '/var/www/html/plantilla/mod/data/classes/completion/custom_completion.php',
    'mod_data\\dates' => '/var/www/html/plantilla/mod/data/classes/dates.php',
    'mod_data\\event\\comment_created' => '/var/www/html/plantilla/mod/data/classes/event/comment_created.php',
    'mod_data\\event\\comment_deleted' => '/var/www/html/plantilla/mod/data/classes/event/comment_deleted.php',
    'mod_data\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/data/classes/event/course_module_instance_list_viewed.php',
    'mod_data\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/data/classes/event/course_module_viewed.php',
    'mod_data\\event\\field_created' => '/var/www/html/plantilla/mod/data/classes/event/field_created.php',
    'mod_data\\event\\field_deleted' => '/var/www/html/plantilla/mod/data/classes/event/field_deleted.php',
    'mod_data\\event\\field_updated' => '/var/www/html/plantilla/mod/data/classes/event/field_updated.php',
    'mod_data\\event\\record_created' => '/var/www/html/plantilla/mod/data/classes/event/record_created.php',
    'mod_data\\event\\record_deleted' => '/var/www/html/plantilla/mod/data/classes/event/record_deleted.php',
    'mod_data\\event\\record_updated' => '/var/www/html/plantilla/mod/data/classes/event/record_updated.php',
    'mod_data\\event\\template_updated' => '/var/www/html/plantilla/mod/data/classes/event/template_updated.php',
    'mod_data\\event\\template_viewed' => '/var/www/html/plantilla/mod/data/classes/event/template_viewed.php',
    'mod_data\\external' => '/var/www/html/plantilla/mod/data/classes/external.php',
    'mod_data\\external\\content_exporter' => '/var/www/html/plantilla/mod/data/classes/external/content_exporter.php',
    'mod_data\\external\\database_summary_exporter' => '/var/www/html/plantilla/mod/data/classes/external/database_summary_exporter.php',
    'mod_data\\external\\delete_saved_preset' => '/var/www/html/plantilla/mod/data/classes/external/delete_saved_preset.php',
    'mod_data\\external\\field_exporter' => '/var/www/html/plantilla/mod/data/classes/external/field_exporter.php',
    'mod_data\\external\\get_mapping_information' => '/var/www/html/plantilla/mod/data/classes/external/get_mapping_information.php',
    'mod_data\\external\\record_exporter' => '/var/www/html/plantilla/mod/data/classes/external/record_exporter.php',
    'mod_data\\form\\import_presets' => '/var/www/html/plantilla/mod/data/classes/form/import_presets.php',
    'mod_data\\form\\save_as_preset' => '/var/www/html/plantilla/mod/data/classes/form/save_as_preset.php',
    'mod_data\\local\\exporter\\csv_entries_exporter' => '/var/www/html/plantilla/mod/data/classes/local/exporter/csv_entries_exporter.php',
    'mod_data\\local\\exporter\\entries_exporter' => '/var/www/html/plantilla/mod/data/classes/local/exporter/entries_exporter.php',
    'mod_data\\local\\exporter\\ods_entries_exporter' => '/var/www/html/plantilla/mod/data/classes/local/exporter/ods_entries_exporter.php',
    'mod_data\\local\\exporter\\utils' => '/var/www/html/plantilla/mod/data/classes/local/exporter/utils.php',
    'mod_data\\local\\importer\\csv_entries_importer' => '/var/www/html/plantilla/mod/data/classes/local/importer/csv_entries_importer.php',
    'mod_data\\local\\importer\\entries_importer' => '/var/www/html/plantilla/mod/data/classes/local/importer/entries_importer.php',
    'mod_data\\local\\importer\\preset_existing_importer' => '/var/www/html/plantilla/mod/data/classes/local/importer/preset_existing_importer.php',
    'mod_data\\local\\importer\\preset_importer' => '/var/www/html/plantilla/mod/data/classes/local/importer/preset_importer.php',
    'mod_data\\local\\importer\\preset_upload_importer' => '/var/www/html/plantilla/mod/data/classes/local/importer/preset_upload_importer.php',
    'mod_data\\manager' => '/var/www/html/plantilla/mod/data/classes/manager.php',
    'mod_data\\output\\action_bar' => '/var/www/html/plantilla/mod/data/classes/output/action_bar.php',
    'mod_data\\output\\add_entries_action' => '/var/www/html/plantilla/mod/data/classes/output/add_entries_action.php',
    'mod_data\\output\\defaulttemplate' => '/var/www/html/plantilla/mod/data/classes/output/defaulttemplate.php',
    'mod_data\\output\\empty_database_action_bar' => '/var/www/html/plantilla/mod/data/classes/output/empty_database_action_bar.php',
    'mod_data\\output\\fields_action_bar' => '/var/www/html/plantilla/mod/data/classes/output/fields_action_bar.php',
    'mod_data\\output\\fields_mappings_action_bar' => '/var/www/html/plantilla/mod/data/classes/output/fields_mappings_action_bar.php',
    'mod_data\\output\\preset_preview' => '/var/www/html/plantilla/mod/data/classes/output/preset_preview.php',
    'mod_data\\output\\presets' => '/var/www/html/plantilla/mod/data/classes/output/presets.php',
    'mod_data\\output\\presets_action_bar' => '/var/www/html/plantilla/mod/data/classes/output/presets_action_bar.php',
    'mod_data\\output\\template_editor' => '/var/www/html/plantilla/mod/data/classes/output/template_editor.php',
    'mod_data\\output\\template_editor_tools' => '/var/www/html/plantilla/mod/data/classes/output/template_editor_tools.php',
    'mod_data\\output\\templates_action_bar' => '/var/www/html/plantilla/mod/data/classes/output/templates_action_bar.php',
    'mod_data\\output\\view_action_bar' => '/var/www/html/plantilla/mod/data/classes/output/view_action_bar.php',
    'mod_data\\output\\view_footer' => '/var/www/html/plantilla/mod/data/classes/output/view_footer.php',
    'mod_data\\output\\zero_state_action_bar' => '/var/www/html/plantilla/mod/data/classes/output/zero_state_action_bar.php',
    'mod_data\\plugininfo\\datafield' => '/var/www/html/plantilla/mod/data/classes/plugininfo/datafield.php',
    'mod_data\\plugininfo\\datapreset' => '/var/www/html/plantilla/mod/data/classes/plugininfo/datapreset.php',
    'mod_data\\preset' => '/var/www/html/plantilla/mod/data/classes/preset.php',
    'mod_data\\privacy\\datafield_provider' => '/var/www/html/plantilla/mod/data/classes/privacy/datafield_provider.php',
    'mod_data\\privacy\\provider' => '/var/www/html/plantilla/mod/data/classes/privacy/provider.php',
    'mod_data\\search\\activity' => '/var/www/html/plantilla/mod/data/classes/search/activity.php',
    'mod_data\\search\\entry' => '/var/www/html/plantilla/mod/data/classes/search/entry.php',
    'mod_data\\search\\sortedcontentqueue' => '/var/www/html/plantilla/mod/data/classes/search/sortedcontentqueue.php',
    'mod_data\\template' => '/var/www/html/plantilla/mod/data/classes/template.php',
    'mod_data_dates' => '/var/www/html/plantilla/mod/data/classes/dates.php',
    'mod_data_external' => '/var/www/html/plantilla/mod/data/classes/external.php',
    'mod_data_manager' => '/var/www/html/plantilla/mod/data/classes/manager.php',
    'mod_data_preset' => '/var/www/html/plantilla/mod/data/classes/preset.php',
    'mod_data_template' => '/var/www/html/plantilla/mod/data/classes/template.php',
    'mod_feedback\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/feedback/classes/analytics/indicator/activity_base.php',
    'mod_feedback\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/feedback/classes/analytics/indicator/cognitive_depth.php',
    'mod_feedback\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/feedback/classes/analytics/indicator/social_breadth.php',
    'mod_feedback\\complete_form' => '/var/www/html/plantilla/mod/feedback/classes/complete_form.php',
    'mod_feedback\\completion' => '/var/www/html/plantilla/mod/feedback/classes/completion.php',
    'mod_feedback\\completion\\custom_completion' => '/var/www/html/plantilla/mod/feedback/classes/completion/custom_completion.php',
    'mod_feedback\\course_map_form' => '/var/www/html/plantilla/mod/feedback/classes/course_map_form.php',
    'mod_feedback\\course_select_form' => '/var/www/html/plantilla/mod/feedback/classes/course_select_form.php',
    'mod_feedback\\courseformat\\overview' => '/var/www/html/plantilla/mod/feedback/classes/courseformat/overview.php',
    'mod_feedback\\dates' => '/var/www/html/plantilla/mod/feedback/classes/dates.php',
    'mod_feedback\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/feedback/classes/event/course_module_instance_list_viewed.php',
    'mod_feedback\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/feedback/classes/event/course_module_viewed.php',
    'mod_feedback\\event\\response_deleted' => '/var/www/html/plantilla/mod/feedback/classes/event/response_deleted.php',
    'mod_feedback\\event\\response_submitted' => '/var/www/html/plantilla/mod/feedback/classes/event/response_submitted.php',
    'mod_feedback\\external' => '/var/www/html/plantilla/mod/feedback/classes/external.php',
    'mod_feedback\\external\\feedback_completed_exporter' => '/var/www/html/plantilla/mod/feedback/classes/external/feedback_completed_exporter.php',
    'mod_feedback\\external\\feedback_completedtmp_exporter' => '/var/www/html/plantilla/mod/feedback/classes/external/feedback_completedtmp_exporter.php',
    'mod_feedback\\external\\feedback_item_exporter' => '/var/www/html/plantilla/mod/feedback/classes/external/feedback_item_exporter.php',
    'mod_feedback\\external\\feedback_summary_exporter' => '/var/www/html/plantilla/mod/feedback/classes/external/feedback_summary_exporter.php',
    'mod_feedback\\external\\feedback_value_exporter' => '/var/www/html/plantilla/mod/feedback/classes/external/feedback_value_exporter.php',
    'mod_feedback\\external\\feedback_valuetmp_exporter' => '/var/www/html/plantilla/mod/feedback/classes/external/feedback_valuetmp_exporter.php',
    'mod_feedback\\external\\questions\\reorder' => '/var/www/html/plantilla/mod/feedback/classes/external/questions/reorder.php',
    'mod_feedback\\form\\create_template_form' => '/var/www/html/plantilla/mod/feedback/classes/form/create_template_form.php',
    'mod_feedback\\form\\use_template_form' => '/var/www/html/plantilla/mod/feedback/classes/form/use_template_form.php',
    'mod_feedback\\manager' => '/var/www/html/plantilla/mod/feedback/classes/manager.php',
    'mod_feedback\\navigation\\views\\secondary' => '/var/www/html/plantilla/mod/feedback/classes/navigation/views/secondary.php',
    'mod_feedback\\observer' => '/var/www/html/plantilla/mod/feedback/classes/observer.php',
    'mod_feedback\\output\\base_action_bar' => '/var/www/html/plantilla/mod/feedback/classes/output/base_action_bar.php',
    'mod_feedback\\output\\edit_action_bar' => '/var/www/html/plantilla/mod/feedback/classes/output/edit_action_bar.php',
    'mod_feedback\\output\\edit_template_action_bar' => '/var/www/html/plantilla/mod/feedback/classes/output/edit_template_action_bar.php',
    'mod_feedback\\output\\renderer' => '/var/www/html/plantilla/mod/feedback/classes/output/renderer.php',
    'mod_feedback\\output\\responses_action_bar' => '/var/www/html/plantilla/mod/feedback/classes/output/responses_action_bar.php',
    'mod_feedback\\output\\standard_action_bar' => '/var/www/html/plantilla/mod/feedback/classes/output/standard_action_bar.php',
    'mod_feedback\\output\\summary' => '/var/www/html/plantilla/mod/feedback/classes/output/summary.php',
    'mod_feedback\\privacy\\provider' => '/var/www/html/plantilla/mod/feedback/classes/privacy/provider.php',
    'mod_feedback\\responses_anon_table' => '/var/www/html/plantilla/mod/feedback/classes/responses_anon_table.php',
    'mod_feedback\\responses_table' => '/var/www/html/plantilla/mod/feedback/classes/responses_table.php',
    'mod_feedback\\search\\activity' => '/var/www/html/plantilla/mod/feedback/classes/search/activity.php',
    'mod_feedback\\structure' => '/var/www/html/plantilla/mod/feedback/classes/structure.php',
    'mod_feedback\\templates_table' => '/var/www/html/plantilla/mod/feedback/classes/templates_table.php',
    'mod_feedback_complete_form' => '/var/www/html/plantilla/mod/feedback/classes/complete_form.php',
    'mod_feedback_completion' => '/var/www/html/plantilla/mod/feedback/classes/completion.php',
    'mod_feedback_course_map_form' => '/var/www/html/plantilla/mod/feedback/classes/course_map_form.php',
    'mod_feedback_course_select_form' => '/var/www/html/plantilla/mod/feedback/classes/course_select_form.php',
    'mod_feedback_dates' => '/var/www/html/plantilla/mod/feedback/classes/dates.php',
    'mod_feedback_external' => '/var/www/html/plantilla/mod/feedback/classes/external.php',
    'mod_feedback_manager' => '/var/www/html/plantilla/mod/feedback/classes/manager.php',
    'mod_feedback_observer' => '/var/www/html/plantilla/mod/feedback/classes/observer.php',
    'mod_feedback_responses_anon_table' => '/var/www/html/plantilla/mod/feedback/classes/responses_anon_table.php',
    'mod_feedback_responses_table' => '/var/www/html/plantilla/mod/feedback/classes/responses_table.php',
    'mod_feedback_structure' => '/var/www/html/plantilla/mod/feedback/classes/structure.php',
    'mod_feedback_templates_table' => '/var/www/html/plantilla/mod/feedback/classes/templates_table.php',
    'mod_folder\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/folder/classes/analytics/indicator/activity_base.php',
    'mod_folder\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/folder/classes/analytics/indicator/cognitive_depth.php',
    'mod_folder\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/folder/classes/analytics/indicator/social_breadth.php',
    'mod_folder\\completion\\custom_completion' => '/var/www/html/plantilla/mod/folder/classes/completion/custom_completion.php',
    'mod_folder\\content\\exporter' => '/var/www/html/plantilla/mod/folder/classes/content/exporter.php',
    'mod_folder\\event\\all_files_downloaded' => '/var/www/html/plantilla/mod/folder/classes/event/all_files_downloaded.php',
    'mod_folder\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/folder/classes/event/course_module_instance_list_viewed.php',
    'mod_folder\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/folder/classes/event/course_module_viewed.php',
    'mod_folder\\event\\folder_updated' => '/var/www/html/plantilla/mod/folder/classes/event/folder_updated.php',
    'mod_folder\\external' => '/var/www/html/plantilla/mod/folder/classes/external.php',
    'mod_folder\\privacy\\provider' => '/var/www/html/plantilla/mod/folder/classes/privacy/provider.php',
    'mod_folder\\search\\activity' => '/var/www/html/plantilla/mod/folder/classes/search/activity.php',
    'mod_folder_external' => '/var/www/html/plantilla/mod/folder/classes/external.php',
    'mod_forum\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/forum/classes/analytics/indicator/activity_base.php',
    'mod_forum\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/forum/classes/analytics/indicator/cognitive_depth.php',
    'mod_forum\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/forum/classes/analytics/indicator/social_breadth.php',
    'mod_forum\\completion\\custom_completion' => '/var/www/html/plantilla/mod/forum/classes/completion/custom_completion.php',
    'mod_forum\\dates' => '/var/www/html/plantilla/mod/forum/classes/dates.php',
    'mod_forum\\event\\assessable_uploaded' => '/var/www/html/plantilla/mod/forum/classes/event/assessable_uploaded.php',
    'mod_forum\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/forum/classes/event/course_module_instance_list_viewed.php',
    'mod_forum\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/forum/classes/event/course_module_viewed.php',
    'mod_forum\\event\\course_searched' => '/var/www/html/plantilla/mod/forum/classes/event/course_searched.php',
    'mod_forum\\event\\discussion_created' => '/var/www/html/plantilla/mod/forum/classes/event/discussion_created.php',
    'mod_forum\\event\\discussion_deleted' => '/var/www/html/plantilla/mod/forum/classes/event/discussion_deleted.php',
    'mod_forum\\event\\discussion_lock_updated' => '/var/www/html/plantilla/mod/forum/classes/event/discussion_lock_updated.php',
    'mod_forum\\event\\discussion_moved' => '/var/www/html/plantilla/mod/forum/classes/event/discussion_moved.php',
    'mod_forum\\event\\discussion_pinned' => '/var/www/html/plantilla/mod/forum/classes/event/discussion_pinned.php',
    'mod_forum\\event\\discussion_subscription_created' => '/var/www/html/plantilla/mod/forum/classes/event/discussion_subscription_created.php',
    'mod_forum\\event\\discussion_subscription_deleted' => '/var/www/html/plantilla/mod/forum/classes/event/discussion_subscription_deleted.php',
    'mod_forum\\event\\discussion_unpinned' => '/var/www/html/plantilla/mod/forum/classes/event/discussion_unpinned.php',
    'mod_forum\\event\\discussion_updated' => '/var/www/html/plantilla/mod/forum/classes/event/discussion_updated.php',
    'mod_forum\\event\\discussion_viewed' => '/var/www/html/plantilla/mod/forum/classes/event/discussion_viewed.php',
    'mod_forum\\event\\post_created' => '/var/www/html/plantilla/mod/forum/classes/event/post_created.php',
    'mod_forum\\event\\post_deleted' => '/var/www/html/plantilla/mod/forum/classes/event/post_deleted.php',
    'mod_forum\\event\\post_updated' => '/var/www/html/plantilla/mod/forum/classes/event/post_updated.php',
    'mod_forum\\event\\readtracking_disabled' => '/var/www/html/plantilla/mod/forum/classes/event/readtracking_disabled.php',
    'mod_forum\\event\\readtracking_enabled' => '/var/www/html/plantilla/mod/forum/classes/event/readtracking_enabled.php',
    'mod_forum\\event\\subscribers_viewed' => '/var/www/html/plantilla/mod/forum/classes/event/subscribers_viewed.php',
    'mod_forum\\event\\subscription_created' => '/var/www/html/plantilla/mod/forum/classes/event/subscription_created.php',
    'mod_forum\\event\\subscription_deleted' => '/var/www/html/plantilla/mod/forum/classes/event/subscription_deleted.php',
    'mod_forum\\event\\subscription_mode_updated' => '/var/www/html/plantilla/mod/forum/classes/event/subscription_mode_updated.php',
    'mod_forum\\event\\user_report_viewed' => '/var/www/html/plantilla/mod/forum/classes/event/user_report_viewed.php',
    'mod_forum\\existing_subscriber_selector' => '/var/www/html/plantilla/mod/forum/classes/existing_subscriber_selector.php',
    'mod_forum\\form\\export_form' => '/var/www/html/plantilla/mod/forum/classes/form/export_form.php',
    'mod_forum\\grades\\forum_gradeitem' => '/var/www/html/plantilla/mod/forum/classes/grades/forum_gradeitem.php',
    'mod_forum\\grades\\gradeitems' => '/var/www/html/plantilla/mod/forum/classes/grades/gradeitems.php',
    'mod_forum\\h5p\\canedit' => '/var/www/html/plantilla/mod/forum/classes/h5p/canedit.php',
    'mod_forum\\local\\builders\\exported_discussion' => '/var/www/html/plantilla/mod/forum/classes/local/builders/exported_discussion.php',
    'mod_forum\\local\\builders\\exported_discussion_summaries' => '/var/www/html/plantilla/mod/forum/classes/local/builders/exported_discussion_summaries.php',
    'mod_forum\\local\\builders\\exported_posts' => '/var/www/html/plantilla/mod/forum/classes/local/builders/exported_posts.php',
    'mod_forum\\local\\container' => '/var/www/html/plantilla/mod/forum/classes/local/container.php',
    'mod_forum\\local\\data_mappers\\legacy\\author' => '/var/www/html/plantilla/mod/forum/classes/local/data_mappers/legacy/author.php',
    'mod_forum\\local\\data_mappers\\legacy\\discussion' => '/var/www/html/plantilla/mod/forum/classes/local/data_mappers/legacy/discussion.php',
    'mod_forum\\local\\data_mappers\\legacy\\forum' => '/var/www/html/plantilla/mod/forum/classes/local/data_mappers/legacy/forum.php',
    'mod_forum\\local\\data_mappers\\legacy\\post' => '/var/www/html/plantilla/mod/forum/classes/local/data_mappers/legacy/post.php',
    'mod_forum\\local\\entities\\author' => '/var/www/html/plantilla/mod/forum/classes/local/entities/author.php',
    'mod_forum\\local\\entities\\discussion' => '/var/www/html/plantilla/mod/forum/classes/local/entities/discussion.php',
    'mod_forum\\local\\entities\\discussion_summary' => '/var/www/html/plantilla/mod/forum/classes/local/entities/discussion_summary.php',
    'mod_forum\\local\\entities\\forum' => '/var/www/html/plantilla/mod/forum/classes/local/entities/forum.php',
    'mod_forum\\local\\entities\\post' => '/var/www/html/plantilla/mod/forum/classes/local/entities/post.php',
    'mod_forum\\local\\entities\\post_read_receipt_collection' => '/var/www/html/plantilla/mod/forum/classes/local/entities/post_read_receipt_collection.php',
    'mod_forum\\local\\entities\\sorter' => '/var/www/html/plantilla/mod/forum/classes/local/entities/sorter.php',
    'mod_forum\\local\\exporters\\author' => '/var/www/html/plantilla/mod/forum/classes/local/exporters/author.php',
    'mod_forum\\local\\exporters\\discussion' => '/var/www/html/plantilla/mod/forum/classes/local/exporters/discussion.php',
    'mod_forum\\local\\exporters\\discussion_summaries' => '/var/www/html/plantilla/mod/forum/classes/local/exporters/discussion_summaries.php',
    'mod_forum\\local\\exporters\\discussion_summary' => '/var/www/html/plantilla/mod/forum/classes/local/exporters/discussion_summary.php',
    'mod_forum\\local\\exporters\\forum' => '/var/www/html/plantilla/mod/forum/classes/local/exporters/forum.php',
    'mod_forum\\local\\exporters\\group' => '/var/www/html/plantilla/mod/forum/classes/local/exporters/group.php',
    'mod_forum\\local\\exporters\\post' => '/var/www/html/plantilla/mod/forum/classes/local/exporters/post.php',
    'mod_forum\\local\\exporters\\posts' => '/var/www/html/plantilla/mod/forum/classes/local/exporters/posts.php',
    'mod_forum\\local\\factories\\builder' => '/var/www/html/plantilla/mod/forum/classes/local/factories/builder.php',
    'mod_forum\\local\\factories\\entity' => '/var/www/html/plantilla/mod/forum/classes/local/factories/entity.php',
    'mod_forum\\local\\factories\\exporter' => '/var/www/html/plantilla/mod/forum/classes/local/factories/exporter.php',
    'mod_forum\\local\\factories\\legacy_data_mapper' => '/var/www/html/plantilla/mod/forum/classes/local/factories/legacy_data_mapper.php',
    'mod_forum\\local\\factories\\manager' => '/var/www/html/plantilla/mod/forum/classes/local/factories/manager.php',
    'mod_forum\\local\\factories\\renderer' => '/var/www/html/plantilla/mod/forum/classes/local/factories/renderer.php',
    'mod_forum\\local\\factories\\url' => '/var/www/html/plantilla/mod/forum/classes/local/factories/url.php',
    'mod_forum\\local\\factories\\vault' => '/var/www/html/plantilla/mod/forum/classes/local/factories/vault.php',
    'mod_forum\\local\\managers\\capability' => '/var/www/html/plantilla/mod/forum/classes/local/managers/capability.php',
    'mod_forum\\local\\renderers\\discussion' => '/var/www/html/plantilla/mod/forum/classes/local/renderers/discussion.php',
    'mod_forum\\local\\renderers\\discussion_list' => '/var/www/html/plantilla/mod/forum/classes/local/renderers/discussion_list.php',
    'mod_forum\\local\\renderers\\posts' => '/var/www/html/plantilla/mod/forum/classes/local/renderers/posts.php',
    'mod_forum\\local\\vaults\\author' => '/var/www/html/plantilla/mod/forum/classes/local/vaults/author.php',
    'mod_forum\\local\\vaults\\db_table_vault' => '/var/www/html/plantilla/mod/forum/classes/local/vaults/db_table_vault.php',
    'mod_forum\\local\\vaults\\discussion' => '/var/www/html/plantilla/mod/forum/classes/local/vaults/discussion.php',
    'mod_forum\\local\\vaults\\discussion_list' => '/var/www/html/plantilla/mod/forum/classes/local/vaults/discussion_list.php',
    'mod_forum\\local\\vaults\\forum' => '/var/www/html/plantilla/mod/forum/classes/local/vaults/forum.php',
    'mod_forum\\local\\vaults\\post' => '/var/www/html/plantilla/mod/forum/classes/local/vaults/post.php',
    'mod_forum\\local\\vaults\\post_attachment' => '/var/www/html/plantilla/mod/forum/classes/local/vaults/post_attachment.php',
    'mod_forum\\local\\vaults\\post_read_receipt_collection' => '/var/www/html/plantilla/mod/forum/classes/local/vaults/post_read_receipt_collection.php',
    'mod_forum\\local\\vaults\\preprocessors\\extract_context' => '/var/www/html/plantilla/mod/forum/classes/local/vaults/preprocessors/extract_context.php',
    'mod_forum\\local\\vaults\\preprocessors\\extract_record' => '/var/www/html/plantilla/mod/forum/classes/local/vaults/preprocessors/extract_record.php',
    'mod_forum\\local\\vaults\\preprocessors\\extract_user' => '/var/www/html/plantilla/mod/forum/classes/local/vaults/preprocessors/extract_user.php',
    'mod_forum\\message\\inbound\\reply_handler' => '/var/www/html/plantilla/mod/forum/classes/message/inbound/reply_handler.php',
    'mod_forum\\observer' => '/var/www/html/plantilla/mod/forum/classes/observer.php',
    'mod_forum\\output\\big_search_form' => '/var/www/html/plantilla/mod/forum/classes/output/big_search_form.php',
    'mod_forum\\output\\courseformat\\activitybadge' => '/var/www/html/plantilla/mod/forum/classes/output/courseformat/activitybadge.php',
    'mod_forum\\output\\email\\renderer' => '/var/www/html/plantilla/mod/forum/classes/output/email/renderer.php',
    'mod_forum\\output\\email\\renderer_textemail' => '/var/www/html/plantilla/mod/forum/classes/output/email/renderer_textemail.php',
    'mod_forum\\output\\emaildigestbasic\\renderer' => '/var/www/html/plantilla/mod/forum/classes/output/emaildigestbasic/renderer.php',
    'mod_forum\\output\\emaildigestbasic\\renderer_textemail' => '/var/www/html/plantilla/mod/forum/classes/output/emaildigestbasic/renderer_textemail.php',
    'mod_forum\\output\\emaildigestfull\\renderer' => '/var/www/html/plantilla/mod/forum/classes/output/emaildigestfull/renderer.php',
    'mod_forum\\output\\emaildigestfull\\renderer_textemail' => '/var/www/html/plantilla/mod/forum/classes/output/emaildigestfull/renderer_textemail.php',
    'mod_forum\\output\\forum_actionbar' => '/var/www/html/plantilla/mod/forum/classes/output/forum_actionbar.php',
    'mod_forum\\output\\forum_post' => '/var/www/html/plantilla/mod/forum/classes/output/forum_post.php',
    'mod_forum\\output\\forum_post_email' => '/var/www/html/plantilla/mod/forum/classes/output/forum_post_email.php',
    'mod_forum\\output\\quick_search_form' => '/var/www/html/plantilla/mod/forum/classes/output/quick_search_form.php',
    'mod_forum\\output\\subscription_actionbar' => '/var/www/html/plantilla/mod/forum/classes/output/subscription_actionbar.php',
    'mod_forum\\plugininfo\\forumreport' => '/var/www/html/plantilla/mod/forum/classes/plugininfo/forumreport.php',
    'mod_forum\\post_form' => '/var/www/html/plantilla/mod/forum/classes/post_form.php',
    'mod_forum\\potential_subscriber_selector' => '/var/www/html/plantilla/mod/forum/classes/potential_subscriber_selector.php',
    'mod_forum\\privacy\\provider' => '/var/www/html/plantilla/mod/forum/classes/privacy/provider.php',
    'mod_forum\\privacy\\subcontext_info' => '/var/www/html/plantilla/mod/forum/classes/privacy/subcontext_info.php',
    'mod_forum\\prune_form' => '/var/www/html/plantilla/mod/forum/classes/prune_form.php',
    'mod_forum\\search\\activity' => '/var/www/html/plantilla/mod/forum/classes/search/activity.php',
    'mod_forum\\search\\post' => '/var/www/html/plantilla/mod/forum/classes/search/post.php',
    'mod_forum\\subscriber_selector_base' => '/var/www/html/plantilla/mod/forum/classes/subscriber_selector_base.php',
    'mod_forum\\subscriptions' => '/var/www/html/plantilla/mod/forum/classes/subscriptions.php',
    'mod_forum\\task\\cron_task' => '/var/www/html/plantilla/mod/forum/classes/task/cron_task.php',
    'mod_forum\\task\\send_user_digests' => '/var/www/html/plantilla/mod/forum/classes/task/send_user_digests.php',
    'mod_forum\\task\\send_user_notifications' => '/var/www/html/plantilla/mod/forum/classes/task/send_user_notifications.php',
    'mod_forum_dates' => '/var/www/html/plantilla/mod/forum/classes/dates.php',
    'mod_forum_existing_subscriber_selector' => '/var/www/html/plantilla/mod/forum/classes/existing_subscriber_selector.php',
    'mod_forum_observer' => '/var/www/html/plantilla/mod/forum/classes/observer.php',
    'mod_forum_post_form' => '/var/www/html/plantilla/mod/forum/classes/post_form.php',
    'mod_forum_potential_subscriber_selector' => '/var/www/html/plantilla/mod/forum/classes/potential_subscriber_selector.php',
    'mod_forum_prune_form' => '/var/www/html/plantilla/mod/forum/classes/prune_form.php',
    'mod_forum_subscriber_selector_base' => '/var/www/html/plantilla/mod/forum/classes/subscriber_selector_base.php',
    'mod_forum_subscriptions' => '/var/www/html/plantilla/mod/forum/classes/subscriptions.php',
    'mod_game\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/game/classes/event/course_module_instance_list_viewed.php',
    'mod_game\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/game/classes/event/course_module_viewed.php',
    'mod_game\\event\\game_played' => '/var/www/html/plantilla/mod/game/classes/event/game_played.php',
    'mod_game\\plugininfo\\game' => '/var/www/html/plantilla/mod/game/classes/plugininfo/game.php',
    'mod_game\\plugininfo\\gametool' => '/var/www/html/plantilla/mod/game/classes/plugininfo/gametool.php',
    'mod_game\\privacy\\gameaccess_provider' => '/var/www/html/plantilla/mod/game/classes/privacy/gameaccess_provider.php',
    'mod_game\\privacy\\helper' => '/var/www/html/plantilla/mod/game/classes/privacy/helper.php',
    'mod_game\\privacy\\legacy_gameaccess_polyfill' => '/var/www/html/plantilla/mod/game/classes/privacy/legacy_gameaccess_polyfill.php',
    'mod_game\\privacy\\provider' => '/var/www/html/plantilla/mod/game/classes/privacy/provider.php',
    'mod_glossary\\admin_setting_display_formats' => '/var/www/html/plantilla/mod/glossary/classes/admin_setting_display_formats.php',
    'mod_glossary\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/glossary/classes/analytics/indicator/activity_base.php',
    'mod_glossary\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/glossary/classes/analytics/indicator/cognitive_depth.php',
    'mod_glossary\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/glossary/classes/analytics/indicator/social_breadth.php',
    'mod_glossary\\completion\\custom_completion' => '/var/www/html/plantilla/mod/glossary/classes/completion/custom_completion.php',
    'mod_glossary\\entry_query_builder' => '/var/www/html/plantilla/mod/glossary/classes/entry_query_builder.php',
    'mod_glossary\\event\\category_created' => '/var/www/html/plantilla/mod/glossary/classes/event/category_created.php',
    'mod_glossary\\event\\category_deleted' => '/var/www/html/plantilla/mod/glossary/classes/event/category_deleted.php',
    'mod_glossary\\event\\category_updated' => '/var/www/html/plantilla/mod/glossary/classes/event/category_updated.php',
    'mod_glossary\\event\\comment_created' => '/var/www/html/plantilla/mod/glossary/classes/event/comment_created.php',
    'mod_glossary\\event\\comment_deleted' => '/var/www/html/plantilla/mod/glossary/classes/event/comment_deleted.php',
    'mod_glossary\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/glossary/classes/event/course_module_instance_list_viewed.php',
    'mod_glossary\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/glossary/classes/event/course_module_viewed.php',
    'mod_glossary\\event\\entry_approved' => '/var/www/html/plantilla/mod/glossary/classes/event/entry_approved.php',
    'mod_glossary\\event\\entry_created' => '/var/www/html/plantilla/mod/glossary/classes/event/entry_created.php',
    'mod_glossary\\event\\entry_deleted' => '/var/www/html/plantilla/mod/glossary/classes/event/entry_deleted.php',
    'mod_glossary\\event\\entry_disapproved' => '/var/www/html/plantilla/mod/glossary/classes/event/entry_disapproved.php',
    'mod_glossary\\event\\entry_updated' => '/var/www/html/plantilla/mod/glossary/classes/event/entry_updated.php',
    'mod_glossary\\event\\entry_viewed' => '/var/www/html/plantilla/mod/glossary/classes/event/entry_viewed.php',
    'mod_glossary\\external' => '/var/www/html/plantilla/mod/glossary/classes/external.php',
    'mod_glossary\\external\\delete_entry' => '/var/www/html/plantilla/mod/glossary/classes/external/delete_entry.php',
    'mod_glossary\\external\\prepare_entry' => '/var/www/html/plantilla/mod/glossary/classes/external/prepare_entry.php',
    'mod_glossary\\external\\update_entry' => '/var/www/html/plantilla/mod/glossary/classes/external/update_entry.php',
    'mod_glossary\\local\\concept_cache' => '/var/www/html/plantilla/mod/glossary/classes/local/concept_cache.php',
    'mod_glossary\\navigation\\views\\secondary' => '/var/www/html/plantilla/mod/glossary/classes/navigation/views/secondary.php',
    'mod_glossary\\output\\renderer' => '/var/www/html/plantilla/mod/glossary/classes/output/renderer.php',
    'mod_glossary\\output\\standard_action_bar' => '/var/www/html/plantilla/mod/glossary/classes/output/standard_action_bar.php',
    'mod_glossary\\privacy\\provider' => '/var/www/html/plantilla/mod/glossary/classes/privacy/provider.php',
    'mod_glossary\\search\\activity' => '/var/www/html/plantilla/mod/glossary/classes/search/activity.php',
    'mod_glossary\\search\\entry' => '/var/www/html/plantilla/mod/glossary/classes/search/entry.php',
    'mod_glossary_admin_setting_display_formats' => '/var/www/html/plantilla/mod/glossary/classes/admin_setting_display_formats.php',
    'mod_glossary_entry_query_builder' => '/var/www/html/plantilla/mod/glossary/classes/entry_query_builder.php',
    'mod_glossary_external' => '/var/www/html/plantilla/mod/glossary/classes/external.php',
    'mod_h5pactivity\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/h5pactivity/classes/event/course_module_instance_list_viewed.php',
    'mod_h5pactivity\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/h5pactivity/classes/event/course_module_viewed.php',
    'mod_h5pactivity\\event\\report_viewed' => '/var/www/html/plantilla/mod/h5pactivity/classes/event/report_viewed.php',
    'mod_h5pactivity\\event\\statement_received' => '/var/www/html/plantilla/mod/h5pactivity/classes/event/statement_received.php',
    'mod_h5pactivity\\external\\get_attempts' => '/var/www/html/plantilla/mod/h5pactivity/classes/external/get_attempts.php',
    'mod_h5pactivity\\external\\get_h5pactivities_by_courses' => '/var/www/html/plantilla/mod/h5pactivity/classes/external/get_h5pactivities_by_courses.php',
    'mod_h5pactivity\\external\\get_h5pactivity_access_information' => '/var/www/html/plantilla/mod/h5pactivity/classes/external/get_h5pactivity_access_information.php',
    'mod_h5pactivity\\external\\get_results' => '/var/www/html/plantilla/mod/h5pactivity/classes/external/get_results.php',
    'mod_h5pactivity\\external\\get_user_attempts' => '/var/www/html/plantilla/mod/h5pactivity/classes/external/get_user_attempts.php',
    'mod_h5pactivity\\external\\h5pactivity_summary_exporter' => '/var/www/html/plantilla/mod/h5pactivity/classes/external/h5pactivity_summary_exporter.php',
    'mod_h5pactivity\\external\\log_report_viewed' => '/var/www/html/plantilla/mod/h5pactivity/classes/external/log_report_viewed.php',
    'mod_h5pactivity\\external\\view_h5pactivity' => '/var/www/html/plantilla/mod/h5pactivity/classes/external/view_h5pactivity.php',
    'mod_h5pactivity\\local\\attempt' => '/var/www/html/plantilla/mod/h5pactivity/classes/local/attempt.php',
    'mod_h5pactivity\\local\\grader' => '/var/www/html/plantilla/mod/h5pactivity/classes/local/grader.php',
    'mod_h5pactivity\\local\\manager' => '/var/www/html/plantilla/mod/h5pactivity/classes/local/manager.php',
    'mod_h5pactivity\\local\\report' => '/var/www/html/plantilla/mod/h5pactivity/classes/local/report.php',
    'mod_h5pactivity\\local\\report\\attempts' => '/var/www/html/plantilla/mod/h5pactivity/classes/local/report/attempts.php',
    'mod_h5pactivity\\local\\report\\participants' => '/var/www/html/plantilla/mod/h5pactivity/classes/local/report/participants.php',
    'mod_h5pactivity\\local\\report\\results' => '/var/www/html/plantilla/mod/h5pactivity/classes/local/report/results.php',
    'mod_h5pactivity\\output\\attempt' => '/var/www/html/plantilla/mod/h5pactivity/classes/output/attempt.php',
    'mod_h5pactivity\\output\\reportattempts' => '/var/www/html/plantilla/mod/h5pactivity/classes/output/reportattempts.php',
    'mod_h5pactivity\\output\\reportlink' => '/var/www/html/plantilla/mod/h5pactivity/classes/output/reportlink.php',
    'mod_h5pactivity\\output\\reportresults' => '/var/www/html/plantilla/mod/h5pactivity/classes/output/reportresults.php',
    'mod_h5pactivity\\output\\result' => '/var/www/html/plantilla/mod/h5pactivity/classes/output/result.php',
    'mod_h5pactivity\\output\\result\\choice' => '/var/www/html/plantilla/mod/h5pactivity/classes/output/result/choice.php',
    'mod_h5pactivity\\output\\result\\fillin' => '/var/www/html/plantilla/mod/h5pactivity/classes/output/result/fillin.php',
    'mod_h5pactivity\\output\\result\\longfillin' => '/var/www/html/plantilla/mod/h5pactivity/classes/output/result/longfillin.php',
    'mod_h5pactivity\\output\\result\\matching' => '/var/www/html/plantilla/mod/h5pactivity/classes/output/result/matching.php',
    'mod_h5pactivity\\output\\result\\other' => '/var/www/html/plantilla/mod/h5pactivity/classes/output/result/other.php',
    'mod_h5pactivity\\output\\result\\sequencing' => '/var/www/html/plantilla/mod/h5pactivity/classes/output/result/sequencing.php',
    'mod_h5pactivity\\output\\result\\truefalse' => '/var/www/html/plantilla/mod/h5pactivity/classes/output/result/truefalse.php',
    'mod_h5pactivity\\privacy\\provider' => '/var/www/html/plantilla/mod/h5pactivity/classes/privacy/provider.php',
    'mod_h5pactivity\\search\\activity' => '/var/www/html/plantilla/mod/h5pactivity/classes/search/activity.php',
    'mod_h5pactivity\\xapi\\handler' => '/var/www/html/plantilla/mod/h5pactivity/classes/xapi/handler.php',
    'mod_hvp\\admin_setting_html' => '/var/www/html/plantilla/mod/hvp/classes/admin_setting_html.php',
    'mod_hvp\\content_hub_service' => '/var/www/html/plantilla/mod/hvp/classes/content_hub_service.php',
    'mod_hvp\\content_type_cache_form' => '/var/www/html/plantilla/mod/hvp/classes/content_type_cache_form.php',
    'mod_hvp\\content_user_data' => '/var/www/html/plantilla/mod/hvp/classes/content_user_data.php',
    'mod_hvp\\curl' => '/var/www/html/plantilla/mod/hvp/classes/curl.php',
    'mod_hvp\\editor_ajax' => '/var/www/html/plantilla/mod/hvp/classes/editor_ajax.php',
    'mod_hvp\\editor_framework' => '/var/www/html/plantilla/mod/hvp/classes/editor_framework.php',
    'mod_hvp\\event' => '/var/www/html/plantilla/mod/hvp/classes/event.php',
    'mod_hvp\\event\\attempt_submitted' => '/var/www/html/plantilla/mod/hvp/classes/event/attempt_submitted.php',
    'mod_hvp\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/hvp/classes/event/course_module_instance_list_viewed.php',
    'mod_hvp\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/hvp/classes/event/course_module_viewed.php',
    'mod_hvp\\file_storage' => '/var/www/html/plantilla/mod/hvp/classes/file_storage.php',
    'mod_hvp\\framework' => '/var/www/html/plantilla/mod/hvp/classes/framework.php',
    'mod_hvp\\mobile_auth' => '/var/www/html/plantilla/mod/hvp/classes/mobile_auth.php',
    'mod_hvp\\output\\mobile' => '/var/www/html/plantilla/mod/hvp/classes/output/mobile.php',
    'mod_hvp\\privacy\\provider' => '/var/www/html/plantilla/mod/hvp/classes/privacy/provider.php',
    'mod_hvp\\results' => '/var/www/html/plantilla/mod/hvp/classes/results.php',
    'mod_hvp\\task\\look_for_updates' => '/var/www/html/plantilla/mod/hvp/classes/task/look_for_updates.php',
    'mod_hvp\\task\\remove_old_auth_tokens' => '/var/www/html/plantilla/mod/hvp/classes/task/remove_old_auth_tokens.php',
    'mod_hvp\\task\\remove_old_log_entries' => '/var/www/html/plantilla/mod/hvp/classes/task/remove_old_log_entries.php',
    'mod_hvp\\task\\remove_tmpfiles' => '/var/www/html/plantilla/mod/hvp/classes/task/remove_tmpfiles.php',
    'mod_hvp\\upload_libraries_form' => '/var/www/html/plantilla/mod/hvp/classes/upload_libraries_form.php',
    'mod_hvp\\user_grades' => '/var/www/html/plantilla/mod/hvp/classes/user_grades.php',
    'mod_hvp\\view_assets' => '/var/www/html/plantilla/mod/hvp/classes/view_assets.php',
    'mod_hvp\\xapi_result' => '/var/www/html/plantilla/mod/hvp/classes/xapi_result.php',
    'mod_hvp_admin_setting_html' => '/var/www/html/plantilla/mod/hvp/classes/admin_setting_html.php',
    'mod_hvp_content_hub_service' => '/var/www/html/plantilla/mod/hvp/classes/content_hub_service.php',
    'mod_hvp_content_type_cache_form' => '/var/www/html/plantilla/mod/hvp/classes/content_type_cache_form.php',
    'mod_hvp_content_user_data' => '/var/www/html/plantilla/mod/hvp/classes/content_user_data.php',
    'mod_hvp_curl' => '/var/www/html/plantilla/mod/hvp/classes/curl.php',
    'mod_hvp_editor_ajax' => '/var/www/html/plantilla/mod/hvp/classes/editor_ajax.php',
    'mod_hvp_editor_framework' => '/var/www/html/plantilla/mod/hvp/classes/editor_framework.php',
    'mod_hvp_event' => '/var/www/html/plantilla/mod/hvp/classes/event.php',
    'mod_hvp_file_storage' => '/var/www/html/plantilla/mod/hvp/classes/file_storage.php',
    'mod_hvp_framework' => '/var/www/html/plantilla/mod/hvp/classes/framework.php',
    'mod_hvp_mobile_auth' => '/var/www/html/plantilla/mod/hvp/classes/mobile_auth.php',
    'mod_hvp_results' => '/var/www/html/plantilla/mod/hvp/classes/results.php',
    'mod_hvp_upload_libraries_form' => '/var/www/html/plantilla/mod/hvp/classes/upload_libraries_form.php',
    'mod_hvp_user_grades' => '/var/www/html/plantilla/mod/hvp/classes/user_grades.php',
    'mod_hvp_view_assets' => '/var/www/html/plantilla/mod/hvp/classes/view_assets.php',
    'mod_hvp_xapi_result' => '/var/www/html/plantilla/mod/hvp/classes/xapi_result.php',
    'mod_imscp\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/imscp/classes/analytics/indicator/activity_base.php',
    'mod_imscp\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/imscp/classes/analytics/indicator/cognitive_depth.php',
    'mod_imscp\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/imscp/classes/analytics/indicator/social_breadth.php',
    'mod_imscp\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/imscp/classes/event/course_module_instance_list_viewed.php',
    'mod_imscp\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/imscp/classes/event/course_module_viewed.php',
    'mod_imscp\\external' => '/var/www/html/plantilla/mod/imscp/classes/external.php',
    'mod_imscp\\privacy\\provider' => '/var/www/html/plantilla/mod/imscp/classes/privacy/provider.php',
    'mod_imscp\\search\\activity' => '/var/www/html/plantilla/mod/imscp/classes/search/activity.php',
    'mod_imscp_external' => '/var/www/html/plantilla/mod/imscp/classes/external.php',
    'mod_label\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/label/classes/analytics/indicator/activity_base.php',
    'mod_label\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/label/classes/analytics/indicator/cognitive_depth.php',
    'mod_label\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/label/classes/analytics/indicator/social_breadth.php',
    'mod_label\\completion\\custom_completion' => '/var/www/html/plantilla/mod/label/classes/completion/custom_completion.php',
    'mod_label\\external' => '/var/www/html/plantilla/mod/label/classes/external.php',
    'mod_label\\navigation\\views\\secondary' => '/var/www/html/plantilla/mod/label/classes/navigation/views/secondary.php',
    'mod_label\\privacy\\provider' => '/var/www/html/plantilla/mod/label/classes/privacy/provider.php',
    'mod_label\\search\\activity' => '/var/www/html/plantilla/mod/label/classes/search/activity.php',
    'mod_label_external' => '/var/www/html/plantilla/mod/label/classes/external.php',
    'mod_lesson\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/lesson/classes/analytics/indicator/activity_base.php',
    'mod_lesson\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/lesson/classes/analytics/indicator/cognitive_depth.php',
    'mod_lesson\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/lesson/classes/analytics/indicator/social_breadth.php',
    'mod_lesson\\cache\\overrides' => '/var/www/html/plantilla/mod/lesson/classes/cache/overrides.php',
    'mod_lesson\\completion\\custom_completion' => '/var/www/html/plantilla/mod/lesson/classes/completion/custom_completion.php',
    'mod_lesson\\dates' => '/var/www/html/plantilla/mod/lesson/classes/dates.php',
    'mod_lesson\\event\\content_page_viewed' => '/var/www/html/plantilla/mod/lesson/classes/event/content_page_viewed.php',
    'mod_lesson\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/lesson/classes/event/course_module_instance_list_viewed.php',
    'mod_lesson\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/lesson/classes/event/course_module_viewed.php',
    'mod_lesson\\event\\essay_assessed' => '/var/www/html/plantilla/mod/lesson/classes/event/essay_assessed.php',
    'mod_lesson\\event\\essay_attempt_viewed' => '/var/www/html/plantilla/mod/lesson/classes/event/essay_attempt_viewed.php',
    'mod_lesson\\event\\group_override_created' => '/var/www/html/plantilla/mod/lesson/classes/event/group_override_created.php',
    'mod_lesson\\event\\group_override_deleted' => '/var/www/html/plantilla/mod/lesson/classes/event/group_override_deleted.php',
    'mod_lesson\\event\\group_override_updated' => '/var/www/html/plantilla/mod/lesson/classes/event/group_override_updated.php',
    'mod_lesson\\event\\highscore_added' => '/var/www/html/plantilla/mod/lesson/classes/event/highscore_added.php',
    'mod_lesson\\event\\highscores_viewed' => '/var/www/html/plantilla/mod/lesson/classes/event/highscores_viewed.php',
    'mod_lesson\\event\\lesson_ended' => '/var/www/html/plantilla/mod/lesson/classes/event/lesson_ended.php',
    'mod_lesson\\event\\lesson_restarted' => '/var/www/html/plantilla/mod/lesson/classes/event/lesson_restarted.php',
    'mod_lesson\\event\\lesson_resumed' => '/var/www/html/plantilla/mod/lesson/classes/event/lesson_resumed.php',
    'mod_lesson\\event\\lesson_started' => '/var/www/html/plantilla/mod/lesson/classes/event/lesson_started.php',
    'mod_lesson\\event\\page_created' => '/var/www/html/plantilla/mod/lesson/classes/event/page_created.php',
    'mod_lesson\\event\\page_deleted' => '/var/www/html/plantilla/mod/lesson/classes/event/page_deleted.php',
    'mod_lesson\\event\\page_moved' => '/var/www/html/plantilla/mod/lesson/classes/event/page_moved.php',
    'mod_lesson\\event\\page_updated' => '/var/www/html/plantilla/mod/lesson/classes/event/page_updated.php',
    'mod_lesson\\event\\question_answered' => '/var/www/html/plantilla/mod/lesson/classes/event/question_answered.php',
    'mod_lesson\\event\\question_viewed' => '/var/www/html/plantilla/mod/lesson/classes/event/question_viewed.php',
    'mod_lesson\\event\\user_override_created' => '/var/www/html/plantilla/mod/lesson/classes/event/user_override_created.php',
    'mod_lesson\\event\\user_override_deleted' => '/var/www/html/plantilla/mod/lesson/classes/event/user_override_deleted.php',
    'mod_lesson\\event\\user_override_updated' => '/var/www/html/plantilla/mod/lesson/classes/event/user_override_updated.php',
    'mod_lesson\\external' => '/var/www/html/plantilla/mod/lesson/classes/external.php',
    'mod_lesson\\external\\lesson_summary_exporter' => '/var/www/html/plantilla/mod/lesson/classes/external/lesson_summary_exporter.php',
    'mod_lesson\\file_info' => '/var/www/html/plantilla/mod/lesson/classes/file_info.php',
    'mod_lesson\\group_observers' => '/var/www/html/plantilla/mod/lesson/classes/group_observers.php',
    'mod_lesson\\local\\numeric\\helper' => '/var/www/html/plantilla/mod/lesson/classes/local/numeric/helper.php',
    'mod_lesson\\output\\edit_action_area' => '/var/www/html/plantilla/mod/lesson/classes/output/edit_action_area.php',
    'mod_lesson\\output\\edit_action_buttons' => '/var/www/html/plantilla/mod/lesson/classes/output/edit_action_buttons.php',
    'mod_lesson\\output\\override_action_menu' => '/var/www/html/plantilla/mod/lesson/classes/output/override_action_menu.php',
    'mod_lesson\\output\\report_action_menu' => '/var/www/html/plantilla/mod/lesson/classes/output/report_action_menu.php',
    'mod_lesson\\privacy\\provider' => '/var/www/html/plantilla/mod/lesson/classes/privacy/provider.php',
    'mod_lesson\\search\\activity' => '/var/www/html/plantilla/mod/lesson/classes/search/activity.php',
    'mod_lesson_dates' => '/var/www/html/plantilla/mod/lesson/classes/dates.php',
    'mod_lesson_external' => '/var/www/html/plantilla/mod/lesson/classes/external.php',
    'mod_lesson_file_info' => '/var/www/html/plantilla/mod/lesson/classes/file_info.php',
    'mod_lesson_group_observers' => '/var/www/html/plantilla/mod/lesson/classes/group_observers.php',
    'mod_lti\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/lti/classes/analytics/indicator/activity_base.php',
    'mod_lti\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/lti/classes/analytics/indicator/cognitive_depth.php',
    'mod_lti\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/lti/classes/analytics/indicator/social_breadth.php',
    'mod_lti\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/lti/classes/event/course_module_instance_list_viewed.php',
    'mod_lti\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/lti/classes/event/course_module_viewed.php',
    'mod_lti\\event\\unknown_service_api_called' => '/var/www/html/plantilla/mod/lti/classes/event/unknown_service_api_called.php',
    'mod_lti\\external' => '/var/www/html/plantilla/mod/lti/classes/external.php',
    'mod_lti\\external\\delete_course_tool_type' => '/var/www/html/plantilla/mod/lti/classes/external/delete_course_tool_type.php',
    'mod_lti\\external\\get_tool_types_and_proxies' => '/var/www/html/plantilla/mod/lti/classes/external/get_tool_types_and_proxies.php',
    'mod_lti\\external\\get_tool_types_and_proxies_count' => '/var/www/html/plantilla/mod/lti/classes/external/get_tool_types_and_proxies_count.php',
    'mod_lti\\external\\toggle_showinactivitychooser' => '/var/www/html/plantilla/mod/lti/classes/external/toggle_showinactivitychooser.php',
    'mod_lti\\helper' => '/var/www/html/plantilla/mod/lti/classes/helper.php',
    'mod_lti\\local\\ltiopenid\\jwks_helper' => '/var/www/html/plantilla/mod/lti/classes/local/ltiopenid/jwks_helper.php',
    'mod_lti\\local\\ltiopenid\\registration_exception' => '/var/www/html/plantilla/mod/lti/classes/local/ltiopenid/registration_exception.php',
    'mod_lti\\local\\ltiopenid\\registration_helper' => '/var/www/html/plantilla/mod/lti/classes/local/ltiopenid/registration_helper.php',
    'mod_lti\\local\\ltiservice\\resource_base' => '/var/www/html/plantilla/mod/lti/classes/local/ltiservice/resource_base.php',
    'mod_lti\\local\\ltiservice\\response' => '/var/www/html/plantilla/mod/lti/classes/local/ltiservice/response.php',
    'mod_lti\\local\\ltiservice\\service_base' => '/var/www/html/plantilla/mod/lti/classes/local/ltiservice/service_base.php',
    'mod_lti\\local\\types_helper' => '/var/www/html/plantilla/mod/lti/classes/local/types_helper.php',
    'mod_lti\\output\\course_tools_page' => '/var/www/html/plantilla/mod/lti/classes/output/course_tools_page.php',
    'mod_lti\\output\\course_tools_page_header' => '/var/www/html/plantilla/mod/lti/classes/output/course_tools_page_header.php',
    'mod_lti\\output\\external_registration_return_page' => '/var/www/html/plantilla/mod/lti/classes/output/external_registration_return_page.php',
    'mod_lti\\output\\registration_upgrade_choice_page' => '/var/www/html/plantilla/mod/lti/classes/output/registration_upgrade_choice_page.php',
    'mod_lti\\output\\renderer' => '/var/www/html/plantilla/mod/lti/classes/output/renderer.php',
    'mod_lti\\output\\repost_crosssite_page' => '/var/www/html/plantilla/mod/lti/classes/output/repost_crosssite_page.php',
    'mod_lti\\output\\tool_configure_page' => '/var/www/html/plantilla/mod/lti/classes/output/tool_configure_page.php',
    'mod_lti\\plugininfo\\ltiservice' => '/var/www/html/plantilla/mod/lti/classes/plugininfo/ltiservice.php',
    'mod_lti\\plugininfo\\ltisource' => '/var/www/html/plantilla/mod/lti/classes/plugininfo/ltisource.php',
    'mod_lti\\privacy\\provider' => '/var/www/html/plantilla/mod/lti/classes/privacy/provider.php',
    'mod_lti\\reportbuilder\\local\\entities\\tool_types' => '/var/www/html/plantilla/mod/lti/classes/reportbuilder/local/entities/tool_types.php',
    'mod_lti\\reportbuilder\\local\\systemreports\\course_external_tools_list' => '/var/www/html/plantilla/mod/lti/classes/reportbuilder/local/systemreports/course_external_tools_list.php',
    'mod_lti\\search\\activity' => '/var/www/html/plantilla/mod/lti/classes/search/activity.php',
    'mod_lti\\service_exception_handler' => '/var/www/html/plantilla/mod/lti/classes/service_exception_handler.php',
    'mod_lti\\task\\clean_access_tokens' => '/var/www/html/plantilla/mod/lti/classes/task/clean_access_tokens.php',
    'mod_lti_external' => '/var/www/html/plantilla/mod/lti/classes/external.php',
    'mod_lti_helper' => '/var/www/html/plantilla/mod/lti/classes/helper.php',
    'mod_lti_service_exception_handler' => '/var/www/html/plantilla/mod/lti/classes/service_exception_handler.php',
    'mod_page\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/page/classes/analytics/indicator/activity_base.php',
    'mod_page\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/page/classes/analytics/indicator/cognitive_depth.php',
    'mod_page\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/page/classes/analytics/indicator/social_breadth.php',
    'mod_page\\content\\exporter' => '/var/www/html/plantilla/mod/page/classes/content/exporter.php',
    'mod_page\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/page/classes/event/course_module_instance_list_viewed.php',
    'mod_page\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/page/classes/event/course_module_viewed.php',
    'mod_page\\external' => '/var/www/html/plantilla/mod/page/classes/external.php',
    'mod_page\\privacy\\provider' => '/var/www/html/plantilla/mod/page/classes/privacy/provider.php',
    'mod_page\\search\\activity' => '/var/www/html/plantilla/mod/page/classes/search/activity.php',
    'mod_page_external' => '/var/www/html/plantilla/mod/page/classes/external.php',
    'mod_qbank\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/qbank/classes/event/course_module_instance_list_viewed.php',
    'mod_qbank\\privacy\\provider' => '/var/www/html/plantilla/mod/qbank/classes/privacy/provider.php',
    'mod_qbank\\task\\transfer_question_categories' => '/var/www/html/plantilla/mod/qbank/classes/task/transfer_question_categories.php',
    'mod_qbank\\task\\transfer_questions' => '/var/www/html/plantilla/mod/qbank/classes/task/transfer_questions.php',
    'mod_quiz\\access_manager' => '/var/www/html/plantilla/mod/quiz/classes/access_manager.php',
    'mod_quiz\\admin\\browser_security_setting' => '/var/www/html/plantilla/mod/quiz/classes/admin/browser_security_setting.php',
    'mod_quiz\\admin\\grade_method_setting' => '/var/www/html/plantilla/mod/quiz/classes/admin/grade_method_setting.php',
    'mod_quiz\\admin\\overdue_handling_setting' => '/var/www/html/plantilla/mod/quiz/classes/admin/overdue_handling_setting.php',
    'mod_quiz\\admin\\review_setting' => '/var/www/html/plantilla/mod/quiz/classes/admin/review_setting.php',
    'mod_quiz\\admin\\user_image_setting' => '/var/www/html/plantilla/mod/quiz/classes/admin/user_image_setting.php',
    'mod_quiz\\adminpresets\\adminpresets_browser_security_setting' => '/var/www/html/plantilla/mod/quiz/classes/adminpresets/adminpresets_browser_security_setting.php',
    'mod_quiz\\adminpresets\\adminpresets_grade_method_setting' => '/var/www/html/plantilla/mod/quiz/classes/adminpresets/adminpresets_grade_method_setting.php',
    'mod_quiz\\adminpresets\\adminpresets_overdue_handling_setting' => '/var/www/html/plantilla/mod/quiz/classes/adminpresets/adminpresets_overdue_handling_setting.php',
    'mod_quiz\\adminpresets\\adminpresets_review_setting' => '/var/www/html/plantilla/mod/quiz/classes/adminpresets/adminpresets_review_setting.php',
    'mod_quiz\\adminpresets\\adminpresets_user_image_setting' => '/var/www/html/plantilla/mod/quiz/classes/adminpresets/adminpresets_user_image_setting.php',
    'mod_quiz\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/quiz/classes/analytics/indicator/activity_base.php',
    'mod_quiz\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/quiz/classes/analytics/indicator/cognitive_depth.php',
    'mod_quiz\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/quiz/classes/analytics/indicator/social_breadth.php',
    'mod_quiz\\cache\\overrides' => '/var/www/html/plantilla/mod/quiz/classes/cache/overrides.php',
    'mod_quiz\\completion\\custom_completion' => '/var/www/html/plantilla/mod/quiz/classes/completion/custom_completion.php',
    'mod_quiz\\dates' => '/var/www/html/plantilla/mod/quiz/classes/dates.php',
    'mod_quiz\\event\\attempt_abandoned' => '/var/www/html/plantilla/mod/quiz/classes/event/attempt_abandoned.php',
    'mod_quiz\\event\\attempt_autosaved' => '/var/www/html/plantilla/mod/quiz/classes/event/attempt_autosaved.php',
    'mod_quiz\\event\\attempt_becameoverdue' => '/var/www/html/plantilla/mod/quiz/classes/event/attempt_becameoverdue.php',
    'mod_quiz\\event\\attempt_deleted' => '/var/www/html/plantilla/mod/quiz/classes/event/attempt_deleted.php',
    'mod_quiz\\event\\attempt_graded' => '/var/www/html/plantilla/mod/quiz/classes/event/attempt_graded.php',
    'mod_quiz\\event\\attempt_manual_grading_completed' => '/var/www/html/plantilla/mod/quiz/classes/event/attempt_manual_grading_completed.php',
    'mod_quiz\\event\\attempt_preview_started' => '/var/www/html/plantilla/mod/quiz/classes/event/attempt_preview_started.php',
    'mod_quiz\\event\\attempt_question_restarted' => '/var/www/html/plantilla/mod/quiz/classes/event/attempt_question_restarted.php',
    'mod_quiz\\event\\attempt_regraded' => '/var/www/html/plantilla/mod/quiz/classes/event/attempt_regraded.php',
    'mod_quiz\\event\\attempt_reopened' => '/var/www/html/plantilla/mod/quiz/classes/event/attempt_reopened.php',
    'mod_quiz\\event\\attempt_reviewed' => '/var/www/html/plantilla/mod/quiz/classes/event/attempt_reviewed.php',
    'mod_quiz\\event\\attempt_started' => '/var/www/html/plantilla/mod/quiz/classes/event/attempt_started.php',
    'mod_quiz\\event\\attempt_submitted' => '/var/www/html/plantilla/mod/quiz/classes/event/attempt_submitted.php',
    'mod_quiz\\event\\attempt_summary_viewed' => '/var/www/html/plantilla/mod/quiz/classes/event/attempt_summary_viewed.php',
    'mod_quiz\\event\\attempt_updated' => '/var/www/html/plantilla/mod/quiz/classes/event/attempt_updated.php',
    'mod_quiz\\event\\attempt_viewed' => '/var/www/html/plantilla/mod/quiz/classes/event/attempt_viewed.php',
    'mod_quiz\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/quiz/classes/event/course_module_instance_list_viewed.php',
    'mod_quiz\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/quiz/classes/event/course_module_viewed.php',
    'mod_quiz\\event\\edit_page_viewed' => '/var/www/html/plantilla/mod/quiz/classes/event/edit_page_viewed.php',
    'mod_quiz\\event\\group_override_created' => '/var/www/html/plantilla/mod/quiz/classes/event/group_override_created.php',
    'mod_quiz\\event\\group_override_deleted' => '/var/www/html/plantilla/mod/quiz/classes/event/group_override_deleted.php',
    'mod_quiz\\event\\group_override_updated' => '/var/www/html/plantilla/mod/quiz/classes/event/group_override_updated.php',
    'mod_quiz\\event\\page_break_created' => '/var/www/html/plantilla/mod/quiz/classes/event/page_break_created.php',
    'mod_quiz\\event\\page_break_deleted' => '/var/www/html/plantilla/mod/quiz/classes/event/page_break_deleted.php',
    'mod_quiz\\event\\question_manually_graded' => '/var/www/html/plantilla/mod/quiz/classes/event/question_manually_graded.php',
    'mod_quiz\\event\\quiz_grade_item_created' => '/var/www/html/plantilla/mod/quiz/classes/event/quiz_grade_item_created.php',
    'mod_quiz\\event\\quiz_grade_item_deleted' => '/var/www/html/plantilla/mod/quiz/classes/event/quiz_grade_item_deleted.php',
    'mod_quiz\\event\\quiz_grade_item_updated' => '/var/www/html/plantilla/mod/quiz/classes/event/quiz_grade_item_updated.php',
    'mod_quiz\\event\\quiz_grade_items_reordered' => '/var/www/html/plantilla/mod/quiz/classes/event/quiz_grade_items_reordered.php',
    'mod_quiz\\event\\quiz_grade_updated' => '/var/www/html/plantilla/mod/quiz/classes/event/quiz_grade_updated.php',
    'mod_quiz\\event\\quiz_repaginated' => '/var/www/html/plantilla/mod/quiz/classes/event/quiz_repaginated.php',
    'mod_quiz\\event\\report_viewed' => '/var/www/html/plantilla/mod/quiz/classes/event/report_viewed.php',
    'mod_quiz\\event\\section_break_created' => '/var/www/html/plantilla/mod/quiz/classes/event/section_break_created.php',
    'mod_quiz\\event\\section_break_deleted' => '/var/www/html/plantilla/mod/quiz/classes/event/section_break_deleted.php',
    'mod_quiz\\event\\section_shuffle_updated' => '/var/www/html/plantilla/mod/quiz/classes/event/section_shuffle_updated.php',
    'mod_quiz\\event\\section_title_updated' => '/var/www/html/plantilla/mod/quiz/classes/event/section_title_updated.php',
    'mod_quiz\\event\\slot_created' => '/var/www/html/plantilla/mod/quiz/classes/event/slot_created.php',
    'mod_quiz\\event\\slot_deleted' => '/var/www/html/plantilla/mod/quiz/classes/event/slot_deleted.php',
    'mod_quiz\\event\\slot_displaynumber_updated' => '/var/www/html/plantilla/mod/quiz/classes/event/slot_displaynumber_updated.php',
    'mod_quiz\\event\\slot_grade_item_updated' => '/var/www/html/plantilla/mod/quiz/classes/event/slot_grade_item_updated.php',
    'mod_quiz\\event\\slot_mark_updated' => '/var/www/html/plantilla/mod/quiz/classes/event/slot_mark_updated.php',
    'mod_quiz\\event\\slot_moved' => '/var/www/html/plantilla/mod/quiz/classes/event/slot_moved.php',
    'mod_quiz\\event\\slot_requireprevious_updated' => '/var/www/html/plantilla/mod/quiz/classes/event/slot_requireprevious_updated.php',
    'mod_quiz\\event\\slot_version_updated' => '/var/www/html/plantilla/mod/quiz/classes/event/slot_version_updated.php',
    'mod_quiz\\event\\user_override_created' => '/var/www/html/plantilla/mod/quiz/classes/event/user_override_created.php',
    'mod_quiz\\event\\user_override_deleted' => '/var/www/html/plantilla/mod/quiz/classes/event/user_override_deleted.php',
    'mod_quiz\\event\\user_override_updated' => '/var/www/html/plantilla/mod/quiz/classes/event/user_override_updated.php',
    'mod_quiz\\external' => '/var/www/html/plantilla/mod/quiz/classes/external.php',
    'mod_quiz\\external\\add_random_questions' => '/var/www/html/plantilla/mod/quiz/classes/external/add_random_questions.php',
    'mod_quiz\\external\\create_grade_item_per_section' => '/var/www/html/plantilla/mod/quiz/classes/external/create_grade_item_per_section.php',
    'mod_quiz\\external\\create_grade_items' => '/var/www/html/plantilla/mod/quiz/classes/external/create_grade_items.php',
    'mod_quiz\\external\\delete_grade_items' => '/var/www/html/plantilla/mod/quiz/classes/external/delete_grade_items.php',
    'mod_quiz\\external\\delete_overrides' => '/var/www/html/plantilla/mod/quiz/classes/external/delete_overrides.php',
    'mod_quiz\\external\\get_edit_grading_page_data' => '/var/www/html/plantilla/mod/quiz/classes/external/get_edit_grading_page_data.php',
    'mod_quiz\\external\\get_overrides' => '/var/www/html/plantilla/mod/quiz/classes/external/get_overrides.php',
    'mod_quiz\\external\\get_reopen_attempt_confirmation' => '/var/www/html/plantilla/mod/quiz/classes/external/get_reopen_attempt_confirmation.php',
    'mod_quiz\\external\\reopen_attempt' => '/var/www/html/plantilla/mod/quiz/classes/external/reopen_attempt.php',
    'mod_quiz\\external\\save_overrides' => '/var/www/html/plantilla/mod/quiz/classes/external/save_overrides.php',
    'mod_quiz\\external\\submit_question_version' => '/var/www/html/plantilla/mod/quiz/classes/external/submit_question_version.php',
    'mod_quiz\\external\\update_filter_condition' => '/var/www/html/plantilla/mod/quiz/classes/external/update_filter_condition.php',
    'mod_quiz\\external\\update_grade_items' => '/var/www/html/plantilla/mod/quiz/classes/external/update_grade_items.php',
    'mod_quiz\\external\\update_slots' => '/var/www/html/plantilla/mod/quiz/classes/external/update_slots.php',
    'mod_quiz\\form\\add_random_form' => '/var/www/html/plantilla/mod/quiz/classes/form/add_random_form.php',
    'mod_quiz\\form\\edit_override_form' => '/var/www/html/plantilla/mod/quiz/classes/form/edit_override_form.php',
    'mod_quiz\\form\\preflight_check_form' => '/var/www/html/plantilla/mod/quiz/classes/form/preflight_check_form.php',
    'mod_quiz\\grade_calculator' => '/var/www/html/plantilla/mod/quiz/classes/grade_calculator.php',
    'mod_quiz\\group_observers' => '/var/www/html/plantilla/mod/quiz/classes/group_observers.php',
    'mod_quiz\\hook\\attempt_state_changed' => '/var/www/html/plantilla/mod/quiz/classes/hook/attempt_state_changed.php',
    'mod_quiz\\hook\\structure_modified' => '/var/www/html/plantilla/mod/quiz/classes/hook/structure_modified.php',
    'mod_quiz\\local\\access_rule_base' => '/var/www/html/plantilla/mod/quiz/classes/local/access_rule_base.php',
    'mod_quiz\\local\\override_cache' => '/var/www/html/plantilla/mod/quiz/classes/local/override_cache.php',
    'mod_quiz\\local\\override_manager' => '/var/www/html/plantilla/mod/quiz/classes/local/override_manager.php',
    'mod_quiz\\local\\reports\\attempts_report' => '/var/www/html/plantilla/mod/quiz/classes/local/reports/attempts_report.php',
    'mod_quiz\\local\\reports\\attempts_report_options' => '/var/www/html/plantilla/mod/quiz/classes/local/reports/attempts_report_options.php',
    'mod_quiz\\local\\reports\\attempts_report_options_form' => '/var/www/html/plantilla/mod/quiz/classes/local/reports/attempts_report_options_form.php',
    'mod_quiz\\local\\reports\\attempts_report_table' => '/var/www/html/plantilla/mod/quiz/classes/local/reports/attempts_report_table.php',
    'mod_quiz\\local\\reports\\report_base' => '/var/www/html/plantilla/mod/quiz/classes/local/reports/report_base.php',
    'mod_quiz\\local\\structure\\slot_random' => '/var/www/html/plantilla/mod/quiz/classes/local/structure/slot_random.php',
    'mod_quiz\\navigation\\views\\secondary' => '/var/www/html/plantilla/mod/quiz/classes/navigation/views/secondary.php',
    'mod_quiz\\notification_helper' => '/var/www/html/plantilla/mod/quiz/classes/notification_helper.php',
    'mod_quiz\\output\\attempt_summary_information' => '/var/www/html/plantilla/mod/quiz/classes/output/attempt_summary_information.php',
    'mod_quiz\\output\\edit_grading_page' => '/var/www/html/plantilla/mod/quiz/classes/output/edit_grading_page.php',
    'mod_quiz\\output\\edit_nav_actions' => '/var/www/html/plantilla/mod/quiz/classes/output/edit_nav_actions.php',
    'mod_quiz\\output\\edit_renderer' => '/var/www/html/plantilla/mod/quiz/classes/output/edit_renderer.php',
    'mod_quiz\\output\\grades\\grade_out_of' => '/var/www/html/plantilla/mod/quiz/classes/output/grades/grade_out_of.php',
    'mod_quiz\\output\\links_to_other_attempts' => '/var/www/html/plantilla/mod/quiz/classes/output/links_to_other_attempts.php',
    'mod_quiz\\output\\list_of_attempts' => '/var/www/html/plantilla/mod/quiz/classes/output/list_of_attempts.php',
    'mod_quiz\\output\\navigation_panel_attempt' => '/var/www/html/plantilla/mod/quiz/classes/output/navigation_panel_attempt.php',
    'mod_quiz\\output\\navigation_panel_base' => '/var/www/html/plantilla/mod/quiz/classes/output/navigation_panel_base.php',
    'mod_quiz\\output\\navigation_panel_review' => '/var/www/html/plantilla/mod/quiz/classes/output/navigation_panel_review.php',
    'mod_quiz\\output\\navigation_question_button' => '/var/www/html/plantilla/mod/quiz/classes/output/navigation_question_button.php',
    'mod_quiz\\output\\navigation_section_heading' => '/var/www/html/plantilla/mod/quiz/classes/output/navigation_section_heading.php',
    'mod_quiz\\output\\overrides_actions' => '/var/www/html/plantilla/mod/quiz/classes/output/overrides_actions.php',
    'mod_quiz\\output\\question_chooser' => '/var/www/html/plantilla/mod/quiz/classes/output/question_chooser.php',
    'mod_quiz\\output\\renderer' => '/var/www/html/plantilla/mod/quiz/classes/output/renderer.php',
    'mod_quiz\\output\\view_page' => '/var/www/html/plantilla/mod/quiz/classes/output/view_page.php',
    'mod_quiz\\plugininfo\\quiz' => '/var/www/html/plantilla/mod/quiz/classes/plugininfo/quiz.php',
    'mod_quiz\\plugininfo\\quizaccess' => '/var/www/html/plantilla/mod/quiz/classes/plugininfo/quizaccess.php',
    'mod_quiz\\privacy\\helper' => '/var/www/html/plantilla/mod/quiz/classes/privacy/helper.php',
    'mod_quiz\\privacy\\legacy_quizaccess_polyfill' => '/var/www/html/plantilla/mod/quiz/classes/privacy/legacy_quizaccess_polyfill.php',
    'mod_quiz\\privacy\\provider' => '/var/www/html/plantilla/mod/quiz/classes/privacy/provider.php',
    'mod_quiz\\privacy\\quizaccess_provider' => '/var/www/html/plantilla/mod/quiz/classes/privacy/quizaccess_provider.php',
    'mod_quiz\\privacy\\quizaccess_user_provider' => '/var/www/html/plantilla/mod/quiz/classes/privacy/quizaccess_user_provider.php',
    'mod_quiz\\question\\bank\\add_action_column' => '/var/www/html/plantilla/mod/quiz/classes/question/bank/add_action_column.php',
    'mod_quiz\\question\\bank\\custom_view' => '/var/www/html/plantilla/mod/quiz/classes/question/bank/custom_view.php',
    'mod_quiz\\question\\bank\\filter\\custom_category_condition' => '/var/www/html/plantilla/mod/quiz/classes/question/bank/filter/custom_category_condition.php',
    'mod_quiz\\question\\bank\\filter\\custom_category_condition_helper' => '/var/www/html/plantilla/mod/quiz/classes/question/bank/filter/custom_category_condition_helper.php',
    'mod_quiz\\question\\bank\\preview_action_column' => '/var/www/html/plantilla/mod/quiz/classes/question/bank/preview_action_column.php',
    'mod_quiz\\question\\bank\\qbank_helper' => '/var/www/html/plantilla/mod/quiz/classes/question/bank/qbank_helper.php',
    'mod_quiz\\question\\bank\\question_name_column' => '/var/www/html/plantilla/mod/quiz/classes/question/bank/question_name_column.php',
    'mod_quiz\\question\\bank\\question_name_text_column' => '/var/www/html/plantilla/mod/quiz/classes/question/bank/question_name_text_column.php',
    'mod_quiz\\question\\bank\\quiz_managecategories_feature' => '/var/www/html/plantilla/mod/quiz/classes/question/bank/quiz_managecategories_feature.php',
    'mod_quiz\\question\\bank\\random_question_view' => '/var/www/html/plantilla/mod/quiz/classes/question/bank/random_question_view.php',
    'mod_quiz\\question\\display_options' => '/var/www/html/plantilla/mod/quiz/classes/question/display_options.php',
    'mod_quiz\\question\\qubaids_for_quiz' => '/var/www/html/plantilla/mod/quiz/classes/question/qubaids_for_quiz.php',
    'mod_quiz\\question\\qubaids_for_quiz_user' => '/var/www/html/plantilla/mod/quiz/classes/question/qubaids_for_quiz_user.php',
    'mod_quiz\\question\\qubaids_for_users_attempts' => '/var/www/html/plantilla/mod/quiz/classes/question/qubaids_for_users_attempts.php',
    'mod_quiz\\quiz_attempt' => '/var/www/html/plantilla/mod/quiz/classes/quiz_attempt.php',
    'mod_quiz\\quiz_settings' => '/var/www/html/plantilla/mod/quiz/classes/quiz_settings.php',
    'mod_quiz\\repaginate' => '/var/www/html/plantilla/mod/quiz/classes/repaginate.php',
    'mod_quiz\\search\\activity' => '/var/www/html/plantilla/mod/quiz/classes/search/activity.php',
    'mod_quiz\\structure' => '/var/www/html/plantilla/mod/quiz/classes/structure.php',
    'mod_quiz\\task\\precreate_attempts' => '/var/www/html/plantilla/mod/quiz/classes/task/precreate_attempts.php',
    'mod_quiz\\task\\queue_all_quiz_open_notification_tasks' => '/var/www/html/plantilla/mod/quiz/classes/task/queue_all_quiz_open_notification_tasks.php',
    'mod_quiz\\task\\queue_quiz_open_notification_tasks_for_users' => '/var/www/html/plantilla/mod/quiz/classes/task/queue_quiz_open_notification_tasks_for_users.php',
    'mod_quiz\\task\\quiz_notify_attempt_manual_grading_completed' => '/var/www/html/plantilla/mod/quiz/classes/task/quiz_notify_attempt_manual_grading_completed.php',
    'mod_quiz\\task\\send_quiz_open_soon_notification_to_user' => '/var/www/html/plantilla/mod/quiz/classes/task/send_quiz_open_soon_notification_to_user.php',
    'mod_quiz\\task\\update_overdue_attempts' => '/var/www/html/plantilla/mod/quiz/classes/task/update_overdue_attempts.php',
    'mod_quiz_access_manager' => '/var/www/html/plantilla/mod/quiz/classes/access_manager.php',
    'mod_quiz_dates' => '/var/www/html/plantilla/mod/quiz/classes/dates.php',
    'mod_quiz_external' => '/var/www/html/plantilla/mod/quiz/classes/external.php',
    'mod_quiz_grade_calculator' => '/var/www/html/plantilla/mod/quiz/classes/grade_calculator.php',
    'mod_quiz_group_observers' => '/var/www/html/plantilla/mod/quiz/classes/group_observers.php',
    'mod_quiz_notification_helper' => '/var/www/html/plantilla/mod/quiz/classes/notification_helper.php',
    'mod_quiz_quiz_attempt' => '/var/www/html/plantilla/mod/quiz/classes/quiz_attempt.php',
    'mod_quiz_quiz_settings' => '/var/www/html/plantilla/mod/quiz/classes/quiz_settings.php',
    'mod_quiz_repaginate' => '/var/www/html/plantilla/mod/quiz/classes/repaginate.php',
    'mod_quiz_structure' => '/var/www/html/plantilla/mod/quiz/classes/structure.php',
    'mod_resource\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/resource/classes/analytics/indicator/activity_base.php',
    'mod_resource\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/resource/classes/analytics/indicator/cognitive_depth.php',
    'mod_resource\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/resource/classes/analytics/indicator/social_breadth.php',
    'mod_resource\\completion\\custom_completion' => '/var/www/html/plantilla/mod/resource/classes/completion/custom_completion.php',
    'mod_resource\\content\\exporter' => '/var/www/html/plantilla/mod/resource/classes/content/exporter.php',
    'mod_resource\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/resource/classes/event/course_module_instance_list_viewed.php',
    'mod_resource\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/resource/classes/event/course_module_viewed.php',
    'mod_resource\\external' => '/var/www/html/plantilla/mod/resource/classes/external.php',
    'mod_resource\\output\\courseformat\\activitybadge' => '/var/www/html/plantilla/mod/resource/classes/output/courseformat/activitybadge.php',
    'mod_resource\\privacy\\provider' => '/var/www/html/plantilla/mod/resource/classes/privacy/provider.php',
    'mod_resource\\search\\activity' => '/var/www/html/plantilla/mod/resource/classes/search/activity.php',
    'mod_resource_external' => '/var/www/html/plantilla/mod/resource/classes/external.php',
    'mod_scorm\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/scorm/classes/analytics/indicator/activity_base.php',
    'mod_scorm\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/scorm/classes/analytics/indicator/cognitive_depth.php',
    'mod_scorm\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/scorm/classes/analytics/indicator/social_breadth.php',
    'mod_scorm\\cache\\elements' => '/var/www/html/plantilla/mod/scorm/classes/cache/elements.php',
    'mod_scorm\\completion\\custom_completion' => '/var/www/html/plantilla/mod/scorm/classes/completion/custom_completion.php',
    'mod_scorm\\dates' => '/var/www/html/plantilla/mod/scorm/classes/dates.php',
    'mod_scorm\\event\\attempt_deleted' => '/var/www/html/plantilla/mod/scorm/classes/event/attempt_deleted.php',
    'mod_scorm\\event\\cmielement_submitted' => '/var/www/html/plantilla/mod/scorm/classes/event/cmielement_submitted.php',
    'mod_scorm\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/scorm/classes/event/course_module_instance_list_viewed.php',
    'mod_scorm\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/scorm/classes/event/course_module_viewed.php',
    'mod_scorm\\event\\interactions_viewed' => '/var/www/html/plantilla/mod/scorm/classes/event/interactions_viewed.php',
    'mod_scorm\\event\\report_viewed' => '/var/www/html/plantilla/mod/scorm/classes/event/report_viewed.php',
    'mod_scorm\\event\\sco_launched' => '/var/www/html/plantilla/mod/scorm/classes/event/sco_launched.php',
    'mod_scorm\\event\\scoreraw_submitted' => '/var/www/html/plantilla/mod/scorm/classes/event/scoreraw_submitted.php',
    'mod_scorm\\event\\status_submitted' => '/var/www/html/plantilla/mod/scorm/classes/event/status_submitted.php',
    'mod_scorm\\event\\tracks_viewed' => '/var/www/html/plantilla/mod/scorm/classes/event/tracks_viewed.php',
    'mod_scorm\\event\\user_report_viewed' => '/var/www/html/plantilla/mod/scorm/classes/event/user_report_viewed.php',
    'mod_scorm\\external' => '/var/www/html/plantilla/mod/scorm/classes/external.php',
    'mod_scorm\\output\\actionbar' => '/var/www/html/plantilla/mod/scorm/classes/output/actionbar.php',
    'mod_scorm\\output\\userreportsactionbar' => '/var/www/html/plantilla/mod/scorm/classes/output/userreportsactionbar.php',
    'mod_scorm\\plugininfo\\scormreport' => '/var/www/html/plantilla/mod/scorm/classes/plugininfo/scormreport.php',
    'mod_scorm\\privacy\\provider' => '/var/www/html/plantilla/mod/scorm/classes/privacy/provider.php',
    'mod_scorm\\report' => '/var/www/html/plantilla/mod/scorm/classes/report.php',
    'mod_scorm\\search\\activity' => '/var/www/html/plantilla/mod/scorm/classes/search/activity.php',
    'mod_scorm\\task\\cron_task' => '/var/www/html/plantilla/mod/scorm/classes/task/cron_task.php',
    'mod_scorm\\task\\update_grades' => '/var/www/html/plantilla/mod/scorm/classes/task/update_grades.php',
    'mod_scorm_dates' => '/var/www/html/plantilla/mod/scorm/classes/dates.php',
    'mod_scorm_external' => '/var/www/html/plantilla/mod/scorm/classes/external.php',
    'mod_scorm_report' => '/var/www/html/plantilla/mod/scorm/classes/report.php',
    'mod_subsection\\courseformat\\sectiondelegate' => '/var/www/html/plantilla/mod/subsection/classes/courseformat/sectiondelegate.php',
    'mod_subsection\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/subsection/classes/event/course_module_instance_list_viewed.php',
    'mod_subsection\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/subsection/classes/event/course_module_viewed.php',
    'mod_subsection\\local\\callbacks\\after_cm_name_edited_handler' => '/var/www/html/plantilla/mod/subsection/classes/local/callbacks/after_cm_name_edited_handler.php',
    'mod_subsection\\local\\callbacks\\before_activitychooserbutton_exported_handler' => '/var/www/html/plantilla/mod/subsection/classes/local/callbacks/before_activitychooserbutton_exported_handler.php',
    'mod_subsection\\manager' => '/var/www/html/plantilla/mod/subsection/classes/manager.php',
    'mod_subsection\\output\\mobile' => '/var/www/html/plantilla/mod/subsection/classes/output/mobile.php',
    'mod_subsection\\permission' => '/var/www/html/plantilla/mod/subsection/classes/permission.php',
    'mod_subsection\\privacy\\provider' => '/var/www/html/plantilla/mod/subsection/classes/privacy/provider.php',
    'mod_subsection_manager' => '/var/www/html/plantilla/mod/subsection/classes/manager.php',
    'mod_subsection_permission' => '/var/www/html/plantilla/mod/subsection/classes/permission.php',
    'mod_url\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/url/classes/analytics/indicator/activity_base.php',
    'mod_url\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/url/classes/analytics/indicator/cognitive_depth.php',
    'mod_url\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/url/classes/analytics/indicator/social_breadth.php',
    'mod_url\\completion\\custom_completion' => '/var/www/html/plantilla/mod/url/classes/completion/custom_completion.php',
    'mod_url\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/url/classes/event/course_module_instance_list_viewed.php',
    'mod_url\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/url/classes/event/course_module_viewed.php',
    'mod_url\\external' => '/var/www/html/plantilla/mod/url/classes/external.php',
    'mod_url\\privacy\\provider' => '/var/www/html/plantilla/mod/url/classes/privacy/provider.php',
    'mod_url\\search\\activity' => '/var/www/html/plantilla/mod/url/classes/search/activity.php',
    'mod_url_external' => '/var/www/html/plantilla/mod/url/classes/external.php',
    'mod_wiki\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/wiki/classes/analytics/indicator/activity_base.php',
    'mod_wiki\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/wiki/classes/analytics/indicator/cognitive_depth.php',
    'mod_wiki\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/wiki/classes/analytics/indicator/social_breadth.php',
    'mod_wiki\\event\\comment_created' => '/var/www/html/plantilla/mod/wiki/classes/event/comment_created.php',
    'mod_wiki\\event\\comment_deleted' => '/var/www/html/plantilla/mod/wiki/classes/event/comment_deleted.php',
    'mod_wiki\\event\\comments_viewed' => '/var/www/html/plantilla/mod/wiki/classes/event/comments_viewed.php',
    'mod_wiki\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/wiki/classes/event/course_module_instance_list_viewed.php',
    'mod_wiki\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/wiki/classes/event/course_module_viewed.php',
    'mod_wiki\\event\\page_created' => '/var/www/html/plantilla/mod/wiki/classes/event/page_created.php',
    'mod_wiki\\event\\page_deleted' => '/var/www/html/plantilla/mod/wiki/classes/event/page_deleted.php',
    'mod_wiki\\event\\page_diff_viewed' => '/var/www/html/plantilla/mod/wiki/classes/event/page_diff_viewed.php',
    'mod_wiki\\event\\page_history_viewed' => '/var/www/html/plantilla/mod/wiki/classes/event/page_history_viewed.php',
    'mod_wiki\\event\\page_locks_deleted' => '/var/www/html/plantilla/mod/wiki/classes/event/page_locks_deleted.php',
    'mod_wiki\\event\\page_map_viewed' => '/var/www/html/plantilla/mod/wiki/classes/event/page_map_viewed.php',
    'mod_wiki\\event\\page_updated' => '/var/www/html/plantilla/mod/wiki/classes/event/page_updated.php',
    'mod_wiki\\event\\page_version_deleted' => '/var/www/html/plantilla/mod/wiki/classes/event/page_version_deleted.php',
    'mod_wiki\\event\\page_version_restored' => '/var/www/html/plantilla/mod/wiki/classes/event/page_version_restored.php',
    'mod_wiki\\event\\page_version_viewed' => '/var/www/html/plantilla/mod/wiki/classes/event/page_version_viewed.php',
    'mod_wiki\\event\\page_viewed' => '/var/www/html/plantilla/mod/wiki/classes/event/page_viewed.php',
    'mod_wiki\\external' => '/var/www/html/plantilla/mod/wiki/classes/external.php',
    'mod_wiki\\output\\action_bar' => '/var/www/html/plantilla/mod/wiki/classes/output/action_bar.php',
    'mod_wiki\\privacy\\provider' => '/var/www/html/plantilla/mod/wiki/classes/privacy/provider.php',
    'mod_wiki\\search\\activity' => '/var/www/html/plantilla/mod/wiki/classes/search/activity.php',
    'mod_wiki\\search\\collaborative_page' => '/var/www/html/plantilla/mod/wiki/classes/search/collaborative_page.php',
    'mod_wiki_external' => '/var/www/html/plantilla/mod/wiki/classes/external.php',
    'mod_workshop\\analytics\\indicator\\activity_base' => '/var/www/html/plantilla/mod/workshop/classes/analytics/indicator/activity_base.php',
    'mod_workshop\\analytics\\indicator\\cognitive_depth' => '/var/www/html/plantilla/mod/workshop/classes/analytics/indicator/cognitive_depth.php',
    'mod_workshop\\analytics\\indicator\\social_breadth' => '/var/www/html/plantilla/mod/workshop/classes/analytics/indicator/social_breadth.php',
    'mod_workshop\\courseformat\\overview' => '/var/www/html/plantilla/mod/workshop/classes/courseformat/overview.php',
    'mod_workshop\\dates' => '/var/www/html/plantilla/mod/workshop/classes/dates.php',
    'mod_workshop\\event\\assessable_uploaded' => '/var/www/html/plantilla/mod/workshop/classes/event/assessable_uploaded.php',
    'mod_workshop\\event\\assessment_evaluated' => '/var/www/html/plantilla/mod/workshop/classes/event/assessment_evaluated.php',
    'mod_workshop\\event\\assessment_evaluations_reset' => '/var/www/html/plantilla/mod/workshop/classes/event/assessment_evaluations_reset.php',
    'mod_workshop\\event\\assessment_reevaluated' => '/var/www/html/plantilla/mod/workshop/classes/event/assessment_reevaluated.php',
    'mod_workshop\\event\\assessments_reset' => '/var/www/html/plantilla/mod/workshop/classes/event/assessments_reset.php',
    'mod_workshop\\event\\course_module_instance_list_viewed' => '/var/www/html/plantilla/mod/workshop/classes/event/course_module_instance_list_viewed.php',
    'mod_workshop\\event\\course_module_viewed' => '/var/www/html/plantilla/mod/workshop/classes/event/course_module_viewed.php',
    'mod_workshop\\event\\phase_automatically_switched' => '/var/www/html/plantilla/mod/workshop/classes/event/phase_automatically_switched.php',
    'mod_workshop\\event\\phase_switched' => '/var/www/html/plantilla/mod/workshop/classes/event/phase_switched.php',
    'mod_workshop\\event\\submission_assessed' => '/var/www/html/plantilla/mod/workshop/classes/event/submission_assessed.php',
    'mod_workshop\\event\\submission_created' => '/var/www/html/plantilla/mod/workshop/classes/event/submission_created.php',
    'mod_workshop\\event\\submission_deleted' => '/var/www/html/plantilla/mod/workshop/classes/event/submission_deleted.php',
    'mod_workshop\\event\\submission_reassessed' => '/var/www/html/plantilla/mod/workshop/classes/event/submission_reassessed.php',
    'mod_workshop\\event\\submission_updated' => '/var/www/html/plantilla/mod/workshop/classes/event/submission_updated.php',
    'mod_workshop\\event\\submission_viewed' => '/var/www/html/plantilla/mod/workshop/classes/event/submission_viewed.php',
    'mod_workshop\\external' => '/var/www/html/plantilla/mod/workshop/classes/external.php',
    'mod_workshop\\external\\assessment_exporter' => '/var/www/html/plantilla/mod/workshop/classes/external/assessment_exporter.php',
    'mod_workshop\\external\\submission_exporter' => '/var/www/html/plantilla/mod/workshop/classes/external/submission_exporter.php',
    'mod_workshop\\external\\workshop_summary_exporter' => '/var/www/html/plantilla/mod/workshop/classes/external/workshop_summary_exporter.php',
    'mod_workshop\\grades\\gradeitems' => '/var/www/html/plantilla/mod/workshop/classes/grades/gradeitems.php',
    'mod_workshop\\output\\actionbar' => '/var/www/html/plantilla/mod/workshop/classes/output/actionbar.php',
    'mod_workshop\\plugininfo\\workshopallocation' => '/var/www/html/plantilla/mod/workshop/classes/plugininfo/workshopallocation.php',
    'mod_workshop\\plugininfo\\workshopeval' => '/var/www/html/plantilla/mod/workshop/classes/plugininfo/workshopeval.php',
    'mod_workshop\\plugininfo\\workshopform' => '/var/www/html/plantilla/mod/workshop/classes/plugininfo/workshopform.php',
    'mod_workshop\\portfolio_caller' => '/var/www/html/plantilla/mod/workshop/classes/portfolio_caller.php',
    'mod_workshop\\privacy\\provider' => '/var/www/html/plantilla/mod/workshop/classes/privacy/provider.php',
    'mod_workshop\\privacy\\workshopform_legacy_polyfill' => '/var/www/html/plantilla/mod/workshop/classes/privacy/workshopform_legacy_polyfill.php',
    'mod_workshop\\privacy\\workshopform_provider' => '/var/www/html/plantilla/mod/workshop/classes/privacy/workshopform_provider.php',
    'mod_workshop\\search\\activity' => '/var/www/html/plantilla/mod/workshop/classes/search/activity.php',
    'mod_workshop\\task\\cron_task' => '/var/www/html/plantilla/mod/workshop/classes/task/cron_task.php',
    'mod_workshop_dates' => '/var/www/html/plantilla/mod/workshop/classes/dates.php',
    'mod_workshop_external' => '/var/www/html/plantilla/mod/workshop/classes/external.php',
    'mod_workshop_portfolio_caller' => '/var/www/html/plantilla/mod/workshop/classes/portfolio_caller.php',
    'moodle_exception' => '/var/www/html/plantilla/lib/classes/exception/moodle_exception.php',
    'moodle_text_filter' => '/var/www/html/plantilla/filter/classes/text_filter.php',
    'moodle_url' => '/var/www/html/plantilla/lib/classes/url.php',
    'null_filter_manager' => '/var/www/html/plantilla/filter/classes/null_filter_manager.php',
    'null_progress_trace' => '/var/www/html/plantilla/lib/classes/output/progress_trace/null_progress_trace.php',
    'page_requirements_manager' => '/var/www/html/plantilla/lib/classes/output/requirements/page_requirements_manager.php',
    'paging_bar' => '/var/www/html/plantilla/lib/classes/output/paging_bar.php',
    'paygw_paypal\\external\\get_config_for_js' => '/var/www/html/plantilla/payment/gateway/paypal/classes/external/get_config_for_js.php',
    'paygw_paypal\\external\\transaction_complete' => '/var/www/html/plantilla/payment/gateway/paypal/classes/external/transaction_complete.php',
    'paygw_paypal\\gateway' => '/var/www/html/plantilla/payment/gateway/paypal/classes/gateway.php',
    'paygw_paypal\\paypal_helper' => '/var/www/html/plantilla/payment/gateway/paypal/classes/paypal_helper.php',
    'paygw_paypal\\privacy\\provider' => '/var/www/html/plantilla/payment/gateway/paypal/classes/privacy/provider.php',
    'paygw_paypal_gateway' => '/var/www/html/plantilla/payment/gateway/paypal/classes/gateway.php',
    'paygw_paypal_paypal_helper' => '/var/www/html/plantilla/payment/gateway/paypal/classes/paypal_helper.php',
    'performance_measuring_filter_manager' => '/var/www/html/plantilla/filter/classes/performance_measuring_filter_manager.php',
    'pix_emoticon' => '/var/www/html/plantilla/lib/classes/output/pix_emoticon.php',
    'pix_icon' => '/var/www/html/plantilla/lib/classes/output/pix_icon.php',
    'pix_icon_font' => '/var/www/html/plantilla/lib/classes/output/pix_icon_font.php',
    'pix_icon_fontawesome' => '/var/www/html/plantilla/lib/classes/output/pix_icon_fontawesome.php',
    'plugin_renderer_base' => '/var/www/html/plantilla/lib/classes/output/plugin_renderer_base.php',
    'popup_action' => '/var/www/html/plantilla/lib/classes/output/actions/popup_action.php',
    'portfolio_download\\privacy\\provider' => '/var/www/html/plantilla/portfolio/download/classes/privacy/provider.php',
    'portfolio_flickr\\privacy\\provider' => '/var/www/html/plantilla/portfolio/flickr/classes/privacy/provider.php',
    'portfolio_googledocs\\privacy\\provider' => '/var/www/html/plantilla/portfolio/googledocs/classes/privacy/provider.php',
    'preferences_group' => '/var/www/html/plantilla/lib/classes/output/preferences_group.php',
    'preferences_groups' => '/var/www/html/plantilla/lib/classes/output/preferences_groups.php',
    'profilefield_checkbox\\privacy\\provider' => '/var/www/html/plantilla/user/profile/field/checkbox/classes/privacy/provider.php',
    'profilefield_datetime\\privacy\\provider' => '/var/www/html/plantilla/user/profile/field/datetime/classes/privacy/provider.php',
    'profilefield_menu\\privacy\\provider' => '/var/www/html/plantilla/user/profile/field/menu/classes/privacy/provider.php',
    'profilefield_social\\helper' => '/var/www/html/plantilla/user/profile/field/social/classes/helper.php',
    'profilefield_social\\privacy\\provider' => '/var/www/html/plantilla/user/profile/field/social/classes/privacy/provider.php',
    'profilefield_social_helper' => '/var/www/html/plantilla/user/profile/field/social/classes/helper.php',
    'profilefield_text\\privacy\\provider' => '/var/www/html/plantilla/user/profile/field/text/classes/privacy/provider.php',
    'profilefield_textarea\\privacy\\provider' => '/var/www/html/plantilla/user/profile/field/textarea/classes/privacy/provider.php',
    'progress_bar' => '/var/www/html/plantilla/lib/classes/output/progress_bar.php',
    'progress_trace' => '/var/www/html/plantilla/lib/classes/output/progress_trace.php',
    'progress_trace_buffer' => '/var/www/html/plantilla/lib/classes/output/progress_trace/progress_trace_buffer.php',
    'qbank_bulkmove\\bulk_move_action' => '/var/www/html/plantilla/question/bank/bulkmove/classes/bulk_move_action.php',
    'qbank_bulkmove\\helper' => '/var/www/html/plantilla/question/bank/bulkmove/classes/helper.php',
    'qbank_bulkmove\\output\\bulk_move' => '/var/www/html/plantilla/question/bank/bulkmove/classes/output/bulk_move.php',
    'qbank_bulkmove\\output\\renderer' => '/var/www/html/plantilla/question/bank/bulkmove/classes/output/renderer.php',
    'qbank_bulkmove\\plugin_feature' => '/var/www/html/plantilla/question/bank/bulkmove/classes/plugin_feature.php',
    'qbank_bulkmove\\privacy\\provider' => '/var/www/html/plantilla/question/bank/bulkmove/classes/privacy/provider.php',
    'qbank_bulkmove_bulk_move_action' => '/var/www/html/plantilla/question/bank/bulkmove/classes/bulk_move_action.php',
    'qbank_bulkmove_helper' => '/var/www/html/plantilla/question/bank/bulkmove/classes/helper.php',
    'qbank_bulkmove_plugin_feature' => '/var/www/html/plantilla/question/bank/bulkmove/classes/plugin_feature.php',
    'qbank_columnsortorder\\column_manager' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/column_manager.php',
    'qbank_columnsortorder\\event\\plugin_observer' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/event/plugin_observer.php',
    'qbank_columnsortorder\\external\\set_column_size' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/external/set_column_size.php',
    'qbank_columnsortorder\\external\\set_columnbank_order' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/external/set_columnbank_order.php',
    'qbank_columnsortorder\\external\\set_hidden_columns' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/external/set_hidden_columns.php',
    'qbank_columnsortorder\\local\\bank\\column_action_move' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/local/bank/column_action_move.php',
    'qbank_columnsortorder\\local\\bank\\column_action_remove' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/local/bank/column_action_remove.php',
    'qbank_columnsortorder\\local\\bank\\column_action_resize' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/local/bank/column_action_resize.php',
    'qbank_columnsortorder\\local\\bank\\preview_view' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/local/bank/preview_view.php',
    'qbank_columnsortorder\\output\\add_column' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/output/add_column.php',
    'qbank_columnsortorder\\output\\column_sort_preview' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/output/column_sort_preview.php',
    'qbank_columnsortorder\\output\\column_sort_ui' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/output/column_sort_ui.php',
    'qbank_columnsortorder\\output\\fragment' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/output/fragment.php',
    'qbank_columnsortorder\\output\\reset_columns' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/output/reset_columns.php',
    'qbank_columnsortorder\\plugin_feature' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/plugin_feature.php',
    'qbank_columnsortorder\\privacy\\provider' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/privacy/provider.php',
    'qbank_columnsortorder\\tests\\external_function_testcase' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/tests/external_function_testcase.php',
    'qbank_columnsortorder_column_manager' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/column_manager.php',
    'qbank_columnsortorder_plugin_feature' => '/var/www/html/plantilla/question/bank/columnsortorder/classes/plugin_feature.php',
    'qbank_comment\\comment_count_column' => '/var/www/html/plantilla/question/bank/comment/classes/comment_count_column.php',
    'qbank_comment\\event\\comment_created' => '/var/www/html/plantilla/question/bank/comment/classes/event/comment_created.php',
    'qbank_comment\\event\\comment_deleted' => '/var/www/html/plantilla/question/bank/comment/classes/event/comment_deleted.php',
    'qbank_comment\\event\\question_deleted_observer' => '/var/www/html/plantilla/question/bank/comment/classes/event/question_deleted_observer.php',
    'qbank_comment\\output\\renderer' => '/var/www/html/plantilla/question/bank/comment/classes/output/renderer.php',
    'qbank_comment\\plugin_feature' => '/var/www/html/plantilla/question/bank/comment/classes/plugin_feature.php',
    'qbank_comment\\privacy\\provider' => '/var/www/html/plantilla/question/bank/comment/classes/privacy/provider.php',
    'qbank_comment_comment_count_column' => '/var/www/html/plantilla/question/bank/comment/classes/comment_count_column.php',
    'qbank_comment_plugin_feature' => '/var/www/html/plantilla/question/bank/comment/classes/plugin_feature.php',
    'qbank_customfields\\custom_field_column' => '/var/www/html/plantilla/question/bank/customfields/classes/custom_field_column.php',
    'qbank_customfields\\customfield\\question_handler' => '/var/www/html/plantilla/question/bank/customfields/classes/customfield/question_handler.php',
    'qbank_customfields\\event\\question_deleted_observer' => '/var/www/html/plantilla/question/bank/customfields/classes/event/question_deleted_observer.php',
    'qbank_customfields\\output\\renderer' => '/var/www/html/plantilla/question/bank/customfields/classes/output/renderer.php',
    'qbank_customfields\\plugin_feature' => '/var/www/html/plantilla/question/bank/customfields/classes/plugin_feature.php',
    'qbank_customfields\\privacy\\provider' => '/var/www/html/plantilla/question/bank/customfields/classes/privacy/provider.php',
    'qbank_customfields_custom_field_column' => '/var/www/html/plantilla/question/bank/customfields/classes/custom_field_column.php',
    'qbank_customfields_plugin_feature' => '/var/www/html/plantilla/question/bank/customfields/classes/plugin_feature.php',
    'qbank_deletequestion\\bulk_delete_action' => '/var/www/html/plantilla/question/bank/deletequestion/classes/bulk_delete_action.php',
    'qbank_deletequestion\\delete_action' => '/var/www/html/plantilla/question/bank/deletequestion/classes/delete_action.php',
    'qbank_deletequestion\\helper' => '/var/www/html/plantilla/question/bank/deletequestion/classes/helper.php',
    'qbank_deletequestion\\hidden_condition' => '/var/www/html/plantilla/question/bank/deletequestion/classes/hidden_condition.php',
    'qbank_deletequestion\\plugin_feature' => '/var/www/html/plantilla/question/bank/deletequestion/classes/plugin_feature.php',
    'qbank_deletequestion\\privacy\\provider' => '/var/www/html/plantilla/question/bank/deletequestion/classes/privacy/provider.php',
    'qbank_deletequestion_bulk_delete_action' => '/var/www/html/plantilla/question/bank/deletequestion/classes/bulk_delete_action.php',
    'qbank_deletequestion_delete_action' => '/var/www/html/plantilla/question/bank/deletequestion/classes/delete_action.php',
    'qbank_deletequestion_helper' => '/var/www/html/plantilla/question/bank/deletequestion/classes/helper.php',
    'qbank_deletequestion_hidden_condition' => '/var/www/html/plantilla/question/bank/deletequestion/classes/hidden_condition.php',
    'qbank_deletequestion_plugin_feature' => '/var/www/html/plantilla/question/bank/deletequestion/classes/plugin_feature.php',
    'qbank_editquestion\\copy_action' => '/var/www/html/plantilla/question/bank/editquestion/classes/copy_action.php',
    'qbank_editquestion\\edit_action' => '/var/www/html/plantilla/question/bank/editquestion/classes/edit_action.php',
    'qbank_editquestion\\editquestion_helper' => '/var/www/html/plantilla/question/bank/editquestion/classes/editquestion_helper.php',
    'qbank_editquestion\\external\\update_question_version_status' => '/var/www/html/plantilla/question/bank/editquestion/classes/external/update_question_version_status.php',
    'qbank_editquestion\\output\\add_new_question' => '/var/www/html/plantilla/question/bank/editquestion/classes/output/add_new_question.php',
    'qbank_editquestion\\output\\renderer' => '/var/www/html/plantilla/question/bank/editquestion/classes/output/renderer.php',
    'qbank_editquestion\\plugin_feature' => '/var/www/html/plantilla/question/bank/editquestion/classes/plugin_feature.php',
    'qbank_editquestion\\privacy\\provider' => '/var/www/html/plantilla/question/bank/editquestion/classes/privacy/provider.php',
    'qbank_editquestion\\qbank_chooser' => '/var/www/html/plantilla/question/bank/editquestion/classes/qbank_chooser.php',
    'qbank_editquestion\\qbank_chooser_item' => '/var/www/html/plantilla/question/bank/editquestion/classes/qbank_chooser_item.php',
    'qbank_editquestion\\question_status_column' => '/var/www/html/plantilla/question/bank/editquestion/classes/question_status_column.php',
    'qbank_editquestion\\status_condition' => '/var/www/html/plantilla/question/bank/editquestion/classes/status_condition.php',
    'qbank_editquestion_copy_action' => '/var/www/html/plantilla/question/bank/editquestion/classes/copy_action.php',
    'qbank_editquestion_edit_action' => '/var/www/html/plantilla/question/bank/editquestion/classes/edit_action.php',
    'qbank_editquestion_editquestion_helper' => '/var/www/html/plantilla/question/bank/editquestion/classes/editquestion_helper.php',
    'qbank_editquestion_plugin_feature' => '/var/www/html/plantilla/question/bank/editquestion/classes/plugin_feature.php',
    'qbank_editquestion_qbank_chooser' => '/var/www/html/plantilla/question/bank/editquestion/classes/qbank_chooser.php',
    'qbank_editquestion_qbank_chooser_item' => '/var/www/html/plantilla/question/bank/editquestion/classes/qbank_chooser_item.php',
    'qbank_editquestion_question_status_column' => '/var/www/html/plantilla/question/bank/editquestion/classes/question_status_column.php',
    'qbank_editquestion_status_condition' => '/var/www/html/plantilla/question/bank/editquestion/classes/status_condition.php',
    'qbank_exportquestions\\exportquestions_helper' => '/var/www/html/plantilla/question/bank/exportquestions/classes/exportquestions_helper.php',
    'qbank_exportquestions\\form\\export_form' => '/var/www/html/plantilla/question/bank/exportquestions/classes/form/export_form.php',
    'qbank_exportquestions\\navigation' => '/var/www/html/plantilla/question/bank/exportquestions/classes/navigation.php',
    'qbank_exportquestions\\plugin_feature' => '/var/www/html/plantilla/question/bank/exportquestions/classes/plugin_feature.php',
    'qbank_exportquestions\\privacy\\provider' => '/var/www/html/plantilla/question/bank/exportquestions/classes/privacy/provider.php',
    'qbank_exportquestions_exportquestions_helper' => '/var/www/html/plantilla/question/bank/exportquestions/classes/exportquestions_helper.php',
    'qbank_exportquestions_navigation' => '/var/www/html/plantilla/question/bank/exportquestions/classes/navigation.php',
    'qbank_exportquestions_plugin_feature' => '/var/www/html/plantilla/question/bank/exportquestions/classes/plugin_feature.php',
    'qbank_exporttoxml\\export_xml_action' => '/var/www/html/plantilla/question/bank/exporttoxml/classes/export_xml_action.php',
    'qbank_exporttoxml\\helper' => '/var/www/html/plantilla/question/bank/exporttoxml/classes/helper.php',
    'qbank_exporttoxml\\plugin_feature' => '/var/www/html/plantilla/question/bank/exporttoxml/classes/plugin_feature.php',
    'qbank_exporttoxml\\privacy\\provider' => '/var/www/html/plantilla/question/bank/exporttoxml/classes/privacy/provider.php',
    'qbank_exporttoxml_export_xml_action' => '/var/www/html/plantilla/question/bank/exporttoxml/classes/export_xml_action.php',
    'qbank_exporttoxml_helper' => '/var/www/html/plantilla/question/bank/exporttoxml/classes/helper.php',
    'qbank_exporttoxml_plugin_feature' => '/var/www/html/plantilla/question/bank/exporttoxml/classes/plugin_feature.php',
    'qbank_history\\helper' => '/var/www/html/plantilla/question/bank/history/classes/helper.php',
    'qbank_history\\history_action' => '/var/www/html/plantilla/question/bank/history/classes/history_action.php',
    'qbank_history\\output\\renderer' => '/var/www/html/plantilla/question/bank/history/classes/output/renderer.php',
    'qbank_history\\plugin_feature' => '/var/www/html/plantilla/question/bank/history/classes/plugin_feature.php',
    'qbank_history\\privacy\\provider' => '/var/www/html/plantilla/question/bank/history/classes/privacy/provider.php',
    'qbank_history\\question_history_view' => '/var/www/html/plantilla/question/bank/history/classes/question_history_view.php',
    'qbank_history\\version_number_column' => '/var/www/html/plantilla/question/bank/history/classes/version_number_column.php',
    'qbank_history_helper' => '/var/www/html/plantilla/question/bank/history/classes/helper.php',
    'qbank_history_history_action' => '/var/www/html/plantilla/question/bank/history/classes/history_action.php',
    'qbank_history_plugin_feature' => '/var/www/html/plantilla/question/bank/history/classes/plugin_feature.php',
    'qbank_history_question_history_view' => '/var/www/html/plantilla/question/bank/history/classes/question_history_view.php',
    'qbank_history_version_number_column' => '/var/www/html/plantilla/question/bank/history/classes/version_number_column.php',
    'qbank_importquestions\\form\\question_import_form' => '/var/www/html/plantilla/question/bank/importquestions/classes/form/question_import_form.php',
    'qbank_importquestions\\navigation' => '/var/www/html/plantilla/question/bank/importquestions/classes/navigation.php',
    'qbank_importquestions\\plugin_feature' => '/var/www/html/plantilla/question/bank/importquestions/classes/plugin_feature.php',
    'qbank_importquestions\\privacy\\provider' => '/var/www/html/plantilla/question/bank/importquestions/classes/privacy/provider.php',
    'qbank_importquestions_navigation' => '/var/www/html/plantilla/question/bank/importquestions/classes/navigation.php',
    'qbank_importquestions_plugin_feature' => '/var/www/html/plantilla/question/bank/importquestions/classes/plugin_feature.php',
    'qbank_managecategories\\category_condition' => '/var/www/html/plantilla/question/bank/managecategories/classes/category_condition.php',
    'qbank_managecategories\\external\\move_category' => '/var/www/html/plantilla/question/bank/managecategories/classes/external/move_category.php',
    'qbank_managecategories\\form\\question_category_edit_form' => '/var/www/html/plantilla/question/bank/managecategories/classes/form/question_category_edit_form.php',
    'qbank_managecategories\\form\\question_move_form' => '/var/www/html/plantilla/question/bank/managecategories/classes/form/question_move_form.php',
    'qbank_managecategories\\helper' => '/var/www/html/plantilla/question/bank/managecategories/classes/helper.php',
    'qbank_managecategories\\navigation' => '/var/www/html/plantilla/question/bank/managecategories/classes/navigation.php',
    'qbank_managecategories\\output\\categories' => '/var/www/html/plantilla/question/bank/managecategories/classes/output/categories.php',
    'qbank_managecategories\\output\\categories_header' => '/var/www/html/plantilla/question/bank/managecategories/classes/output/categories_header.php',
    'qbank_managecategories\\output\\category' => '/var/www/html/plantilla/question/bank/managecategories/classes/output/category.php',
    'qbank_managecategories\\plugin_feature' => '/var/www/html/plantilla/question/bank/managecategories/classes/plugin_feature.php',
    'qbank_managecategories\\privacy\\provider' => '/var/www/html/plantilla/question/bank/managecategories/classes/privacy/provider.php',
    'qbank_managecategories\\question_categories' => '/var/www/html/plantilla/question/bank/managecategories/classes/question_categories.php',
    'qbank_managecategories\\question_category_list' => '/var/www/html/plantilla/question/bank/managecategories/classes/question_category_list.php',
    'qbank_managecategories\\question_category_list_item' => '/var/www/html/plantilla/question/bank/managecategories/classes/question_category_list_item.php',
    'qbank_managecategories\\question_category_object' => '/var/www/html/plantilla/question/bank/managecategories/classes/question_category_object.php',
    'qbank_managecategories_category_condition' => '/var/www/html/plantilla/question/bank/managecategories/classes/category_condition.php',
    'qbank_managecategories_helper' => '/var/www/html/plantilla/question/bank/managecategories/classes/helper.php',
    'qbank_managecategories_navigation' => '/var/www/html/plantilla/question/bank/managecategories/classes/navigation.php',
    'qbank_managecategories_plugin_feature' => '/var/www/html/plantilla/question/bank/managecategories/classes/plugin_feature.php',
    'qbank_managecategories_question_categories' => '/var/www/html/plantilla/question/bank/managecategories/classes/question_categories.php',
    'qbank_managecategories_question_category_list' => '/var/www/html/plantilla/question/bank/managecategories/classes/question_category_list.php',
    'qbank_managecategories_question_category_list_item' => '/var/www/html/plantilla/question/bank/managecategories/classes/question_category_list_item.php',
    'qbank_managecategories_question_category_object' => '/var/www/html/plantilla/question/bank/managecategories/classes/question_category_object.php',
    'qbank_previewquestion\\form\\preview_options_form' => '/var/www/html/plantilla/question/bank/previewquestion/classes/form/preview_options_form.php',
    'qbank_previewquestion\\helper' => '/var/www/html/plantilla/question/bank/previewquestion/classes/helper.php',
    'qbank_previewquestion\\output\\renderer' => '/var/www/html/plantilla/question/bank/previewquestion/classes/output/renderer.php',
    'qbank_previewquestion\\plugin_feature' => '/var/www/html/plantilla/question/bank/previewquestion/classes/plugin_feature.php',
    'qbank_previewquestion\\preview_action' => '/var/www/html/plantilla/question/bank/previewquestion/classes/preview_action.php',
    'qbank_previewquestion\\privacy\\provider' => '/var/www/html/plantilla/question/bank/previewquestion/classes/privacy/provider.php',
    'qbank_previewquestion\\question_preview_options' => '/var/www/html/plantilla/question/bank/previewquestion/classes/question_preview_options.php',
    'qbank_previewquestion_helper' => '/var/www/html/plantilla/question/bank/previewquestion/classes/helper.php',
    'qbank_previewquestion_plugin_feature' => '/var/www/html/plantilla/question/bank/previewquestion/classes/plugin_feature.php',
    'qbank_previewquestion_preview_action' => '/var/www/html/plantilla/question/bank/previewquestion/classes/preview_action.php',
    'qbank_previewquestion_question_preview_options' => '/var/www/html/plantilla/question/bank/previewquestion/classes/question_preview_options.php',
    'qbank_statistics\\columns\\discrimination_index' => '/var/www/html/plantilla/question/bank/statistics/classes/columns/discrimination_index.php',
    'qbank_statistics\\columns\\discriminative_efficiency' => '/var/www/html/plantilla/question/bank/statistics/classes/columns/discriminative_efficiency.php',
    'qbank_statistics\\columns\\facility_index' => '/var/www/html/plantilla/question/bank/statistics/classes/columns/facility_index.php',
    'qbank_statistics\\helper' => '/var/www/html/plantilla/question/bank/statistics/classes/helper.php',
    'qbank_statistics\\output\\renderer' => '/var/www/html/plantilla/question/bank/statistics/classes/output/renderer.php',
    'qbank_statistics\\plugin_feature' => '/var/www/html/plantilla/question/bank/statistics/classes/plugin_feature.php',
    'qbank_statistics\\privacy\\provider' => '/var/www/html/plantilla/question/bank/statistics/classes/privacy/provider.php',
    'qbank_statistics_helper' => '/var/www/html/plantilla/question/bank/statistics/classes/helper.php',
    'qbank_statistics_plugin_feature' => '/var/www/html/plantilla/question/bank/statistics/classes/plugin_feature.php',
    'qbank_tagquestion\\event\\question_deleted_observer' => '/var/www/html/plantilla/question/bank/tagquestion/classes/event/question_deleted_observer.php',
    'qbank_tagquestion\\external\\submit_tags' => '/var/www/html/plantilla/question/bank/tagquestion/classes/external/submit_tags.php',
    'qbank_tagquestion\\form\\tags_form' => '/var/www/html/plantilla/question/bank/tagquestion/classes/form/tags_form.php',
    'qbank_tagquestion\\output\\renderer' => '/var/www/html/plantilla/question/bank/tagquestion/classes/output/renderer.php',
    'qbank_tagquestion\\plugin_feature' => '/var/www/html/plantilla/question/bank/tagquestion/classes/plugin_feature.php',
    'qbank_tagquestion\\privacy\\provider' => '/var/www/html/plantilla/question/bank/tagquestion/classes/privacy/provider.php',
    'qbank_tagquestion\\tag_condition' => '/var/www/html/plantilla/question/bank/tagquestion/classes/tag_condition.php',
    'qbank_tagquestion\\tags_action' => '/var/www/html/plantilla/question/bank/tagquestion/classes/tags_action.php',
    'qbank_tagquestion_plugin_feature' => '/var/www/html/plantilla/question/bank/tagquestion/classes/plugin_feature.php',
    'qbank_tagquestion_tag_condition' => '/var/www/html/plantilla/question/bank/tagquestion/classes/tag_condition.php',
    'qbank_tagquestion_tags_action' => '/var/www/html/plantilla/question/bank/tagquestion/classes/tags_action.php',
    'qbank_usage\\helper' => '/var/www/html/plantilla/question/bank/usage/classes/helper.php',
    'qbank_usage\\output\\renderer' => '/var/www/html/plantilla/question/bank/usage/classes/output/renderer.php',
    'qbank_usage\\plugin_feature' => '/var/www/html/plantilla/question/bank/usage/classes/plugin_feature.php',
    'qbank_usage\\privacy\\provider' => '/var/www/html/plantilla/question/bank/usage/classes/privacy/provider.php',
    'qbank_usage\\question_last_used_column' => '/var/www/html/plantilla/question/bank/usage/classes/question_last_used_column.php',
    'qbank_usage\\question_usage_column' => '/var/www/html/plantilla/question/bank/usage/classes/question_usage_column.php',
    'qbank_usage\\tables\\question_usage_table' => '/var/www/html/plantilla/question/bank/usage/classes/tables/question_usage_table.php',
    'qbank_usage_helper' => '/var/www/html/plantilla/question/bank/usage/classes/helper.php',
    'qbank_usage_plugin_feature' => '/var/www/html/plantilla/question/bank/usage/classes/plugin_feature.php',
    'qbank_usage_question_last_used_column' => '/var/www/html/plantilla/question/bank/usage/classes/question_last_used_column.php',
    'qbank_usage_question_usage_column' => '/var/www/html/plantilla/question/bank/usage/classes/question_usage_column.php',
    'qbank_viewcreator\\createdby_condition' => '/var/www/html/plantilla/question/bank/viewcreator/classes/createdby_condition.php',
    'qbank_viewcreator\\creator_name_column' => '/var/www/html/plantilla/question/bank/viewcreator/classes/creator_name_column.php',
    'qbank_viewcreator\\modifiedby_condition' => '/var/www/html/plantilla/question/bank/viewcreator/classes/modifiedby_condition.php',
    'qbank_viewcreator\\modifier_name_column' => '/var/www/html/plantilla/question/bank/viewcreator/classes/modifier_name_column.php',
    'qbank_viewcreator\\output\\renderer' => '/var/www/html/plantilla/question/bank/viewcreator/classes/output/renderer.php',
    'qbank_viewcreator\\plugin_feature' => '/var/www/html/plantilla/question/bank/viewcreator/classes/plugin_feature.php',
    'qbank_viewcreator\\privacy\\provider' => '/var/www/html/plantilla/question/bank/viewcreator/classes/privacy/provider.php',
    'qbank_viewcreator\\timemodified_condition' => '/var/www/html/plantilla/question/bank/viewcreator/classes/timemodified_condition.php',
    'qbank_viewcreator\\user_condition' => '/var/www/html/plantilla/question/bank/viewcreator/classes/user_condition.php',
    'qbank_viewcreator_createdby_condition' => '/var/www/html/plantilla/question/bank/viewcreator/classes/createdby_condition.php',
    'qbank_viewcreator_creator_name_column' => '/var/www/html/plantilla/question/bank/viewcreator/classes/creator_name_column.php',
    'qbank_viewcreator_modifiedby_condition' => '/var/www/html/plantilla/question/bank/viewcreator/classes/modifiedby_condition.php',
    'qbank_viewcreator_modifier_name_column' => '/var/www/html/plantilla/question/bank/viewcreator/classes/modifier_name_column.php',
    'qbank_viewcreator_plugin_feature' => '/var/www/html/plantilla/question/bank/viewcreator/classes/plugin_feature.php',
    'qbank_viewcreator_timemodified_condition' => '/var/www/html/plantilla/question/bank/viewcreator/classes/timemodified_condition.php',
    'qbank_viewcreator_user_condition' => '/var/www/html/plantilla/question/bank/viewcreator/classes/user_condition.php',
    'qbank_viewquestionname\\output\\questionname' => '/var/www/html/plantilla/question/bank/viewquestionname/classes/output/questionname.php',
    'qbank_viewquestionname\\plugin_feature' => '/var/www/html/plantilla/question/bank/viewquestionname/classes/plugin_feature.php',
    'qbank_viewquestionname\\privacy\\provider' => '/var/www/html/plantilla/question/bank/viewquestionname/classes/privacy/provider.php',
    'qbank_viewquestionname\\question_idnumber_condition' => '/var/www/html/plantilla/question/bank/viewquestionname/classes/question_idnumber_condition.php',
    'qbank_viewquestionname\\question_name_condition' => '/var/www/html/plantilla/question/bank/viewquestionname/classes/question_name_condition.php',
    'qbank_viewquestionname\\question_name_idnumber_tags_column' => '/var/www/html/plantilla/question/bank/viewquestionname/classes/question_name_idnumber_tags_column.php',
    'qbank_viewquestionname\\viewquestionname_column_helper' => '/var/www/html/plantilla/question/bank/viewquestionname/classes/viewquestionname_column_helper.php',
    'qbank_viewquestionname_plugin_feature' => '/var/www/html/plantilla/question/bank/viewquestionname/classes/plugin_feature.php',
    'qbank_viewquestionname_question_idnumber_condition' => '/var/www/html/plantilla/question/bank/viewquestionname/classes/question_idnumber_condition.php',
    'qbank_viewquestionname_question_name_condition' => '/var/www/html/plantilla/question/bank/viewquestionname/classes/question_name_condition.php',
    'qbank_viewquestionname_question_name_idnumber_tags_column' => '/var/www/html/plantilla/question/bank/viewquestionname/classes/question_name_idnumber_tags_column.php',
    'qbank_viewquestionname_viewquestionname_column_helper' => '/var/www/html/plantilla/question/bank/viewquestionname/classes/viewquestionname_column_helper.php',
    'qbank_viewquestiontext\\external\\set_question_text_format' => '/var/www/html/plantilla/question/bank/viewquestiontext/classes/external/set_question_text_format.php',
    'qbank_viewquestiontext\\output\\question_text_format' => '/var/www/html/plantilla/question/bank/viewquestiontext/classes/output/question_text_format.php',
    'qbank_viewquestiontext\\plugin_feature' => '/var/www/html/plantilla/question/bank/viewquestiontext/classes/plugin_feature.php',
    'qbank_viewquestiontext\\privacy\\provider' => '/var/www/html/plantilla/question/bank/viewquestiontext/classes/privacy/provider.php',
    'qbank_viewquestiontext\\question_text_row' => '/var/www/html/plantilla/question/bank/viewquestiontext/classes/question_text_row.php',
    'qbank_viewquestiontext\\questiontext_condition' => '/var/www/html/plantilla/question/bank/viewquestiontext/classes/questiontext_condition.php',
    'qbank_viewquestiontext_plugin_feature' => '/var/www/html/plantilla/question/bank/viewquestiontext/classes/plugin_feature.php',
    'qbank_viewquestiontext_question_text_row' => '/var/www/html/plantilla/question/bank/viewquestiontext/classes/question_text_row.php',
    'qbank_viewquestiontext_questiontext_condition' => '/var/www/html/plantilla/question/bank/viewquestiontext/classes/questiontext_condition.php',
    'qbank_viewquestiontype\\plugin_feature' => '/var/www/html/plantilla/question/bank/viewquestiontype/classes/plugin_feature.php',
    'qbank_viewquestiontype\\privacy\\provider' => '/var/www/html/plantilla/question/bank/viewquestiontype/classes/privacy/provider.php',
    'qbank_viewquestiontype\\question_type_column' => '/var/www/html/plantilla/question/bank/viewquestiontype/classes/question_type_column.php',
    'qbank_viewquestiontype\\type_condition' => '/var/www/html/plantilla/question/bank/viewquestiontype/classes/type_condition.php',
    'qbank_viewquestiontype_plugin_feature' => '/var/www/html/plantilla/question/bank/viewquestiontype/classes/plugin_feature.php',
    'qbank_viewquestiontype_question_type_column' => '/var/www/html/plantilla/question/bank/viewquestiontype/classes/question_type_column.php',
    'qbank_viewquestiontype_type_condition' => '/var/www/html/plantilla/question/bank/viewquestiontype/classes/type_condition.php',
    'qbehaviour_adaptive\\privacy\\provider' => '/var/www/html/plantilla/question/behaviour/adaptive/classes/privacy/provider.php',
    'qbehaviour_adaptivenopenalty\\privacy\\provider' => '/var/www/html/plantilla/question/behaviour/adaptivenopenalty/classes/privacy/provider.php',
    'qbehaviour_deferredcbm\\privacy\\provider' => '/var/www/html/plantilla/question/behaviour/deferredcbm/classes/privacy/provider.php',
    'qbehaviour_deferredfeedback\\privacy\\provider' => '/var/www/html/plantilla/question/behaviour/deferredfeedback/classes/privacy/provider.php',
    'qbehaviour_immediatecbm\\privacy\\provider' => '/var/www/html/plantilla/question/behaviour/immediatecbm/classes/privacy/provider.php',
    'qbehaviour_immediatefeedback\\privacy\\provider' => '/var/www/html/plantilla/question/behaviour/immediatefeedback/classes/privacy/provider.php',
    'qbehaviour_informationitem\\privacy\\provider' => '/var/www/html/plantilla/question/behaviour/informationitem/classes/privacy/provider.php',
    'qbehaviour_interactive\\privacy\\provider' => '/var/www/html/plantilla/question/behaviour/interactive/classes/privacy/provider.php',
    'qbehaviour_interactivecountback\\privacy\\provider' => '/var/www/html/plantilla/question/behaviour/interactivecountback/classes/privacy/provider.php',
    'qbehaviour_manualgraded\\privacy\\provider' => '/var/www/html/plantilla/question/behaviour/manualgraded/classes/privacy/provider.php',
    'qbehaviour_missing\\privacy\\provider' => '/var/www/html/plantilla/question/behaviour/missing/classes/privacy/provider.php',
    'qformat_aiken\\privacy\\provider' => '/var/www/html/plantilla/question/format/aiken/classes/privacy/provider.php',
    'qformat_blackboard_six\\privacy\\provider' => '/var/www/html/plantilla/question/format/blackboard_six/classes/privacy/provider.php',
    'qformat_gift\\privacy\\provider' => '/var/www/html/plantilla/question/format/gift/classes/privacy/provider.php',
    'qformat_missingword\\privacy\\provider' => '/var/www/html/plantilla/question/format/missingword/classes/privacy/provider.php',
    'qformat_multianswer\\privacy\\provider' => '/var/www/html/plantilla/question/format/multianswer/classes/privacy/provider.php',
    'qformat_xhtml\\privacy\\provider' => '/var/www/html/plantilla/question/format/xhtml/classes/privacy/provider.php',
    'qformat_xml\\privacy\\provider' => '/var/www/html/plantilla/question/format/xml/classes/privacy/provider.php',
    'qtype_calculated\\privacy\\provider' => '/var/www/html/plantilla/question/type/calculated/classes/privacy/provider.php',
    'qtype_calculated\\qtype_calculated_answer' => '/var/www/html/plantilla/question/type/calculated/classes/qtype_calculated_answer.php',
    'qtype_calculated_qtype_calculated_answer' => '/var/www/html/plantilla/question/type/calculated/classes/qtype_calculated_answer.php',
    'qtype_calculatedmulti\\privacy\\provider' => '/var/www/html/plantilla/question/type/calculatedmulti/classes/privacy/provider.php',
    'qtype_calculatedmulti\\qtype_calculatedmulti_answer' => '/var/www/html/plantilla/question/type/calculatedmulti/classes/qtype_calculatedmulti_answer.php',
    'qtype_calculatedmulti_qtype_calculatedmulti_answer' => '/var/www/html/plantilla/question/type/calculatedmulti/classes/qtype_calculatedmulti_answer.php',
    'qtype_calculatedsimple\\privacy\\provider' => '/var/www/html/plantilla/question/type/calculatedsimple/classes/privacy/provider.php',
    'qtype_ddimageortext\\privacy\\provider' => '/var/www/html/plantilla/question/type/ddimageortext/classes/privacy/provider.php',
    'qtype_ddmarker\\privacy\\provider' => '/var/www/html/plantilla/question/type/ddmarker/classes/privacy/provider.php',
    'qtype_ddwtos\\privacy\\provider' => '/var/www/html/plantilla/question/type/ddwtos/classes/privacy/provider.php',
    'qtype_description\\privacy\\provider' => '/var/www/html/plantilla/question/type/description/classes/privacy/provider.php',
    'qtype_essay\\privacy\\provider' => '/var/www/html/plantilla/question/type/essay/classes/privacy/provider.php',
    'qtype_gapselect\\privacy\\provider' => '/var/www/html/plantilla/question/type/gapselect/classes/privacy/provider.php',
    'qtype_match\\privacy\\provider' => '/var/www/html/plantilla/question/type/match/classes/privacy/provider.php',
    'qtype_missingtype\\privacy\\provider' => '/var/www/html/plantilla/question/type/missingtype/classes/privacy/provider.php',
    'qtype_multianswer\\privacy\\provider' => '/var/www/html/plantilla/question/type/multianswer/classes/privacy/provider.php',
    'qtype_multianswer\\task\\cleanup_duplicate_subquestions' => '/var/www/html/plantilla/question/type/multianswer/classes/task/cleanup_duplicate_subquestions.php',
    'qtype_multichoice\\admin_setting_answernumbering' => '/var/www/html/plantilla/question/type/multichoice/classes/admin_setting_answernumbering.php',
    'qtype_multichoice\\privacy\\provider' => '/var/www/html/plantilla/question/type/multichoice/classes/privacy/provider.php',
    'qtype_multichoice_admin_setting_answernumbering' => '/var/www/html/plantilla/question/type/multichoice/classes/admin_setting_answernumbering.php',
    'qtype_numerical\\privacy\\provider' => '/var/www/html/plantilla/question/type/numerical/classes/privacy/provider.php',
    'qtype_ordering\\output\\correct_response' => '/var/www/html/plantilla/question/type/ordering/classes/output/correct_response.php',
    'qtype_ordering\\output\\feedback' => '/var/www/html/plantilla/question/type/ordering/classes/output/feedback.php',
    'qtype_ordering\\output\\formulation_and_controls' => '/var/www/html/plantilla/question/type/ordering/classes/output/formulation_and_controls.php',
    'qtype_ordering\\output\\num_parts_correct' => '/var/www/html/plantilla/question/type/ordering/classes/output/num_parts_correct.php',
    'qtype_ordering\\output\\renderable_base' => '/var/www/html/plantilla/question/type/ordering/classes/output/renderable_base.php',
    'qtype_ordering\\output\\specific_grade_detail_feedback' => '/var/www/html/plantilla/question/type/ordering/classes/output/specific_grade_detail_feedback.php',
    'qtype_ordering\\privacy\\provider' => '/var/www/html/plantilla/question/type/ordering/classes/privacy/provider.php',
    'qtype_ordering\\question_hint_ordering' => '/var/www/html/plantilla/question/type/ordering/classes/question_hint_ordering.php',
    'qtype_ordering_question_hint_ordering' => '/var/www/html/plantilla/question/type/ordering/classes/question_hint_ordering.php',
    'qtype_random\\privacy\\provider' => '/var/www/html/plantilla/question/type/random/classes/privacy/provider.php',
    'qtype_randomsamatch\\privacy\\provider' => '/var/www/html/plantilla/question/type/randomsamatch/classes/privacy/provider.php',
    'qtype_shortanswer\\privacy\\provider' => '/var/www/html/plantilla/question/type/shortanswer/classes/privacy/provider.php',
    'qtype_truefalse\\privacy\\provider' => '/var/www/html/plantilla/question/type/truefalse/classes/privacy/provider.php',
    'quiz_grading\\privacy\\provider' => '/var/www/html/plantilla/mod/quiz/report/grading/classes/privacy/provider.php',
    'quiz_overview\\privacy\\provider' => '/var/www/html/plantilla/mod/quiz/report/overview/classes/privacy/provider.php',
    'quiz_responses\\privacy\\provider' => '/var/www/html/plantilla/mod/quiz/report/responses/classes/privacy/provider.php',
    'quiz_statistics\\calculated' => '/var/www/html/plantilla/mod/quiz/report/statistics/classes/calculated.php',
    'quiz_statistics\\calculator' => '/var/www/html/plantilla/mod/quiz/report/statistics/classes/calculator.php',
    'quiz_statistics\\event\\observer\\attempt_submitted' => '/var/www/html/plantilla/mod/quiz/report/statistics/classes/event/observer/attempt_submitted.php',
    'quiz_statistics\\hook_callbacks' => '/var/www/html/plantilla/mod/quiz/report/statistics/classes/hook_callbacks.php',
    'quiz_statistics\\privacy\\provider' => '/var/www/html/plantilla/mod/quiz/report/statistics/classes/privacy/provider.php',
    'quiz_statistics\\quiz_attempt_deleted' => '/var/www/html/plantilla/mod/quiz/report/statistics/classes/quiz_attempt_deleted.php',
    'quiz_statistics\\task\\recalculate' => '/var/www/html/plantilla/mod/quiz/report/statistics/classes/task/recalculate.php',
    'quiz_statistics\\tests\\statistics_helper' => '/var/www/html/plantilla/mod/quiz/report/statistics/classes/tests/statistics_helper.php',
    'quiz_statistics\\tests\\statistics_test_trait' => '/var/www/html/plantilla/mod/quiz/report/statistics/classes/tests/statistics_test_trait.php',
    'quiz_statistics_calculated' => '/var/www/html/plantilla/mod/quiz/report/statistics/classes/calculated.php',
    'quiz_statistics_calculator' => '/var/www/html/plantilla/mod/quiz/report/statistics/classes/calculator.php',
    'quiz_statistics_hook_callbacks' => '/var/www/html/plantilla/mod/quiz/report/statistics/classes/hook_callbacks.php',
    'quiz_statistics_quiz_attempt_deleted' => '/var/www/html/plantilla/mod/quiz/report/statistics/classes/quiz_attempt_deleted.php',
    'quizaccess_delaybetweenattempts\\privacy\\provider' => '/var/www/html/plantilla/mod/quiz/accessrule/delaybetweenattempts/classes/privacy/provider.php',
    'quizaccess_ipaddress\\privacy\\provider' => '/var/www/html/plantilla/mod/quiz/accessrule/ipaddress/classes/privacy/provider.php',
    'quizaccess_numattempts\\privacy\\provider' => '/var/www/html/plantilla/mod/quiz/accessrule/numattempts/classes/privacy/provider.php',
    'quizaccess_offlineattempts\\privacy\\provider' => '/var/www/html/plantilla/mod/quiz/accessrule/offlineattempts/classes/privacy/provider.php',
    'quizaccess_openclosedate\\privacy\\provider' => '/var/www/html/plantilla/mod/quiz/accessrule/openclosedate/classes/privacy/provider.php',
    'quizaccess_password\\privacy\\provider' => '/var/www/html/plantilla/mod/quiz/accessrule/password/classes/privacy/provider.php',
    'quizaccess_seb\\config_key' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/config_key.php',
    'quizaccess_seb\\event\\access_prevented' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/event/access_prevented.php',
    'quizaccess_seb\\event\\template_created' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/event/template_created.php',
    'quizaccess_seb\\event\\template_deleted' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/event/template_deleted.php',
    'quizaccess_seb\\event\\template_disabled' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/event/template_disabled.php',
    'quizaccess_seb\\event\\template_enabled' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/event/template_enabled.php',
    'quizaccess_seb\\event\\template_updated' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/event/template_updated.php',
    'quizaccess_seb\\external\\validate_quiz_keys' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/external/validate_quiz_keys.php',
    'quizaccess_seb\\helper' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/helper.php',
    'quizaccess_seb\\hideif_rule' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/hideif_rule.php',
    'quizaccess_seb\\link_generator' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/link_generator.php',
    'quizaccess_seb\\local\\form\\template' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/local/form/template.php',
    'quizaccess_seb\\local\\table\\template_list' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/local/table/template_list.php',
    'quizaccess_seb\\privacy\\provider' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/privacy/provider.php',
    'quizaccess_seb\\property_list' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/property_list.php',
    'quizaccess_seb\\seb_access_manager' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/seb_access_manager.php',
    'quizaccess_seb\\seb_quiz_settings' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/seb_quiz_settings.php',
    'quizaccess_seb\\settings_provider' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/settings_provider.php',
    'quizaccess_seb\\template' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/template.php',
    'quizaccess_seb\\template_controller' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/template_controller.php',
    'quizaccess_seb_config_key' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/config_key.php',
    'quizaccess_seb_helper' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/helper.php',
    'quizaccess_seb_hideif_rule' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/hideif_rule.php',
    'quizaccess_seb_link_generator' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/link_generator.php',
    'quizaccess_seb_property_list' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/property_list.php',
    'quizaccess_seb_seb_access_manager' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/seb_access_manager.php',
    'quizaccess_seb_seb_quiz_settings' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/seb_quiz_settings.php',
    'quizaccess_seb_settings_provider' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/settings_provider.php',
    'quizaccess_seb_template' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/template.php',
    'quizaccess_seb_template_controller' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/classes/template_controller.php',
    'quizaccess_securewindow\\privacy\\provider' => '/var/www/html/plantilla/mod/quiz/accessrule/securewindow/classes/privacy/provider.php',
    'quizaccess_timelimit\\privacy\\provider' => '/var/www/html/plantilla/mod/quiz/accessrule/timelimit/classes/privacy/provider.php',
    'renderable' => '/var/www/html/plantilla/lib/classes/output/renderable.php',
    'renderer_base' => '/var/www/html/plantilla/lib/classes/output/renderer_base.php',
    'renderer_factory' => '/var/www/html/plantilla/lib/classes/output/renderer_factory/renderer_factory_interface.php',
    'renderer_factory_base' => '/var/www/html/plantilla/lib/classes/output/renderer_factory/renderer_factory_base.php',
    'report_backups\\privacy\\provider' => '/var/www/html/plantilla/report/backups/classes/privacy/provider.php',
    'report_competency\\external' => '/var/www/html/plantilla/report/competency/classes/external.php',
    'report_competency\\output\\renderer' => '/var/www/html/plantilla/report/competency/classes/output/renderer.php',
    'report_competency\\output\\report' => '/var/www/html/plantilla/report/competency/classes/output/report.php',
    'report_competency\\output\\user_course_navigation' => '/var/www/html/plantilla/report/competency/classes/output/user_course_navigation.php',
    'report_competency\\privacy\\provider' => '/var/www/html/plantilla/report/competency/classes/privacy/provider.php',
    'report_competency_external' => '/var/www/html/plantilla/report/competency/classes/external.php',
    'report_completion\\event\\report_viewed' => '/var/www/html/plantilla/report/completion/classes/event/report_viewed.php',
    'report_completion\\event\\user_report_viewed' => '/var/www/html/plantilla/report/completion/classes/event/user_report_viewed.php',
    'report_completion\\privacy\\provider' => '/var/www/html/plantilla/report/completion/classes/privacy/provider.php',
    'report_configlog\\privacy\\provider' => '/var/www/html/plantilla/report/configlog/classes/privacy/provider.php',
    'report_configlog\\reportbuilder\\local\\entities\\config_change' => '/var/www/html/plantilla/report/configlog/classes/reportbuilder/local/entities/config_change.php',
    'report_configlog\\reportbuilder\\local\\systemreports\\config_changes' => '/var/www/html/plantilla/report/configlog/classes/reportbuilder/local/systemreports/config_changes.php',
    'report_courseoverview\\privacy\\provider' => '/var/www/html/plantilla/report/courseoverview/classes/privacy/provider.php',
    'report_customsql\\event\\query_deleted' => '/var/www/html/plantilla/report/customsql/classes/event/query_deleted.php',
    'report_customsql\\event\\query_edited' => '/var/www/html/plantilla/report/customsql/classes/event/query_edited.php',
    'report_customsql\\event\\query_viewed' => '/var/www/html/plantilla/report/customsql/classes/event/query_viewed.php',
    'report_customsql\\external\\get_users' => '/var/www/html/plantilla/report/customsql/classes/external/get_users.php',
    'report_customsql\\local\\category' => '/var/www/html/plantilla/report/customsql/classes/local/category.php',
    'report_customsql\\local\\query' => '/var/www/html/plantilla/report/customsql/classes/local/query.php',
    'report_customsql\\output\\category' => '/var/www/html/plantilla/report/customsql/classes/output/category.php',
    'report_customsql\\output\\category_query' => '/var/www/html/plantilla/report/customsql/classes/output/category_query.php',
    'report_customsql\\output\\index_page' => '/var/www/html/plantilla/report/customsql/classes/output/index_page.php',
    'report_customsql\\output\\renderer' => '/var/www/html/plantilla/report/customsql/classes/output/renderer.php',
    'report_customsql\\privacy\\provider' => '/var/www/html/plantilla/report/customsql/classes/privacy/provider.php',
    'report_customsql\\task\\run_reports' => '/var/www/html/plantilla/report/customsql/classes/task/run_reports.php',
    'report_customsql\\utils' => '/var/www/html/plantilla/report/customsql/classes/utils.php',
    'report_customsql_utils' => '/var/www/html/plantilla/report/customsql/classes/utils.php',
    'report_eventlist\\filter_form' => '/var/www/html/plantilla/report/eventlist/classes/filter_form.php',
    'report_eventlist\\list_generator' => '/var/www/html/plantilla/report/eventlist/classes/list_generator.php',
    'report_eventlist\\privacy\\provider' => '/var/www/html/plantilla/report/eventlist/classes/privacy/provider.php',
    'report_eventlist\\renderer' => '/var/www/html/plantilla/report/eventlist/classes/renderer.php',
    'report_eventlist_filter_form' => '/var/www/html/plantilla/report/eventlist/classes/filter_form.php',
    'report_eventlist_list_generator' => '/var/www/html/plantilla/report/eventlist/classes/list_generator.php',
    'report_eventlist_renderer' => '/var/www/html/plantilla/report/eventlist/classes/renderer.php',
    'report_infectedfiles\\output\\renderer' => '/var/www/html/plantilla/report/infectedfiles/classes/output/renderer.php',
    'report_infectedfiles\\privacy\\provider' => '/var/www/html/plantilla/report/infectedfiles/classes/privacy/provider.php',
    'report_infectedfiles\\table\\infectedfiles_table' => '/var/www/html/plantilla/report/infectedfiles/classes/table/infectedfiles_table.php',
    'report_insights\\external' => '/var/www/html/plantilla/report/insights/classes/external.php',
    'report_insights\\output\\actions_exporter' => '/var/www/html/plantilla/report/insights/classes/output/actions_exporter.php',
    'report_insights\\output\\insight' => '/var/www/html/plantilla/report/insights/classes/output/insight.php',
    'report_insights\\output\\insights_list' => '/var/www/html/plantilla/report/insights/classes/output/insights_list.php',
    'report_insights\\output\\renderer' => '/var/www/html/plantilla/report/insights/classes/output/renderer.php',
    'report_insights\\privacy\\provider' => '/var/www/html/plantilla/report/insights/classes/privacy/provider.php',
    'report_insights_external' => '/var/www/html/plantilla/report/insights/classes/external.php',
    'report_log\\event\\report_viewed' => '/var/www/html/plantilla/report/log/classes/event/report_viewed.php',
    'report_log\\event\\user_report_viewed' => '/var/www/html/plantilla/report/log/classes/event/user_report_viewed.php',
    'report_log\\helper' => '/var/www/html/plantilla/report/log/classes/helper.php',
    'report_log\\privacy\\provider' => '/var/www/html/plantilla/report/log/classes/privacy/provider.php',
    'report_log\\renderable' => '/var/www/html/plantilla/report/log/classes/renderable.php',
    'report_log\\renderer' => '/var/www/html/plantilla/report/log/classes/renderer.php',
    'report_log\\table_log' => '/var/www/html/plantilla/report/log/classes/table_log.php',
    'report_log_helper' => '/var/www/html/plantilla/report/log/classes/helper.php',
    'report_log_renderable' => '/var/www/html/plantilla/report/log/classes/renderable.php',
    'report_log_renderer' => '/var/www/html/plantilla/report/log/classes/renderer.php',
    'report_log_table_log' => '/var/www/html/plantilla/report/log/classes/table_log.php',
    'report_loglive\\event\\report_viewed' => '/var/www/html/plantilla/report/loglive/classes/event/report_viewed.php',
    'report_loglive\\privacy\\provider' => '/var/www/html/plantilla/report/loglive/classes/privacy/provider.php',
    'report_loglive\\renderable' => '/var/www/html/plantilla/report/loglive/classes/renderable.php',
    'report_loglive\\renderer' => '/var/www/html/plantilla/report/loglive/classes/renderer.php',
    'report_loglive\\renderer_ajax' => '/var/www/html/plantilla/report/loglive/classes/renderer_ajax.php',
    'report_loglive\\table_log' => '/var/www/html/plantilla/report/loglive/classes/table_log.php',
    'report_loglive\\table_log_ajax' => '/var/www/html/plantilla/report/loglive/classes/table_log_ajax.php',
    'report_loglive_renderable' => '/var/www/html/plantilla/report/loglive/classes/renderable.php',
    'report_loglive_renderer' => '/var/www/html/plantilla/report/loglive/classes/renderer.php',
    'report_loglive_renderer_ajax' => '/var/www/html/plantilla/report/loglive/classes/renderer_ajax.php',
    'report_loglive_table_log' => '/var/www/html/plantilla/report/loglive/classes/table_log.php',
    'report_loglive_table_log_ajax' => '/var/www/html/plantilla/report/loglive/classes/table_log_ajax.php',
    'report_outline\\event\\activity_report_viewed' => '/var/www/html/plantilla/report/outline/classes/event/activity_report_viewed.php',
    'report_outline\\event\\report_viewed' => '/var/www/html/plantilla/report/outline/classes/event/report_viewed.php',
    'report_outline\\filter_form' => '/var/www/html/plantilla/report/outline/classes/filter_form.php',
    'report_outline\\output\\activitieslist' => '/var/www/html/plantilla/report/outline/classes/output/activitieslist.php',
    'report_outline\\output\\hierarchicalactivities' => '/var/www/html/plantilla/report/outline/classes/output/hierarchicalactivities.php',
    'report_outline\\privacy\\provider' => '/var/www/html/plantilla/report/outline/classes/privacy/provider.php',
    'report_outline_filter_form' => '/var/www/html/plantilla/report/outline/classes/filter_form.php',
    'report_participation\\event\\report_viewed' => '/var/www/html/plantilla/report/participation/classes/event/report_viewed.php',
    'report_participation\\privacy\\provider' => '/var/www/html/plantilla/report/participation/classes/privacy/provider.php',
    'report_performance\\privacy\\provider' => '/var/www/html/plantilla/report/performance/classes/privacy/provider.php',
    'report_progress\\local\\helper' => '/var/www/html/plantilla/report/progress/classes/local/helper.php',
    'report_progress\\output\\renderer' => '/var/www/html/plantilla/report/progress/classes/output/renderer.php',
    'report_progress\\privacy\\provider' => '/var/www/html/plantilla/report/progress/classes/privacy/provider.php',
    'report_questioninstances\\event\\report_viewed' => '/var/www/html/plantilla/report/questioninstances/classes/event/report_viewed.php',
    'report_questioninstances\\privacy\\provider' => '/var/www/html/plantilla/report/questioninstances/classes/privacy/provider.php',
    'report_security\\event\\report_viewed' => '/var/www/html/plantilla/report/security/classes/event/report_viewed.php',
    'report_security\\privacy\\provider' => '/var/www/html/plantilla/report/security/classes/privacy/provider.php',
    'report_stats\\event\\report_viewed' => '/var/www/html/plantilla/report/stats/classes/event/report_viewed.php',
    'report_stats\\event\\user_report_viewed' => '/var/www/html/plantilla/report/stats/classes/event/user_report_viewed.php',
    'report_stats\\privacy\\provider' => '/var/www/html/plantilla/report/stats/classes/privacy/provider.php',
    'report_status\\privacy\\provider' => '/var/www/html/plantilla/report/status/classes/privacy/provider.php',
    'report_themeusage\\form\\theme_usage_form' => '/var/www/html/plantilla/report/themeusage/classes/form/theme_usage_form.php',
    'report_themeusage\\privacy\\provider' => '/var/www/html/plantilla/report/themeusage/classes/privacy/provider.php',
    'report_themeusage\\reportbuilder\\local\\entities\\theme' => '/var/www/html/plantilla/report/themeusage/classes/reportbuilder/local/entities/theme.php',
    'report_themeusage\\reportbuilder\\local\\systemreports\\theme_usage_report' => '/var/www/html/plantilla/report/themeusage/classes/reportbuilder/local/systemreports/theme_usage_report.php',
    'report_usersessions\\privacy\\provider' => '/var/www/html/plantilla/report/usersessions/classes/privacy/provider.php',
    'repository_areafiles\\privacy\\provider' => '/var/www/html/plantilla/repository/areafiles/classes/privacy/provider.php',
    'repository_contentbank\\browser\\contentbank_browser' => '/var/www/html/plantilla/repository/contentbank/classes/browser/contentbank_browser.php',
    'repository_contentbank\\browser\\contentbank_browser_context_course' => '/var/www/html/plantilla/repository/contentbank/classes/browser/contentbank_browser_context_course.php',
    'repository_contentbank\\browser\\contentbank_browser_context_coursecat' => '/var/www/html/plantilla/repository/contentbank/classes/browser/contentbank_browser_context_coursecat.php',
    'repository_contentbank\\browser\\contentbank_browser_context_system' => '/var/www/html/plantilla/repository/contentbank/classes/browser/contentbank_browser_context_system.php',
    'repository_contentbank\\contentbank_search' => '/var/www/html/plantilla/repository/contentbank/classes/contentbank_search.php',
    'repository_contentbank\\helper' => '/var/www/html/plantilla/repository/contentbank/classes/helper.php',
    'repository_contentbank\\privacy\\provider' => '/var/www/html/plantilla/repository/contentbank/classes/privacy/provider.php',
    'repository_contentbank_contentbank_search' => '/var/www/html/plantilla/repository/contentbank/classes/contentbank_search.php',
    'repository_contentbank_helper' => '/var/www/html/plantilla/repository/contentbank/classes/helper.php',
    'repository_coursefiles\\privacy\\provider' => '/var/www/html/plantilla/repository/coursefiles/classes/privacy/provider.php',
    'repository_dropbox\\authentication_exception' => '/var/www/html/plantilla/repository/dropbox/classes/authentication_exception.php',
    'repository_dropbox\\dropbox' => '/var/www/html/plantilla/repository/dropbox/classes/dropbox.php',
    'repository_dropbox\\dropbox_exception' => '/var/www/html/plantilla/repository/dropbox/classes/dropbox_exception.php',
    'repository_dropbox\\privacy\\provider' => '/var/www/html/plantilla/repository/dropbox/classes/privacy/provider.php',
    'repository_dropbox\\provider_exception' => '/var/www/html/plantilla/repository/dropbox/classes/provider_exception.php',
    'repository_dropbox\\rate_limit_exception' => '/var/www/html/plantilla/repository/dropbox/classes/rate_limit_exception.php',
    'repository_dropbox\\task\\cron_task' => '/var/www/html/plantilla/repository/dropbox/classes/task/cron_task.php',
    'repository_dropbox_authentication_exception' => '/var/www/html/plantilla/repository/dropbox/classes/authentication_exception.php',
    'repository_dropbox_dropbox' => '/var/www/html/plantilla/repository/dropbox/classes/dropbox.php',
    'repository_dropbox_dropbox_exception' => '/var/www/html/plantilla/repository/dropbox/classes/dropbox_exception.php',
    'repository_dropbox_provider_exception' => '/var/www/html/plantilla/repository/dropbox/classes/provider_exception.php',
    'repository_dropbox_rate_limit_exception' => '/var/www/html/plantilla/repository/dropbox/classes/rate_limit_exception.php',
    'repository_equella\\privacy\\provider' => '/var/www/html/plantilla/repository/equella/classes/privacy/provider.php',
    'repository_filesystem\\privacy\\provider' => '/var/www/html/plantilla/repository/filesystem/classes/privacy/provider.php',
    'repository_filesystem\\task\\cron_task' => '/var/www/html/plantilla/repository/filesystem/classes/task/cron_task.php',
    'repository_flickr\\privacy\\provider' => '/var/www/html/plantilla/repository/flickr/classes/privacy/provider.php',
    'repository_flickr_public\\privacy\\provider' => '/var/www/html/plantilla/repository/flickr_public/classes/privacy/provider.php',
    'repository_googledocs\\googledocs_content' => '/var/www/html/plantilla/repository/googledocs/classes/googledocs_content.php',
    'repository_googledocs\\googledocs_content_search' => '/var/www/html/plantilla/repository/googledocs/classes/googledocs_content_search.php',
    'repository_googledocs\\helper' => '/var/www/html/plantilla/repository/googledocs/classes/helper.php',
    'repository_googledocs\\local\\browser\\googledocs_drive_content' => '/var/www/html/plantilla/repository/googledocs/classes/local/browser/googledocs_drive_content.php',
    'repository_googledocs\\local\\browser\\googledocs_root_content' => '/var/www/html/plantilla/repository/googledocs/classes/local/browser/googledocs_root_content.php',
    'repository_googledocs\\local\\browser\\googledocs_shared_drives_content' => '/var/www/html/plantilla/repository/googledocs/classes/local/browser/googledocs_shared_drives_content.php',
    'repository_googledocs\\local\\node\\file_node' => '/var/www/html/plantilla/repository/googledocs/classes/local/node/file_node.php',
    'repository_googledocs\\local\\node\\folder_node' => '/var/www/html/plantilla/repository/googledocs/classes/local/node/folder_node.php',
    'repository_googledocs\\local\\node\\node' => '/var/www/html/plantilla/repository/googledocs/classes/local/node/node.php',
    'repository_googledocs\\privacy\\provider' => '/var/www/html/plantilla/repository/googledocs/classes/privacy/provider.php',
    'repository_googledocs\\rest' => '/var/www/html/plantilla/repository/googledocs/classes/rest.php',
    'repository_googledocs_googledocs_content' => '/var/www/html/plantilla/repository/googledocs/classes/googledocs_content.php',
    'repository_googledocs_googledocs_content_search' => '/var/www/html/plantilla/repository/googledocs/classes/googledocs_content_search.php',
    'repository_googledocs_helper' => '/var/www/html/plantilla/repository/googledocs/classes/helper.php',
    'repository_googledocs_rest' => '/var/www/html/plantilla/repository/googledocs/classes/rest.php',
    'repository_local\\privacy\\provider' => '/var/www/html/plantilla/repository/local/classes/privacy/provider.php',
    'repository_merlot\\privacy\\provider' => '/var/www/html/plantilla/repository/merlot/classes/privacy/provider.php',
    'repository_nextcloud\\access_controlled_link_manager' => '/var/www/html/plantilla/repository/nextcloud/classes/access_controlled_link_manager.php',
    'repository_nextcloud\\configuration_exception' => '/var/www/html/plantilla/repository/nextcloud/classes/configuration_exception.php',
    'repository_nextcloud\\issuer_management' => '/var/www/html/plantilla/repository/nextcloud/classes/issuer_management.php',
    'repository_nextcloud\\ocs_client' => '/var/www/html/plantilla/repository/nextcloud/classes/ocs_client.php',
    'repository_nextcloud\\privacy\\provider' => '/var/www/html/plantilla/repository/nextcloud/classes/privacy/provider.php',
    'repository_nextcloud\\request_exception' => '/var/www/html/plantilla/repository/nextcloud/classes/request_exception.php',
    'repository_nextcloud_access_controlled_link_manager' => '/var/www/html/plantilla/repository/nextcloud/classes/access_controlled_link_manager.php',
    'repository_nextcloud_configuration_exception' => '/var/www/html/plantilla/repository/nextcloud/classes/configuration_exception.php',
    'repository_nextcloud_issuer_management' => '/var/www/html/plantilla/repository/nextcloud/classes/issuer_management.php',
    'repository_nextcloud_ocs_client' => '/var/www/html/plantilla/repository/nextcloud/classes/ocs_client.php',
    'repository_nextcloud_request_exception' => '/var/www/html/plantilla/repository/nextcloud/classes/request_exception.php',
    'repository_onedrive\\access' => '/var/www/html/plantilla/repository/onedrive/classes/access.php',
    'repository_onedrive\\privacy\\provider' => '/var/www/html/plantilla/repository/onedrive/classes/privacy/provider.php',
    'repository_onedrive\\remove_temp_access_task' => '/var/www/html/plantilla/repository/onedrive/classes/remove_temp_access_task.php',
    'repository_onedrive\\rest' => '/var/www/html/plantilla/repository/onedrive/classes/rest.php',
    'repository_onedrive_access' => '/var/www/html/plantilla/repository/onedrive/classes/access.php',
    'repository_onedrive_remove_temp_access_task' => '/var/www/html/plantilla/repository/onedrive/classes/remove_temp_access_task.php',
    'repository_onedrive_rest' => '/var/www/html/plantilla/repository/onedrive/classes/rest.php',
    'repository_recent\\privacy\\provider' => '/var/www/html/plantilla/repository/recent/classes/privacy/provider.php',
    'repository_s3\\privacy\\provider' => '/var/www/html/plantilla/repository/s3/classes/privacy/provider.php',
    'repository_upload\\privacy\\provider' => '/var/www/html/plantilla/repository/upload/classes/privacy/provider.php',
    'repository_url\\privacy\\provider' => '/var/www/html/plantilla/repository/url/classes/privacy/provider.php',
    'repository_user\\privacy\\provider' => '/var/www/html/plantilla/repository/user/classes/privacy/provider.php',
    'repository_webdav\\privacy\\provider' => '/var/www/html/plantilla/repository/webdav/classes/privacy/provider.php',
    'repository_wikimedia\\privacy\\provider' => '/var/www/html/plantilla/repository/wikimedia/classes/privacy/provider.php',
    'repository_youtube\\privacy\\provider' => '/var/www/html/plantilla/repository/youtube/classes/privacy/provider.php',
    'require_login_exception' => '/var/www/html/plantilla/lib/classes/exception/require_login_exception.php',
    'require_login_session_timeout_exception' => '/var/www/html/plantilla/lib/classes/exception/require_login_session_timeout_exception.php',
    'required_capability_exception' => '/var/www/html/plantilla/lib/classes/exception/required_capability_exception.php',
    'scormreport_basic\\privacy\\provider' => '/var/www/html/plantilla/mod/scorm/report/basic/classes/privacy/provider.php',
    'scormreport_basic\\report' => '/var/www/html/plantilla/mod/scorm/report/basic/classes/report.php',
    'scormreport_basic_report' => '/var/www/html/plantilla/mod/scorm/report/basic/classes/report.php',
    'scormreport_graphs\\privacy\\provider' => '/var/www/html/plantilla/mod/scorm/report/graphs/classes/privacy/provider.php',
    'scormreport_graphs\\report' => '/var/www/html/plantilla/mod/scorm/report/graphs/classes/report.php',
    'scormreport_graphs_report' => '/var/www/html/plantilla/mod/scorm/report/graphs/classes/report.php',
    'scormreport_interactions\\privacy\\provider' => '/var/www/html/plantilla/mod/scorm/report/interactions/classes/privacy/provider.php',
    'scormreport_interactions\\report' => '/var/www/html/plantilla/mod/scorm/report/interactions/classes/report.php',
    'scormreport_interactions_report' => '/var/www/html/plantilla/mod/scorm/report/interactions/classes/report.php',
    'scormreport_objectives\\privacy\\provider' => '/var/www/html/plantilla/mod/scorm/report/objectives/classes/privacy/provider.php',
    'scormreport_objectives\\report' => '/var/www/html/plantilla/mod/scorm/report/objectives/classes/report.php',
    'scormreport_objectives_report' => '/var/www/html/plantilla/mod/scorm/report/objectives/classes/report.php',
    'search_simpledb\\engine' => '/var/www/html/plantilla/search/engine/simpledb/classes/engine.php',
    'search_simpledb\\privacy\\provider' => '/var/www/html/plantilla/search/engine/simpledb/classes/privacy/provider.php',
    'search_simpledb_engine' => '/var/www/html/plantilla/search/engine/simpledb/classes/engine.php',
    'search_solr\\check\\connection' => '/var/www/html/plantilla/search/engine/solr/classes/check/connection.php',
    'search_solr\\document' => '/var/www/html/plantilla/search/engine/solr/classes/document.php',
    'search_solr\\engine' => '/var/www/html/plantilla/search/engine/solr/classes/engine.php',
    'search_solr\\privacy\\provider' => '/var/www/html/plantilla/search/engine/solr/classes/privacy/provider.php',
    'search_solr\\schema' => '/var/www/html/plantilla/search/engine/solr/classes/schema.php',
    'search_solr_document' => '/var/www/html/plantilla/search/engine/solr/classes/document.php',
    'search_solr_engine' => '/var/www/html/plantilla/search/engine/solr/classes/engine.php',
    'search_solr_schema' => '/var/www/html/plantilla/search/engine/solr/classes/schema.php',
    'single_button' => '/var/www/html/plantilla/lib/classes/output/single_button.php',
    'single_select' => '/var/www/html/plantilla/lib/classes/output/single_select.php',
    'smsgateway_aws\\gateway' => '/var/www/html/plantilla/sms/gateway/aws/classes/gateway.php',
    'smsgateway_aws\\helper' => '/var/www/html/plantilla/sms/gateway/aws/classes/helper.php',
    'smsgateway_aws\\hook_listener' => '/var/www/html/plantilla/sms/gateway/aws/classes/hook_listener.php',
    'smsgateway_aws\\local\\aws_sms_service_provider' => '/var/www/html/plantilla/sms/gateway/aws/classes/local/aws_sms_service_provider.php',
    'smsgateway_aws\\local\\service\\aws_sns' => '/var/www/html/plantilla/sms/gateway/aws/classes/local/service/aws_sns.php',
    'smsgateway_aws\\privacy\\provider' => '/var/www/html/plantilla/sms/gateway/aws/classes/privacy/provider.php',
    'smsgateway_aws_gateway' => '/var/www/html/plantilla/sms/gateway/aws/classes/gateway.php',
    'smsgateway_aws_helper' => '/var/www/html/plantilla/sms/gateway/aws/classes/helper.php',
    'smsgateway_aws_hook_listener' => '/var/www/html/plantilla/sms/gateway/aws/classes/hook_listener.php',
    'smsgateway_modica\\gateway' => '/var/www/html/plantilla/sms/gateway/modica/classes/gateway.php',
    'smsgateway_modica\\hook_listener' => '/var/www/html/plantilla/sms/gateway/modica/classes/hook_listener.php',
    'smsgateway_modica\\privacy\\provider' => '/var/www/html/plantilla/sms/gateway/modica/classes/privacy/provider.php',
    'smsgateway_modica_gateway' => '/var/www/html/plantilla/sms/gateway/modica/classes/gateway.php',
    'smsgateway_modica_hook_listener' => '/var/www/html/plantilla/sms/gateway/modica/classes/hook_listener.php',
    'standard_renderer_factory' => '/var/www/html/plantilla/lib/classes/output/renderer_factory/standard_renderer_factory.php',
    'table_dataformat_export_format' => '/var/www/html/plantilla/lib/table/classes/dataformat_export_format.php',
    'table_default_export_format_parent' => '/var/www/html/plantilla/lib/table/classes/base_export_format.php',
    'table_sql' => '/var/www/html/plantilla/lib/table/classes/sql_table.php',
    'tabobject' => '/var/www/html/plantilla/lib/classes/output/tabobject.php',
    'tabtree' => '/var/www/html/plantilla/lib/classes/output/tabtree.php',
    'templatable' => '/var/www/html/plantilla/lib/classes/output/templatable.php',
    'text_progress_trace' => '/var/www/html/plantilla/lib/classes/output/progress_trace/text_progress_trace.php',
    'theme_boost\\admin_settingspage_tabs' => '/var/www/html/plantilla/theme/boost/classes/admin_settingspage_tabs.php',
    'theme_boost\\autoprefixer' => '/var/www/html/plantilla/theme/boost/classes/autoprefixer.php',
    'theme_boost\\boostnavbar' => '/var/www/html/plantilla/theme/boost/classes/boostnavbar.php',
    'theme_boost\\output\\core_renderer' => '/var/www/html/plantilla/theme/boost/classes/output/core_renderer.php',
    'theme_boost\\privacy\\provider' => '/var/www/html/plantilla/theme/boost/classes/privacy/provider.php',
    'theme_boost_admin_settingspage_tabs' => '/var/www/html/plantilla/theme/boost/classes/admin_settingspage_tabs.php',
    'theme_boost_autoprefixer' => '/var/www/html/plantilla/theme/boost/classes/autoprefixer.php',
    'theme_boost_boostnavbar' => '/var/www/html/plantilla/theme/boost/classes/boostnavbar.php',
    'theme_classic\\output\\core_renderer' => '/var/www/html/plantilla/theme/classic/classes/output/core_renderer.php',
    'theme_classic\\output\\icon_system_fontawesome' => '/var/www/html/plantilla/theme/classic/classes/output/icon_system_fontawesome.php',
    'theme_classic\\privacy\\provider' => '/var/www/html/plantilla/theme/classic/classes/privacy/provider.php',
    'theme_config' => '/var/www/html/plantilla/lib/classes/output/theme_config.php',
    'theme_moove\\api\\accessibility' => '/var/www/html/plantilla/theme/moove/classes/api/accessibility.php',
    'theme_moove\\core_h5p_renderer' => '/var/www/html/plantilla/theme/moove/classes/core_h5p_renderer.php',
    'theme_moove\\mod_hvp_renderer' => '/var/www/html/plantilla/theme/moove/classes/mod_hvp_renderer.php',
    'theme_moove\\output\\boostnavbar' => '/var/www/html/plantilla/theme/moove/classes/output/boostnavbar.php',
    'theme_moove\\output\\core\\admin_renderer' => '/var/www/html/plantilla/theme/moove/classes/output/core/admin_renderer.php',
    'theme_moove\\output\\core\\course_renderer' => '/var/www/html/plantilla/theme/moove/classes/output/core/course_renderer.php',
    'theme_moove\\output\\core_course\\activity_navigation' => '/var/www/html/plantilla/theme/moove/classes/output/core_course/activity_navigation.php',
    'theme_moove\\output\\core_renderer' => '/var/www/html/plantilla/theme/moove/classes/output/core_renderer.php',
    'theme_moove\\output\\renderer' => '/var/www/html/plantilla/theme/moove/classes/output/renderer.php',
    'theme_moove\\privacy\\provider' => '/var/www/html/plantilla/theme/moove/classes/privacy/provider.php',
    'theme_moove\\util\\course' => '/var/www/html/plantilla/theme/moove/classes/util/course.php',
    'theme_moove\\util\\extras' => '/var/www/html/plantilla/theme/moove/classes/util/extras.php',
    'theme_moove\\util\\settings' => '/var/www/html/plantilla/theme/moove/classes/util/settings.php',
    'theme_moove\\util\\user' => '/var/www/html/plantilla/theme/moove/classes/util/user.php',
    'theme_moove_core_h5p_renderer' => '/var/www/html/plantilla/theme/moove/classes/core_h5p_renderer.php',
    'theme_moove_mod_hvp_renderer' => '/var/www/html/plantilla/theme/moove/classes/mod_hvp_renderer.php',
    'theme_overridden_renderer_factory' => '/var/www/html/plantilla/lib/classes/output/renderer_factory/theme_overridden_renderer_factory.php',
    'tiny_accessibilitychecker\\plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/accessibilitychecker/classes/plugininfo.php',
    'tiny_accessibilitychecker\\privacy\\provider' => '/var/www/html/plantilla/lib/editor/tiny/plugins/accessibilitychecker/classes/privacy/provider.php',
    'tiny_accessibilitychecker_plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/accessibilitychecker/classes/plugininfo.php',
    'tiny_aiplacement\\plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/aiplacement/classes/plugininfo.php',
    'tiny_aiplacement\\privacy\\provider' => '/var/www/html/plantilla/lib/editor/tiny/plugins/aiplacement/classes/privacy/provider.php',
    'tiny_aiplacement_plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/aiplacement/classes/plugininfo.php',
    'tiny_autosave\\autosave_manager' => '/var/www/html/plantilla/lib/editor/tiny/plugins/autosave/classes/autosave_manager.php',
    'tiny_autosave\\external\\reset_autosave_session' => '/var/www/html/plantilla/lib/editor/tiny/plugins/autosave/classes/external/reset_autosave_session.php',
    'tiny_autosave\\external\\resume_autosave_session' => '/var/www/html/plantilla/lib/editor/tiny/plugins/autosave/classes/external/resume_autosave_session.php',
    'tiny_autosave\\external\\update_autosave_session_content' => '/var/www/html/plantilla/lib/editor/tiny/plugins/autosave/classes/external/update_autosave_session_content.php',
    'tiny_autosave\\plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/autosave/classes/plugininfo.php',
    'tiny_autosave\\privacy\\provider' => '/var/www/html/plantilla/lib/editor/tiny/plugins/autosave/classes/privacy/provider.php',
    'tiny_autosave_autosave_manager' => '/var/www/html/plantilla/lib/editor/tiny/plugins/autosave/classes/autosave_manager.php',
    'tiny_autosave_plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/autosave/classes/plugininfo.php',
    'tiny_equation\\external\\filter' => '/var/www/html/plantilla/lib/editor/tiny/plugins/equation/classes/external/filter.php',
    'tiny_equation\\plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/equation/classes/plugininfo.php',
    'tiny_equation\\privacy\\provider' => '/var/www/html/plantilla/lib/editor/tiny/plugins/equation/classes/privacy/provider.php',
    'tiny_equation_plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/equation/classes/plugininfo.php',
    'tiny_h5p\\plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/h5p/classes/plugininfo.php',
    'tiny_h5p\\privacy\\provider' => '/var/www/html/plantilla/lib/editor/tiny/plugins/h5p/classes/privacy/provider.php',
    'tiny_h5p_plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/h5p/classes/plugininfo.php',
    'tiny_html\\plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/html/classes/plugininfo.php',
    'tiny_html\\privacy\\provider' => '/var/www/html/plantilla/lib/editor/tiny/plugins/html/classes/privacy/provider.php',
    'tiny_html_plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/html/classes/plugininfo.php',
    'tiny_link\\plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/link/classes/plugininfo.php',
    'tiny_link\\privacy\\provider' => '/var/www/html/plantilla/lib/editor/tiny/plugins/link/classes/privacy/provider.php',
    'tiny_link_plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/link/classes/plugininfo.php',
    'tiny_media\\external\\preview' => '/var/www/html/plantilla/lib/editor/tiny/plugins/media/classes/external/preview.php',
    'tiny_media\\form\\manage_files_form' => '/var/www/html/plantilla/lib/editor/tiny/plugins/media/classes/form/manage_files_form.php',
    'tiny_media\\plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/media/classes/plugininfo.php',
    'tiny_media\\privacy\\provider' => '/var/www/html/plantilla/lib/editor/tiny/plugins/media/classes/privacy/provider.php',
    'tiny_media_plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/media/classes/plugininfo.php',
    'tiny_noautolink\\plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/noautolink/classes/plugininfo.php',
    'tiny_noautolink\\privacy\\provider' => '/var/www/html/plantilla/lib/editor/tiny/plugins/noautolink/classes/privacy/provider.php',
    'tiny_noautolink_plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/noautolink/classes/plugininfo.php',
    'tiny_premium\\external\\get_api_key' => '/var/www/html/plantilla/lib/editor/tiny/plugins/premium/classes/external/get_api_key.php',
    'tiny_premium\\local\\admin_setting_tiny_premium_plugins' => '/var/www/html/plantilla/lib/editor/tiny/plugins/premium/classes/local/admin_setting_tiny_premium_plugins.php',
    'tiny_premium\\manager' => '/var/www/html/plantilla/lib/editor/tiny/plugins/premium/classes/manager.php',
    'tiny_premium\\plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/premium/classes/plugininfo.php',
    'tiny_premium\\privacy\\provider' => '/var/www/html/plantilla/lib/editor/tiny/plugins/premium/classes/privacy/provider.php',
    'tiny_premium_manager' => '/var/www/html/plantilla/lib/editor/tiny/plugins/premium/classes/manager.php',
    'tiny_premium_plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/premium/classes/plugininfo.php',
    'tiny_recordrtc\\constants' => '/var/www/html/plantilla/lib/editor/tiny/plugins/recordrtc/classes/constants.php',
    'tiny_recordrtc\\plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/recordrtc/classes/plugininfo.php',
    'tiny_recordrtc\\privacy\\provider' => '/var/www/html/plantilla/lib/editor/tiny/plugins/recordrtc/classes/privacy/provider.php',
    'tiny_recordrtc_constants' => '/var/www/html/plantilla/lib/editor/tiny/plugins/recordrtc/classes/constants.php',
    'tiny_recordrtc_plugininfo' => '/var/www/html/plantilla/lib/editor/tiny/plugins/recordrtc/classes/plugininfo.php',
    'tool_admin_presets\\event\\preset_deleted' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/event/preset_deleted.php',
    'tool_admin_presets\\event\\preset_downloaded' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/event/preset_downloaded.php',
    'tool_admin_presets\\event\\preset_exported' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/event/preset_exported.php',
    'tool_admin_presets\\event\\preset_imported' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/event/preset_imported.php',
    'tool_admin_presets\\event\\preset_loaded' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/event/preset_loaded.php',
    'tool_admin_presets\\event\\preset_previewed' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/event/preset_previewed.php',
    'tool_admin_presets\\event\\preset_reverted' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/event/preset_reverted.php',
    'tool_admin_presets\\event\\presets_listed' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/event/presets_listed.php',
    'tool_admin_presets\\external\\delete_preset' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/external/delete_preset.php',
    'tool_admin_presets\\form\\continue_form' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/form/continue_form.php',
    'tool_admin_presets\\form\\export_form' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/form/export_form.php',
    'tool_admin_presets\\form\\import_form' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/form/import_form.php',
    'tool_admin_presets\\form\\load_form' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/form/load_form.php',
    'tool_admin_presets\\local\\action\\base' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/local/action/base.php',
    'tool_admin_presets\\local\\action\\delete' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/local/action/delete.php',
    'tool_admin_presets\\local\\action\\export' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/local/action/export.php',
    'tool_admin_presets\\local\\action\\import' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/local/action/import.php',
    'tool_admin_presets\\local\\action\\load' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/local/action/load.php',
    'tool_admin_presets\\local\\action\\rollback' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/local/action/rollback.php',
    'tool_admin_presets\\output\\export_import' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/output/export_import.php',
    'tool_admin_presets\\output\\presets_list' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/output/presets_list.php',
    'tool_admin_presets\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/privacy/provider.php',
    'tool_admin_presets\\reportbuilder\\local\\entities\\admin_preset' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/reportbuilder/local/entities/admin_preset.php',
    'tool_admin_presets\\reportbuilder\\local\\systemreports\\admin_presets' => '/var/www/html/plantilla/admin/tool/admin_presets/classes/reportbuilder/local/systemreports/admin_presets.php',
    'tool_analytics\\clihelper' => '/var/www/html/plantilla/admin/tool/analytics/classes/clihelper.php',
    'tool_analytics\\external' => '/var/www/html/plantilla/admin/tool/analytics/classes/external.php',
    'tool_analytics\\output\\form\\edit_model' => '/var/www/html/plantilla/admin/tool/analytics/classes/output/form/edit_model.php',
    'tool_analytics\\output\\form\\import_model' => '/var/www/html/plantilla/admin/tool/analytics/classes/output/form/import_model.php',
    'tool_analytics\\output\\helper' => '/var/www/html/plantilla/admin/tool/analytics/classes/output/helper.php',
    'tool_analytics\\output\\insights_report' => '/var/www/html/plantilla/admin/tool/analytics/classes/output/insights_report.php',
    'tool_analytics\\output\\invalid_analysables' => '/var/www/html/plantilla/admin/tool/analytics/classes/output/invalid_analysables.php',
    'tool_analytics\\output\\model_logs' => '/var/www/html/plantilla/admin/tool/analytics/classes/output/model_logs.php',
    'tool_analytics\\output\\models_list' => '/var/www/html/plantilla/admin/tool/analytics/classes/output/models_list.php',
    'tool_analytics\\output\\renderer' => '/var/www/html/plantilla/admin/tool/analytics/classes/output/renderer.php',
    'tool_analytics\\output\\restorable_models' => '/var/www/html/plantilla/admin/tool/analytics/classes/output/restorable_models.php',
    'tool_analytics\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/analytics/classes/privacy/provider.php',
    'tool_analytics\\task\\predict_models' => '/var/www/html/plantilla/admin/tool/analytics/classes/task/predict_models.php',
    'tool_analytics\\task\\train_models' => '/var/www/html/plantilla/admin/tool/analytics/classes/task/train_models.php',
    'tool_analytics_clihelper' => '/var/www/html/plantilla/admin/tool/analytics/classes/clihelper.php',
    'tool_analytics_external' => '/var/www/html/plantilla/admin/tool/analytics/classes/external.php',
    'tool_availabilityconditions\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/availabilityconditions/classes/privacy/provider.php',
    'tool_behat\\external\\get_entity_generator' => '/var/www/html/plantilla/admin/tool/behat/classes/external/get_entity_generator.php',
    'tool_behat\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/behat/classes/privacy/provider.php',
    'tool_brickfield\\accessibility' => '/var/www/html/plantilla/admin/tool/brickfield/classes/accessibility.php',
    'tool_brickfield\\analysis' => '/var/www/html/plantilla/admin/tool/brickfield/classes/analysis.php',
    'tool_brickfield\\area_base' => '/var/www/html/plantilla/admin/tool/brickfield/classes/area_base.php',
    'tool_brickfield\\brickfieldconnect' => '/var/www/html/plantilla/admin/tool/brickfield/classes/brickfieldconnect.php',
    'tool_brickfield\\event\\analysis_requested' => '/var/www/html/plantilla/admin/tool/brickfield/classes/event/analysis_requested.php',
    'tool_brickfield\\event\\report_downloaded' => '/var/www/html/plantilla/admin/tool/brickfield/classes/event/report_downloaded.php',
    'tool_brickfield\\event\\report_viewed' => '/var/www/html/plantilla/admin/tool/brickfield/classes/event/report_viewed.php',
    'tool_brickfield\\eventobservers' => '/var/www/html/plantilla/admin/tool/brickfield/classes/eventobservers.php',
    'tool_brickfield\\form\\registration_form' => '/var/www/html/plantilla/admin/tool/brickfield/classes/form/registration_form.php',
    'tool_brickfield\\local\\areas\\core_course\\base' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/core_course/base.php',
    'tool_brickfield\\local\\areas\\core_course\\category_base' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/core_course/category_base.php',
    'tool_brickfield\\local\\areas\\core_course\\category_description' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/core_course/category_description.php',
    'tool_brickfield\\local\\areas\\core_course\\category_name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/core_course/category_name.php',
    'tool_brickfield\\local\\areas\\core_course\\fullname' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/core_course/fullname.php',
    'tool_brickfield\\local\\areas\\core_course\\sectionname' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/core_course/sectionname.php',
    'tool_brickfield\\local\\areas\\core_course\\sectionsummary' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/core_course/sectionsummary.php',
    'tool_brickfield\\local\\areas\\core_course\\shortname' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/core_course/shortname.php',
    'tool_brickfield\\local\\areas\\core_course\\summary' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/core_course/summary.php',
    'tool_brickfield\\local\\areas\\core_question\\answerbase' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/core_question/answerbase.php',
    'tool_brickfield\\local\\areas\\core_question\\base' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/core_question/base.php',
    'tool_brickfield\\local\\areas\\core_question\\generalfeedback' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/core_question/generalfeedback.php',
    'tool_brickfield\\local\\areas\\core_question\\questionanswers' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/core_question/questionanswers.php',
    'tool_brickfield\\local\\areas\\core_question\\questionfeedback' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/core_question/questionfeedback.php',
    'tool_brickfield\\local\\areas\\core_question\\questionname' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/core_question/questionname.php',
    'tool_brickfield\\local\\areas\\core_question\\questiontext' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/core_question/questiontext.php',
    'tool_brickfield\\local\\areas\\mod_assign\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_assign/intro.php',
    'tool_brickfield\\local\\areas\\mod_assign\\name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_assign/name.php',
    'tool_brickfield\\local\\areas\\mod_book\\base' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_book/base.php',
    'tool_brickfield\\local\\areas\\mod_book\\chaptercontent' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_book/chaptercontent.php',
    'tool_brickfield\\local\\areas\\mod_book\\chaptertitle' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_book/chaptertitle.php',
    'tool_brickfield\\local\\areas\\mod_book\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_book/intro.php',
    'tool_brickfield\\local\\areas\\mod_book\\name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_book/name.php',
    'tool_brickfield\\local\\areas\\mod_choice\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_choice/intro.php',
    'tool_brickfield\\local\\areas\\mod_choice\\name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_choice/name.php',
    'tool_brickfield\\local\\areas\\mod_choice\\option' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_choice/option.php',
    'tool_brickfield\\local\\areas\\mod_data\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_data/intro.php',
    'tool_brickfield\\local\\areas\\mod_data\\name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_data/name.php',
    'tool_brickfield\\local\\areas\\mod_feedback\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_feedback/intro.php',
    'tool_brickfield\\local\\areas\\mod_feedback\\name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_feedback/name.php',
    'tool_brickfield\\local\\areas\\mod_folder\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_folder/intro.php',
    'tool_brickfield\\local\\areas\\mod_folder\\name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_folder/name.php',
    'tool_brickfield\\local\\areas\\mod_forum\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_forum/intro.php',
    'tool_brickfield\\local\\areas\\mod_forum\\name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_forum/name.php',
    'tool_brickfield\\local\\areas\\mod_glossary\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_glossary/intro.php',
    'tool_brickfield\\local\\areas\\mod_glossary\\name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_glossary/name.php',
    'tool_brickfield\\local\\areas\\mod_imscp\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_imscp/intro.php',
    'tool_brickfield\\local\\areas\\mod_imscp\\name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_imscp/name.php',
    'tool_brickfield\\local\\areas\\mod_label\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_label/intro.php',
    'tool_brickfield\\local\\areas\\mod_lesson\\answer_answer' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_lesson/answer_answer.php',
    'tool_brickfield\\local\\areas\\mod_lesson\\answer_base' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_lesson/answer_base.php',
    'tool_brickfield\\local\\areas\\mod_lesson\\answer_response' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_lesson/answer_response.php',
    'tool_brickfield\\local\\areas\\mod_lesson\\base' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_lesson/base.php',
    'tool_brickfield\\local\\areas\\mod_lesson\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_lesson/intro.php',
    'tool_brickfield\\local\\areas\\mod_lesson\\name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_lesson/name.php',
    'tool_brickfield\\local\\areas\\mod_lesson\\page_base' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_lesson/page_base.php',
    'tool_brickfield\\local\\areas\\mod_lesson\\pagecontent' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_lesson/pagecontent.php',
    'tool_brickfield\\local\\areas\\mod_lesson\\pagetitle' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_lesson/pagetitle.php',
    'tool_brickfield\\local\\areas\\mod_lti\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_lti/intro.php',
    'tool_brickfield\\local\\areas\\mod_lti\\name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_lti/name.php',
    'tool_brickfield\\local\\areas\\mod_page\\content' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_page/content.php',
    'tool_brickfield\\local\\areas\\mod_page\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_page/intro.php',
    'tool_brickfield\\local\\areas\\mod_page\\name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_page/name.php',
    'tool_brickfield\\local\\areas\\mod_quiz\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_quiz/intro.php',
    'tool_brickfield\\local\\areas\\mod_quiz\\name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_quiz/name.php',
    'tool_brickfield\\local\\areas\\mod_resource\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_resource/intro.php',
    'tool_brickfield\\local\\areas\\mod_resource\\name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_resource/name.php',
    'tool_brickfield\\local\\areas\\mod_scorm\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_scorm/intro.php',
    'tool_brickfield\\local\\areas\\mod_scorm\\name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_scorm/name.php',
    'tool_brickfield\\local\\areas\\mod_url\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_url/intro.php',
    'tool_brickfield\\local\\areas\\mod_url\\name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_url/name.php',
    'tool_brickfield\\local\\areas\\mod_wiki\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_wiki/intro.php',
    'tool_brickfield\\local\\areas\\mod_wiki\\name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_wiki/name.php',
    'tool_brickfield\\local\\areas\\mod_workshop\\intro' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_workshop/intro.php',
    'tool_brickfield\\local\\areas\\mod_workshop\\name' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/mod_workshop/name.php',
    'tool_brickfield\\local\\areas\\module_area_base' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/areas/module_area_base.php',
    'tool_brickfield\\local\\htmlchecker\\brickfield_accessibility' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/brickfield_accessibility.php',
    'tool_brickfield\\local\\htmlchecker\\brickfield_accessibility_guideline' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/brickfield_accessibility_guideline.php',
    'tool_brickfield\\local\\htmlchecker\\brickfield_accessibility_report_item' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/brickfield_accessibility_report_item.php',
    'tool_brickfield\\local\\htmlchecker\\brickfield_accessibility_reporter' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/brickfield_accessibility_reporter.php',
    'tool_brickfield\\local\\htmlchecker\\common\\body_color_contrast' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/body_color_contrast.php',
    'tool_brickfield\\local\\htmlchecker\\common\\body_wai_ert_color_contrast' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/body_wai_ert_color_contrast.php',
    'tool_brickfield\\local\\htmlchecker\\common\\brickfield_accessibility_color_test' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/brickfield_accessibility_color_test.php',
    'tool_brickfield\\local\\htmlchecker\\common\\brickfield_accessibility_css' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/brickfield_accessibility_css.php',
    'tool_brickfield\\local\\htmlchecker\\common\\brickfield_accessibility_dom_element' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/brickfield_accessibility_dom_element.php',
    'tool_brickfield\\local\\htmlchecker\\common\\brickfield_accessibility_header_test' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/brickfield_accessibility_header_test.php',
    'tool_brickfield\\local\\htmlchecker\\common\\brickfield_accessibility_table_test' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/brickfield_accessibility_table_test.php',
    'tool_brickfield\\local\\htmlchecker\\common\\brickfield_accessibility_tag_test' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/brickfield_accessibility_tag_test.php',
    'tool_brickfield\\local\\htmlchecker\\common\\brickfield_accessibility_test' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/brickfield_accessibility_test.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\a_links_dont_open_new_window' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/a_links_dont_open_new_window.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\a_must_contain_text' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/a_must_contain_text.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\a_suspicious_link_text' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/a_suspicious_link_text.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\area_dont_open_new_window' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/area_dont_open_new_window.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\area_has_alt_value' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/area_has_alt_value.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\basefont_is_not_used' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/basefont_is_not_used.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\blink_is_not_used' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/blink_is_not_used.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\bold_is_not_used' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/bold_is_not_used.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\content_too_long' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/content_too_long.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\css_text_has_contrast' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/css_text_has_contrast.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\embed_has_associated_no_embed' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/embed_has_associated_no_embed.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\header_h3' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/header_h3.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\headers_have_text' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/headers_have_text.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\i_is_not_used' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/i_is_not_used.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\img_alt_is_different' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/img_alt_is_different.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\img_alt_is_too_long' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/img_alt_is_too_long.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\img_alt_not_empty_in_anchor' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/img_alt_not_empty_in_anchor.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\img_alt_not_place_holder' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/img_alt_not_place_holder.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\img_has_alt' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/img_has_alt.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\img_with_map_has_use_map' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/img_with_map_has_use_map.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\legend_text_not_empty' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/legend_text_not_empty.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\marquee_is_not_used' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/marquee_is_not_used.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\no_headings' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/no_headings.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\object_must_have_embed' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/object_must_have_embed.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\object_must_have_title' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/object_must_have_title.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\object_must_have_valid_title' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/object_must_have_valid_title.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\strike_is_not_used' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/strike_is_not_used.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\table_data_should_have_th' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/table_data_should_have_th.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\table_summary_does_not_duplicate_caption' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/table_summary_does_not_duplicate_caption.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\table_td_should_not_merge' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/table_td_should_not_merge.php',
    'tool_brickfield\\local\\htmlchecker\\common\\checks\\table_th_should_have_scope' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/checks/table_th_should_have_scope.php',
    'tool_brickfield\\local\\htmlchecker\\common\\html_elements' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/html_elements.php',
    'tool_brickfield\\local\\htmlchecker\\common\\input_has_label' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/input_has_label.php',
    'tool_brickfield\\local\\htmlchecker\\common\\input_tab_index' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/common/input_tab_index.php',
    'tool_brickfield\\local\\htmlchecker\\guidelines\\brickfield_guideline' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/guidelines/brickfield_guideline.php',
    'tool_brickfield\\local\\htmlchecker\\guidelines\\brickfield_textonly_guideline' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/guidelines/brickfield_textonly_guideline.php',
    'tool_brickfield\\local\\htmlchecker\\reporters\\report_array' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/reporters/report_array.php',
    'tool_brickfield\\local\\htmlchecker\\reporters\\report_codehighlight' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/reporters/report_codehighlight.php',
    'tool_brickfield\\local\\htmlchecker\\reporters\\report_demo' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/reporters/report_demo.php',
    'tool_brickfield\\local\\htmlchecker\\reporters\\report_static' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/reporters/report_static.php',
    'tool_brickfield\\local\\htmlchecker\\reporters\\report_xml' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/htmlchecker/reporters/report_xml.php',
    'tool_brickfield\\local\\tool\\activityresults' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/tool/activityresults.php',
    'tool_brickfield\\local\\tool\\advanced' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/tool/advanced.php',
    'tool_brickfield\\local\\tool\\bfpdf' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/tool/bfpdf.php',
    'tool_brickfield\\local\\tool\\checktyperesults' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/tool/checktyperesults.php',
    'tool_brickfield\\local\\tool\\errors' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/tool/errors.php',
    'tool_brickfield\\local\\tool\\filter' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/tool/filter.php',
    'tool_brickfield\\local\\tool\\printable' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/tool/printable.php',
    'tool_brickfield\\local\\tool\\tool' => '/var/www/html/plantilla/admin/tool/brickfield/classes/local/tool/tool.php',
    'tool_brickfield\\manager' => '/var/www/html/plantilla/admin/tool/brickfield/classes/manager.php',
    'tool_brickfield\\output\\activityresults\\renderer' => '/var/www/html/plantilla/admin/tool/brickfield/classes/output/activityresults/renderer.php',
    'tool_brickfield\\output\\advanced\\renderer' => '/var/www/html/plantilla/admin/tool/brickfield/classes/output/advanced/renderer.php',
    'tool_brickfield\\output\\checktyperesults\\renderer' => '/var/www/html/plantilla/admin/tool/brickfield/classes/output/checktyperesults/renderer.php',
    'tool_brickfield\\output\\errors\\renderer' => '/var/www/html/plantilla/admin/tool/brickfield/classes/output/errors/renderer.php',
    'tool_brickfield\\output\\printable\\renderer' => '/var/www/html/plantilla/admin/tool/brickfield/classes/output/printable/renderer.php',
    'tool_brickfield\\output\\renderer' => '/var/www/html/plantilla/admin/tool/brickfield/classes/output/renderer.php',
    'tool_brickfield\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/brickfield/classes/privacy/provider.php',
    'tool_brickfield\\registration' => '/var/www/html/plantilla/admin/tool/brickfield/classes/registration.php',
    'tool_brickfield\\scheduler' => '/var/www/html/plantilla/admin/tool/brickfield/classes/scheduler.php',
    'tool_brickfield\\sitedata' => '/var/www/html/plantilla/admin/tool/brickfield/classes/sitedata.php',
    'tool_brickfield\\task\\bulk_process_caches' => '/var/www/html/plantilla/admin/tool/brickfield/classes/task/bulk_process_caches.php',
    'tool_brickfield\\task\\bulk_process_courses' => '/var/www/html/plantilla/admin/tool/brickfield/classes/task/bulk_process_courses.php',
    'tool_brickfield\\task\\checkid_validation' => '/var/www/html/plantilla/admin/tool/brickfield/classes/task/checkid_validation.php',
    'tool_brickfield\\task\\process_analysis_requests' => '/var/www/html/plantilla/admin/tool/brickfield/classes/task/process_analysis_requests.php',
    'tool_brickfield\\task\\update_summarydata' => '/var/www/html/plantilla/admin/tool/brickfield/classes/task/update_summarydata.php',
    'tool_brickfield_accessibility' => '/var/www/html/plantilla/admin/tool/brickfield/classes/accessibility.php',
    'tool_brickfield_analysis' => '/var/www/html/plantilla/admin/tool/brickfield/classes/analysis.php',
    'tool_brickfield_area_base' => '/var/www/html/plantilla/admin/tool/brickfield/classes/area_base.php',
    'tool_brickfield_brickfieldconnect' => '/var/www/html/plantilla/admin/tool/brickfield/classes/brickfieldconnect.php',
    'tool_brickfield_eventobservers' => '/var/www/html/plantilla/admin/tool/brickfield/classes/eventobservers.php',
    'tool_brickfield_manager' => '/var/www/html/plantilla/admin/tool/brickfield/classes/manager.php',
    'tool_brickfield_registration' => '/var/www/html/plantilla/admin/tool/brickfield/classes/registration.php',
    'tool_brickfield_scheduler' => '/var/www/html/plantilla/admin/tool/brickfield/classes/scheduler.php',
    'tool_brickfield_sitedata' => '/var/www/html/plantilla/admin/tool/brickfield/classes/sitedata.php',
    'tool_capability\\event\\report_viewed' => '/var/www/html/plantilla/admin/tool/capability/classes/event/report_viewed.php',
    'tool_capability\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/capability/classes/privacy/provider.php',
    'tool_capability\\settings_form' => '/var/www/html/plantilla/admin/tool/capability/classes/settings_form.php',
    'tool_capability_settings_form' => '/var/www/html/plantilla/admin/tool/capability/classes/settings_form.php',
    'tool_cohortroles\\api' => '/var/www/html/plantilla/admin/tool/cohortroles/classes/api.php',
    'tool_cohortroles\\cohort_role_assignment' => '/var/www/html/plantilla/admin/tool/cohortroles/classes/cohort_role_assignment.php',
    'tool_cohortroles\\form\\assign_role_cohort' => '/var/www/html/plantilla/admin/tool/cohortroles/classes/form/assign_role_cohort.php',
    'tool_cohortroles\\observers' => '/var/www/html/plantilla/admin/tool/cohortroles/classes/observers.php',
    'tool_cohortroles\\output\\cohort_role_assignments_table' => '/var/www/html/plantilla/admin/tool/cohortroles/classes/output/cohort_role_assignments_table.php',
    'tool_cohortroles\\output\\renderer' => '/var/www/html/plantilla/admin/tool/cohortroles/classes/output/renderer.php',
    'tool_cohortroles\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/cohortroles/classes/privacy/provider.php',
    'tool_cohortroles\\task\\cohort_role_sync' => '/var/www/html/plantilla/admin/tool/cohortroles/classes/task/cohort_role_sync.php',
    'tool_cohortroles_api' => '/var/www/html/plantilla/admin/tool/cohortroles/classes/api.php',
    'tool_cohortroles_cohort_role_assignment' => '/var/www/html/plantilla/admin/tool/cohortroles/classes/cohort_role_assignment.php',
    'tool_cohortroles_observers' => '/var/www/html/plantilla/admin/tool/cohortroles/classes/observers.php',
    'tool_componentlibrary\\local\\examples\\dynamictabs\\tab1' => '/var/www/html/plantilla/admin/tool/componentlibrary/classes/local/examples/dynamictabs/tab1.php',
    'tool_componentlibrary\\local\\examples\\dynamictabs\\tab2' => '/var/www/html/plantilla/admin/tool/componentlibrary/classes/local/examples/dynamictabs/tab2.php',
    'tool_componentlibrary\\local\\examples\\formelements\\example' => '/var/www/html/plantilla/admin/tool/componentlibrary/classes/local/examples/formelements/example.php',
    'tool_componentlibrary\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/componentlibrary/classes/privacy/provider.php',
    'tool_customlang\\form\\export' => '/var/www/html/plantilla/admin/tool/customlang/classes/form/export.php',
    'tool_customlang\\form\\import' => '/var/www/html/plantilla/admin/tool/customlang/classes/form/import.php',
    'tool_customlang\\local\\importer' => '/var/www/html/plantilla/admin/tool/customlang/classes/local/importer.php',
    'tool_customlang\\local\\mlang\\langstring' => '/var/www/html/plantilla/admin/tool/customlang/classes/local/mlang/langstring.php',
    'tool_customlang\\local\\mlang\\logstatus' => '/var/www/html/plantilla/admin/tool/customlang/classes/local/mlang/logstatus.php',
    'tool_customlang\\local\\mlang\\phpparser' => '/var/www/html/plantilla/admin/tool/customlang/classes/local/mlang/phpparser.php',
    'tool_customlang\\output\\renderer' => '/var/www/html/plantilla/admin/tool/customlang/classes/output/renderer.php',
    'tool_customlang\\output\\translator' => '/var/www/html/plantilla/admin/tool/customlang/classes/output/translator.php',
    'tool_customlang\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/customlang/classes/privacy/provider.php',
    'tool_dataprivacy\\api' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/api.php',
    'tool_dataprivacy\\category' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/category.php',
    'tool_dataprivacy\\context_instance' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/context_instance.php',
    'tool_dataprivacy\\contextlevel' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/contextlevel.php',
    'tool_dataprivacy\\contextlist_context' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/contextlist_context.php',
    'tool_dataprivacy\\data_registry' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/data_registry.php',
    'tool_dataprivacy\\data_request' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/data_request.php',
    'tool_dataprivacy\\dataprivacy_contextlist' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/dataprivacy_contextlist.php',
    'tool_dataprivacy\\event\\user_deleted_observer' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/event/user_deleted_observer.php',
    'tool_dataprivacy\\expired_context' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/expired_context.php',
    'tool_dataprivacy\\expired_contexts_manager' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/expired_contexts_manager.php',
    'tool_dataprivacy\\expiry_info' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/expiry_info.php',
    'tool_dataprivacy\\external' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/external.php',
    'tool_dataprivacy\\external\\category_exporter' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/external/category_exporter.php',
    'tool_dataprivacy\\external\\context_instance_exporter' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/external/context_instance_exporter.php',
    'tool_dataprivacy\\external\\create_data_request' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/external/create_data_request.php',
    'tool_dataprivacy\\external\\data_request_exporter' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/external/data_request_exporter.php',
    'tool_dataprivacy\\external\\get_access_information' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/external/get_access_information.php',
    'tool_dataprivacy\\external\\get_data_requests' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/external/get_data_requests.php',
    'tool_dataprivacy\\external\\name_description_exporter' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/external/name_description_exporter.php',
    'tool_dataprivacy\\external\\purpose_exporter' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/external/purpose_exporter.php',
    'tool_dataprivacy\\external\\submit_selected_courses_form' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/external/submit_selected_courses_form.php',
    'tool_dataprivacy\\filtered_userlist' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/filtered_userlist.php',
    'tool_dataprivacy\\form\\category' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/form/category.php',
    'tool_dataprivacy\\form\\contactdpo' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/form/contactdpo.php',
    'tool_dataprivacy\\form\\context_instance' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/form/context_instance.php',
    'tool_dataprivacy\\form\\contextlevel' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/form/contextlevel.php',
    'tool_dataprivacy\\form\\exportfilter_form' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/form/exportfilter_form.php',
    'tool_dataprivacy\\form\\purpose' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/form/purpose.php',
    'tool_dataprivacy\\hook_callbacks' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/hook_callbacks.php',
    'tool_dataprivacy\\local\\helper' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/local/helper.php',
    'tool_dataprivacy\\manager_observer' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/manager_observer.php',
    'tool_dataprivacy\\metadata_registry' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/metadata_registry.php',
    'tool_dataprivacy\\output\\categories' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/output/categories.php',
    'tool_dataprivacy\\output\\crud_element' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/output/crud_element.php',
    'tool_dataprivacy\\output\\data_deletion_page' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/output/data_deletion_page.php',
    'tool_dataprivacy\\output\\data_registry_compliance_page' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/output/data_registry_compliance_page.php',
    'tool_dataprivacy\\output\\data_registry_page' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/output/data_registry_page.php',
    'tool_dataprivacy\\output\\data_requests_page' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/output/data_requests_page.php',
    'tool_dataprivacy\\output\\data_requests_table' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/output/data_requests_table.php',
    'tool_dataprivacy\\output\\defaults_page' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/output/defaults_page.php',
    'tool_dataprivacy\\output\\expired_contexts_table' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/output/expired_contexts_table.php',
    'tool_dataprivacy\\output\\my_data_requests_page' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/output/my_data_requests_page.php',
    'tool_dataprivacy\\output\\purposes' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/output/purposes.php',
    'tool_dataprivacy\\output\\renderer' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/output/renderer.php',
    'tool_dataprivacy\\output\\request_filter' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/output/request_filter.php',
    'tool_dataprivacy\\output\\summary_page' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/output/summary_page.php',
    'tool_dataprivacy\\page_helper' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/page_helper.php',
    'tool_dataprivacy\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/privacy/provider.php',
    'tool_dataprivacy\\purpose' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/purpose.php',
    'tool_dataprivacy\\purpose_override' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/purpose_override.php',
    'tool_dataprivacy\\request_contextlist' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/request_contextlist.php',
    'tool_dataprivacy\\task\\delete_existing_deleted_users' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/task/delete_existing_deleted_users.php',
    'tool_dataprivacy\\task\\delete_expired_contexts' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/task/delete_expired_contexts.php',
    'tool_dataprivacy\\task\\delete_expired_requests' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/task/delete_expired_requests.php',
    'tool_dataprivacy\\task\\expired_retention_period' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/task/expired_retention_period.php',
    'tool_dataprivacy\\task\\initiate_data_request_task' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/task/initiate_data_request_task.php',
    'tool_dataprivacy\\task\\process_data_request_task' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/task/process_data_request_task.php',
    'tool_dataprivacy_api' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/api.php',
    'tool_dataprivacy_category' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/category.php',
    'tool_dataprivacy_context_instance' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/context_instance.php',
    'tool_dataprivacy_contextlevel' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/contextlevel.php',
    'tool_dataprivacy_contextlist_context' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/contextlist_context.php',
    'tool_dataprivacy_data_registry' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/data_registry.php',
    'tool_dataprivacy_data_request' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/data_request.php',
    'tool_dataprivacy_dataprivacy_contextlist' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/dataprivacy_contextlist.php',
    'tool_dataprivacy_expired_context' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/expired_context.php',
    'tool_dataprivacy_expired_contexts_manager' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/expired_contexts_manager.php',
    'tool_dataprivacy_expiry_info' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/expiry_info.php',
    'tool_dataprivacy_external' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/external.php',
    'tool_dataprivacy_filtered_userlist' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/filtered_userlist.php',
    'tool_dataprivacy_hook_callbacks' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/hook_callbacks.php',
    'tool_dataprivacy_manager_observer' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/manager_observer.php',
    'tool_dataprivacy_metadata_registry' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/metadata_registry.php',
    'tool_dataprivacy_page_helper' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/page_helper.php',
    'tool_dataprivacy_purpose' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/purpose.php',
    'tool_dataprivacy_purpose_override' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/purpose_override.php',
    'tool_dataprivacy_request_contextlist' => '/var/www/html/plantilla/admin/tool/dataprivacy/classes/request_contextlist.php',
    'tool_dbtransfer\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/dbtransfer/classes/privacy/provider.php',
    'tool_filetypes\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/filetypes/classes/privacy/provider.php',
    'tool_filetypes\\utils' => '/var/www/html/plantilla/admin/tool/filetypes/classes/utils.php',
    'tool_filetypes_utils' => '/var/www/html/plantilla/admin/tool/filetypes/classes/utils.php',
    'tool_generator\\backend' => '/var/www/html/plantilla/admin/tool/generator/classes/backend.php',
    'tool_generator\\course_backend' => '/var/www/html/plantilla/admin/tool/generator/classes/course_backend.php',
    'tool_generator\\form\\featureimport' => '/var/www/html/plantilla/admin/tool/generator/classes/form/featureimport.php',
    'tool_generator\\local\\testscenario\\parsedfeature' => '/var/www/html/plantilla/admin/tool/generator/classes/local/testscenario/parsedfeature.php',
    'tool_generator\\local\\testscenario\\runner' => '/var/www/html/plantilla/admin/tool/generator/classes/local/testscenario/runner.php',
    'tool_generator\\local\\testscenario\\steprunner' => '/var/www/html/plantilla/admin/tool/generator/classes/local/testscenario/steprunner.php',
    'tool_generator\\make_course_form' => '/var/www/html/plantilla/admin/tool/generator/classes/make_course_form.php',
    'tool_generator\\make_testplan_form' => '/var/www/html/plantilla/admin/tool/generator/classes/make_testplan_form.php',
    'tool_generator\\output\\parsingresult' => '/var/www/html/plantilla/admin/tool/generator/classes/output/parsingresult.php',
    'tool_generator\\output\\stepsinformation' => '/var/www/html/plantilla/admin/tool/generator/classes/output/stepsinformation.php',
    'tool_generator\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/generator/classes/privacy/provider.php',
    'tool_generator\\site_backend' => '/var/www/html/plantilla/admin/tool/generator/classes/site_backend.php',
    'tool_generator\\testplan_backend' => '/var/www/html/plantilla/admin/tool/generator/classes/testplan_backend.php',
    'tool_generator_backend' => '/var/www/html/plantilla/admin/tool/generator/classes/backend.php',
    'tool_generator_course_backend' => '/var/www/html/plantilla/admin/tool/generator/classes/course_backend.php',
    'tool_generator_make_course_form' => '/var/www/html/plantilla/admin/tool/generator/classes/make_course_form.php',
    'tool_generator_make_testplan_form' => '/var/www/html/plantilla/admin/tool/generator/classes/make_testplan_form.php',
    'tool_generator_site_backend' => '/var/www/html/plantilla/admin/tool/generator/classes/site_backend.php',
    'tool_generator_testplan_backend' => '/var/www/html/plantilla/admin/tool/generator/classes/testplan_backend.php',
    'tool_httpsreplace\\form' => '/var/www/html/plantilla/admin/tool/httpsreplace/classes/form.php',
    'tool_httpsreplace\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/httpsreplace/classes/privacy/provider.php',
    'tool_httpsreplace\\url_finder' => '/var/www/html/plantilla/admin/tool/httpsreplace/classes/url_finder.php',
    'tool_httpsreplace_form' => '/var/www/html/plantilla/admin/tool/httpsreplace/classes/form.php',
    'tool_httpsreplace_url_finder' => '/var/www/html/plantilla/admin/tool/httpsreplace/classes/url_finder.php',
    'tool_installaddon\\installer' => '/var/www/html/plantilla/admin/tool/installaddon/classes/installer.php',
    'tool_installaddon\\installfromzip_form' => '/var/www/html/plantilla/admin/tool/installaddon/classes/installfromzip_form.php',
    'tool_installaddon\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/installaddon/classes/privacy/provider.php',
    'tool_installaddon_installer' => '/var/www/html/plantilla/admin/tool/installaddon/classes/installer.php',
    'tool_installaddon_installfromzip_form' => '/var/www/html/plantilla/admin/tool/installaddon/classes/installfromzip_form.php',
    'tool_langimport\\controller' => '/var/www/html/plantilla/admin/tool/langimport/classes/controller.php',
    'tool_langimport\\event\\langpack_imported' => '/var/www/html/plantilla/admin/tool/langimport/classes/event/langpack_imported.php',
    'tool_langimport\\event\\langpack_removed' => '/var/www/html/plantilla/admin/tool/langimport/classes/event/langpack_removed.php',
    'tool_langimport\\event\\langpack_updated' => '/var/www/html/plantilla/admin/tool/langimport/classes/event/langpack_updated.php',
    'tool_langimport\\locale' => '/var/www/html/plantilla/admin/tool/langimport/classes/locale.php',
    'tool_langimport\\output\\langimport_page' => '/var/www/html/plantilla/admin/tool/langimport/classes/output/langimport_page.php',
    'tool_langimport\\output\\renderer' => '/var/www/html/plantilla/admin/tool/langimport/classes/output/renderer.php',
    'tool_langimport\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/langimport/classes/privacy/provider.php',
    'tool_langimport\\task\\install_langpacks' => '/var/www/html/plantilla/admin/tool/langimport/classes/task/install_langpacks.php',
    'tool_langimport\\task\\update_langpacks_task' => '/var/www/html/plantilla/admin/tool/langimport/classes/task/update_langpacks_task.php',
    'tool_langimport_controller' => '/var/www/html/plantilla/admin/tool/langimport/classes/controller.php',
    'tool_langimport_locale' => '/var/www/html/plantilla/admin/tool/langimport/classes/locale.php',
    'tool_licensemanager\\form\\edit_license' => '/var/www/html/plantilla/admin/tool/licensemanager/classes/form/edit_license.php',
    'tool_licensemanager\\helper' => '/var/www/html/plantilla/admin/tool/licensemanager/classes/helper.php',
    'tool_licensemanager\\manager' => '/var/www/html/plantilla/admin/tool/licensemanager/classes/manager.php',
    'tool_licensemanager\\output\\renderer' => '/var/www/html/plantilla/admin/tool/licensemanager/classes/output/renderer.php',
    'tool_licensemanager\\output\\table' => '/var/www/html/plantilla/admin/tool/licensemanager/classes/output/table.php',
    'tool_licensemanager\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/licensemanager/classes/privacy/provider.php',
    'tool_licensemanager_helper' => '/var/www/html/plantilla/admin/tool/licensemanager/classes/helper.php',
    'tool_licensemanager_manager' => '/var/www/html/plantilla/admin/tool/licensemanager/classes/manager.php',
    'tool_log\\helper\\buffered_writer' => '/var/www/html/plantilla/admin/tool/log/classes/helper/buffered_writer.php',
    'tool_log\\helper\\reader' => '/var/www/html/plantilla/admin/tool/log/classes/helper/reader.php',
    'tool_log\\helper\\store' => '/var/www/html/plantilla/admin/tool/log/classes/helper/store.php',
    'tool_log\\local\\privacy\\helper' => '/var/www/html/plantilla/admin/tool/log/classes/local/privacy/helper.php',
    'tool_log\\local\\privacy\\logstore_provider' => '/var/www/html/plantilla/admin/tool/log/classes/local/privacy/logstore_provider.php',
    'tool_log\\local\\privacy\\logstore_userlist_provider' => '/var/www/html/plantilla/admin/tool/log/classes/local/privacy/logstore_userlist_provider.php',
    'tool_log\\local\\privacy\\moodle_database_export_and_delete' => '/var/www/html/plantilla/admin/tool/log/classes/local/privacy/moodle_database_export_and_delete.php',
    'tool_log\\log\\manager' => '/var/www/html/plantilla/admin/tool/log/classes/log/manager.php',
    'tool_log\\log\\observer' => '/var/www/html/plantilla/admin/tool/log/classes/log/observer.php',
    'tool_log\\log\\store' => '/var/www/html/plantilla/admin/tool/log/classes/log/store.php',
    'tool_log\\log\\writer' => '/var/www/html/plantilla/admin/tool/log/classes/log/writer.php',
    'tool_log\\plugininfo\\logstore' => '/var/www/html/plantilla/admin/tool/log/classes/plugininfo/logstore.php',
    'tool_log\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/log/classes/privacy/provider.php',
    'tool_log\\setting_managestores' => '/var/www/html/plantilla/admin/tool/log/classes/setting_managestores.php',
    'tool_log_setting_managestores' => '/var/www/html/plantilla/admin/tool/log/classes/setting_managestores.php',
    'tool_lp\\course_competencies_form_element' => '/var/www/html/plantilla/admin/tool/lp/classes/course_competencies_form_element.php',
    'tool_lp\\course_competency_overridegrade_form_element' => '/var/www/html/plantilla/admin/tool/lp/classes/course_competency_overridegrade_form_element.php',
    'tool_lp\\course_competency_rule_form_element' => '/var/www/html/plantilla/admin/tool/lp/classes/course_competency_rule_form_element.php',
    'tool_lp\\course_competency_statistics' => '/var/www/html/plantilla/admin/tool/lp/classes/course_competency_statistics.php',
    'tool_lp\\external' => '/var/www/html/plantilla/admin/tool/lp/classes/external.php',
    'tool_lp\\external\\competency_path_exporter' => '/var/www/html/plantilla/admin/tool/lp/classes/external/competency_path_exporter.php',
    'tool_lp\\external\\competency_summary_exporter' => '/var/www/html/plantilla/admin/tool/lp/classes/external/competency_summary_exporter.php',
    'tool_lp\\external\\course_competency_statistics_exporter' => '/var/www/html/plantilla/admin/tool/lp/classes/external/course_competency_statistics_exporter.php',
    'tool_lp\\external\\path_node_exporter' => '/var/www/html/plantilla/admin/tool/lp/classes/external/path_node_exporter.php',
    'tool_lp\\external\\template_statistics_exporter' => '/var/www/html/plantilla/admin/tool/lp/classes/external/template_statistics_exporter.php',
    'tool_lp\\external\\user_competency_summary_exporter' => '/var/www/html/plantilla/admin/tool/lp/classes/external/user_competency_summary_exporter.php',
    'tool_lp\\external\\user_competency_summary_in_course_exporter' => '/var/www/html/plantilla/admin/tool/lp/classes/external/user_competency_summary_in_course_exporter.php',
    'tool_lp\\external\\user_competency_summary_in_plan_exporter' => '/var/www/html/plantilla/admin/tool/lp/classes/external/user_competency_summary_in_plan_exporter.php',
    'tool_lp\\external\\user_evidence_competency_summary_exporter' => '/var/www/html/plantilla/admin/tool/lp/classes/external/user_evidence_competency_summary_exporter.php',
    'tool_lp\\external\\user_evidence_summary_exporter' => '/var/www/html/plantilla/admin/tool/lp/classes/external/user_evidence_summary_exporter.php',
    'tool_lp\\form\\competency' => '/var/www/html/plantilla/admin/tool/lp/classes/form/competency.php',
    'tool_lp\\form\\competency_framework' => '/var/www/html/plantilla/admin/tool/lp/classes/form/competency_framework.php',
    'tool_lp\\form\\framework_autocomplete' => '/var/www/html/plantilla/admin/tool/lp/classes/form/framework_autocomplete.php',
    'tool_lp\\form\\plan' => '/var/www/html/plantilla/admin/tool/lp/classes/form/plan.php',
    'tool_lp\\form\\template' => '/var/www/html/plantilla/admin/tool/lp/classes/form/template.php',
    'tool_lp\\form\\template_cohorts' => '/var/www/html/plantilla/admin/tool/lp/classes/form/template_cohorts.php',
    'tool_lp\\form\\template_plans' => '/var/www/html/plantilla/admin/tool/lp/classes/form/template_plans.php',
    'tool_lp\\form\\user_evidence' => '/var/www/html/plantilla/admin/tool/lp/classes/form/user_evidence.php',
    'tool_lp\\output\\competency_plan_navigation' => '/var/www/html/plantilla/admin/tool/lp/classes/output/competency_plan_navigation.php',
    'tool_lp\\output\\competency_summary' => '/var/www/html/plantilla/admin/tool/lp/classes/output/competency_summary.php',
    'tool_lp\\output\\course_competencies_page' => '/var/www/html/plantilla/admin/tool/lp/classes/output/course_competencies_page.php',
    'tool_lp\\output\\manage_competencies_page' => '/var/www/html/plantilla/admin/tool/lp/classes/output/manage_competencies_page.php',
    'tool_lp\\output\\manage_competency_frameworks_page' => '/var/www/html/plantilla/admin/tool/lp/classes/output/manage_competency_frameworks_page.php',
    'tool_lp\\output\\manage_templates_page' => '/var/www/html/plantilla/admin/tool/lp/classes/output/manage_templates_page.php',
    'tool_lp\\output\\module_navigation' => '/var/www/html/plantilla/admin/tool/lp/classes/output/module_navigation.php',
    'tool_lp\\output\\plan_page' => '/var/www/html/plantilla/admin/tool/lp/classes/output/plan_page.php',
    'tool_lp\\output\\plans_page' => '/var/www/html/plantilla/admin/tool/lp/classes/output/plans_page.php',
    'tool_lp\\output\\related_competencies' => '/var/www/html/plantilla/admin/tool/lp/classes/output/related_competencies.php',
    'tool_lp\\output\\renderer' => '/var/www/html/plantilla/admin/tool/lp/classes/output/renderer.php',
    'tool_lp\\output\\template_cohorts_page' => '/var/www/html/plantilla/admin/tool/lp/classes/output/template_cohorts_page.php',
    'tool_lp\\output\\template_cohorts_table' => '/var/www/html/plantilla/admin/tool/lp/classes/output/template_cohorts_table.php',
    'tool_lp\\output\\template_competencies_page' => '/var/www/html/plantilla/admin/tool/lp/classes/output/template_competencies_page.php',
    'tool_lp\\output\\template_plans_page' => '/var/www/html/plantilla/admin/tool/lp/classes/output/template_plans_page.php',
    'tool_lp\\output\\template_plans_table' => '/var/www/html/plantilla/admin/tool/lp/classes/output/template_plans_table.php',
    'tool_lp\\output\\user_competency_course_navigation' => '/var/www/html/plantilla/admin/tool/lp/classes/output/user_competency_course_navigation.php',
    'tool_lp\\output\\user_competency_summary' => '/var/www/html/plantilla/admin/tool/lp/classes/output/user_competency_summary.php',
    'tool_lp\\output\\user_competency_summary_in_course' => '/var/www/html/plantilla/admin/tool/lp/classes/output/user_competency_summary_in_course.php',
    'tool_lp\\output\\user_competency_summary_in_plan' => '/var/www/html/plantilla/admin/tool/lp/classes/output/user_competency_summary_in_plan.php',
    'tool_lp\\output\\user_evidence_list_page' => '/var/www/html/plantilla/admin/tool/lp/classes/output/user_evidence_list_page.php',
    'tool_lp\\output\\user_evidence_page' => '/var/www/html/plantilla/admin/tool/lp/classes/output/user_evidence_page.php',
    'tool_lp\\page_helper' => '/var/www/html/plantilla/admin/tool/lp/classes/page_helper.php',
    'tool_lp\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/lp/classes/privacy/provider.php',
    'tool_lp\\site_competencies_form_element' => '/var/www/html/plantilla/admin/tool/lp/classes/site_competencies_form_element.php',
    'tool_lp\\template_statistics' => '/var/www/html/plantilla/admin/tool/lp/classes/template_statistics.php',
    'tool_lp\\url_resolver' => '/var/www/html/plantilla/admin/tool/lp/classes/url_resolver.php',
    'tool_lp_course_competencies_form_element' => '/var/www/html/plantilla/admin/tool/lp/classes/course_competencies_form_element.php',
    'tool_lp_course_competency_overridegrade_form_element' => '/var/www/html/plantilla/admin/tool/lp/classes/course_competency_overridegrade_form_element.php',
    'tool_lp_course_competency_rule_form_element' => '/var/www/html/plantilla/admin/tool/lp/classes/course_competency_rule_form_element.php',
    'tool_lp_course_competency_statistics' => '/var/www/html/plantilla/admin/tool/lp/classes/course_competency_statistics.php',
    'tool_lp_external' => '/var/www/html/plantilla/admin/tool/lp/classes/external.php',
    'tool_lp_page_helper' => '/var/www/html/plantilla/admin/tool/lp/classes/page_helper.php',
    'tool_lp_site_competencies_form_element' => '/var/www/html/plantilla/admin/tool/lp/classes/site_competencies_form_element.php',
    'tool_lp_template_statistics' => '/var/www/html/plantilla/admin/tool/lp/classes/template_statistics.php',
    'tool_lp_url_resolver' => '/var/www/html/plantilla/admin/tool/lp/classes/url_resolver.php',
    'tool_lpimportcsv\\form\\export' => '/var/www/html/plantilla/admin/tool/lpimportcsv/classes/form/export.php',
    'tool_lpimportcsv\\form\\import' => '/var/www/html/plantilla/admin/tool/lpimportcsv/classes/form/import.php',
    'tool_lpimportcsv\\form\\import_confirm' => '/var/www/html/plantilla/admin/tool/lpimportcsv/classes/form/import_confirm.php',
    'tool_lpimportcsv\\framework_exporter' => '/var/www/html/plantilla/admin/tool/lpimportcsv/classes/framework_exporter.php',
    'tool_lpimportcsv\\framework_importer' => '/var/www/html/plantilla/admin/tool/lpimportcsv/classes/framework_importer.php',
    'tool_lpimportcsv\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/lpimportcsv/classes/privacy/provider.php',
    'tool_lpimportcsv_framework_exporter' => '/var/www/html/plantilla/admin/tool/lpimportcsv/classes/framework_exporter.php',
    'tool_lpimportcsv_framework_importer' => '/var/www/html/plantilla/admin/tool/lpimportcsv/classes/framework_importer.php',
    'tool_lpmigrate\\form\\migrate_framework' => '/var/www/html/plantilla/admin/tool/lpmigrate/classes/form/migrate_framework.php',
    'tool_lpmigrate\\framework_mapper' => '/var/www/html/plantilla/admin/tool/lpmigrate/classes/framework_mapper.php',
    'tool_lpmigrate\\framework_processor' => '/var/www/html/plantilla/admin/tool/lpmigrate/classes/framework_processor.php',
    'tool_lpmigrate\\output\\migrate_framework_results' => '/var/www/html/plantilla/admin/tool/lpmigrate/classes/output/migrate_framework_results.php',
    'tool_lpmigrate\\output\\renderer' => '/var/www/html/plantilla/admin/tool/lpmigrate/classes/output/renderer.php',
    'tool_lpmigrate\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/lpmigrate/classes/privacy/provider.php',
    'tool_lpmigrate_framework_mapper' => '/var/www/html/plantilla/admin/tool/lpmigrate/classes/framework_mapper.php',
    'tool_lpmigrate_framework_processor' => '/var/www/html/plantilla/admin/tool/lpmigrate/classes/framework_processor.php',
    'tool_messageinbound\\edit_handler_form' => '/var/www/html/plantilla/admin/tool/messageinbound/classes/edit_handler_form.php',
    'tool_messageinbound\\manager' => '/var/www/html/plantilla/admin/tool/messageinbound/classes/manager.php',
    'tool_messageinbound\\message\\inbound\\invalid_recipient_handler' => '/var/www/html/plantilla/admin/tool/messageinbound/classes/message/inbound/invalid_recipient_handler.php',
    'tool_messageinbound\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/messageinbound/classes/privacy/provider.php',
    'tool_messageinbound\\task\\cleanup_task' => '/var/www/html/plantilla/admin/tool/messageinbound/classes/task/cleanup_task.php',
    'tool_messageinbound\\task\\pickup_task' => '/var/www/html/plantilla/admin/tool/messageinbound/classes/task/pickup_task.php',
    'tool_messageinbound\\utils' => '/var/www/html/plantilla/admin/tool/messageinbound/classes/utils.php',
    'tool_messageinbound_edit_handler_form' => '/var/www/html/plantilla/admin/tool/messageinbound/classes/edit_handler_form.php',
    'tool_messageinbound_manager' => '/var/www/html/plantilla/admin/tool/messageinbound/classes/manager.php',
    'tool_messageinbound_utils' => '/var/www/html/plantilla/admin/tool/messageinbound/classes/utils.php',
    'tool_mfa\\event\\user_deleted_factor' => '/var/www/html/plantilla/admin/tool/mfa/classes/event/user_deleted_factor.php',
    'tool_mfa\\event\\user_failed_mfa' => '/var/www/html/plantilla/admin/tool/mfa/classes/event/user_failed_mfa.php',
    'tool_mfa\\event\\user_passed_mfa' => '/var/www/html/plantilla/admin/tool/mfa/classes/event/user_passed_mfa.php',
    'tool_mfa\\event\\user_revoked_factor' => '/var/www/html/plantilla/admin/tool/mfa/classes/event/user_revoked_factor.php',
    'tool_mfa\\event\\user_setup_factor' => '/var/www/html/plantilla/admin/tool/mfa/classes/event/user_setup_factor.php',
    'tool_mfa\\hook\\after_user_passed_mfa' => '/var/www/html/plantilla/admin/tool/mfa/classes/hook/after_user_passed_mfa.php',
    'tool_mfa\\hook_callbacks' => '/var/www/html/plantilla/admin/tool/mfa/classes/hook_callbacks.php',
    'tool_mfa\\local\\factor\\fallback' => '/var/www/html/plantilla/admin/tool/mfa/classes/local/factor/fallback.php',
    'tool_mfa\\local\\factor\\object_factor' => '/var/www/html/plantilla/admin/tool/mfa/classes/local/factor/object_factor.php',
    'tool_mfa\\local\\factor\\object_factor_base' => '/var/www/html/plantilla/admin/tool/mfa/classes/local/factor/object_factor_base.php',
    'tool_mfa\\local\\form\\factor_action_confirmation_form' => '/var/www/html/plantilla/admin/tool/mfa/classes/local/form/factor_action_confirmation_form.php',
    'tool_mfa\\local\\form\\global_form_manager' => '/var/www/html/plantilla/admin/tool/mfa/classes/local/form/global_form_manager.php',
    'tool_mfa\\local\\form\\login_form' => '/var/www/html/plantilla/admin/tool/mfa/classes/local/form/login_form.php',
    'tool_mfa\\local\\form\\reset_factor' => '/var/www/html/plantilla/admin/tool/mfa/classes/local/form/reset_factor.php',
    'tool_mfa\\local\\form\\setup_factor_form' => '/var/www/html/plantilla/admin/tool/mfa/classes/local/form/setup_factor_form.php',
    'tool_mfa\\local\\form\\verification_field' => '/var/www/html/plantilla/admin/tool/mfa/classes/local/form/verification_field.php',
    'tool_mfa\\local\\hooks\\extend_bulk_user_actions' => '/var/www/html/plantilla/admin/tool/mfa/classes/local/hooks/extend_bulk_user_actions.php',
    'tool_mfa\\local\\secret_manager' => '/var/www/html/plantilla/admin/tool/mfa/classes/local/secret_manager.php',
    'tool_mfa\\manager' => '/var/www/html/plantilla/admin/tool/mfa/classes/manager.php',
    'tool_mfa\\output\\renderer' => '/var/www/html/plantilla/admin/tool/mfa/classes/output/renderer.php',
    'tool_mfa\\plugininfo\\factor' => '/var/www/html/plantilla/admin/tool/mfa/classes/plugininfo/factor.php',
    'tool_mfa\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/mfa/classes/privacy/provider.php',
    'tool_mfa\\table\\admin_setting_managemfa' => '/var/www/html/plantilla/admin/tool/mfa/classes/table/admin_setting_managemfa.php',
    'tool_mfa_hook_callbacks' => '/var/www/html/plantilla/admin/tool/mfa/classes/hook_callbacks.php',
    'tool_mfa_manager' => '/var/www/html/plantilla/admin/tool/mfa/classes/manager.php',
    'tool_mobile\\api' => '/var/www/html/plantilla/admin/tool/mobile/classes/api.php',
    'tool_mobile\\external' => '/var/www/html/plantilla/admin/tool/mobile/classes/external.php',
    'tool_mobile\\hook_callbacks' => '/var/www/html/plantilla/admin/tool/mobile/classes/hook_callbacks.php',
    'tool_mobile\\local\\hooks\\user\\after_user_passed_mfa' => '/var/www/html/plantilla/admin/tool/mobile/classes/local/hooks/user/after_user_passed_mfa.php',
    'tool_mobile\\output\\renderer' => '/var/www/html/plantilla/admin/tool/mobile/classes/output/renderer.php',
    'tool_mobile\\output\\subscription' => '/var/www/html/plantilla/admin/tool/mobile/classes/output/subscription.php',
    'tool_mobile\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/mobile/classes/privacy/provider.php',
    'tool_mobile_api' => '/var/www/html/plantilla/admin/tool/mobile/classes/api.php',
    'tool_mobile_external' => '/var/www/html/plantilla/admin/tool/mobile/classes/external.php',
    'tool_mobile_hook_callbacks' => '/var/www/html/plantilla/admin/tool/mobile/classes/hook_callbacks.php',
    'tool_monitor\\event\\rule_created' => '/var/www/html/plantilla/admin/tool/monitor/classes/event/rule_created.php',
    'tool_monitor\\event\\rule_deleted' => '/var/www/html/plantilla/admin/tool/monitor/classes/event/rule_deleted.php',
    'tool_monitor\\event\\rule_updated' => '/var/www/html/plantilla/admin/tool/monitor/classes/event/rule_updated.php',
    'tool_monitor\\event\\subscription_created' => '/var/www/html/plantilla/admin/tool/monitor/classes/event/subscription_created.php',
    'tool_monitor\\event\\subscription_criteria_met' => '/var/www/html/plantilla/admin/tool/monitor/classes/event/subscription_criteria_met.php',
    'tool_monitor\\event\\subscription_deleted' => '/var/www/html/plantilla/admin/tool/monitor/classes/event/subscription_deleted.php',
    'tool_monitor\\eventlist' => '/var/www/html/plantilla/admin/tool/monitor/classes/eventlist.php',
    'tool_monitor\\eventobservers' => '/var/www/html/plantilla/admin/tool/monitor/classes/eventobservers.php',
    'tool_monitor\\notification_task' => '/var/www/html/plantilla/admin/tool/monitor/classes/notification_task.php',
    'tool_monitor\\output\\managerules\\renderable' => '/var/www/html/plantilla/admin/tool/monitor/classes/output/managerules/renderable.php',
    'tool_monitor\\output\\managerules\\renderer' => '/var/www/html/plantilla/admin/tool/monitor/classes/output/managerules/renderer.php',
    'tool_monitor\\output\\managesubs\\renderer' => '/var/www/html/plantilla/admin/tool/monitor/classes/output/managesubs/renderer.php',
    'tool_monitor\\output\\managesubs\\rules' => '/var/www/html/plantilla/admin/tool/monitor/classes/output/managesubs/rules.php',
    'tool_monitor\\output\\managesubs\\subs' => '/var/www/html/plantilla/admin/tool/monitor/classes/output/managesubs/subs.php',
    'tool_monitor\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/monitor/classes/privacy/provider.php',
    'tool_monitor\\rule' => '/var/www/html/plantilla/admin/tool/monitor/classes/rule.php',
    'tool_monitor\\rule_form' => '/var/www/html/plantilla/admin/tool/monitor/classes/rule_form.php',
    'tool_monitor\\rule_manager' => '/var/www/html/plantilla/admin/tool/monitor/classes/rule_manager.php',
    'tool_monitor\\subscription' => '/var/www/html/plantilla/admin/tool/monitor/classes/subscription.php',
    'tool_monitor\\subscription_manager' => '/var/www/html/plantilla/admin/tool/monitor/classes/subscription_manager.php',
    'tool_monitor\\task\\check_subscriptions' => '/var/www/html/plantilla/admin/tool/monitor/classes/task/check_subscriptions.php',
    'tool_monitor\\task\\clean_events' => '/var/www/html/plantilla/admin/tool/monitor/classes/task/clean_events.php',
    'tool_monitor_eventlist' => '/var/www/html/plantilla/admin/tool/monitor/classes/eventlist.php',
    'tool_monitor_eventobservers' => '/var/www/html/plantilla/admin/tool/monitor/classes/eventobservers.php',
    'tool_monitor_notification_task' => '/var/www/html/plantilla/admin/tool/monitor/classes/notification_task.php',
    'tool_monitor_rule' => '/var/www/html/plantilla/admin/tool/monitor/classes/rule.php',
    'tool_monitor_rule_form' => '/var/www/html/plantilla/admin/tool/monitor/classes/rule_form.php',
    'tool_monitor_rule_manager' => '/var/www/html/plantilla/admin/tool/monitor/classes/rule_manager.php',
    'tool_monitor_subscription' => '/var/www/html/plantilla/admin/tool/monitor/classes/subscription.php',
    'tool_monitor_subscription_manager' => '/var/www/html/plantilla/admin/tool/monitor/classes/subscription_manager.php',
    'tool_moodlenet\\external' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/external.php',
    'tool_moodlenet\\local\\import_backup_helper' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/local/import_backup_helper.php',
    'tool_moodlenet\\local\\import_handler_info' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/local/import_handler_info.php',
    'tool_moodlenet\\local\\import_handler_registry' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/local/import_handler_registry.php',
    'tool_moodlenet\\local\\import_info' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/local/import_info.php',
    'tool_moodlenet\\local\\import_processor' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/local/import_processor.php',
    'tool_moodlenet\\local\\import_strategy' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/local/import_strategy.php',
    'tool_moodlenet\\local\\import_strategy_file' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/local/import_strategy_file.php',
    'tool_moodlenet\\local\\import_strategy_link' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/local/import_strategy_link.php',
    'tool_moodlenet\\local\\remote_resource' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/local/remote_resource.php',
    'tool_moodlenet\\local\\url' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/local/url.php',
    'tool_moodlenet\\moodlenet_user_profile' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/moodlenet_user_profile.php',
    'tool_moodlenet\\output\\renderer' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/output/renderer.php',
    'tool_moodlenet\\output\\select_page' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/output/select_page.php',
    'tool_moodlenet\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/privacy/provider.php',
    'tool_moodlenet\\profile_manager' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/profile_manager.php',
    'tool_moodlenet\\task\\post_install' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/task/post_install.php',
    'tool_moodlenet\\task\\send_enable_notification' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/task/send_enable_notification.php',
    'tool_moodlenet\\task\\send_mnet_profiles_data_removed_notification' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/task/send_mnet_profiles_data_removed_notification.php',
    'tool_moodlenet_external' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/external.php',
    'tool_moodlenet_moodlenet_user_profile' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/moodlenet_user_profile.php',
    'tool_moodlenet_profile_manager' => '/var/www/html/plantilla/admin/tool/moodlenet/classes/profile_manager.php',
    'tool_multilangupgrade\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/multilangupgrade/classes/privacy/provider.php',
    'tool_oauth2\\form\\endpoint' => '/var/www/html/plantilla/admin/tool/oauth2/classes/form/endpoint.php',
    'tool_oauth2\\form\\issuer' => '/var/www/html/plantilla/admin/tool/oauth2/classes/form/issuer.php',
    'tool_oauth2\\form\\user_field_mapping' => '/var/www/html/plantilla/admin/tool/oauth2/classes/form/user_field_mapping.php',
    'tool_oauth2\\output\\renderer' => '/var/www/html/plantilla/admin/tool/oauth2/classes/output/renderer.php',
    'tool_oauth2\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/oauth2/classes/privacy/provider.php',
    'tool_phpunit\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/phpunit/classes/privacy/provider.php',
    'tool_policy\\acceptances_table' => '/var/www/html/plantilla/admin/tool/policy/classes/acceptances_table.php',
    'tool_policy\\api' => '/var/www/html/plantilla/admin/tool/policy/classes/api.php',
    'tool_policy\\event\\acceptance_base' => '/var/www/html/plantilla/admin/tool/policy/classes/event/acceptance_base.php',
    'tool_policy\\event\\acceptance_created' => '/var/www/html/plantilla/admin/tool/policy/classes/event/acceptance_created.php',
    'tool_policy\\event\\acceptance_updated' => '/var/www/html/plantilla/admin/tool/policy/classes/event/acceptance_updated.php',
    'tool_policy\\external' => '/var/www/html/plantilla/admin/tool/policy/classes/external.php',
    'tool_policy\\external\\get_user_acceptances' => '/var/www/html/plantilla/admin/tool/policy/classes/external/get_user_acceptances.php',
    'tool_policy\\external\\set_acceptances_status' => '/var/www/html/plantilla/admin/tool/policy/classes/external/set_acceptances_status.php',
    'tool_policy\\form\\accept_policy' => '/var/www/html/plantilla/admin/tool/policy/classes/form/accept_policy.php',
    'tool_policy\\form\\policydoc' => '/var/www/html/plantilla/admin/tool/policy/classes/form/policydoc.php',
    'tool_policy\\hook_callbacks' => '/var/www/html/plantilla/admin/tool/policy/classes/hook_callbacks.php',
    'tool_policy\\output\\acceptances' => '/var/www/html/plantilla/admin/tool/policy/classes/output/acceptances.php',
    'tool_policy\\output\\acceptances_filter' => '/var/www/html/plantilla/admin/tool/policy/classes/output/acceptances_filter.php',
    'tool_policy\\output\\guestconsent' => '/var/www/html/plantilla/admin/tool/policy/classes/output/guestconsent.php',
    'tool_policy\\output\\page_agreedocs' => '/var/www/html/plantilla/admin/tool/policy/classes/output/page_agreedocs.php',
    'tool_policy\\output\\page_managedocs_list' => '/var/www/html/plantilla/admin/tool/policy/classes/output/page_managedocs_list.php',
    'tool_policy\\output\\page_nopermission' => '/var/www/html/plantilla/admin/tool/policy/classes/output/page_nopermission.php',
    'tool_policy\\output\\page_viewalldoc' => '/var/www/html/plantilla/admin/tool/policy/classes/output/page_viewalldoc.php',
    'tool_policy\\output\\page_viewdoc' => '/var/www/html/plantilla/admin/tool/policy/classes/output/page_viewdoc.php',
    'tool_policy\\output\\renderer' => '/var/www/html/plantilla/admin/tool/policy/classes/output/renderer.php',
    'tool_policy\\output\\user_agreement' => '/var/www/html/plantilla/admin/tool/policy/classes/output/user_agreement.php',
    'tool_policy\\policy_exporter' => '/var/www/html/plantilla/admin/tool/policy/classes/policy_exporter.php',
    'tool_policy\\policy_version' => '/var/www/html/plantilla/admin/tool/policy/classes/policy_version.php',
    'tool_policy\\policy_version_exporter' => '/var/www/html/plantilla/admin/tool/policy/classes/policy_version_exporter.php',
    'tool_policy\\privacy\\local\\sitepolicy\\handler' => '/var/www/html/plantilla/admin/tool/policy/classes/privacy/local/sitepolicy/handler.php',
    'tool_policy\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/policy/classes/privacy/provider.php',
    'tool_policy\\test\\helper' => '/var/www/html/plantilla/admin/tool/policy/classes/test/helper.php',
    'tool_policy_acceptances_table' => '/var/www/html/plantilla/admin/tool/policy/classes/acceptances_table.php',
    'tool_policy_api' => '/var/www/html/plantilla/admin/tool/policy/classes/api.php',
    'tool_policy_external' => '/var/www/html/plantilla/admin/tool/policy/classes/external.php',
    'tool_policy_hook_callbacks' => '/var/www/html/plantilla/admin/tool/policy/classes/hook_callbacks.php',
    'tool_policy_policy_exporter' => '/var/www/html/plantilla/admin/tool/policy/classes/policy_exporter.php',
    'tool_policy_policy_version' => '/var/www/html/plantilla/admin/tool/policy/classes/policy_version.php',
    'tool_policy_policy_version_exporter' => '/var/www/html/plantilla/admin/tool/policy/classes/policy_version_exporter.php',
    'tool_profiling\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/profiling/classes/privacy/provider.php',
    'tool_recyclebin\\base_bin' => '/var/www/html/plantilla/admin/tool/recyclebin/classes/base_bin.php',
    'tool_recyclebin\\category_bin' => '/var/www/html/plantilla/admin/tool/recyclebin/classes/category_bin.php',
    'tool_recyclebin\\course_bin' => '/var/www/html/plantilla/admin/tool/recyclebin/classes/course_bin.php',
    'tool_recyclebin\\event\\category_bin_item_created' => '/var/www/html/plantilla/admin/tool/recyclebin/classes/event/category_bin_item_created.php',
    'tool_recyclebin\\event\\category_bin_item_deleted' => '/var/www/html/plantilla/admin/tool/recyclebin/classes/event/category_bin_item_deleted.php',
    'tool_recyclebin\\event\\category_bin_item_restored' => '/var/www/html/plantilla/admin/tool/recyclebin/classes/event/category_bin_item_restored.php',
    'tool_recyclebin\\event\\course_bin_item_created' => '/var/www/html/plantilla/admin/tool/recyclebin/classes/event/course_bin_item_created.php',
    'tool_recyclebin\\event\\course_bin_item_deleted' => '/var/www/html/plantilla/admin/tool/recyclebin/classes/event/course_bin_item_deleted.php',
    'tool_recyclebin\\event\\course_bin_item_restored' => '/var/www/html/plantilla/admin/tool/recyclebin/classes/event/course_bin_item_restored.php',
    'tool_recyclebin\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/recyclebin/classes/privacy/provider.php',
    'tool_recyclebin\\task\\cleanup_category_bin' => '/var/www/html/plantilla/admin/tool/recyclebin/classes/task/cleanup_category_bin.php',
    'tool_recyclebin\\task\\cleanup_course_bin' => '/var/www/html/plantilla/admin/tool/recyclebin/classes/task/cleanup_course_bin.php',
    'tool_recyclebin_base_bin' => '/var/www/html/plantilla/admin/tool/recyclebin/classes/base_bin.php',
    'tool_recyclebin_category_bin' => '/var/www/html/plantilla/admin/tool/recyclebin/classes/category_bin.php',
    'tool_recyclebin_course_bin' => '/var/www/html/plantilla/admin/tool/recyclebin/classes/course_bin.php',
    'tool_replace\\form' => '/var/www/html/plantilla/admin/tool/replace/classes/form.php',
    'tool_replace\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/replace/classes/privacy/provider.php',
    'tool_replace_form' => '/var/www/html/plantilla/admin/tool/replace/classes/form.php',
    'tool_spamcleaner\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/spamcleaner/classes/privacy/provider.php',
    'tool_task\\check\\adhocqueue' => '/var/www/html/plantilla/admin/tool/task/classes/check/adhocqueue.php',
    'tool_task\\check\\cronrunning' => '/var/www/html/plantilla/admin/tool/task/classes/check/cronrunning.php',
    'tool_task\\check\\longrunningtasks' => '/var/www/html/plantilla/admin/tool/task/classes/check/longrunningtasks.php',
    'tool_task\\check\\maxfaildelay' => '/var/www/html/plantilla/admin/tool/task/classes/check/maxfaildelay.php',
    'tool_task\\edit_scheduled_task_form' => '/var/www/html/plantilla/admin/tool/task/classes/edit_scheduled_task_form.php',
    'tool_task\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/task/classes/privacy/provider.php',
    'tool_task\\running_tasks_table' => '/var/www/html/plantilla/admin/tool/task/classes/running_tasks_table.php',
    'tool_task\\scheduled_checker_task' => '/var/www/html/plantilla/admin/tool/task/classes/scheduled_checker_task.php',
    'tool_task_edit_scheduled_task_form' => '/var/www/html/plantilla/admin/tool/task/classes/edit_scheduled_task_form.php',
    'tool_task_running_tasks_table' => '/var/www/html/plantilla/admin/tool/task/classes/running_tasks_table.php',
    'tool_task_scheduled_checker_task' => '/var/www/html/plantilla/admin/tool/task/classes/scheduled_checker_task.php',
    'tool_templatelibrary\\api' => '/var/www/html/plantilla/admin/tool/templatelibrary/classes/api.php',
    'tool_templatelibrary\\external' => '/var/www/html/plantilla/admin/tool/templatelibrary/classes/external.php',
    'tool_templatelibrary\\output\\list_templates_page' => '/var/www/html/plantilla/admin/tool/templatelibrary/classes/output/list_templates_page.php',
    'tool_templatelibrary\\output\\renderer' => '/var/www/html/plantilla/admin/tool/templatelibrary/classes/output/renderer.php',
    'tool_templatelibrary\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/templatelibrary/classes/privacy/provider.php',
    'tool_templatelibrary_api' => '/var/www/html/plantilla/admin/tool/templatelibrary/classes/api.php',
    'tool_templatelibrary_external' => '/var/www/html/plantilla/admin/tool/templatelibrary/classes/external.php',
    'tool_unsuproles\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/unsuproles/classes/privacy/provider.php',
    'tool_uploadcourse\\base_form' => '/var/www/html/plantilla/admin/tool/uploadcourse/classes/base_form.php',
    'tool_uploadcourse\\course' => '/var/www/html/plantilla/admin/tool/uploadcourse/classes/course.php',
    'tool_uploadcourse\\helper' => '/var/www/html/plantilla/admin/tool/uploadcourse/classes/helper.php',
    'tool_uploadcourse\\permissions' => '/var/www/html/plantilla/admin/tool/uploadcourse/classes/permissions.php',
    'tool_uploadcourse\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/uploadcourse/classes/privacy/provider.php',
    'tool_uploadcourse\\processor' => '/var/www/html/plantilla/admin/tool/uploadcourse/classes/processor.php',
    'tool_uploadcourse\\step1_form' => '/var/www/html/plantilla/admin/tool/uploadcourse/classes/step1_form.php',
    'tool_uploadcourse\\step2_form' => '/var/www/html/plantilla/admin/tool/uploadcourse/classes/step2_form.php',
    'tool_uploadcourse\\tracker' => '/var/www/html/plantilla/admin/tool/uploadcourse/classes/tracker.php',
    'tool_uploadcourse_base_form' => '/var/www/html/plantilla/admin/tool/uploadcourse/classes/base_form.php',
    'tool_uploadcourse_course' => '/var/www/html/plantilla/admin/tool/uploadcourse/classes/course.php',
    'tool_uploadcourse_helper' => '/var/www/html/plantilla/admin/tool/uploadcourse/classes/helper.php',
    'tool_uploadcourse_permissions' => '/var/www/html/plantilla/admin/tool/uploadcourse/classes/permissions.php',
    'tool_uploadcourse_processor' => '/var/www/html/plantilla/admin/tool/uploadcourse/classes/processor.php',
    'tool_uploadcourse_step1_form' => '/var/www/html/plantilla/admin/tool/uploadcourse/classes/step1_form.php',
    'tool_uploadcourse_step2_form' => '/var/www/html/plantilla/admin/tool/uploadcourse/classes/step2_form.php',
    'tool_uploadcourse_tracker' => '/var/www/html/plantilla/admin/tool/uploadcourse/classes/tracker.php',
    'tool_uploaduser\\cli_helper' => '/var/www/html/plantilla/admin/tool/uploaduser/classes/cli_helper.php',
    'tool_uploaduser\\local\\cli_progress_tracker' => '/var/www/html/plantilla/admin/tool/uploaduser/classes/local/cli_progress_tracker.php',
    'tool_uploaduser\\local\\field_value_validators' => '/var/www/html/plantilla/admin/tool/uploaduser/classes/local/field_value_validators.php',
    'tool_uploaduser\\local\\text_progress_tracker' => '/var/www/html/plantilla/admin/tool/uploaduser/classes/local/text_progress_tracker.php',
    'tool_uploaduser\\preview' => '/var/www/html/plantilla/admin/tool/uploaduser/classes/preview.php',
    'tool_uploaduser\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/uploaduser/classes/privacy/provider.php',
    'tool_uploaduser\\process' => '/var/www/html/plantilla/admin/tool/uploaduser/classes/process.php',
    'tool_uploaduser_cli_helper' => '/var/www/html/plantilla/admin/tool/uploaduser/classes/cli_helper.php',
    'tool_uploaduser_preview' => '/var/www/html/plantilla/admin/tool/uploaduser/classes/preview.php',
    'tool_uploaduser_process' => '/var/www/html/plantilla/admin/tool/uploaduser/classes/process.php',
    'tool_usertours\\cache' => '/var/www/html/plantilla/admin/tool/usertours/classes/cache.php',
    'tool_usertours\\configuration' => '/var/www/html/plantilla/admin/tool/usertours/classes/configuration.php',
    'tool_usertours\\event\\step_shown' => '/var/www/html/plantilla/admin/tool/usertours/classes/event/step_shown.php',
    'tool_usertours\\event\\tour_ended' => '/var/www/html/plantilla/admin/tool/usertours/classes/event/tour_ended.php',
    'tool_usertours\\event\\tour_reset' => '/var/www/html/plantilla/admin/tool/usertours/classes/event/tour_reset.php',
    'tool_usertours\\event\\tour_started' => '/var/www/html/plantilla/admin/tool/usertours/classes/event/tour_started.php',
    'tool_usertours\\external\\tour' => '/var/www/html/plantilla/admin/tool/usertours/classes/external/tour.php',
    'tool_usertours\\helper' => '/var/www/html/plantilla/admin/tool/usertours/classes/helper.php',
    'tool_usertours\\hook\\before_clientside_filter_fetch' => '/var/www/html/plantilla/admin/tool/usertours/classes/hook/before_clientside_filter_fetch.php',
    'tool_usertours\\hook\\before_serverside_filter_fetch' => '/var/www/html/plantilla/admin/tool/usertours/classes/hook/before_serverside_filter_fetch.php',
    'tool_usertours\\hook_callbacks' => '/var/www/html/plantilla/admin/tool/usertours/classes/hook_callbacks.php',
    'tool_usertours\\local\\clientside_filter\\clientside_filter' => '/var/www/html/plantilla/admin/tool/usertours/classes/local/clientside_filter/clientside_filter.php',
    'tool_usertours\\local\\clientside_filter\\cssselector' => '/var/www/html/plantilla/admin/tool/usertours/classes/local/clientside_filter/cssselector.php',
    'tool_usertours\\local\\filter\\accessdate' => '/var/www/html/plantilla/admin/tool/usertours/classes/local/filter/accessdate.php',
    'tool_usertours\\local\\filter\\base' => '/var/www/html/plantilla/admin/tool/usertours/classes/local/filter/base.php',
    'tool_usertours\\local\\filter\\category' => '/var/www/html/plantilla/admin/tool/usertours/classes/local/filter/category.php',
    'tool_usertours\\local\\filter\\course' => '/var/www/html/plantilla/admin/tool/usertours/classes/local/filter/course.php',
    'tool_usertours\\local\\filter\\courseformat' => '/var/www/html/plantilla/admin/tool/usertours/classes/local/filter/courseformat.php',
    'tool_usertours\\local\\filter\\role' => '/var/www/html/plantilla/admin/tool/usertours/classes/local/filter/role.php',
    'tool_usertours\\local\\filter\\theme' => '/var/www/html/plantilla/admin/tool/usertours/classes/local/filter/theme.php',
    'tool_usertours\\local\\forms\\editstep' => '/var/www/html/plantilla/admin/tool/usertours/classes/local/forms/editstep.php',
    'tool_usertours\\local\\forms\\edittour' => '/var/www/html/plantilla/admin/tool/usertours/classes/local/forms/edittour.php',
    'tool_usertours\\local\\forms\\importtour' => '/var/www/html/plantilla/admin/tool/usertours/classes/local/forms/importtour.php',
    'tool_usertours\\local\\table\\step_list' => '/var/www/html/plantilla/admin/tool/usertours/classes/local/table/step_list.php',
    'tool_usertours\\local\\table\\tour_list' => '/var/www/html/plantilla/admin/tool/usertours/classes/local/table/tour_list.php',
    'tool_usertours\\local\\target\\base' => '/var/www/html/plantilla/admin/tool/usertours/classes/local/target/base.php',
    'tool_usertours\\local\\target\\block' => '/var/www/html/plantilla/admin/tool/usertours/classes/local/target/block.php',
    'tool_usertours\\local\\target\\selector' => '/var/www/html/plantilla/admin/tool/usertours/classes/local/target/selector.php',
    'tool_usertours\\local\\target\\unattached' => '/var/www/html/plantilla/admin/tool/usertours/classes/local/target/unattached.php',
    'tool_usertours\\manager' => '/var/www/html/plantilla/admin/tool/usertours/classes/manager.php',
    'tool_usertours\\output\\renderer' => '/var/www/html/plantilla/admin/tool/usertours/classes/output/renderer.php',
    'tool_usertours\\output\\step' => '/var/www/html/plantilla/admin/tool/usertours/classes/output/step.php',
    'tool_usertours\\output\\tour' => '/var/www/html/plantilla/admin/tool/usertours/classes/output/tour.php',
    'tool_usertours\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/usertours/classes/privacy/provider.php',
    'tool_usertours\\step' => '/var/www/html/plantilla/admin/tool/usertours/classes/step.php',
    'tool_usertours\\target' => '/var/www/html/plantilla/admin/tool/usertours/classes/target.php',
    'tool_usertours\\tour' => '/var/www/html/plantilla/admin/tool/usertours/classes/tour.php',
    'tool_usertours_cache' => '/var/www/html/plantilla/admin/tool/usertours/classes/cache.php',
    'tool_usertours_configuration' => '/var/www/html/plantilla/admin/tool/usertours/classes/configuration.php',
    'tool_usertours_helper' => '/var/www/html/plantilla/admin/tool/usertours/classes/helper.php',
    'tool_usertours_hook_callbacks' => '/var/www/html/plantilla/admin/tool/usertours/classes/hook_callbacks.php',
    'tool_usertours_manager' => '/var/www/html/plantilla/admin/tool/usertours/classes/manager.php',
    'tool_usertours_step' => '/var/www/html/plantilla/admin/tool/usertours/classes/step.php',
    'tool_usertours_target' => '/var/www/html/plantilla/admin/tool/usertours/classes/target.php',
    'tool_usertours_tour' => '/var/www/html/plantilla/admin/tool/usertours/classes/tour.php',
    'tool_xmldb\\external' => '/var/www/html/plantilla/admin/tool/xmldb/classes/external.php',
    'tool_xmldb\\privacy\\provider' => '/var/www/html/plantilla/admin/tool/xmldb/classes/privacy/provider.php',
    'tool_xmldb_external' => '/var/www/html/plantilla/admin/tool/xmldb/classes/external.php',
    'url_select' => '/var/www/html/plantilla/lib/classes/output/url_select.php',
    'user_picture' => '/var/www/html/plantilla/lib/classes/output/user_picture.php',
    'webservice_parameter_exception' => '/var/www/html/plantilla/lib/classes/exception/webservice_parameter_exception.php',
    'webservice_rest\\privacy\\provider' => '/var/www/html/plantilla/webservice/rest/classes/privacy/provider.php',
    'webservice_soap\\privacy\\provider' => '/var/www/html/plantilla/webservice/soap/classes/privacy/provider.php',
    'webservice_soap\\wsdl' => '/var/www/html/plantilla/webservice/soap/classes/wsdl.php',
    'webservice_soap_wsdl' => '/var/www/html/plantilla/webservice/soap/classes/wsdl.php',
    'workshopallocation_manual\\privacy\\provider' => '/var/www/html/plantilla/mod/workshop/allocation/manual/classes/privacy/provider.php',
    'workshopallocation_random\\privacy\\provider' => '/var/www/html/plantilla/mod/workshop/allocation/random/classes/privacy/provider.php',
    'workshopallocation_scheduled\\observer' => '/var/www/html/plantilla/mod/workshop/allocation/scheduled/classes/observer.php',
    'workshopallocation_scheduled\\privacy\\provider' => '/var/www/html/plantilla/mod/workshop/allocation/scheduled/classes/privacy/provider.php',
    'workshopallocation_scheduled\\task\\cron_task' => '/var/www/html/plantilla/mod/workshop/allocation/scheduled/classes/task/cron_task.php',
    'workshopallocation_scheduled_observer' => '/var/www/html/plantilla/mod/workshop/allocation/scheduled/classes/observer.php',
    'workshopeval_best\\privacy\\provider' => '/var/www/html/plantilla/mod/workshop/eval/best/classes/privacy/provider.php',
    'workshopform_accumulative\\privacy\\provider' => '/var/www/html/plantilla/mod/workshop/form/accumulative/classes/privacy/provider.php',
    'workshopform_comments\\privacy\\provider' => '/var/www/html/plantilla/mod/workshop/form/comments/classes/privacy/provider.php',
    'workshopform_numerrors\\privacy\\provider' => '/var/www/html/plantilla/mod/workshop/form/numerrors/classes/privacy/provider.php',
    'workshopform_rubric\\privacy\\provider' => '/var/www/html/plantilla/mod/workshop/form/rubric/classes/privacy/provider.php',
    'xhtml_container_stack' => '/var/www/html/plantilla/lib/classes/output/xhtml_container_stack.php',
  ),
  'classmaprenames' => 
  array (
    'core_reportbuilder\\report_access_exception' => 'core_reportbuilder\\exception\\report_access_exception',
    'core_reportbuilder\\source_invalid_exception' => 'core_reportbuilder\\exception\\source_invalid_exception',
    'core_reportbuilder\\source_unavailable_exception' => 'core_reportbuilder\\exception\\source_unavailable_exception',
    'PNG_MetaDataHandler' => 'core_badges\\png_metadata_handler',
    'filter_activitynames' => 'filter_activitynames\\text_filter',
    'filter_algebra' => 'filter_algebra\\text_filter',
    'filter_codehighlighter' => 'filter_codehighlighter\\text_filter',
    'filter_data' => 'filter_data\\text_filter',
    'filter_displayh5p' => 'filter_displayh5p\\text_filter',
    'filter_emailprotect' => 'filter_emailprotect\\text_filter',
    'filter_emoticon' => 'filter_emoticon\\text_filter',
    'filter_glossary' => 'filter_glossary\\text_filter',
    'filter_mathjaxloader' => 'filter_mathjaxloader\\text_filter',
    'filter_mediaplugin' => 'filter_mediaplugin\\text_filter',
    'filter_multilang' => 'filter_multilang\\text_filter',
    'filter_tex' => 'filter_tex\\text_filter',
    'filter_urltolink' => 'filter_urltolink\\text_filter',
  ),
  'filemap' => 
  array (
    'lib.php' => 
    array (
      'aiplacement' => 
      array (
      ),
      'aiprovider' => 
      array (
      ),
      'antivirus' => 
      array (
      ),
      'availability' => 
      array (
      ),
      'qtype' => 
      array (
        'calculated' => '/var/www/html/plantilla/question/type/calculated/lib.php',
        'calculatedmulti' => '/var/www/html/plantilla/question/type/calculatedmulti/lib.php',
        'calculatedsimple' => '/var/www/html/plantilla/question/type/calculatedsimple/lib.php',
        'ddimageortext' => '/var/www/html/plantilla/question/type/ddimageortext/lib.php',
        'ddmarker' => '/var/www/html/plantilla/question/type/ddmarker/lib.php',
        'ddwtos' => '/var/www/html/plantilla/question/type/ddwtos/lib.php',
        'essay' => '/var/www/html/plantilla/question/type/essay/lib.php',
        'gapselect' => '/var/www/html/plantilla/question/type/gapselect/lib.php',
        'match' => '/var/www/html/plantilla/question/type/match/lib.php',
        'multichoice' => '/var/www/html/plantilla/question/type/multichoice/lib.php',
        'numerical' => '/var/www/html/plantilla/question/type/numerical/lib.php',
        'ordering' => '/var/www/html/plantilla/question/type/ordering/lib.php',
        'randomsamatch' => '/var/www/html/plantilla/question/type/randomsamatch/lib.php',
        'shortanswer' => '/var/www/html/plantilla/question/type/shortanswer/lib.php',
        'truefalse' => '/var/www/html/plantilla/question/type/truefalse/lib.php',
      ),
      'mod' => 
      array (
        'assign' => '/var/www/html/plantilla/mod/assign/lib.php',
        'bigbluebuttonbn' => '/var/www/html/plantilla/mod/bigbluebuttonbn/lib.php',
        'book' => '/var/www/html/plantilla/mod/book/lib.php',
        'choice' => '/var/www/html/plantilla/mod/choice/lib.php',
        'data' => '/var/www/html/plantilla/mod/data/lib.php',
        'feedback' => '/var/www/html/plantilla/mod/feedback/lib.php',
        'folder' => '/var/www/html/plantilla/mod/folder/lib.php',
        'forum' => '/var/www/html/plantilla/mod/forum/lib.php',
        'game' => '/var/www/html/plantilla/mod/game/lib.php',
        'glossary' => '/var/www/html/plantilla/mod/glossary/lib.php',
        'h5pactivity' => '/var/www/html/plantilla/mod/h5pactivity/lib.php',
        'hvp' => '/var/www/html/plantilla/mod/hvp/lib.php',
        'imscp' => '/var/www/html/plantilla/mod/imscp/lib.php',
        'label' => '/var/www/html/plantilla/mod/label/lib.php',
        'lesson' => '/var/www/html/plantilla/mod/lesson/lib.php',
        'lti' => '/var/www/html/plantilla/mod/lti/lib.php',
        'page' => '/var/www/html/plantilla/mod/page/lib.php',
        'qbank' => '/var/www/html/plantilla/mod/qbank/lib.php',
        'quiz' => '/var/www/html/plantilla/mod/quiz/lib.php',
        'resource' => '/var/www/html/plantilla/mod/resource/lib.php',
        'scorm' => '/var/www/html/plantilla/mod/scorm/lib.php',
        'subsection' => '/var/www/html/plantilla/mod/subsection/lib.php',
        'url' => '/var/www/html/plantilla/mod/url/lib.php',
        'wiki' => '/var/www/html/plantilla/mod/wiki/lib.php',
        'workshop' => '/var/www/html/plantilla/mod/workshop/lib.php',
      ),
      'auth' => 
      array (
        'lti' => '/var/www/html/plantilla/auth/lti/lib.php',
        'none' => '/var/www/html/plantilla/auth/none/lib.php',
        'oauth2' => '/var/www/html/plantilla/auth/oauth2/lib.php',
        'shibboleth' => '/var/www/html/plantilla/auth/shibboleth/lib.php',
      ),
      'calendartype' => 
      array (
      ),
      'communication' => 
      array (
      ),
      'customfield' => 
      array (
        'date' => '/var/www/html/plantilla/customfield/field/date/lib.php',
        'textarea' => '/var/www/html/plantilla/customfield/field/textarea/lib.php',
      ),
      'enrol' => 
      array (
        'category' => '/var/www/html/plantilla/enrol/category/lib.php',
        'cohort' => '/var/www/html/plantilla/enrol/cohort/lib.php',
        'database' => '/var/www/html/plantilla/enrol/database/lib.php',
        'fee' => '/var/www/html/plantilla/enrol/fee/lib.php',
        'flatfile' => '/var/www/html/plantilla/enrol/flatfile/lib.php',
        'guest' => '/var/www/html/plantilla/enrol/guest/lib.php',
        'imsenterprise' => '/var/www/html/plantilla/enrol/imsenterprise/lib.php',
        'ldap' => '/var/www/html/plantilla/enrol/ldap/lib.php',
        'lti' => '/var/www/html/plantilla/enrol/lti/lib.php',
        'manual' => '/var/www/html/plantilla/enrol/manual/lib.php',
        'meta' => '/var/www/html/plantilla/enrol/meta/lib.php',
        'paypal' => '/var/www/html/plantilla/enrol/paypal/lib.php',
        'self' => '/var/www/html/plantilla/enrol/self/lib.php',
      ),
      'message' => 
      array (
        'airnotifier' => '/var/www/html/plantilla/message/output/airnotifier/lib.php',
        'popup' => '/var/www/html/plantilla/message/output/popup/lib.php',
      ),
      'block' => 
      array (
        'accessreview' => '/var/www/html/plantilla/blocks/accessreview/lib.php',
        'comments' => '/var/www/html/plantilla/blocks/comments/lib.php',
        'configurable_reports' => '/var/www/html/plantilla/blocks/configurable_reports/lib.php',
        'html' => '/var/www/html/plantilla/blocks/html/lib.php',
        'myoverview' => '/var/www/html/plantilla/blocks/myoverview/lib.php',
        'online_users' => '/var/www/html/plantilla/blocks/online_users/lib.php',
        'recentlyaccesseditems' => '/var/www/html/plantilla/blocks/recentlyaccesseditems/lib.php',
        'timeline' => '/var/www/html/plantilla/blocks/timeline/lib.php',
      ),
      'media' => 
      array (
      ),
      'filter' => 
      array (
        'tex' => '/var/www/html/plantilla/filter/tex/lib.php',
      ),
      'editor' => 
      array (
        'textarea' => '/var/www/html/plantilla/lib/editor/textarea/lib.php',
        'tiny' => '/var/www/html/plantilla/lib/editor/tiny/lib.php',
      ),
      'format' => 
      array (
        'singleactivity' => '/var/www/html/plantilla/course/format/singleactivity/lib.php',
        'social' => '/var/www/html/plantilla/course/format/social/lib.php',
        'tiles' => '/var/www/html/plantilla/course/format/tiles/lib.php',
        'topics' => '/var/www/html/plantilla/course/format/topics/lib.php',
        'weeks' => '/var/www/html/plantilla/course/format/weeks/lib.php',
      ),
      'dataformat' => 
      array (
      ),
      'profilefield' => 
      array (
      ),
      'report' => 
      array (
        'competency' => '/var/www/html/plantilla/report/competency/lib.php',
        'completion' => '/var/www/html/plantilla/report/completion/lib.php',
        'customsql' => '/var/www/html/plantilla/report/customsql/lib.php',
        'insights' => '/var/www/html/plantilla/report/insights/lib.php',
        'log' => '/var/www/html/plantilla/report/log/lib.php',
        'loglive' => '/var/www/html/plantilla/report/loglive/lib.php',
        'outline' => '/var/www/html/plantilla/report/outline/lib.php',
        'participation' => '/var/www/html/plantilla/report/participation/lib.php',
        'progress' => '/var/www/html/plantilla/report/progress/lib.php',
        'stats' => '/var/www/html/plantilla/report/stats/lib.php',
        'usersessions' => '/var/www/html/plantilla/report/usersessions/lib.php',
      ),
      'coursereport' => 
      array (
      ),
      'gradeexport' => 
      array (
      ),
      'gradeimport' => 
      array (
        'xml' => '/var/www/html/plantilla/grade/import/xml/lib.php',
      ),
      'gradepenalty' => 
      array (
        'duedate' => '/var/www/html/plantilla/grade/penalty/duedate/lib.php',
      ),
      'gradereport' => 
      array (
        'grader' => '/var/www/html/plantilla/grade/report/grader/lib.php',
        'overview' => '/var/www/html/plantilla/grade/report/overview/lib.php',
        'singleview' => '/var/www/html/plantilla/grade/report/singleview/lib.php',
        'summary' => '/var/www/html/plantilla/grade/report/summary/lib.php',
        'user' => '/var/www/html/plantilla/grade/report/user/lib.php',
      ),
      'gradingform' => 
      array (
        'guide' => '/var/www/html/plantilla/grade/grading/form/guide/lib.php',
        'rubric' => '/var/www/html/plantilla/grade/grading/form/rubric/lib.php',
      ),
      'mlbackend' => 
      array (
      ),
      'webservice' => 
      array (
        'rest' => '/var/www/html/plantilla/webservice/rest/lib.php',
        'soap' => '/var/www/html/plantilla/webservice/soap/lib.php',
      ),
      'repository' => 
      array (
        'areafiles' => '/var/www/html/plantilla/repository/areafiles/lib.php',
        'contentbank' => '/var/www/html/plantilla/repository/contentbank/lib.php',
        'coursefiles' => '/var/www/html/plantilla/repository/coursefiles/lib.php',
        'dropbox' => '/var/www/html/plantilla/repository/dropbox/lib.php',
        'equella' => '/var/www/html/plantilla/repository/equella/lib.php',
        'filesystem' => '/var/www/html/plantilla/repository/filesystem/lib.php',
        'flickr' => '/var/www/html/plantilla/repository/flickr/lib.php',
        'flickr_public' => '/var/www/html/plantilla/repository/flickr_public/lib.php',
        'googledocs' => '/var/www/html/plantilla/repository/googledocs/lib.php',
        'local' => '/var/www/html/plantilla/repository/local/lib.php',
        'merlot' => '/var/www/html/plantilla/repository/merlot/lib.php',
        'nextcloud' => '/var/www/html/plantilla/repository/nextcloud/lib.php',
        'onedrive' => '/var/www/html/plantilla/repository/onedrive/lib.php',
        'recent' => '/var/www/html/plantilla/repository/recent/lib.php',
        's3' => '/var/www/html/plantilla/repository/s3/lib.php',
        'upload' => '/var/www/html/plantilla/repository/upload/lib.php',
        'url' => '/var/www/html/plantilla/repository/url/lib.php',
        'user' => '/var/www/html/plantilla/repository/user/lib.php',
        'webdav' => '/var/www/html/plantilla/repository/webdav/lib.php',
        'wikimedia' => '/var/www/html/plantilla/repository/wikimedia/lib.php',
        'youtube' => '/var/www/html/plantilla/repository/youtube/lib.php',
      ),
      'portfolio' => 
      array (
        'download' => '/var/www/html/plantilla/portfolio/download/lib.php',
        'flickr' => '/var/www/html/plantilla/portfolio/flickr/lib.php',
        'googledocs' => '/var/www/html/plantilla/portfolio/googledocs/lib.php',
      ),
      'search' => 
      array (
        'solr' => '/var/www/html/plantilla/search/engine/solr/lib.php',
      ),
      'qbank' => 
      array (
        'bulkmove' => '/var/www/html/plantilla/question/bank/bulkmove/lib.php',
        'columnsortorder' => '/var/www/html/plantilla/question/bank/columnsortorder/lib.php',
        'comment' => '/var/www/html/plantilla/question/bank/comment/lib.php',
        'customfields' => '/var/www/html/plantilla/question/bank/customfields/lib.php',
        'exporttoxml' => '/var/www/html/plantilla/question/bank/exporttoxml/lib.php',
        'managecategories' => '/var/www/html/plantilla/question/bank/managecategories/lib.php',
        'previewquestion' => '/var/www/html/plantilla/question/bank/previewquestion/lib.php',
        'tagquestion' => '/var/www/html/plantilla/question/bank/tagquestion/lib.php',
        'usage' => '/var/www/html/plantilla/question/bank/usage/lib.php',
        'viewcreator' => '/var/www/html/plantilla/question/bank/viewcreator/lib.php',
        'viewquestionname' => '/var/www/html/plantilla/question/bank/viewquestionname/lib.php',
      ),
      'qbehaviour' => 
      array (
      ),
      'qformat' => 
      array (
        'xhtml' => '/var/www/html/plantilla/question/format/xhtml/lib.php',
      ),
      'plagiarism' => 
      array (
      ),
      'tool' => 
      array (
        'admin_presets' => '/var/www/html/plantilla/admin/tool/admin_presets/lib.php',
        'brickfield' => '/var/www/html/plantilla/admin/tool/brickfield/lib.php',
        'customlang' => '/var/www/html/plantilla/admin/tool/customlang/lib.php',
        'dataprivacy' => '/var/www/html/plantilla/admin/tool/dataprivacy/lib.php',
        'generator' => '/var/www/html/plantilla/admin/tool/generator/lib.php',
        'langimport' => '/var/www/html/plantilla/admin/tool/langimport/lib.php',
        'lp' => '/var/www/html/plantilla/admin/tool/lp/lib.php',
        'mfa' => '/var/www/html/plantilla/admin/tool/mfa/lib.php',
        'mobile' => '/var/www/html/plantilla/admin/tool/mobile/lib.php',
        'monitor' => '/var/www/html/plantilla/admin/tool/monitor/lib.php',
        'moodlenet' => '/var/www/html/plantilla/admin/tool/moodlenet/lib.php',
        'policy' => '/var/www/html/plantilla/admin/tool/policy/lib.php',
        'recyclebin' => '/var/www/html/plantilla/admin/tool/recyclebin/lib.php',
        'task' => '/var/www/html/plantilla/admin/tool/task/lib.php',
        'uploadcourse' => '/var/www/html/plantilla/admin/tool/uploadcourse/lib.php',
        'usertours' => '/var/www/html/plantilla/admin/tool/usertours/lib.php',
      ),
      'cachestore' => 
      array (
        'apcu' => '/var/www/html/plantilla/cache/stores/apcu/lib.php',
        'file' => '/var/www/html/plantilla/cache/stores/file/lib.php',
        'redis' => '/var/www/html/plantilla/cache/stores/redis/lib.php',
        'session' => '/var/www/html/plantilla/cache/stores/session/lib.php',
        'static' => '/var/www/html/plantilla/cache/stores/static/lib.php',
      ),
      'cachelock' => 
      array (
        'file' => '/var/www/html/plantilla/cache/locks/file/lib.php',
      ),
      'fileconverter' => 
      array (
        'googledrive' => '/var/www/html/plantilla/files/converter/googledrive/lib.php',
      ),
      'contenttype' => 
      array (
      ),
      'theme' => 
      array (
        'boost' => '/var/www/html/plantilla/theme/boost/lib.php',
        'classic' => '/var/www/html/plantilla/theme/classic/lib.php',
        'moove' => '/var/www/html/plantilla/theme/moove/lib.php',
      ),
      'local' => 
      array (
      ),
      'h5plib' => 
      array (
      ),
      'paygw' => 
      array (
      ),
      'smsgateway' => 
      array (
      ),
      'assignsubmission' => 
      array (
        'comments' => '/var/www/html/plantilla/mod/assign/submission/comments/lib.php',
        'file' => '/var/www/html/plantilla/mod/assign/submission/file/lib.php',
        'onlinetext' => '/var/www/html/plantilla/mod/assign/submission/onlinetext/lib.php',
      ),
      'assignfeedback' => 
      array (
        'comments' => '/var/www/html/plantilla/mod/assign/feedback/comments/lib.php',
        'editpdf' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/lib.php',
        'file' => '/var/www/html/plantilla/mod/assign/feedback/file/lib.php',
      ),
      'bbbext' => 
      array (
      ),
      'booktool' => 
      array (
        'exportimscp' => '/var/www/html/plantilla/mod/book/tool/exportimscp/lib.php',
        'importhtml' => '/var/www/html/plantilla/mod/book/tool/importhtml/lib.php',
        'print' => '/var/www/html/plantilla/mod/book/tool/print/lib.php',
      ),
      'datafield' => 
      array (
      ),
      'datapreset' => 
      array (
      ),
      'forumreport' => 
      array (
      ),
      'ltisource' => 
      array (
      ),
      'ltiservice' => 
      array (
      ),
      'quiz' => 
      array (
        'statistics' => '/var/www/html/plantilla/mod/quiz/report/statistics/lib.php',
      ),
      'quizaccess' => 
      array (
        'seb' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/lib.php',
      ),
      'scormreport' => 
      array (
      ),
      'workshopform' => 
      array (
        'accumulative' => '/var/www/html/plantilla/mod/workshop/form/accumulative/lib.php',
        'comments' => '/var/www/html/plantilla/mod/workshop/form/comments/lib.php',
        'numerrors' => '/var/www/html/plantilla/mod/workshop/form/numerrors/lib.php',
        'rubric' => '/var/www/html/plantilla/mod/workshop/form/rubric/lib.php',
      ),
      'workshopallocation' => 
      array (
        'manual' => '/var/www/html/plantilla/mod/workshop/allocation/manual/lib.php',
        'random' => '/var/www/html/plantilla/mod/workshop/allocation/random/lib.php',
        'scheduled' => '/var/www/html/plantilla/mod/workshop/allocation/scheduled/lib.php',
      ),
      'workshopeval' => 
      array (
        'best' => '/var/www/html/plantilla/mod/workshop/eval/best/lib.php',
      ),
      'tiny' => 
      array (
      ),
      'logstore' => 
      array (
      ),
      'factor' => 
      array (
      ),
    ),
    'settings.php' => 
    array (
      'aiplacement' => 
      array (
      ),
      'aiprovider' => 
      array (
      ),
      'antivirus' => 
      array (
        'clamav' => '/var/www/html/plantilla/lib/antivirus/clamav/settings.php',
      ),
      'availability' => 
      array (
      ),
      'qtype' => 
      array (
        'multichoice' => '/var/www/html/plantilla/question/type/multichoice/settings.php',
        'ordering' => '/var/www/html/plantilla/question/type/ordering/settings.php',
      ),
      'mod' => 
      array (
        'assign' => '/var/www/html/plantilla/mod/assign/settings.php',
        'bigbluebuttonbn' => '/var/www/html/plantilla/mod/bigbluebuttonbn/settings.php',
        'book' => '/var/www/html/plantilla/mod/book/settings.php',
        'data' => '/var/www/html/plantilla/mod/data/settings.php',
        'feedback' => '/var/www/html/plantilla/mod/feedback/settings.php',
        'folder' => '/var/www/html/plantilla/mod/folder/settings.php',
        'forum' => '/var/www/html/plantilla/mod/forum/settings.php',
        'game' => '/var/www/html/plantilla/mod/game/settings.php',
        'glossary' => '/var/www/html/plantilla/mod/glossary/settings.php',
        'h5pactivity' => '/var/www/html/plantilla/mod/h5pactivity/settings.php',
        'hvp' => '/var/www/html/plantilla/mod/hvp/settings.php',
        'imscp' => '/var/www/html/plantilla/mod/imscp/settings.php',
        'label' => '/var/www/html/plantilla/mod/label/settings.php',
        'lesson' => '/var/www/html/plantilla/mod/lesson/settings.php',
        'lti' => '/var/www/html/plantilla/mod/lti/settings.php',
        'page' => '/var/www/html/plantilla/mod/page/settings.php',
        'quiz' => '/var/www/html/plantilla/mod/quiz/settings.php',
        'resource' => '/var/www/html/plantilla/mod/resource/settings.php',
        'scorm' => '/var/www/html/plantilla/mod/scorm/settings.php',
        'subsection' => '/var/www/html/plantilla/mod/subsection/settings.php',
        'url' => '/var/www/html/plantilla/mod/url/settings.php',
        'workshop' => '/var/www/html/plantilla/mod/workshop/settings.php',
      ),
      'auth' => 
      array (
        'db' => '/var/www/html/plantilla/auth/db/settings.php',
        'email' => '/var/www/html/plantilla/auth/email/settings.php',
        'ldap' => '/var/www/html/plantilla/auth/ldap/settings.php',
        'manual' => '/var/www/html/plantilla/auth/manual/settings.php',
        'none' => '/var/www/html/plantilla/auth/none/settings.php',
        'oauth2' => '/var/www/html/plantilla/auth/oauth2/settings.php',
        'shibboleth' => '/var/www/html/plantilla/auth/shibboleth/settings.php',
      ),
      'calendartype' => 
      array (
      ),
      'communication' => 
      array (
        'matrix' => '/var/www/html/plantilla/communication/provider/matrix/settings.php',
      ),
      'customfield' => 
      array (
      ),
      'enrol' => 
      array (
        'category' => '/var/www/html/plantilla/enrol/category/settings.php',
        'cohort' => '/var/www/html/plantilla/enrol/cohort/settings.php',
        'database' => '/var/www/html/plantilla/enrol/database/settings.php',
        'fee' => '/var/www/html/plantilla/enrol/fee/settings.php',
        'flatfile' => '/var/www/html/plantilla/enrol/flatfile/settings.php',
        'guest' => '/var/www/html/plantilla/enrol/guest/settings.php',
        'imsenterprise' => '/var/www/html/plantilla/enrol/imsenterprise/settings.php',
        'ldap' => '/var/www/html/plantilla/enrol/ldap/settings.php',
        'lti' => '/var/www/html/plantilla/enrol/lti/settings.php',
        'manual' => '/var/www/html/plantilla/enrol/manual/settings.php',
        'meta' => '/var/www/html/plantilla/enrol/meta/settings.php',
        'paypal' => '/var/www/html/plantilla/enrol/paypal/settings.php',
        'self' => '/var/www/html/plantilla/enrol/self/settings.php',
      ),
      'message' => 
      array (
        'airnotifier' => '/var/www/html/plantilla/message/output/airnotifier/settings.php',
      ),
      'block' => 
      array (
        'accessreview' => '/var/www/html/plantilla/blocks/accessreview/settings.php',
        'activity_results' => '/var/www/html/plantilla/blocks/activity_results/settings.php',
        'configurable_reports' => '/var/www/html/plantilla/blocks/configurable_reports/settings.php',
        'course_list' => '/var/www/html/plantilla/blocks/course_list/settings.php',
        'html' => '/var/www/html/plantilla/blocks/html/settings.php',
        'myoverview' => '/var/www/html/plantilla/blocks/myoverview/settings.php',
        'online_users' => '/var/www/html/plantilla/blocks/online_users/settings.php',
        'recentlyaccessedcourses' => '/var/www/html/plantilla/blocks/recentlyaccessedcourses/settings.php',
        'rss_client' => '/var/www/html/plantilla/blocks/rss_client/settings.php',
        'section_links' => '/var/www/html/plantilla/blocks/section_links/settings.php',
        'starredcourses' => '/var/www/html/plantilla/blocks/starredcourses/settings.php',
        'tag_youtube' => '/var/www/html/plantilla/blocks/tag_youtube/settings.php',
      ),
      'media' => 
      array (
        'videojs' => '/var/www/html/plantilla/media/player/videojs/settings.php',
        'vimeo' => '/var/www/html/plantilla/media/player/vimeo/settings.php',
        'youtube' => '/var/www/html/plantilla/media/player/youtube/settings.php',
      ),
      'filter' => 
      array (
        'displayh5p' => '/var/www/html/plantilla/filter/displayh5p/settings.php',
        'emoticon' => '/var/www/html/plantilla/filter/emoticon/settings.php',
        'mathjaxloader' => '/var/www/html/plantilla/filter/mathjaxloader/settings.php',
        'mediaplugin' => '/var/www/html/plantilla/filter/mediaplugin/settings.php',
        'multilang' => '/var/www/html/plantilla/filter/multilang/settings.php',
        'tex' => '/var/www/html/plantilla/filter/tex/settings.php',
        'urltolink' => '/var/www/html/plantilla/filter/urltolink/settings.php',
      ),
      'editor' => 
      array (
        'tiny' => '/var/www/html/plantilla/lib/editor/tiny/settings.php',
      ),
      'format' => 
      array (
        'singleactivity' => '/var/www/html/plantilla/course/format/singleactivity/settings.php',
        'tiles' => '/var/www/html/plantilla/course/format/tiles/settings.php',
        'topics' => '/var/www/html/plantilla/course/format/topics/settings.php',
        'weeks' => '/var/www/html/plantilla/course/format/weeks/settings.php',
      ),
      'dataformat' => 
      array (
      ),
      'profilefield' => 
      array (
      ),
      'report' => 
      array (
        'backups' => '/var/www/html/plantilla/report/backups/settings.php',
        'configlog' => '/var/www/html/plantilla/report/configlog/settings.php',
        'courseoverview' => '/var/www/html/plantilla/report/courseoverview/settings.php',
        'customsql' => '/var/www/html/plantilla/report/customsql/settings.php',
        'eventlist' => '/var/www/html/plantilla/report/eventlist/settings.php',
        'infectedfiles' => '/var/www/html/plantilla/report/infectedfiles/settings.php',
        'insights' => '/var/www/html/plantilla/report/insights/settings.php',
        'log' => '/var/www/html/plantilla/report/log/settings.php',
        'loglive' => '/var/www/html/plantilla/report/loglive/settings.php',
        'performance' => '/var/www/html/plantilla/report/performance/settings.php',
        'questioninstances' => '/var/www/html/plantilla/report/questioninstances/settings.php',
        'security' => '/var/www/html/plantilla/report/security/settings.php',
        'stats' => '/var/www/html/plantilla/report/stats/settings.php',
        'status' => '/var/www/html/plantilla/report/status/settings.php',
        'themeusage' => '/var/www/html/plantilla/report/themeusage/settings.php',
      ),
      'coursereport' => 
      array (
      ),
      'gradeexport' => 
      array (
      ),
      'gradeimport' => 
      array (
      ),
      'gradepenalty' => 
      array (
        'duedate' => '/var/www/html/plantilla/grade/penalty/duedate/settings.php',
      ),
      'gradereport' => 
      array (
        'grader' => '/var/www/html/plantilla/grade/report/grader/settings.php',
        'history' => '/var/www/html/plantilla/grade/report/history/settings.php',
        'overview' => '/var/www/html/plantilla/grade/report/overview/settings.php',
        'user' => '/var/www/html/plantilla/grade/report/user/settings.php',
      ),
      'gradingform' => 
      array (
      ),
      'mlbackend' => 
      array (
        'python' => '/var/www/html/plantilla/lib/mlbackend/python/settings.php',
      ),
      'webservice' => 
      array (
      ),
      'repository' => 
      array (
      ),
      'portfolio' => 
      array (
      ),
      'search' => 
      array (
        'solr' => '/var/www/html/plantilla/search/engine/solr/settings.php',
      ),
      'qbank' => 
      array (
        'columnsortorder' => '/var/www/html/plantilla/question/bank/columnsortorder/settings.php',
        'customfields' => '/var/www/html/plantilla/question/bank/customfields/settings.php',
      ),
      'qbehaviour' => 
      array (
      ),
      'qformat' => 
      array (
      ),
      'plagiarism' => 
      array (
      ),
      'tool' => 
      array (
        'admin_presets' => '/var/www/html/plantilla/admin/tool/admin_presets/settings.php',
        'analytics' => '/var/www/html/plantilla/admin/tool/analytics/settings.php',
        'availabilityconditions' => '/var/www/html/plantilla/admin/tool/availabilityconditions/settings.php',
        'behat' => '/var/www/html/plantilla/admin/tool/behat/settings.php',
        'brickfield' => '/var/www/html/plantilla/admin/tool/brickfield/settings.php',
        'capability' => '/var/www/html/plantilla/admin/tool/capability/settings.php',
        'cohortroles' => '/var/www/html/plantilla/admin/tool/cohortroles/settings.php',
        'componentlibrary' => '/var/www/html/plantilla/admin/tool/componentlibrary/settings.php',
        'customlang' => '/var/www/html/plantilla/admin/tool/customlang/settings.php',
        'dataprivacy' => '/var/www/html/plantilla/admin/tool/dataprivacy/settings.php',
        'dbtransfer' => '/var/www/html/plantilla/admin/tool/dbtransfer/settings.php',
        'filetypes' => '/var/www/html/plantilla/admin/tool/filetypes/settings.php',
        'generator' => '/var/www/html/plantilla/admin/tool/generator/settings.php',
        'httpsreplace' => '/var/www/html/plantilla/admin/tool/httpsreplace/settings.php',
        'installaddon' => '/var/www/html/plantilla/admin/tool/installaddon/settings.php',
        'langimport' => '/var/www/html/plantilla/admin/tool/langimport/settings.php',
        'licensemanager' => '/var/www/html/plantilla/admin/tool/licensemanager/settings.php',
        'log' => '/var/www/html/plantilla/admin/tool/log/settings.php',
        'lp' => '/var/www/html/plantilla/admin/tool/lp/settings.php',
        'lpimportcsv' => '/var/www/html/plantilla/admin/tool/lpimportcsv/settings.php',
        'lpmigrate' => '/var/www/html/plantilla/admin/tool/lpmigrate/settings.php',
        'messageinbound' => '/var/www/html/plantilla/admin/tool/messageinbound/settings.php',
        'mfa' => '/var/www/html/plantilla/admin/tool/mfa/settings.php',
        'mobile' => '/var/www/html/plantilla/admin/tool/mobile/settings.php',
        'monitor' => '/var/www/html/plantilla/admin/tool/monitor/settings.php',
        'moodlenet' => '/var/www/html/plantilla/admin/tool/moodlenet/settings.php',
        'multilangupgrade' => '/var/www/html/plantilla/admin/tool/multilangupgrade/settings.php',
        'oauth2' => '/var/www/html/plantilla/admin/tool/oauth2/settings.php',
        'phpunit' => '/var/www/html/plantilla/admin/tool/phpunit/settings.php',
        'policy' => '/var/www/html/plantilla/admin/tool/policy/settings.php',
        'profiling' => '/var/www/html/plantilla/admin/tool/profiling/settings.php',
        'recyclebin' => '/var/www/html/plantilla/admin/tool/recyclebin/settings.php',
        'replace' => '/var/www/html/plantilla/admin/tool/replace/settings.php',
        'spamcleaner' => '/var/www/html/plantilla/admin/tool/spamcleaner/settings.php',
        'task' => '/var/www/html/plantilla/admin/tool/task/settings.php',
        'templatelibrary' => '/var/www/html/plantilla/admin/tool/templatelibrary/settings.php',
        'unsuproles' => '/var/www/html/plantilla/admin/tool/unsuproles/settings.php',
        'uploadcourse' => '/var/www/html/plantilla/admin/tool/uploadcourse/settings.php',
        'uploaduser' => '/var/www/html/plantilla/admin/tool/uploaduser/settings.php',
        'usertours' => '/var/www/html/plantilla/admin/tool/usertours/settings.php',
        'xmldb' => '/var/www/html/plantilla/admin/tool/xmldb/settings.php',
      ),
      'cachestore' => 
      array (
        'apcu' => '/var/www/html/plantilla/cache/stores/apcu/settings.php',
        'redis' => '/var/www/html/plantilla/cache/stores/redis/settings.php',
      ),
      'cachelock' => 
      array (
      ),
      'fileconverter' => 
      array (
        'googledrive' => '/var/www/html/plantilla/files/converter/googledrive/settings.php',
        'unoconv' => '/var/www/html/plantilla/files/converter/unoconv/settings.php',
      ),
      'contenttype' => 
      array (
      ),
      'theme' => 
      array (
        'boost' => '/var/www/html/plantilla/theme/boost/settings.php',
        'classic' => '/var/www/html/plantilla/theme/classic/settings.php',
        'moove' => '/var/www/html/plantilla/theme/moove/settings.php',
      ),
      'local' => 
      array (
      ),
      'h5plib' => 
      array (
      ),
      'paygw' => 
      array (
        'paypal' => '/var/www/html/plantilla/payment/gateway/paypal/settings.php',
      ),
      'smsgateway' => 
      array (
      ),
      'assignsubmission' => 
      array (
        'file' => '/var/www/html/plantilla/mod/assign/submission/file/settings.php',
        'onlinetext' => '/var/www/html/plantilla/mod/assign/submission/onlinetext/settings.php',
      ),
      'assignfeedback' => 
      array (
        'comments' => '/var/www/html/plantilla/mod/assign/feedback/comments/settings.php',
        'editpdf' => '/var/www/html/plantilla/mod/assign/feedback/editpdf/settings.php',
        'file' => '/var/www/html/plantilla/mod/assign/feedback/file/settings.php',
        'offline' => '/var/www/html/plantilla/mod/assign/feedback/offline/settings.php',
      ),
      'bbbext' => 
      array (
      ),
      'booktool' => 
      array (
      ),
      'datafield' => 
      array (
      ),
      'datapreset' => 
      array (
      ),
      'forumreport' => 
      array (
      ),
      'ltisource' => 
      array (
      ),
      'ltiservice' => 
      array (
      ),
      'quiz' => 
      array (
        'statistics' => '/var/www/html/plantilla/mod/quiz/report/statistics/settings.php',
      ),
      'quizaccess' => 
      array (
        'seb' => '/var/www/html/plantilla/mod/quiz/accessrule/seb/settings.php',
      ),
      'scormreport' => 
      array (
      ),
      'workshopform' => 
      array (
        'numerrors' => '/var/www/html/plantilla/mod/workshop/form/numerrors/settings.php',
      ),
      'workshopallocation' => 
      array (
        'random' => '/var/www/html/plantilla/mod/workshop/allocation/random/settings.php',
      ),
      'workshopeval' => 
      array (
        'best' => '/var/www/html/plantilla/mod/workshop/eval/best/settings.php',
      ),
      'tiny' => 
      array (
        'equation' => '/var/www/html/plantilla/lib/editor/tiny/plugins/equation/settings.php',
        'premium' => '/var/www/html/plantilla/lib/editor/tiny/plugins/premium/settings.php',
        'recordrtc' => '/var/www/html/plantilla/lib/editor/tiny/plugins/recordrtc/settings.php',
      ),
      'logstore' => 
      array (
        'database' => '/var/www/html/plantilla/admin/tool/log/store/database/settings.php',
        'standard' => '/var/www/html/plantilla/admin/tool/log/store/standard/settings.php',
      ),
      'factor' => 
      array (
        'admin' => '/var/www/html/plantilla/admin/tool/mfa/factor/admin/settings.php',
        'auth' => '/var/www/html/plantilla/admin/tool/mfa/factor/auth/settings.php',
        'capability' => '/var/www/html/plantilla/admin/tool/mfa/factor/capability/settings.php',
        'cohort' => '/var/www/html/plantilla/admin/tool/mfa/factor/cohort/settings.php',
        'email' => '/var/www/html/plantilla/admin/tool/mfa/factor/email/settings.php',
        'grace' => '/var/www/html/plantilla/admin/tool/mfa/factor/grace/settings.php',
        'iprange' => '/var/www/html/plantilla/admin/tool/mfa/factor/iprange/settings.php',
        'nosetup' => '/var/www/html/plantilla/admin/tool/mfa/factor/nosetup/settings.php',
        'role' => '/var/www/html/plantilla/admin/tool/mfa/factor/role/settings.php',
        'sms' => '/var/www/html/plantilla/admin/tool/mfa/factor/sms/settings.php',
        'token' => '/var/www/html/plantilla/admin/tool/mfa/factor/token/settings.php',
        'totp' => '/var/www/html/plantilla/admin/tool/mfa/factor/totp/settings.php',
        'webauthn' => '/var/www/html/plantilla/admin/tool/mfa/factor/webauthn/settings.php',
      ),
    ),
  ),
  'version' => 2025041401.09,
);
